(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   8366988,     156505]
NotebookOptionsPosition[   8364464,     156429]
NotebookOutlinePosition[   8364884,     156445]
CellTagsIndexPosition[   8364841,     156442]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Simulations", "Title",
 CellChangeTimes->{{3.702024223654941*^9, 
  3.702024241581757*^9}},ExpressionUUID->"9a85d76e-1dd1-4e0a-a748-\
d6a368ce5525"],

Cell[CellGroupData[{

Cell["Code", "Section",
 CellChangeTimes->{{3.702027822445588*^9, 
  3.702027828845439*^9}},ExpressionUUID->"51421247-8c40-437f-a7e5-\
2e0b97293a8e"],

Cell["\<\
Compute the time needed to complete the simulations dynamically\
\>", "Item",
 CellChangeTimes->{{3.6665189519158373`*^9, 3.666518976094171*^9}, {
  3.6665199119996147`*^9, 3.666519912218708*^9}, {3.702027762765994*^9, 
  3.7020277751498137`*^9}},ExpressionUUID->"3fff4d0d-448d-4397-b529-\
6750b5e567af"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"RemainingTime", ",", "HoldAll"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"RemainingTime", "[", 
   RowBox[{
   "content_", ",", "ticker_", ",", "min_", ",", "max_", ",", "period_"}], 
   "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"T0", "=", 
       RowBox[{"AbsoluteTime", "[", "]"}]}], ",", "lstTickerTracker", ",", 
      RowBox[{"tickerTracker", "=", 
       RowBox[{"{", "}"}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"ticker", "=", "min"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Monitor", "[", 
      RowBox[{"content", ",", 
       RowBox[{"Refresh", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"lstTickerTracker", "=", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"tickerTracker", ",", 
             RowBox[{"AbsoluteTime", "[", "]"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Panel", "@", 
           RowBox[{"Grid", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"\"\<Initiated at timestamp:\>\"", ",", 
                 RowBox[{"ToString", "[", 
                  RowBox[{"DateString", "[", "T0", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\"\<Current progress:  \>\"", ",", 
                 RowBox[{"ProgressIndicator", "[", 
                  RowBox[{"ticker", ",", 
                   RowBox[{"{", 
                    RowBox[{"min", ",", "max"}], "}"}]}], "]"}], ",", 
                 "ticker"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\"\<Avg. Exp. process termination: \>\"", ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Length", "[", "lstTickerTracker", "]"}], ">", 
                    "9"}], ",", 
                   RowBox[{"ToString", "[", 
                    RowBox[{"DateString", "[", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"AbsoluteTime", "[", "]"}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"AbsoluteTime", "[", "]"}], "-", "T0"}], ")"}], 
                    "/", "ticker"}], "*", 
                    RowBox[{"(", 
                    RowBox[{"max", "-", "min"}], ")"}]}]}], ")"}], "]"}], 
                    "]"}], ",", "\"\<Initializing...\>\""}], "]"}]}], "}"}], 
               ",", 
               RowBox[{"{", 
                RowBox[{"\"\<Current timestamp: \>\"", ",", 
                 RowBox[{"ToString", "[", 
                  RowBox[{"DateString", "[", 
                   RowBox[{"AbsoluteTime", "[", "]"}], "]"}], "]"}]}], 
                "}"}]}], "}"}], ",", 
             RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}]}]}], ",", 
         RowBox[{"UpdateInterval", "\[Rule]", "period"}], ",", 
         RowBox[{"TrackedSymbols", "\[Rule]", 
          RowBox[{"{", "}"}]}]}], "]"}]}], "]"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6969426628034773`*^9, 3.6969426695281982`*^9}, {
  3.6973678692934465`*^9, 3.6973679222334747`*^9}, {3.69736850452678*^9, 
  3.6973685092930527`*^9}, {3.702031094982318*^9, 3.702031095428537*^9}},
 ExpressionUUID -> "ac2715b1-057a-4c32-a5fb-cae2fef9c54f"],

Cell[TextData[{
 "Phenotype to relative fitness ",
 StyleBox["cm",
  FontSlant->"Italic"]
}], "Item",
 CellChangeTimes->{{3.6665189519158373`*^9, 3.666518976094171*^9}, {
  3.6665199119996147`*^9, 
  3.666519912218708*^9}},ExpressionUUID->"e9228500-fbfe-466d-b9cc-\
d821bf70fd80"],

Cell["\<\
- takes :
\t#xpop : list (2 lvls) of reals,  represents the coordinates of all the \
individuals of the population in the phenotype space
\t#mmax : real, represents the maximal malthusian fitness reachable in the \
environment
- gives: list of reals, represents the malthusian fitness of all the \
individuals computed under the Fisher Geometric Model\
\>", "Text",
 CellChangeTimes->{{3.6665189874367123`*^9, 3.6665190330017014`*^9}, {
  3.666519075658949*^9, 3.666519114606447*^9}, {3.6665196074828444`*^9, 
  3.666519841388315*^9}, {3.666519901227026*^9, 3.666519915978904*^9}, {
  3.666520344859754*^9, 3.6665203487155123`*^9}, {3.66652041215969*^9, 
  3.666520454379718*^9}, {3.70202450426328*^9, 3.702024583670601*^9}, {
  3.702024653478055*^9, 
  3.702024679573826*^9}},ExpressionUUID->"8e3ea1ed-0976-46f5-b964-\
e9ebce230170"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cm", "=", 
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xpop", ",", "_Real", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"mmax", ",", "_Real"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Function", "[", 
        RowBox[{"z", ",", 
         RowBox[{"mmax", "-", 
          FractionBox[
           SuperscriptBox[
            RowBox[{"Norm", "[", "z", "]"}], "2"], "2"]}]}], "]"}], "/@", 
       "xpop"}], 
      RowBox[{"(*", 
       RowBox[{
       "Compute", " ", "malthusian", " ", "fitness", " ", "under", " ", "the",
         " ", "FGM"}], "*)"}], "\[IndentingNewLine]", ",", 
      RowBox[{"RuntimeAttributes", "\[Rule]", 
       RowBox[{"{", "Listable", "}"}]}]}], "]"}]}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.6119768425764227`*^9, 3.611976889316488*^9}, {
  3.658597861800867*^9, 3.658597862764922*^9}, {3.6585978967398653`*^9, 
  3.6585979166690054`*^9}, {3.7020243831604977`*^9, 3.702024384728511*^9}, {
  3.702024692870083*^9, 3.7020247141822147`*^9}},
 ExpressionUUID -> "d960bf92-7a08-4177-8222-a524fa72a548"],

Cell["\<\
Evolutionary + Demographic Simulation of a population under selection, \
mutation & drift\
\>", "Item",
 CellChangeTimes->{{3.6665189519158373`*^9, 3.666518976094171*^9}, {
  3.6665199119996147`*^9, 3.666519912218708*^9}, {3.666519944908289*^9, 
  3.666519983676652*^9}, {3.666520250251336*^9, 3.666520279456147*^9}, {
  3.667731515656975*^9, 
  3.667731621692161*^9}},ExpressionUUID->"0d5357dc-0688-49c4-b5fd-\
ff10b35705c2"],

Cell[TextData[{
 "- takes :\n\t#xo : list (2 lvls) of reals, represents the coordinates of \
all the individuals of the population in the phenotype space at ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]],ExpressionUUID->
  "f37b2327-aee9-44bb-8b21-f1a44f6f1aa2"],
 "\n\t#U : real, mutation rate for one time step\n\t#rmax : real, maximal \
fitness (at the optimal phenotype) of the landscape\n\t#alleles : list (2 \
lvls) of reals, represents effects of mutations on the phenotype.\n\t#tmax: \
integer, maximal number of time step for the simulation\n\t#w : boolean, if \
True -> record the fitness until tmax even if the population is rescued\n- \
gives : \n\t#wm : list (1 lvl) of reals, dynamic of the mean Wright fitness \
of the population recorded at every time steps\n\t#Ns :  list (1 lvl) of \
integer, dynamic of the population size recorded at every time steps\n\t# \
list : (status of the population, boolean, rescued -> 0, extinct -> 1) & \
(text : time of extinction)\n\t#vwm: list (1 lvl) of reals, dynamic of the \
variance Wright fitness of the population recorded at every time steps"
}], "Text",
 CellChangeTimes->{{3.666520303277051*^9, 3.6665204086359463`*^9}, {
  3.666520488799423*^9, 3.666520693931891*^9}, {3.666520799772007*^9, 
  3.6665207999801807`*^9}, {3.666520908796261*^9, 3.666520964700212*^9}, {
  3.666521446445166*^9, 3.6665215235496283`*^9}, {3.6665241041923857`*^9, 
  3.666524108080143*^9}, {3.6677316423136597`*^9, 3.667732073657516*^9}, {
  3.667732115322793*^9, 3.667732133337792*^9}, {3.667733865806807*^9, 
  3.667733968109054*^9}, {3.702024744837834*^9, 3.702025089650776*^9}, {
  3.702025261249907*^9, 
  3.702025306913494*^9}},ExpressionUUID->"16c59a17-31ca-4c5f-b36d-\
4fcf6b04dba3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"simulation", "=."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"simulation", "=", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"xo", ",", "_Real", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"U", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"rmax", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"alleles", ",", "_Real", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"tmax", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"w", ",", " ", 
         RowBox[{"True", "|", "False"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Block", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xpop", "=", "xo"}], ",", 
         RowBox[{"(*", 
          RowBox[{
          "Initialization", " ", "of", " ", "the", " ", "list", " ", "of", 
           " ", "phenotypes"}], "*)"}], "\[IndentingNewLine]", 
         RowBox[{"wm", "=", 
          RowBox[{"{", 
           RowBox[{"Mean", "[", 
            RowBox[{"Exp", "[", 
             RowBox[{"cm", "[", 
              RowBox[{"xo", ",", "rmax"}], "]"}], "]"}], "]"}], "}"}]}], ",", 
         
         RowBox[{"(*", 
          RowBox[{
          "Initialization", " ", "of", " ", "the", " ", "dynamic", " ", "of", 
           " ", "the", " ", "mean", " ", "fitness"}], "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"Nt", "=", 
          RowBox[{"Length", "[", "xo", "]"}]}], ",", 
         RowBox[{"(*", 
          RowBox[{
          "Initialization", " ", "of", " ", "the", " ", "population", " ", 
           "size"}], "*)"}], "\[IndentingNewLine]", 
         RowBox[{"Ns", "=", 
          RowBox[{"{", 
           RowBox[{"Length", "[", "xo", "]"}], "}"}]}], ",", 
         RowBox[{"(*", 
          RowBox[{
          "Initialization", " ", "of", " ", "the", " ", "dynamic", " ", "of", 
           " ", "the", " ", "population", " ", "size"}], "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"vwm", "=", 
          RowBox[{"{", 
           RowBox[{"Variance", "[", 
            RowBox[{"Exp", "[", 
             RowBox[{"cm", "[", 
              RowBox[{"xo", ",", "rmax"}], "]"}], "]"}], "]"}], "}"}]}], ",", 
         
         RowBox[{"(*", 
          RowBox[{
          "Initialization", " ", "of", " ", "the", " ", "dynamic", " ", "of", 
           " ", "the", " ", "variance", " ", "in", " ", "fitness"}], "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"t", "=", "0"}], ",", 
         RowBox[{"(*", 
          RowBox[{"Initialization", " ", "of", " ", "time"}], "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"text", "=", "0"}]}], "}"}], ",", 
       RowBox[{"(*", 
        RowBox[{
        "variable", " ", "to", " ", "record", " ", "the", " ", "time", " ", 
         "of", " ", "extinction"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"While", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"t", "<", "tmax"}], ")"}], "&&", 
           RowBox[{"(", 
            RowBox[{"0", "<", "Nt", "\[LessEqual]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Mean", "[", 
                 RowBox[{"Exp", "[", 
                  RowBox[{"cm", "[", 
                   RowBox[{"xpop", ",", "rmax"}], "]"}], "]"}], "]"}], ">", 
                "1"}], ",", 
               FractionBox[
                RowBox[{"6", "*", 
                 RowBox[{"Log", "[", "10", "]"}]}], 
                RowBox[{"Log", "[", 
                 RowBox[{"Mean", "[", 
                  RowBox[{"Exp", "[", 
                   RowBox[{"cm", "[", 
                    RowBox[{"xpop", ",", "rmax"}], "]"}], "]"}], "]"}], 
                 "]"}]], ",", 
               RowBox[{"2", 
                RowBox[{"Length", "[", "xo", "]"}]}]}], "]"}]}], ")"}]}], ",", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{
            "Loop", " ", "on", " ", "time", " ", "which", " ", "end", " ", 
             "when", " ", 
             RowBox[{"(", 
              RowBox[{"t", ">", "tmax"}], ")"}]}], " ", "|", " ", 
            RowBox[{"Nt", "<", "1"}], " ", "|", " ", 
            RowBox[{
             RowBox[{
              SubscriptBox["P", "ext"], "~"}], "<", 
             SuperscriptBox["10", 
              RowBox[{"-", "6"}]]}], " ", "|", " ", 
            RowBox[{"Nt", ">", " ", 
             RowBox[{"2", 
              SubscriptBox["N", "t0"]}]}]}], "*)"}], "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"t", "++"}], ";", "\[IndentingNewLine]", 
           RowBox[{"xpop", "=", 
            RowBox[{"RandomChoice", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Exp", "[", 
                RowBox[{"cm", "[", 
                 RowBox[{"xpop", ",", "rmax"}], "]"}], "]"}], "\[Rule]", 
               "xpop"}], ",", "Nt"}], "]"}]}], ";", 
           RowBox[{"(*", 
            RowBox[{
             RowBox[{"selection", " ", "+", " ", 
              RowBox[{"drift", " ", "with", " ", 
               RowBox[{"N", "[", 
                RowBox[{"t", "+", "1"}], "]"}]}]}], " ", "=", " ", 
             RowBox[{"E", 
              RowBox[{"(", "W", ")"}], " ", 
              RowBox[{"N", "[", "t", "]"}]}]}], "*)"}], "\[IndentingNewLine]", 
           RowBox[{"xpop", "=", 
            RowBox[{"xpop", "+", 
             RowBox[{
              RowBox[{"Function", "[", 
               RowBox[{
                RowBox[{"{", "k", "}"}], ",", 
                RowBox[{"Total", "[", 
                 RowBox[{"RandomChoice", "[", 
                  RowBox[{"alleles", ",", "k"}], "]"}], "]"}]}], "]"}], "/@", 
              
              RowBox[{"RandomVariate", "[", 
               RowBox[{
                RowBox[{"PoissonDistribution", "[", "U", "]"}], ",", "Nt"}], 
               "]"}]}]}]}], ";", 
           RowBox[{"(*", "mutation", "*)"}], "\[IndentingNewLine]", 
           RowBox[{"Nt", "=", 
            RowBox[{"IntegerPart", "[", 
             RowBox[{"RandomVariate", "[", 
              RowBox[{"PoissonDistribution", "[", 
               RowBox[{"Nt", " ", 
                RowBox[{"Mean", "[", 
                 RowBox[{"Exp", "[", 
                  RowBox[{"cm", "[", 
                   RowBox[{"xpop", ",", "rmax"}], "]"}], "]"}], "]"}]}], 
               "]"}], "]"}], "]"}]}], ";", 
           RowBox[{"(*", 
            RowBox[{"Stochastic", " ", "demography"}], "*)"}], 
           "\[IndentingNewLine]", 
           RowBox[{"wm", "=", 
            RowBox[{"AppendTo", "[", 
             RowBox[{"wm", ",", 
              RowBox[{"Mean", "[", 
               RowBox[{"Exp", "[", 
                RowBox[{"cm", "[", 
                 RowBox[{"xpop", ",", "rmax"}], "]"}], "]"}], "]"}]}], 
             "]"}]}], ";", 
           RowBox[{"Ns", "=", 
            RowBox[{"AppendTo", "[", 
             RowBox[{"Ns", ",", "Nt"}], "]"}]}], ";", 
           RowBox[{"(*", 
            RowBox[{"record", " ", "dynamics"}], "*)"}], 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Length", "[", 
               RowBox[{"cm", "[", 
                RowBox[{"xpop", ",", "rmax"}], "]"}], "]"}], ">", "1"}], ",", 
             
             RowBox[{"vwm", "=", 
              RowBox[{"AppendTo", "[", 
               RowBox[{"vwm", ",", 
                RowBox[{"Variance", "[", 
                 RowBox[{"Exp", "[", 
                  RowBox[{"cm", "[", 
                   RowBox[{"xpop", ",", "rmax"}], "]"}], "]"}], "]"}]}], 
               "]"}]}], ",", 
             RowBox[{"vwm", "=", 
              RowBox[{"AppendTo", "[", 
               RowBox[{"vwm", ",", "0"}], "]"}]}]}], "]"}], ";", 
           RowBox[{"(*", 
            RowBox[{"record", " ", "dynamics"}], "*)"}], 
           "\[IndentingNewLine]", 
           RowBox[{"text", "=", "t"}]}]}], " ", 
         RowBox[{"(*", 
          RowBox[{"record", " ", "time", " ", "for", " ", "extinction"}], 
          "*)"}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", "w", ")"}], "&&", 
           RowBox[{"(", 
            RowBox[{"t", "<", "tmax"}], ")"}], "&&", 
           RowBox[{"(", 
            RowBox[{"0", "<", "Nt"}], ")"}]}], ",", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{
            "Continue", " ", "only", " ", "the", " ", "evolutionary", " ", 
             "dynamic", " ", "after", " ", "the", " ", "rescue", " ", "if", 
             " ", "W"}], " ", "=", " ", "True"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "<", "tmax"}], ")"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"xpop", "=", 
              RowBox[{"RandomChoice", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"Exp", "[", 
                  RowBox[{"cm", "[", 
                   RowBox[{"xpop", ",", "rmax"}], "]"}], "]"}], "\[Rule]", 
                 "xpop"}], ",", "Nt"}], "]"}]}], ";", 
             RowBox[{"(*", 
              RowBox[{
               RowBox[{"selection", " ", "+", " ", 
                RowBox[{"drift", " ", "with", " ", 
                 RowBox[{"N", "[", 
                  RowBox[{"t", "+", "1"}], "]"}]}]}], " ", "=", " ", 
               RowBox[{"E", 
                RowBox[{"(", "W", ")"}], " ", 
                RowBox[{"N", "[", "t", "]"}]}]}], "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{"xpop", "=", 
              RowBox[{"xpop", "+", 
               RowBox[{
                RowBox[{"Function", "[", 
                 RowBox[{
                  RowBox[{"{", "k", "}"}], ",", 
                  RowBox[{"Total", "[", 
                   RowBox[{"RandomChoice", "[", 
                    RowBox[{"alleles", ",", "k"}], "]"}], "]"}]}], "]"}], "/@", 
                RowBox[{"RandomVariate", "[", 
                 RowBox[{
                  RowBox[{"PoissonDistribution", "[", "U", "]"}], ",", "Nt"}],
                  "]"}]}]}]}], ";", 
             RowBox[{"(*", "mutation", "*)"}], "\[IndentingNewLine]", 
             RowBox[{"wm", "=", 
              RowBox[{"AppendTo", "[", 
               RowBox[{"wm", ",", 
                RowBox[{"Mean", "[", 
                 RowBox[{"Exp", "[", 
                  RowBox[{"cm", "[", 
                   RowBox[{"xpop", ",", "rmax"}], "]"}], "]"}], "]"}]}], 
               "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Length", "[", 
                 RowBox[{"cm", "[", 
                  RowBox[{"xpop", ",", "rmax"}], "]"}], "]"}], ">", "1"}], 
               ",", 
               RowBox[{"vwm", "=", 
                RowBox[{"AppendTo", "[", 
                 RowBox[{"vwm", ",", 
                  RowBox[{"Variance", "[", 
                   RowBox[{"Exp", "[", 
                    RowBox[{"cm", "[", 
                    RowBox[{"xpop", ",", "rmax"}], "]"}], "]"}], "]"}]}], 
                 "]"}]}], ",", 
               RowBox[{"vwm", "=", 
                RowBox[{"AppendTo", "[", 
                 RowBox[{"vwm", ",", "0"}], "]"}]}]}], "]"}], ";", 
             RowBox[{"t", "++"}]}]}], "\[IndentingNewLine]", "]"}]}], "]"}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"wm", ",", "Ns", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"Nt", ">", "0"}], ",", "0", ",", "1"}], "]"}], ",", 
            "text"}], "}"}], ",", "vwm"}], "}"}]}]}], 
      RowBox[{"(*", "Outputs", "*)"}], "\[IndentingNewLine]", "]"}], ",", 
     RowBox[{"RuntimeAttributes", "\[Rule]", 
      RowBox[{"{", "Listable", "}"}]}], ",", 
     RowBox[{"Parallelization", "\[Rule]", "True"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.6967511459935207`*^9, 3.6967514722993813`*^9}, {
   3.696751543194429*^9, 3.696751733284116*^9}, {3.696752011603695*^9, 
   3.6967520791613398`*^9}, {3.6967521219711*^9, 3.696752124252122*^9}, {
   3.6967522257101927`*^9, 3.696752229357605*^9}, {3.696752265535914*^9, 
   3.696752265694126*^9}, {3.696752308879242*^9, 3.696752309423244*^9}, {
   3.696752372078886*^9, 3.696752406478608*^9}, {3.696757970096745*^9, 
   3.696757995441702*^9}, {3.696769474276814*^9, 3.696769623587722*^9}, {
   3.696769698636673*^9, 3.696769756655184*^9}, 3.69677045476309*^9, {
   3.696832664418141*^9, 3.696832683951906*^9}, {3.6969121608272657`*^9, 
   3.696912164734351*^9}, 3.696934384179381*^9, {3.69693446596811*^9, 
   3.696934475004323*^9}, {3.6969374229174147`*^9, 3.696937433151664*^9}, {
   3.697173343325631*^9, 3.697173349075859*^9}, 3.697173541161797*^9, {
   3.697173576642095*^9, 3.69717360144413*^9}, {3.697347628636127*^9, 
   3.697347628745373*^9}, {3.697347770616013*^9, 3.697347864506792*^9}, {
   3.697347894664422*^9, 3.697347922283814*^9}, {3.697348069569489*^9, 
   3.697348072365035*^9}, 3.697348582341084*^9, 3.6973511327531023`*^9, 
   3.697352820232897*^9, {3.697366573281319*^9, 3.6973665968936696`*^9}, {
   3.697453881932283*^9, 3.697453886206984*^9}, 3.6974540765109453`*^9, {
   3.697463097398931*^9, 3.697463193917128*^9}, {3.6974632548840103`*^9, 
   3.697463260247558*^9}, {3.6974633941400843`*^9, 3.697463400928087*^9}, {
   3.697782497801066*^9, 3.697782536792809*^9}, {3.697782588362875*^9, 
   3.6977825928911037`*^9}, {3.697789378334325*^9, 3.697789400818453*^9}, {
   3.697790089662166*^9, 3.697790094168635*^9}, {3.6977901600651712`*^9, 
   3.6977901642411947`*^9}, {3.697892251726357*^9, 3.697892294048481*^9}, {
   3.697894080754133*^9, 3.697894080815612*^9}, {3.700289590267305*^9, 
   3.7002895981085577`*^9}, 3.702024295722651*^9, {3.7020243345501957`*^9, 
   3.7020243606200027`*^9}, {3.7020251010446367`*^9, 
   3.7020252492901373`*^9}, {3.7020253184506474`*^9, 3.702025359106141*^9}, {
   3.702025403075654*^9, 3.702025464211294*^9}, {3.7020268209341297`*^9, 
   3.702027105475377*^9}, {3.702027742768051*^9, 3.7020277428959103`*^9}},
 ExpressionUUID -> "d28a684d-982e-406e-b360-fe0959ea6e6d"],

Cell["Parallelization of the simulations over replicates", "Item",
 CellChangeTimes->{{3.6665189519158373`*^9, 3.666518976094171*^9}, {
  3.6665199119996147`*^9, 3.666519912218708*^9}, {3.666519944908289*^9, 
  3.666519983676652*^9}, {3.666520250251336*^9, 3.666520279456147*^9}, {
  3.667731515656975*^9, 3.667731621692161*^9}, {3.702027400064723*^9, 
  3.702027412032731*^9}},ExpressionUUID->"f32ff9f6-6822-425e-a096-\
1f29be7d544f"],

Cell[TextData[{
 "- takes :\n\t#xo : list (2 lvls) of reals, represents the coordinates of \
all the individuals of the population in the phenotype space at ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]],
  ExpressionUUID -> "60878bf7-5c2a-471d-9514-66c12a903735"],
 "\n\t#U : real, mutation rate for one time step\n\t#rmax : real, maximal \
fitness (at the optimal phenotype) of the landscape\n\t#alleles : list (2 \
lvls) of reals, represents effects of mutations on the phenotype.\n\t#tmax: \
integer, maximal number of time step for the simulation\n\t#nrep : integer, \
number of replicats\n\t#w : boolean, if True -> record the fitness until tmax \
even if the population is rescued\n- gives : \n\t#wm : list (2 lvls) of \
reals, dynamics of the mean Wright fitness of the population recorded at \
every time steps\n\t#Ns :  list (2 lvls) of integer, dynamics of the \
population size recorded at every time steps\n\t# list (2 lvls): (status of \
the populations, boolean, rescued -> 0, extinct -> 1) & (text : time of \
extinction)\n\t#vwm: list (2 lvls) of reals, dynamics of the variance Wright \
fitness of the population recorded at every time steps"
}], "Text",
 CellChangeTimes->{{3.666520303277051*^9, 3.6665204086359463`*^9}, {
  3.666520488799423*^9, 3.666520693931891*^9}, {3.666520799772007*^9, 
  3.6665207999801807`*^9}, {3.666520908796261*^9, 3.666520964700212*^9}, {
  3.666521446445166*^9, 3.6665215235496283`*^9}, {3.6665241041923857`*^9, 
  3.666524108080143*^9}, {3.6677316423136597`*^9, 3.667732073657516*^9}, {
  3.667732115322793*^9, 3.667732133337792*^9}, {3.667733865806807*^9, 
  3.667733968109054*^9}, {3.702024744837834*^9, 3.702025089650776*^9}, {
  3.702025261249907*^9, 3.702025306913494*^9}, {3.702027416849229*^9, 
  3.702027490608779*^9}},
 ExpressionUUID -> "95b101c2-82ec-469c-b30b-159823acc2c4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"FGM", "=."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FGM", "=", "\[IndentingNewLine]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "xo", ",", "U", ",", "rmax", ",", "alleles", ",", "tmax", ",", "nrep", 
       ",", "w"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Block", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"parallelSow", ",", 
         RowBox[{"(*", 
          RowBox[{"Parralele", " ", "function", " ", "name"}], "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"rep", "=", "0"}], ",", 
         RowBox[{"(*", 
          RowBox[{
          "Initialization", " ", "of", " ", "the", " ", "number", " ", "of", 
           " ", "replicates"}], "*)"}], "\[IndentingNewLine]", 
         RowBox[{"outs", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", "}"}], ",", 
            RowBox[{"{", "nrep", "}"}]}], "]"}]}]}], "}"}], ",", 
       RowBox[{"(*", 
        RowBox[{
        "Temporary", " ", "variable", " ", "for", " ", "the", " ", "ouputs", 
         " ", "of", " ", "the", " ", "simulations"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"SetSharedFunction", "[", "parallelSow", "]"}], ";", 
        RowBox[{"(*", 
         RowBox[{
         "Parallelization", " ", "of", " ", "the", " ", "function", " ", 
          "sow"}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"SetSharedVariable", "[", "rep", "]"}], ";", 
        RowBox[{"(*", 
         RowBox[{"Parallelization", " ", "of", " ", "the", " ", "variable"}], 
         "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"parallelSow", "[", 
          RowBox[{"expr_", ",", "tag_"}], "]"}], ":=", 
         RowBox[{"Sow", "[", 
          RowBox[{"expr", ",", "tag"}], "]"}]}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{
         "Parallelization", " ", "of", " ", "the", " ", "replicates", " ", 
          "and", " ", "extraction", " ", "of", " ", "the", " ", "variables", 
          " ", "of", " ", "interest", " ", "from", " ", "the", " ", 
          "simulations"}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"RemainingTime", "[", 
         RowBox[{
          RowBox[{"Block", "[", 
           RowBox[{
            RowBox[{"{", "out", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"outs", "=", 
             RowBox[{"Reap", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"Parallelize", "[", 
                RowBox[{"Do", "[", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"out", "=", 
                    RowBox[{
                    RowBox[{"simulation", "[", 
                    RowBox[{
                    "xo", ",", "U", ",", "rmax", ",", "alleles", ",", "tmax", 
                    ",", "w"}], "]"}], "//", "Quiet"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{"parallelSow", "[", 
                    RowBox[{
                    RowBox[{"out", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", "\"\<W\>\""}], "]"}],
                    ";", "\[IndentingNewLine]", 
                   RowBox[{"parallelSow", "[", 
                    RowBox[{
                    RowBox[{"out", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "\"\<N\>\""}], "]"}],
                    ";", "\[IndentingNewLine]", 
                   RowBox[{"parallelSow", "[", 
                    RowBox[{
                    RowBox[{"out", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], ",", "\"\<Pr\>\""}], 
                    "]"}], ";", "\[IndentingNewLine]", 
                   RowBox[{"parallelSow", "[", 
                    RowBox[{
                    RowBox[{"out", "[", 
                    RowBox[{"[", "4", "]"}], "]"}], ",", "\"\<vW\>\""}], 
                    "]"}], ";", 
                   RowBox[{"rep", "++"}], ";"}], "\[IndentingNewLine]", ",", 
                  RowBox[{"{", "nrep", "}"}]}], "]"}], "]"}], 
               "\[IndentingNewLine]", ",", 
               RowBox[{"{", 
                RowBox[{
                "\"\<W\>\"", ",", "\"\<N\>\"", ",", "\"\<Pr\>\"", ",", 
                 "\"\<vW\>\""}], "}"}]}], "]"}]}]}], "\[IndentingNewLine]", 
           "]"}], ",", "rep", ",", "1", ",", "nrep", ",", "0.1"}], "]"}], ";",
         "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"outs", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "1", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"outs", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "2", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"outs", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "3", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"outs", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "4", ",", "1"}], "]"}], "]"}]}], "}"}]}]}], 
      RowBox[{"(*", 
       RowBox[{
       "Ouputs", " ", "of", " ", "the", " ", "dynamics", " ", "of", " ", 
        "all", " ", "the", " ", "replicats", " ", 
        RowBox[{"(", 
         RowBox[{"Wt", ",", " ", "Nt", ",", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Prescue", " ", "&"}], " ", "text"}], ")"}], ",", " ", 
          RowBox[{"V", 
           RowBox[{"(", "Wt", ")"}]}]}]}]}], "*)"}], "\[IndentingNewLine]", 
      "]"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.70202710764355*^9, 3.702027207187374*^9}, {
  3.702027241666492*^9, 3.7020273828337317`*^9}, {3.7020277348795977`*^9, 
  3.70202773790291*^9}},
 ExpressionUUID -> "8365eb37-a49d-405d-bd25-d1aaa21d6e6d"],

Cell["\<\
Evolutionary simulation of a population (with constant population size) under \
selection, mutation & drift\
\>", "Item",
 CellChangeTimes->{{3.6665189519158373`*^9, 3.666518976094171*^9}, {
  3.6665199119996147`*^9, 3.666519912218708*^9}, {3.666519944908289*^9, 
  3.666519983676652*^9}, {3.666520250251336*^9, 3.666520279456147*^9}, {
  3.667731515656975*^9, 3.667731621692161*^9}, {3.702027562287397*^9, 
  3.702027578287326*^9}},ExpressionUUID->"db447963-2ec1-421f-a4f5-\
fab50056b3af"],

Cell["\<\
Same functions as previously but with a constant population size\
\>", "Text",
 CellChangeTimes->{{3.702027499885325*^9, 3.702027524480015*^9}, 
   3.702027592299296*^9},ExpressionUUID->"9a1c43ae-0735-4a26-9d11-\
4565c1c410a7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"simulationNCst", "=."}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"simulationNCst", "=", "\[IndentingNewLine]", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"xo", ",", "_Real", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"U", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"rmax", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"alleles", ",", "_Real", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"tmax", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Ntot", ",", "_Integer"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xpop", "=", "xo"}], ",", 
         RowBox[{"wm", "=", 
          RowBox[{"Table", "[", 
           RowBox[{"0.", ",", 
            RowBox[{"{", 
             RowBox[{"tmax", "+", "1"}], "}"}]}], "]"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"wm", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "=", 
         RowBox[{"Mean", "[", 
          RowBox[{"Exp", "[", 
           RowBox[{"cm", "[", 
            RowBox[{"xpop", ",", "rmax"}], "]"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Do", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"xpop", "=", 
            RowBox[{"RandomChoice", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Exp", "[", 
                RowBox[{"cm", "[", 
                 RowBox[{"xpop", ",", "rmax"}], "]"}], "]"}], "\[Rule]", 
               "xpop"}], ",", "Ntot"}], "]"}]}], ";", 
           RowBox[{"(*", 
            RowBox[{
             RowBox[{"selection", " ", "+", " ", 
              RowBox[{"drift", " ", "with", " ", 
               RowBox[{"N", "[", 
                RowBox[{"t", "+", "1"}], "]"}]}]}], " ", "=", " ", 
             RowBox[{"E", 
              RowBox[{"(", "W", ")"}], " ", 
              RowBox[{"N", "[", "t", "]"}]}]}], "*)"}], "\[IndentingNewLine]", 
           RowBox[{"xpop", "=", 
            RowBox[{"xpop", "+", 
             RowBox[{
              RowBox[{"Function", "[", 
               RowBox[{
                RowBox[{"{", "k", "}"}], ",", 
                RowBox[{"Total", "[", 
                 RowBox[{"RandomChoice", "[", 
                  RowBox[{"alleles", ",", "k"}], "]"}], "]"}]}], "]"}], "/@", 
              
              RowBox[{"RandomVariate", "[", 
               RowBox[{
                RowBox[{"PoissonDistribution", "[", "U", "]"}], ",", "Ntot"}],
                "]"}]}]}]}], ";", 
           RowBox[{"(*", "mutation", "*)"}], "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"wm", "[", 
             RowBox[{"[", 
              RowBox[{"t", "+", "1"}], "]"}], "]"}], "=", 
            RowBox[{"Mean", "[", 
             RowBox[{"Exp", "[", 
              RowBox[{"cm", "[", 
               RowBox[{"xpop", ",", "rmax"}], "]"}], "]"}], "]"}]}], ";"}], 
          "\[IndentingNewLine]", ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "1", ",", "tmax"}], "}"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"wm", ",", "xpop"}], "}"}]}]}], "\[IndentingNewLine]", "]"}],
      ",", 
     RowBox[{"RuntimeAttributes", "\[Rule]", 
      RowBox[{"{", "Listable", "}"}]}], ",", 
     RowBox[{"Parallelization", "\[Rule]", "True"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 ExpressionUUID -> "a7c55fdc-1cd8-45dc-9dc5-dafe0364bfcd"],

Cell["Parallelization of the simulations over replicates", "Item",
 CellChangeTimes->{{3.6665189519158373`*^9, 3.666518976094171*^9}, {
  3.6665199119996147`*^9, 3.666519912218708*^9}, {3.666519944908289*^9, 
  3.666519983676652*^9}, {3.666520250251336*^9, 3.666520279456147*^9}, {
  3.667731515656975*^9, 3.667731621692161*^9}, {3.702027400064723*^9, 
  3.702027412032731*^9}},ExpressionUUID->"d366a16d-8e07-4b25-a4e4-\
17613d6fbb12"],

Cell["\<\
Same functions as previously but :
- with a constant population size
- give the dynamic only for the fitness (2 lvls) and give the final \
population list (2 lvls) of all the phenotypes at mutation selection balance \
\
\>", "Text",
 CellChangeTimes->{{3.702027499885325*^9, 3.702027524480015*^9}, 
   3.702027592299296*^9, {3.702027625310892*^9, 
   3.70202772403028*^9}},ExpressionUUID->"e3534ebc-1783-492f-a2c7-\
5f3028ce1d9e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"FGMNCst", "=."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FGMNCst", "=", "\[IndentingNewLine]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "xo", ",", "U", ",", "rmax", ",", "alleles", ",", "tmax", ",", "nrep"}],
       "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"With", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Ntot", "=", 
         RowBox[{"Length", "[", "xo", "]"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Block", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"parallelSow", ",", 
           RowBox[{"rep", "=", "0"}], ",", 
           RowBox[{"outs", "=", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", "}"}], ",", 
              RowBox[{"{", "nrep", "}"}]}], "]"}]}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"nrep", ">", "1"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"SetSharedFunction", "[", "parallelSow", "]"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"SetSharedVariable", "[", "rep", "]"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"parallelSow", "[", 
               RowBox[{"expr_", ",", "tag_"}], "]"}], ":=", 
              RowBox[{"Sow", "[", 
               RowBox[{"expr", ",", "tag"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"RemainingTime", "[", 
              RowBox[{
               RowBox[{"Block", "[", 
                RowBox[{
                 RowBox[{"{", "out", "}"}], ",", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"outs", "=", 
                   RowBox[{"Reap", "[", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Parallelize", "[", 
                    RowBox[{"Do", "[", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"out", "=", 
                    RowBox[{
                    RowBox[{"simulationNCst", "[", 
                    RowBox[{
                    "xo", ",", "U", ",", "rmax", ",", "alleles", ",", "tmax", 
                    ",", "Ntot"}], "]"}], "//", "Quiet"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"parallelSow", "[", 
                    RowBox[{
                    RowBox[{"out", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", "\"\<W\>\""}], "]"}],
                     ";", "\[IndentingNewLine]", 
                    RowBox[{"parallelSow", "[", 
                    RowBox[{
                    RowBox[{"out", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "\"\<xpop\>\""}], 
                    "]"}], ";", 
                    RowBox[{"rep", "++"}], ";"}], "\[IndentingNewLine]", ",", 
                    
                    RowBox[{"{", "nrep", "}"}]}], "]"}], "]"}], 
                    "\[IndentingNewLine]", ",", 
                    RowBox[{"{", 
                    RowBox[{"\"\<W\>\"", ",", "\"\<xpop\>\""}], "}"}]}], 
                    "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ",", 
               "rep", ",", "1", ",", "nrep", ",", "0.1"}], "]"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Block", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"out", ",", "t"}], "}"}], ",", "\[IndentingNewLine]", 
              RowBox[{"outs", "=", 
               RowBox[{"Reap", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                  RowBox[{"out", "=", 
                   RowBox[{"RemainingTime", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"simulationNCst", "[", 
                    RowBox[{
                    "xo", ",", "U", ",", "rmax", ",", "alleles", ",", "tmax", 
                    ",", "Ntot"}], "]"}], "//", "Quiet"}], ",", "t", ",", "0",
                     ",", "tmax", ",", "0.1"}], "]"}]}], ";", 
                  "\[IndentingNewLine]", 
                  RowBox[{"Sow", "[", 
                   RowBox[{
                    RowBox[{"out", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", "\"\<W\>\""}], "]"}],
                   ";", "\[IndentingNewLine]", 
                  RowBox[{"Sow", "[", 
                   RowBox[{
                    RowBox[{"out", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "\"\<xpop\>\""}], 
                   "]"}], ";", 
                  RowBox[{"rep", "++"}], ";"}], "\[IndentingNewLine]", ",", 
                 RowBox[{"{", 
                  RowBox[{"\"\<W\>\"", ",", "\"\<xpop\>\""}], "}"}]}], 
                "]"}]}]}], "\[IndentingNewLine]", "]"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"outs", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "1", ",", "1"}], "]"}], "]"}], ",", 
            RowBox[{"outs", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "2", ",", "1"}], "]"}], "]"}]}], "}"}]}]}], 
        "\[IndentingNewLine]", "]"}]}], "]"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.6967418987426662`*^9, 3.6967419531933603`*^9}, {
   3.69674198732911*^9, 3.696742080165221*^9}, {3.696742119728137*^9, 
   3.6967421350150537`*^9}, 3.6967421882806797`*^9, {3.696742237491008*^9, 
   3.6967422393468227`*^9}, {3.696742667841529*^9, 3.696742672434795*^9}, {
   3.696742704610071*^9, 3.6967427522106743`*^9}, {3.696742791569849*^9, 
   3.696742792529752*^9}, {3.6967433215401163`*^9, 3.696743324479398*^9}, {
   3.69674343802772*^9, 3.69674345577017*^9}, 3.696744559379133*^9, {
   3.6967446028343563`*^9, 3.6967446443931847`*^9}, {3.696744695282875*^9, 
   3.696745003373519*^9}, {3.696745044107589*^9, 3.696745241041957*^9}, {
   3.696745312409123*^9, 3.696745370406358*^9}, {3.696745402186661*^9, 
   3.696745808966052*^9}, {3.696745987252262*^9, 3.696745990924328*^9}, {
   3.696746135791882*^9, 3.696746138803063*^9}, 3.696746183052067*^9, {
   3.6967462509248877`*^9, 3.6967462750325813`*^9}, {3.6967463055537243`*^9, 
   3.696746342306569*^9}, {3.6967463997645617`*^9, 3.696746445210659*^9}, {
   3.6967468276135263`*^9, 3.69674687548985*^9}, 3.696747082380311*^9, {
   3.696747185736369*^9, 3.696747186823142*^9}, {3.696747269500012*^9, 
   3.6967472707555323`*^9}, {3.696747369050708*^9, 3.696747386584386*^9}, {
   3.6967474238091383`*^9, 3.6967474254301157`*^9}, {3.69693117237386*^9, 
   3.696931208566784*^9}, {3.696932247496593*^9, 3.696932271291664*^9}, {
   3.696932316068123*^9, 3.696932431522345*^9}, {3.696932773029119*^9, 
   3.69693279739323*^9}, {3.696934020646245*^9, 3.6969340271424847`*^9}, {
   3.696934101334423*^9, 3.696934108462144*^9}, {3.6969341669504013`*^9, 
   3.696934174119154*^9}, {3.6969342366189337`*^9, 3.696934237805393*^9}, 
   3.696934375754607*^9, {3.6969344214939947`*^9, 3.696934430234496*^9}, {
   3.6969345063408327`*^9, 3.696934548226474*^9}, {3.696934678659957*^9, 
   3.696934800827901*^9}, {3.6969349068206053`*^9, 3.696934960049254*^9}, {
   3.696934993393244*^9, 3.6969350149273*^9}, {3.6969350911537933`*^9, 
   3.6969350923525887`*^9}, 3.696935269050218*^9, {3.696935585816584*^9, 
   3.696935641254245*^9}, {3.696935699850024*^9, 3.696935817938725*^9}, {
   3.696935967102593*^9, 3.696935972031057*^9}, {3.6969374104258432`*^9, 
   3.696937414158848*^9}, {3.696937446544297*^9, 3.696937476868353*^9}, {
   3.69693750801071*^9, 3.696937540634459*^9}, {3.696937965616984*^9, 
   3.696937977347192*^9}, {3.696938027729101*^9, 3.6969380326116257`*^9}, 
   3.696938087630336*^9, {3.696938175954073*^9, 3.6969381870484447`*^9}, {
   3.696938226062763*^9, 3.6969382365995493`*^9}, {3.696938270232462*^9, 
   3.696938280516086*^9}, {3.696938339902334*^9, 3.696938362582755*^9}, {
   3.696938425182043*^9, 3.696938549365018*^9}, {3.696938583613679*^9, 
   3.696938589332388*^9}, {3.696939119920095*^9, 3.696939120239994*^9}, {
   3.696939199254425*^9, 3.696939231235757*^9}, 3.696939299840695*^9, {
   3.696939490701722*^9, 3.696939497933178*^9}, {3.696940778273692*^9, 
   3.6969408045013647`*^9}, {3.696940892446557*^9, 3.6969408937265177`*^9}, {
   3.696940929843379*^9, 3.69694093263983*^9}, {3.6969412550772133`*^9, 
   3.696941282689395*^9}, {3.6969457052201366`*^9, 3.696945728580915*^9}, {
   3.6974632288636637`*^9, 3.69746324646949*^9}, {3.702024289610355*^9, 
   3.702024299018477*^9}, 3.702027534435175*^9},
 ExpressionUUID -> "fca84559-3150-4874-8336-87c8194c4977"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example and representation of results", "Section",
 CellChangeTimes->{{3.702027843261364*^9, 3.702027857196909*^9}},
 ExpressionUUID -> "6c00f4e0-1d3b-466a-b0b4-f19611da3953"],

Cell[CellGroupData[{

Cell[TextData[{
 "Example for only ",
 StyleBox["de novo",
  FontSlant->"Italic"],
 " mutation"
}], "Subsection",
 CellChangeTimes->{{3.7020278724611797`*^9, 3.70202791065306*^9}, 
   3.702728279140745*^9},
 ExpressionUUID -> "285463bf-09f2-4908-ae56-38b410115d95"],

Cell["Parameters et initialization of the population", "Item",
 CellChangeTimes->{{3.702030543335829*^9, 3.70203056723954*^9}, {
  3.7027294358939075`*^9, 3.702729444356392*^9}},
 ExpressionUUID -> "e16c65ad-bdc9-4a16-bc34-9f9f600ce930"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"No", "=", 
   SuperscriptBox["10", "5"]}], ";", 
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmax", "=", "1000"}], ";", " ", 
  RowBox[{"na", "=", 
   SuperscriptBox["10", "6"]}], ";", 
  RowBox[{"nrep", "=", "1000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";", 
  RowBox[{"\[Lambda]", "=", " ", 
   RowBox[{"2", " ", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rd", "=", "0.05"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"2", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "5"}]]}]}], " ", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"allelesFGM", "=", 
   RowBox[{"RandomVariate", "[", 
    RowBox[{
     RowBox[{"MultinormalDistribution", "[", 
      RowBox[{
       RowBox[{"0", 
        RowBox[{"UnitVector", "[", 
         RowBox[{"n", ",", "1"}], "]"}]}], ",", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"IdentityMatrix", "[", "n", "]"}]}]}], "]"}], ",", "na"}], 
    "]"}]}], ";", 
  RowBox[{"(*", 
   RowBox[{"Mutations", " ", "effects", " ", "on", " ", "phenotypes"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"xini", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      SqrtBox[
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{"rmax", "+", "rd"}], ")"}]}]], 
      RowBox[{"UnitVector", "[", 
       RowBox[{"n", ",", "1"}], "]"}]}], ",", 
     RowBox[{"{", "No", "}"}]}], "]"}], 
   RowBox[{"(*", 
    RowBox[{"Initial", " ", "population"}], "*)"}]}]}]}], "Input",
 CellChangeTimes->{
  3.7020282178346167`*^9, {3.702028301162031*^9, 3.702028311145953*^9}, {
   3.702028351497774*^9, 3.702028391465397*^9}, {3.70202851192909*^9, 
   3.7020285698320217`*^9}, {3.702028700055134*^9, 3.70202870253507*^9}, {
   3.702028823494272*^9, 3.7020288784544163`*^9}, 3.702029117011627*^9, {
   3.702029172739476*^9, 3.702029173395179*^9}, {3.7020309643725033`*^9, 
   3.7020309944199963`*^9}, {3.702728071109846*^9, 3.7027281083729777`*^9}, {
   3.7027281390617332`*^9, 3.7027281558616943`*^9}, {3.7027293431106005`*^9, 
   3.702729343574627*^9}, 3.703308488631798*^9, 3.7282166292371855`*^9, 
   3.728216801278427*^9},
 ExpressionUUID -> "97e2cfff-73a8-412f-be2a-eb1c0fabcfc2"],

Cell[BoxData[
 InterpretationBox[
  TagBox[
   PanelBox[GridBox[{
      {
       StyleBox[
        StyleBox[
         DynamicBox[ToBoxes[
           FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
           StandardForm],
          ImageSizeCache->{299., {3., 9.}}],
         StripOnInput->False,
         DynamicUpdating->True], "Panel",
        StripOnInput->False,
        Background->None]},
      {
       ItemBox[
        TagBox[
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"\[LeftSkeleton]", "99977", "\[RightSkeleton]"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
            "1.0488088481701516`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
            "}"}]}], "}"}],
         Short[#, 5]& ],
        Background->GrayLevel[1],
        BaseStyle->{Deployed -> False},
        Frame->True,
        FrameStyle->GrayLevel[0, 0.2],
        StripOnInput->False]},
      {
       RowBox[{
        ButtonBox[
         StyleBox[
          StyleBox[
           DynamicBox[ToBoxes[
             FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
             StandardForm],
            ImageSizeCache->{54., {1., 9.}}],
           StripOnInput->False,
           DynamicUpdating->True], "Panel",
          StripOnInput->False,
          Background->None],
         Appearance->Automatic,
         ButtonFunction:>OutputSizeLimit`ButtonFunction[
          Identity, 52, 26953320965877864239, 5/2],
         Enabled->True,
         Evaluator->Automatic,
         Method->"Queued"], "\[ThinSpace]", 
        ButtonBox[
         StyleBox[
          StyleBox[
           DynamicBox[ToBoxes[
             FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
             StandardForm],
            ImageSizeCache->{60., {1., 9.}}],
           StripOnInput->False,
           DynamicUpdating->True], "Panel",
          StripOnInput->False,
          Background->None],
         Appearance->Automatic,
         ButtonFunction:>OutputSizeLimit`ButtonFunction[
          Identity, 52, 26953320965877864239, 5 2],
         Enabled->True,
         Evaluator->Automatic,
         Method->"Queued"], "\[ThinSpace]", 
        ButtonBox[
         StyleBox[
          StyleBox[
           DynamicBox[ToBoxes[
             FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
             StandardForm],
            ImageSizeCache->{92., {3., 9.}}],
           StripOnInput->False,
           DynamicUpdating->True], "Panel",
          StripOnInput->False,
          Background->None],
         Appearance->Automatic,
         ButtonFunction:>OutputSizeLimit`ButtonFunction[
          Identity, 52, 26953320965877864239, Infinity],
         Enabled->True,
         Evaluator->Automatic,
         Method->"Queued"], "\[ThinSpace]", 
        ButtonBox[
         StyleBox[
          StyleBox[
           DynamicBox[ToBoxes[
             FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
             StandardForm],
            ImageSizeCache->{78., {1., 9.}}],
           StripOnInput->False,
           DynamicUpdating->True], "Panel",
          StripOnInput->False,
          Background->None],
         Appearance->Automatic,
         ButtonFunction:>FrontEndExecute[{
            FrontEnd`SetOptions[
            FrontEnd`$FrontEnd, 
             FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
            FrontEnd`FrontEndToken["PreferencesDialog"]}],
         Evaluator->None,
         Method->"Preemptive"]}]}
     },
     DefaultBaseStyle->"Column",
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[1.2]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    DefaultBaseStyle->{},
    FrameMargins->5],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  Out[52]]], "Output",
 CellChangeTimes->{{3.7282166232171774`*^9, 3.72821663209719*^9}, 
   3.728216804208431*^9}]
}, Open  ]],

Cell["Simulations of rescues", "Item",
 CellChangeTimes->{{3.702030587687306*^9, 3.7020305894320927`*^9}, {
  3.70272905269599*^9, 3.7027290544530907`*^9}},
 ExpressionUUID -> "fa894fc8-4133-444a-adf9-10eaab9c2c79"],

Cell[BoxData[
 RowBox[{
  RowBox[{"out", "=", 
   RowBox[{"FGM", "[", 
    RowBox[{
    "xini", ",", "U", ",", "rmax", ",", "allelesFGM", ",", "tmax", ",", 
     "nrep", ",", "False"}], "]"}]}], ";", 
  RowBox[{"EmitSound", "[", 
   RowBox[{"Play", "[", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"1000", 
       RowBox[{"t", "^", "2"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.702028020381042*^9, {3.70202805732902*^9, 3.7020280913876543`*^9}, {
   3.702028177258871*^9, 3.7020282003470497`*^9}, 3.702028246266089*^9, 
   3.702028475593751*^9, 3.702028892853054*^9, {3.702029051252069*^9, 
   3.702029052342152*^9}, {3.702029437393388*^9, 3.702029458193593*^9}, {
   3.7020295407366323`*^9, 3.7020295915380993`*^9}, {3.7020296530565577`*^9, 
   3.70202965398308*^9}, {3.702030439048958*^9, 3.702030442920479*^9}, {
   3.7027291306144466`*^9, 3.702729137716853*^9}, {3.7027292250618486`*^9, 
   3.7027292311431966`*^9}, {3.702729301397215*^9, 3.7027293135419097`*^9}},
 ExpressionUUID -> "9bfd8cc1-13b5-4ac6-8fbb-a2d9040b5c7b"],

Cell["Scaling for graphics", "Item",
 CellChangeTimes->{{3.702030475176388*^9, 3.702030517192234*^9}, {
  3.702030953700338*^9, 3.70203095610056*^9}, {3.7027293821018305`*^9, 
  3.702729418308902*^9}},
 ExpressionUUID -> "ef3a70ae-0b6d-48d4-a307-05e8d790753e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"mms", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Log", "[", "#", "]"}], "&"}], "/@", 
    RowBox[{"out", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmss", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           RowBox[{"Length", "[", "#", "]"}], "-", "1"}]}], "]"}], ",", "#"}],
        "}"}], "]"}], "&"}], "/@", "mms"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mtp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           RowBox[{"Length", "[", "#", "]"}], "-", "1"}]}], "]"}], ",", "#"}],
        "}"}], "]"}], "&"}], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Mean", "[", "#", "]"}], "&"}], "/@", 
     RowBox[{"Flatten", "[", 
      RowBox[{"mms", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "2", "}"}], ",", 
         RowBox[{"{", "1", "}"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vms", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Log", "[", "#", "]"}], "&"}], "/@", 
    RowBox[{"out", "[", 
     RowBox[{"[", "4", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vmss", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           RowBox[{"Length", "[", "#", "]"}], "-", "1"}]}], "]"}], ",", "#"}],
        "}"}], "]"}], "&"}], "/@", "vms"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vtp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           RowBox[{"Length", "[", "#", "]"}], "-", "1"}]}], "]"}], ",", "#"}],
        "}"}], "]"}], "&"}], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Mean", "[", "#", "]"}], "&"}], "/@", 
     RowBox[{"Flatten", "[", 
      RowBox[{"vms", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "2", "}"}], ",", 
         RowBox[{"{", "1", "}"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Nss", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           RowBox[{"Length", "[", "#", "]"}], "-", "1"}]}], "]"}], ",", "#"}],
        "}"}], "]"}], "&"}], "/@", 
    RowBox[{"out", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ntp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           RowBox[{"Length", "[", "#", "]"}], "-", "1"}]}], "]"}], ",", "#"}],
        "}"}], "]"}], "&"}], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Mean", "[", "#", "]"}], "&"}], "/@", 
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"out", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "2", "}"}], ",", 
         RowBox[{"{", "1", "}"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pdf", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"tmax", "+", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PP", "=", 
   RowBox[{
    RowBox[{"Extract", "[", 
     RowBox[{
      RowBox[{"out", "[", 
       RowBox[{"[", "3", "]"}], "]"}], ",", 
      RowBox[{"Position", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"out", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", 
        RowBox[{"x_", "/;", 
         RowBox[{"x", "==", "1"}]}]}], "]"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cdf", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"tmax", "+", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"pdf", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", "1"}], "]"}], "]"}], "=", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "/", "nrep"}]}], ")"}], "&"}], "/@", 
   RowBox[{"(", 
    RowBox[{"Tally", "[", 
     RowBox[{"Sort", "[", "PP", "]"}], "]"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"cdf", "[", 
      RowBox[{"[", "i", "]"}], "]"}], "=", 
     RowBox[{"Total", "[", 
      RowBox[{"pdf", "[", 
       RowBox[{"[", 
        RowBox[{"1", ";;", "i"}], "]"}], "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"tmax", "+", "1"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pdf", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Range", "[", 
       RowBox[{"0", ",", "tmax"}], "]"}], ",", "pdf"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cdf", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Range", "[", 
       RowBox[{"0", ",", "tmax"}], "]"}], ",", "cdf"}], "}"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7020304629533997`*^9, 3.702030467593549*^9}},
 ExpressionUUID -> "872d18e2-ef8b-429b-b275-865a2d7c37b2"],

Cell["Graphics", "Item",
 CellChangeTimes->{{3.702030531927964*^9, 3.702030533335875*^9}, {
  3.7033084782577796`*^9, 3.7033084782889795`*^9}},
 ExpressionUUID -> "4dadad81-047a-412e-9440-3fb2380c9051"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ListPlot", "[", 
     RowBox[{"mmss", ",", "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "tmax"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "1.1"}], "rd"}], ",", "rmax"}], "}"}]}], "}"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"Joined", "\[Rule]", " ", "True"}], ",", "\[IndentingNewLine]", 
      
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"{", 
         RowBox[{"Orange", ",", 
          RowBox[{"Opacity", "[", "0.2", "]"}]}], "}"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<t\>\"", ",", "Bold"}], "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{
          "\"\<\!\(\*SubscriptBox[OverscriptBox[\(r\), \(_\)], \(t\)]\)\>\"", 
           ",", "Bold"}], "]"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"AxesStyle", "\[Rule]", "Thick"}], ",", "\[IndentingNewLine]", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Background", "\[Rule]", "None"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Background", "\[Rule]", "None"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", " ", 
       RowBox[{"{", "\"\<All replicates\>\"", "}"}]}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"mtp", ",", "\[IndentingNewLine]", 
      RowBox[{"Joined", "\[Rule]", " ", "True"}], ",", "\[IndentingNewLine]", 
      
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", "Thick"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", " ", 
       RowBox[{"{", "\"\<Mean of the replicates\>\"", "}"}]}]}], "]"}]}], 
   "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ListLogPlot", "[", 
     RowBox[{"Nss", ",", "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "tmax"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "No"}], "}"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Joined", "\[Rule]", " ", "True"}], ",", "\[IndentingNewLine]", 
      
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"{", 
         RowBox[{"Orange", ",", 
          RowBox[{"Opacity", "[", "0.2", "]"}]}], "}"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<t\>\"", ",", "Bold"}], "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<\!\(\*SubscriptBox[\(N\), \(t\)]\)\>\"", ",", "Bold"}],
           "]"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"AxesStyle", "\[Rule]", "Thick"}], ",", "\[IndentingNewLine]", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Background", "\[Rule]", "None"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Background", "\[Rule]", "None"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", " ", 
       RowBox[{"{", "\"\<All replicates\>\"", "}"}]}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ListLogPlot", "[", 
     RowBox[{"Ntp", ",", "\[IndentingNewLine]", 
      RowBox[{"Joined", "\[Rule]", " ", "True"}], ",", "\[IndentingNewLine]", 
      
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", "Thick"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", " ", 
       RowBox[{"{", "\"\<Mean of the replicates\>\"", "}"}]}]}], "]"}]}], 
   "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"cdf", ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "tmax"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"Joined", "\[Rule]", " ", "True"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Blue", ",", "Thick"}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Style", "[", 
       RowBox[{"\"\<t\>\"", ",", "Bold"}], "]"}], ",", 
      RowBox[{"Style", "[", 
       RowBox[{
       "\"\<\!\(\*SubscriptBox[\(P\), \(ext\)]\)(t)\>\"", ",", "Bold"}], 
       "]"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesStyle", "\[Rule]", "Thick"}], ",", "\[IndentingNewLine]", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Background", "\[Rule]", "None"}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Background", "\[Rule]", "None"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotLegends", "\[Rule]", " ", 
    RowBox[{"{", "\"\<Over all replicates\>\"", "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.702029212966033*^9, 3.702029217092496*^9}, {
  3.702029915118822*^9, 3.70203013910067*^9}, {3.7020301701239443`*^9, 
  3.7020301707954473`*^9}, {3.702030232572843*^9, 3.702030402825589*^9}, {
  3.702030697064245*^9, 3.702030937973783*^9}, {3.702031296418846*^9, 
  3.7020313083383303`*^9}},
 ExpressionUUID -> "8f35501b-e279-4aa4-9651-7aeeaa4b16b6"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {{}, {}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdk31MVWUcx4+Ujhw5dLL1B4tLOiJwhFoZAvEFeb/gfYEL3MvbuS9QGxKb
tFFp60jM1KQiJ9zLm1dLBbEorgQZ6SlovhAClS63sLuZQphUVusVVy3Pw+95
2O7YZ9/z+X2f5znPCXfUmCsCJEk68e/vv//an2Jr9ng83af/px+TQpym5w4w
liDN0jwQt58f09cxDkbQjZmR/YxXQr19fseCfx8Wz137NJNxKN65691xPWMd
vu8dmF7O+AGMRPeOveXWeDV2nm14Gowj8NONty0ZjCNx8XpWy3CLxlGYGU+L
H2W8BpP9ezsD2PwYfBXSmzHD/Fj8uugF65+M16JqKtu6hPE67IyP8UWzeetR
ZUvf2M/4EXxwpGbZYcaP4vO73csdzH8MddPjS35hvAHPmpKeWuDH0bHuUoSd
rS8OMSFV2UOMN2LItvTnjxjHY7586WcS4wRMTNRvC2rVOBHBY4NPJjJ+AtE9
Ez9sZZyE8KZSVzfzgfen11w9qLECTBlaXfezPBkn2gfnKzVfSYahXd/pZ/NS
cM/x2rEulqfg4aAdvgGWb0Lo9OniEZZvQkOYh9ynVJxdS1hJRVeRu2Nh/2kY
7ppxn2J5GibrE76dYXk6hlL2FWex+em41tv1zQjLM3Bvrst3hvkZ+DjkWFMt
yzMRtrU+LovlmUj5pPrlGpZnYf220etbWJ6Fc721sxdZno3dX07OXWZ5NlZF
6l9aeB96/HWF7k+P9Cm6/xz0PVgdu6dNy3MweNLxqsr8XBy/EBX4XaeW5+LY
rcAVUV4t34xbXxhWph/W8s2INJ5vaNZYMmDL6LkPZ3u03IDtvoS/V/u03IjB
2LnQF7vuMIwo9D1jkt7Unjei0fDHRFv7HVaNONpP129CXx9hmHCzh+7XhF2H
CKsmNLZT34ycFuqbITdS34zh3dQ3I24P9fOwnTLyEPAK9fPQQ1nNg24v9fNx
mTLyhf58XKKs5uPgsiu/BWvvQ7Ig4jXqW3CBsmKB5XXqW+Boov0FOPQG9QtQ
tY/6BYikrBYgfD/1CxHTTP1C/E5ZKYSRslqIdjf1i5DqoX4RGlqpX4SeDuoX
oY2yZMUkfZ+w4iHKihUjbdS3IpGyZMMA7YMNZ7h+G0bp+lQb6ihLxfDT/UBg
pRhR9H6pxfx9k0pQzd2/EngpKyV4j/NLcJXzS7GY6y/FBq6/FOOU1VKc4s6/
DKu48y9DLLf/Mjgoq2UwU5bK+Rzlgl+OMM4vxzx3fjKSaa4TGDI/T5ZRy82X
+X6v4KsC+4XnJTs/X2fn1wc7blKWBVbs+Jqy145K7r7YsYiyX2DJwbPOIbwP
ByxcvwMruH4H//14BVaF+X5hvuQU+p3CfXbyz8tOfj2Kk/8evEKuOvnz8Dtx
kut38eenc/HfG4RcdvG+4kI31y/kqgsert+FXVx/BZ/rBIbAcgXvK0LureDX
owq5X8ilSp51lUK/wPIC/wMZW/3l
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0wtM1VUcB/C/4gPTSJlzmDqvYWa3NE3UxNCvL17yvLzf//vgcUFEbKKF
un+sroQg8hKuQP5zgo+R4tamM6d/jdTMGqkRPkbXsnRLpzJyC+esVud4zo/t
jn32O9/z+52z859mK7JkD1UU5d4/v3//sz8tdZfb7T54+j89XHr6hDnoCbeC
wNd9BrftZvbGyeqMkc3cY2E5UPloA/d4WI4P9U3j9sPT7ginF/dk7Dv74Ewv
39+EoWvvVt3kfgVxuT0Bl7mnw9X2JPMA9wwENPh9WcY9E4NZi0Kc3GaU5kb0
3mtifhNNA14vhPH6bHwe4XIFcM+BMqakqp57Ltp7p56t4H4bW5fvKy7hnoe3
imIv1PLzBKClpO/cIe752Bj347mDzcwLMPnjntD73Aux2edScWML8ztY0rGl
zp97EV4cXebt18ociK5LV8d0cS/Gibbff9vA17+Lw9OHj/yC7x+E3mtzzWO5
l2DAPG7Jej7fUuxf1TbK4AZmX9m0YBrbTwMsYW2uSJ5fhgmNCyN/Zeu1Zaj/
9PGhCp5fDs/4sp9reH05rn6QcoavV1Yg6pXgG528vgI7bgffbef3uRLF/V1b
9jNrKzHim69re3h9FeaPnvJwkNdXodMc/ew83z8YdWGDPXvZvFowBq+/nJ/P
8yEInLf31h2eD0F/ZW73el4PhTPkIop5PRTqR5cu9vP3E4bB79/wXsvrYWi/
PnHKGp4PR5jvjKyZvB6ODhQ13Of51Vh87IKPg9dX46dxQY1Wno9A6C338+9P
i8DxPsFKJAJuK6HR/HyR+DPzekpBI6tH4Vmhb9m2XawehW7XgD2OWYmGfdh4
l5nXo1E/8VbBZZ6PwayXikvOMiMGJZsffHa6ga2PQZ7d/Wpb/f82YnBg8mv7
kmtZPhYpU2aV+texfCzaDs+/caqG5WPx157tezLYeiMWj+tir5W7WN6Cdd/t
qXFVsLwFGxeV+ujbWd6Ci4El3f47WN6Ck7+Y+st3snwc3K7Nm+6w+RCHSc3r
3SPYPFocIr3LD23i88dBTbadu8LPH49Hh306p7H5EI91YR0/XKti+XiEvx9x
vukTlo9Hx5Gur26yeZUErA0J+LCSzYcEtPpufvwH66cl4Ogkr62V7Ps1EhDr
Zfbr62T5RDzoLqoqO8ryiRiZ6lV26hjLJ2LCiGG9re0sn4jZVeL7SIL3DsFI
gi5aS0K1aCMJA6KVZDirxXwyhuwU88nYJtpIxtQaMZ+CqFoxn4KZdWI+BUdE
GynYXS/mU9EnGqkY1SjmU1HaJOZTcdMt5tNg2y3mibU0BDWL+TRsaRHz6aho
FfPpSBKtpWOBaCOd5DMQLhoZiBL7aRnyPEYGGkQrmTgongeZyBfPq2UiQ7wP
IxNm0UqWXEcWdOn+slAo5cl6RZXrJhXDxf4gVlUMSPurqBatk/0MVe7nUTFR
6m/FVqm/lfS3okXqb8W34n1pViwT71O34j3pvq2YI9pDrNjgI9pkk98XiFUb
nkr9bdgoWrchR7Rhw0Nxfo8NHtGKXa6b7PJ+sMvvQ7XjvtTfLs+j21Eu9Sfr
PWQ/xSHPa3LIeThIf4d8Hxqx7kCA1N+BIVJ/BxKk/tmkf7acB7GaDX+pf7Z8
fzqxkU36Eys58JX6EyNHnk8l1nLkeXRig6z35MAt9c+V78+UK79vkLpKrJH1
OrFB7CFW8mSbiEGsEmvEep78Xow8+T15iBWnvN7klO8HTnm9SqyR9TqxQexx
kvPn44TUP5+cP5/cP6lrxDqxQezJJ99fATl/ATl/gTyfSqyRvE7yBrGHWFkj
20QMYpVYI9aJDWIPsVJIzk+MQtL/uf8G8vlAgA==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw9y3tMk1cAxuEP5wXpBDMoOGnUykJEtAJTnBfsS0uR+9d+pZWpE8UIW1gQ
HQNUBuVqANEiA8oUxILAFhc16FARWmFsZMzqcCHx8gdMhITMlVkMZLowF845
Jzk5efI7rzTpsHBoHsdxe9/e/196DLtr6urqvrXMaVKe65uc8wszh4J3bib8
yOyMZ8KkrIZ5KbzF1VfimD0QuuLy5FPmZWg1dfnfYJZgKsjm2s28Csu/+ynj
EfNqdEtWi9qZP8DlwEzFOLMvZmuy9ZnMa7Dr8ZIlEcxr4T/Q3qtgXoc3j8T5
ArMMVxWJ2eHMAdBNiZynTdSBaMwYvFLMehA2/FD51Pkb6g9RcqTDs571jbDe
WFRkZvtNML/647ArczAOpvw2bwHzZjSu+cfG11J/hO0Hp5SnmbdAdm66MpN5
KyQqR34W229Db2TPfY55O4oe1zpJmUPw+xPB7M68A06Ga44/a6jlmLlqe6Bi
HeisCM9Iot0ASKU+eSVf0x6KWwm55buraA9FkNepEVEl7Qp4mZ/dbjhDuwLe
/Wdu9VXQrsRA/67zAawrceplotv35bSHYdOXhoRrZbSHYXZm5bsexbSr4PKx
zjj+Fe0q2NXtLhvzaA+HwSf9U0su7eFQjGidbNm070SgaMRv+VHad2LrvokC
13TaI3DAbr4zuJ/2CNg3DDnG9tAeiZD6hkP1UbRHQhmS9+94MO1RmJ/VE5Yu
pj0K18scrzsktEdjTOZauM6D9mgkBRf6d9rbSI8B5zJy1jFBbIhBr9Bmqx2m
PRbP+U/2tzygPRYVkavuORfSHgfLRWnhQjntcXjPb8dz/q9W0nls4bqlE2Zi
A4+SrtTUfZ/Rrsbt1i5+2osYarSXNm+Lnm0h/9XwNrmldRqJrWpUn8TnvPoS
2WswdNpruGWsmew1eJkVMDXqSWzQ4MRoU0psQhPZa+B54W52sjsxJ6B+RfO4
3XqR7AWIG0Wq+cfMZC/AR81l5hhJtwpIsvCDaiUxp8VQn8m34Hgj2Wtx4G4u
v2i0gey1KL1nkSz++zzZa7FwulyTIjlH9vFwu/nFq/77tWQfD5+wRP+OmWqy
j8es0M03KavIPh4/u/T68i+MZK9DcunQsOlJGdnr0PZr8PvGBcVkr8OFE4Mx
Gj6H7HXITx2IKC8i5vRItFUZzyKN7PVY31PWWqwUy+f2esT0PVya7pY2Z6se
MnfFygK/Y/L/AGhP0qc=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlH1M1HUcx3/KSrQiRmyK4jyFGJkRIIgaypsHeTrA4w44nvndHY9NlEUb
GvzxE1qjEjEeTo6HPAJtlwxdZmu44keJThRnJYFF49pstCXpHFsJ1qq137fP
93vb7fba+/v6vL/f38Ntth4ylq2UJOn6P99/f7WPkm93OByu0f/oQczdPwxt
9Ywl+BT4PJ5j7Im5816N1Yy9kZpyryaBsS/WPFw+Mtml8TrUrgvd3MrYH/cf
hz3VxliH8cNnO1oYb0H8dNzVWsaB2DAalnDqpMZBmDdMT8QwDsZklOfptYy3
4pPYmImiTo234bWkpVV1jEPgZf/49XN2jUPxxvDzd/tZHob6rIvLO1geDndA
gO8Q4+1YHDM57jOOwKTvctmHjCNhNtT//g2btwOeU7uf3c72FwXdR98+OsDW
70TELaQdZbwL619tjvFj63fjuYF7cbMsfwU3F9e+9CfjaNSM2Xu3seu1B+dW
7jR6svuxF0cvBtyZYnkMoho8fjvOcmCmx3vjLxorgOtGvR0sj0XgpSb/Gc1X
YjHw1iV9creWx+Fahpof3KPlcahu3xQ0w/x4VFxZiPXX1ivxGIjUd3r0aXkC
er+LcKqsPwFD0ceavmfz9+Hm4O0v1jN/H2o2xAenszwRdQGr7RnMT4T14IrB
IdafhLbx6OER5iehxbZq9GVtv1IyQiOqPFy9Wp4M8/Aq5xTLU/DrMyFL8SxP
Qcp00+dnWJ4KW3et6St2/lT4JR64cor166GfM/WHd2i5Hi/o/yrqa9HyNHg1
r1GPsDwNZ4qiH25t1/J0VFTs/bSmTcvT0egybzSy5yMDNr/LC6c1VjIQ/eZP
DUEs34+oruwXPdn592PphoO87wY8MUEYBpReJawYkHGZsGpAwJfUz0TIKPUz
Mf5141gk8zPxQ4fLP5z5mWi4QH0jys5T34g7Q7TfiIMu2m/E7AfUN+Ha+9Q3
obST+ibMtVLfhP63qZ+F25SRhSffoX4WdlFWs3CLspSNwHepn43DlJVsdFNW
s/EjZSkHpmPUz8FnlJUcPN1C/RzMU5bMqD5OfTOC6HkVM7acoL4ZI5SlXDx6
j/q52NNG/Vz8TFnNxSHKUh5S26mfB5Wykgdvej/UPAzaqZ+PecrIxwoH9fPh
1U39fFzooX4BzvZRvwCVlJUCqL3UF1gqhELnoRBLtE8pRCjXXwgfuj+pCKtP
Ur8IfpSVIrRSVgWWirHI+cWo76J+MXopq8XI5vpLYKX7QwmM3P5LsInbfwl/
PSWZZ53AkPnzyzJiufkyaik7BV+V4aD7dQvzJAs/T2cR+i1YoL5swXXu+bCg
mbLTAhdl1YI6rt8iXD8r7+useECvN6yI4PoFVqwo5/qt/HzVKvRbMcL123hf
Z+PXQ2DZxs9XbPx+nMJ6VWC3DbNcfynPOoEhsCywIrBTYFVgd6lw/jKhX2AI
LJcJ91/InQKrArsFlsqFfoEhsCywUs7vxymwWs6f1y3kUoXQX8HnqOB9WcgV
gZ3CelXI3QJLlTzrKoXzC7lcyc9XhNwp5Gol/z66K/n/A6mKZ10V/z7i//xv
RSWA/w==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw9jw881Pcfx2/Zr1Sz1mNnCHWVP/1hU8SSeFUu5L/T0eH+n0h+/TFN+WWH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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlAlMlEcYhn9QW40VQUnRIrj1CiVKEe8DfZVTUVmW+/53gVUOa2uNiFY6
xCgqWMUictmuV1OrllgsNjbG3zOt1rbGBK14rBRt0KRYj4o1QNu0M858m2w2
T97vnfebb2b2TdsyS46rpmm///P995d/WEpVTU3NgZP/0cPZ+1xZ+AXBGk7b
Eq+/ENwXY7sPT24Q7I6bgd6VewV7Iqj062lFgodA686//o7gYfDJ2Nb1Si1n
EwZe6dv5QOgj8ElBl2ud4FHw8KvI9BH1Y1A5dNjTYsF+OPvol442Ue+P1lOd
0fcEj4V53+OO5aI+ACvXBB85KzgQ/f2aNloFj8ejflsPdQp/EKZf6cjoFjwB
I8tdfO8Lnohzvjej3hM8CQXrLjcUivUm41LIpnH1gqfA8y9H18t5T0Xd2JtP
UgVPQ3GkZvEUPB36Petdn2rOM3DSK8LjYCXnmfig/VKLuYJzMLLK/Ht2bOc8
C7krzq/7Yyvn2egTWOvw3cIZ2Li6uvztj/5nBvy0syvdRehz0NJZsvN2Gdfn
4PmvKwsHbuP6XDwdP/jwZJ7P5qJh2Oa4EKGHIGD13eF7OLMQ/DzCa3uU0EPh
f/RoUwnPY6G4eqjN/ZzoNwztJWd6ny7nehjOTCl5Pkno4Yj4oe1qLGcWjg7b
lz8WiHlEwD78xeffif4icCJiWZRN5Ecib/Tmi9+I/Ei8dnz/7iSep83D6iuW
8qFiPvOwav8d44Lwz8eoi813G8X+5mPM4Fvr3aq4HoVnh8YNOC30KBy77ZZg
Ef0twIC20p5Qfp5sAbx9c8z5wr8Qw4/5h9nrub4Q0RPfeDJ4F9cXwRz0bfWr
/H6xRWifWHHZo47r0WhPbIu8I9aPxqZql1kbdnDdjI6u0f3u8/5gxvnllt/a
NvN6M8Z85untxfs1zPBvdoxuEP3HINutf+OffF6IQekxz7nPxHnEoOlS/pS9
nI0YJJxybW0W99OCI+ta4t03cb8FN1qHDHjKuN+CqWW7fK4t534LEFQ7sPdK
7o/Fre9vf+FdwP2xeNydUeS3gftj4XU4OO5xEffHwu9g4Vcta7k/DkGvV6XH
fcj9cQjNWzoycD33x2FEwKAHKaXcH4c1K9qs53m/WjwWZqOxh58X4nHi4Uj7
OHHf4tH06dEtgXzeRjyK5zWuihH3JwEsrNPZzOeDBBSfmjEBYv4J8Jha5tXO
75+RAPeZnbtLOGuJ2F334v6Bj7k/EfVba17+n7NEFG6T2EiEXWYtCYEVEiMJ
NplZEoK3y/4k9KqU/cnokRnJiN0h+5MRUCX7kzFjp+xPwbVa2U+YpSB8l+xP
weV62Z+q6khFkcwsFa1yvUHqtTT0Uvxp2CLXszQ1z0jDW0p+OtbKjHS1nqVj
muJPR6riz8CeOtmfgXdlZhl4X56HkYGuGtmfieHK/DKRVy37M7FGZiMT/ZT5
6xgqs0lXdRBd1+EvM9PRR17foSNZydNRJrNTx0OZNavKJivs8v5ghU3en25V
58GsCJTZYYWbMi8rLsrrOa04oMzPhniZTYRhU/vRbWq/zAYXWXfY4FT2b8Mg
Jd+GQiU/i+RnoUbJz8INJZ8wy8JxJZ+wQdhJWMtW2ZStzgfZ2KjkE2bZar8O
wgapdxJdyyH5OWT/hHXCLEdd30HYIOwkfs1O8u1k/4R1Us8IO+wk367mOQlr
i1U2LVb9IKwTZoQdZD2DsJPUa0tUNi0h8ye6TpgRdhA2yHpOwlouyc8l+blk
/rnqe2aEHYQNwk7CWp7Kpjz1fYHoOtEZ0R155P0R3Un8Wr7KJsIgrBNm+SSf
sEHYmU/ef4E6X1MBuX9E14nOCDsKyP0j7CSsLSX5S8n5E10nOiPseMl/A7Pv
UBE=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlHtQVVUUxrcU+UgJyUYdNG/UFJHSFa5vxQ9FVETez8vr3AuXN3KvSiUh
HBMQTPMRoqCM10xmFDWdxlEj7WiWf5iaWjmZM56ccZzR8YEzphZa09RZnL34
h/nNt7717bXXPvc1Z2WSy0cIMbqfEP/+N/5Ue2tbW9vub/6j+zNlFthrm9i8
l3gAduY11DQT++P30+P2NBEPQ+C17z9IIR6BjM8/uVBMPAphL6WV9PWz4Ja1
13cFcRAmDjsSXEn8BjImV9fcJn4TtkJ7VStxMDZuXdi0gTgEDYcT4/ryxmKX
b/O1sHaDQxE+OtkTRroVldbywa8Qj8eg7ku70ojDMNSuTbASh2PtqjJnPrEN
ESfOuKcTT8DYmmibjXgizi/OHBhLPAkBj7oOW4gn40HeuTUniKfguZnZ1feJ
p+La8vKeJ8TT4N5357fhxNNRVl/gqNpi8Axgj60xnTgC9YHHSsYRz8SHS0+V
rNhsMHC866d7FoNVYN9nyRWuVkOPxJgdFTtrDb8aiYYTy1a4KH8WXLZfx10m
fRZujNyU2Ep5s2EN8+taSfpshP/ckn2a9CjsjmnfHkx6FEY8qgt8TPocVLSf
6g6i881B467Oo1mkR6On9GH3d+SPxuJ79rcz6XxzsT9uzTParzoXS6uOLe7z
z8Ogc9aYLvLPQ9DwG4Nukz4fK6OLupLJPx+dfr8U0H2IGDiCekeFkh6DlKPX
/RMpfwE2dETcSid9AXof/L1uKOmx8N3RNOYk5cdist2v0Yf0hfhh/Org0q2G
vhC54TcdGzsMPQ7ZQ748u5b8ceh1+YRU0/niEeYf1zGY9HjMODQmZCTtPwG1
sU+fHNz0PyMBvp073g1oMeoT0OMz1brKYC0BD8cfrP/YqBeJaL+TOaLO0JGI
1GdXrkyhfSXiVOXVITeNfC0RDW+VJoUa84gk1EfUXGw1GEnYFx/lod8fNQnF
Z+tSFOM9akkoyj0wYACdPxnNfxxxeg1GMnJFAF6l/GRUrYnNmEr5yWjxO2qj
+xIpeN519+4LBiMFH/WPqDhp5KkpON2V9PJ2o5+WguqYgP4W8qci8MJtv/NG
PVJR6/9Xzx6671Toq/dfiTPm0VLxbeiz4zG03zQcunxm0jKDkYaGS8u7q2j+
NCw998WkePKn4Z3HL/ouIX863ouNrKsnfzo2bGzr+/1W0zH8UxNr6ehqMbHI
wNdmRgYGt5r9GVi32ezPwLYtZn8mdDMjE7Y2sz8TUWbWMvHUzMKO5dvMfjtW
d5j9dlw365oda80ssnBjq9mfhT/bzf4sqGZdy0KnWRfZ2GRmZGOJ5M/GVen8
2ZgnzZ+Dgeb7QQ5CzKwy1nIwzcwiFxWSPxc5kj8XJyV/Li5K/jwclPx5qJX8
efA1n1fLk/clFJwxz2dhDAWR5vtQFNyR9qtgt5m9inx/mgKnmXWmC4fc3+KQ
3wccSDWz4kCAlO9Ak5TvYO+N6boDX0nvzynv1+JEm5TvxPtSvhP9pHzGXsaa
E69L+ayfyJe/F0u+fB7ky/er5MvnU5nfy3QtX55XZ/1FgaxbCtj+C+R6hdWr
Bez+C1g+q9dZP+Fi78/F5messHqVsZex5pLvT3ex/Rey/EKWz3SFscrYy1hj
/XTGoki+L0sRy2e6UoRCKZ+xt4jls34600Uxe/+MUczmZ6yyei/TtWK2/2J5
HlEi78dSwr4/pislLJ+xl7FWwvIZi1KWX8ryma4wXS1l75+xxlhnLMrY/hmj
TK5XyuTzqKzey1hjfp2xKGfzl8v3A8YKq1cZexlr5Sy/nO2/gv3+MAZjpUJ+
bypjL6vXGOusXixi3/8i9v6ZrjBWWb2X6RpjndWLSvb9MQZjhbHK2FvJ8hnr
jIVbZn/GFrd8f1amg3ECY4Wx283eD+u/nrHXLb+XA4w1xj+y/jrT7zMWHjnP
n7HFI/ezeth+PGx+xgrr52asMl7vYb8nHjY/Y62P/wEgd27R
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1X1MVXUYB/Cjs2U1zZFNKqursHTku0QKwv2iV1REuVzu5eLl7dw3XuTy
kjWyF93RrU1FRQwvXAE9+bJB05rmXGTl0ZCZ6RpW2otbx1WudBJZKTXN1tr5
+fwe/3GfPb/veX7Pcw4wIVDnCg9XFOWhYYry3//WP80XjcVi3cf/16B9XU6p
/7ywgl/nl8d2C49E3wOzHt4rPAbJ7TN/1oTHolmd3HRSOB6HpzY7LguPx1PJ
P7oOCNuQGjwysFF4IrJ++v3aJOFEBE749yQIP4OqTZ73G4Qn49L4d9enCCfh
SMxM6mmzPAXdA6vWeUV9Gq5MuZPpFp4BvXGg9z3hmdCuIu6q8CysWWtv+Ep4
Nta5flNvCyfjsXG5tz07LT+Hm9n914aEU/B3hZpYK/w8bt1IuZ0jPAe5x7pO
7BeeC/+B6+4LwqkYynAm1LdbTsM3H76+u0F4Hv78vsv5nXA6fF0nB1YLZ8DR
37thn7AdmbVpjs3CwK1VJSPaLGtAQl+cvUfUM/Hiwe3e6aKeiS9GnY5rFvPP
x9CZkeV1oj4fWavP9qSL/S+AfU6T4+tWq74AjbbPU69ErboD8ZcH/xrRYtUd
aHtyXNRvWVmIc//srx5t9dMW4uJF97Mdon8WEu1r3ZmdVj0Lp8JT01J3WfVF
OFwzoS9k7VNbhNzo/kPHdlj1xagNP5HRKvovRtOlwcJOcb8laD96xr5B3H8J
vn265bi3w6pn48DRUYEqy1o21jzY0vuqeH9L8faNiumrmqz6UsR/2Zkwb6NV
z0Fy7+mMqY1WPQf9F1N2vbHFqi/D3uidjAYx3zJMfDw9OteyshwvHTv/x0Sx
n+VIs6VOekvsPxdDfevPxot6Lmbf13GhX8znRPyp2L2ffzjx2glizYm7HxEb
TpT3ECt5uHKU5vMw/AjN5yFwiObzML2L5l3Ys4/mXdjVQfMuTIvSvAvDttF8
Pj7ZSPP58G2i+Xy8Q23kI7GR5t14hBpuVFBrbtylNtz4dDPNe6BuoXkPTlFr
HlygNjxI2krzBUijRgF+oNYK8GgTzRfgILXiRTfdB7yY0UzzXtRtp3kvst+k
+UKMbaH5Qtyl1goxZgfNF+IcrSsr5PNYgVZ6XluBF6T3x6z4cLCN5n1Ib6d5
H+Lp92D4kNJJ80V4hRpF6Je+nyLcpM8zinA/rSvFKKN1FOOXnTRfDBe1UYxM
aqUEpnT/EjRSayUoaaX5EqRRK6VIokYpaqi1UiymzzNK0UGtlCEuRvNl+Fjq
z+pGGUZL91cRoLap8nxQcYfmVVXOayou0bqu4rrUT8XL1KaKbmrFjxi1zQ+P
NI9f3q/qx6A0H7PuxzCpv1+e32R1JSDnbQHWn9XVgJzXAvL99ACSpf7seWYA
G6T+QZRL8wflfgjK91dZXQvKz9OD8n6NID6T+gfl+ygh1j8kvy+E5PNqiPUP
sflDcEj9Q/I+TFZXwqx/GB9I/cPy96Uya8x6WJ7XYDaZlXLZNmaUy/dRy1l/
dl5nNphNllcqZNuYUSHnVVbXmHVmo0L+HkxWVypZf2ZUsvkr5Z9XrVJ+vs7y
BrNZyfZfxfozo0rupzJrVez7Z3mD2axi/Vey97+S9Wd1daW8D41ZZ+cNVjeZ
lWrWnxnMajV7/8w6s1Et78tkViJs/xH5fSIi71eNsP1H5N8POnueEWHzR9j+
a9j8Naw/s1oj30dj1tl5o4bNz6zUsr8/zGBWmTVmvZb1Z3Wzlv3+r2P9mcGs
1rH5mXVmg9lkz1Pq5foYZlu9fH4GM5idzCpzfb28H415Gzuv3/O/AI0VHg==

         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxVzQlQlHUcxvGFigBlUKYYQOJaghJswQsWhX1YRe4FlmUvFigSjywElOFm
F2mRRO5LSkBYIYirkCYY2iBUVLy1Q8QLrTG1AhIYZUCq4f9/m3bmnZ3PPO/3
/dnG7hXG6bJYrJR/nn//6U8lr6qpqWkdWNIk7/9m4bZiFed9xvpgP5K8aGe8
AosTmt5uxq+hXf/tlg7GZjD+Wcd38Qi1Jdif3LjwlLEN0jJMbzUxtsN8B3fh
YTW1PaSpdTsdmd0BXtstuImM34LyTaeJlcy91dh7+epvRoyd8eFIwzN7xu+g
jO2h3czYBfdWtbfqM3bFRzv620aZ+2sxdLZi4jJzbx06TOrHrZj316M5bub+
B4w3oG3UnjfH9BsRNfnFWk4ltRv6o+P2zJZRuyOZn50yyJiLuh+E+fbl1B6w
Sly4bs7smzDYYplys5h6M0Q+ZhzFYWpP3Jib/vrHQ9ReKHY+yv/PPKwz4v5Z
mUcNWFzUvm5RSKwCMp9sMvEspbs3atK0kWP0nsobkt76hBPMfT5WTr0wtWN2
Pvp0bmWMFNF9C5TZ6gM7Sui+BZWOnzo/yqX7VrinPkj2oVZtxcKULc8im+4+
CLYNVny5n+4+iK7Ja7y/j+7bcDs4rbY9le7b8FWda+3BA3T3xWLOimpZFt19
MWco8PNW0t0PVbPuajH9nsoPlT3GXe4pdPcHK+suv5/Z/THVpa0PT6R7AMpN
piZU1KoAWC7Efrc+je6BsOG+MvrHbroHIm+izsBCQfcg+B7Y9WvCOroHQT4z
JrW3pXsw+h8v2Deb0z0Y1/oy1lta012AO6V3X+0zo7sAzzkVI+eYPgSNxwRz
3y+jewjs3EocTzjSPRTxLkYDWdMtS0YoitgDM6WniFWh2Fiu7e4dIx4MxZqH
JtVtDcSsMFzGuLa7hfZhOCVVe87n0T4MHxfHJp1Oon0YhJr9a9KVtBdCNbz6
F3UQ7YXodDr2k5ZLeyFsLnQnvKRLeyGOnrS9NH/7c9KHw7R/sohzhRjhGJ6c
a5jcR6wKx3TxSM3jaOLBcJzTvfekVkZ7EW49jup4akB7EQQPn8uk8c2kF2F/
69AbHsnEgyJMWnbttrrWRPoI6AoqxpILjpM+ArH+i2wrD2JVBDoMRlOG0jWk
j8Byt7TF+FxilhjsayHsZmtiiBEaGWPT6dVIejECvrG+N7y8gfRi9Hi3bWex
iFkSONRG38z8/RjpJTgu6ji8s7me9BIIJvQuntH5jPQSfFuspzrDIWZJ4ZWU
WlpVcIT0UiTu6hx3WFVNein4VzKL+KlVpJfieq/QdOeyStLL4NQYxL1ZVUZ6
GQwVzwo3KktIL4PkzoZ0w9DDpJfhvcCg63KvfNLLwU88bztunkV6OWbPx4dc
PZlOejncFs6meSRnk14OhZlNp8g1ifSRiElQciQcAekjURhrUdD0rpi31Efi
gb5p88tqxZIHIzFzUKyrx0teMksBjWmG6K/s1CVDgdgY13yrgUzSK+Ce3aZx
kStJr0DPhW0xeVE5pI/CIb9LTkX6atJH4bRGbbXHOJf0UVA779DkCPJ5fwOu
IGBh
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxNkwtMU1cch+9wGECmbnE6VAIoGIOPiYDIQ/pDEMpDWwql0JZWZKDoEGEg
G7Kt4hYfgFAVBBHU8hDFt2xUQL1BfJA4GUYdjMzHBh2CCj4Ax8TMpeccadI0
X77/98+5t/farUmSxJlwHJf17vv/L/1o5IXFxcXHLhtpQJBVck7bx5iD97PX
fzYwNkPfGzRWM56MrfFlR9IYT0Gro1dLO+PPkOopHV7HeCb8NgWUezO2hXMR
r/dhPAupvaP2Bxjb48kvFerjjOdAdt+wrY3xXIx3l04tY+wIX7uSMdczHy8i
A+6+7xfCxHSsX4QH1mn6e4ydsKXQI7iD8WIkCgW/ig9QdsZHAzc9sxm74FZW
Tc1axq5AijrGnvESvEjvsvBi7IYplr7f3WD7l+KUJNFSx9gd2h0b87uKKHvg
Ue7bms8Ze+KN36RETzbvhTMnmj0OM16GdSa1+/Rs3hteS6YmxzAvQL9/ZZuK
MVB1rP9lPZ3XADa6P5IdmPdBaVdZv89+6n0w4JTZvpAytxyyoXn3OgqoX47e
qydPX6bM+eJ5Y9D0i/nU+2LlNwlXHHOp90NZW9neq3nU+wHrNx3YTOe5Ffht
7tGkaTupX4HB8397FDDvj7/CEg8qtNT7Q1e60fXjvdQH4OG2x+kxzAfgqKnN
CVPKnBDTtQuz6tj5hJjAu5cXsD4QRbG5dYt2Ux+IHPs1op4d1Achtq3L1IGy
JgiBOW/3XKHn5YJREV21cZD5YAhfmk0o3UV9CDpzhjKfs/0h6LE0VGdQ5lai
Lm/UxoTdn5Uw70mOr2DnW4WzooRrrpQ1q/BT91Dia+ZFMDi99uxk+0XY0H/S
TsyeDzF0oVmL3ShDjF3Xit+/HxoxXJrGMC+GFT+GuVAoGscwQuF8YWwfCtsw
+wSOPg98KCTFIw0W7P+TvHt//Bt30/sBCZ6VLDB4ZtBegs7ZP+ROT6G9BF9K
tyYY0mgfhlFHs+z5cbQPw+/67U1WctqHoSTXO2SblPZhOGxpcj0unvbhWHZO
mvNIQftwiLpHsjKjaB+OCyvqw5vDaR+OIGm2+blY2kthdmpVSAbdDymGzYMz
5nrQXgrXusrgD8xpL0V3uqPrjJZq0kegpeKr+kezCCMCTqI5XgteHSV9BGwO
3W9IDyCej8D8f61mfiKkvQx7vWrLGwS0l2Ha7aU32rWENTI0jZ7WKZNpL8On
8zb87GBP+0i0tO50G66jfSQqesQ1r9bTPhITNG2piXQ/H4nGGZfU9WnkfFwU
uieXmGu/qCJ9FEbW+ky8dJGwJgrK5Jrr8vNkno9Ck3aowCqQ9nJ08W7a4VrC
kGOiOk+/ewm9fjlGt8fuO7uF7OPlsH5qEd+rrCS9AlXZhpNmZ8pJr0Bzztqk
CIOO9Ao8Hp/hciiFMK9Agf/sPQ95wpwSqu/vvFr87WHSK/Hw+Ehf37xS0ivR
N6R9E9JXSHolHjyVfdgi2EX6aNzNvzPOTred9NEYjSlpjE9KJ3009CLn1nbb
ONJHI+SIa2zVuIFLxl6F2pqezMG3PgJjr8Imm47NT5SpRtaoULZ0/02X28lG
5lXoeJzdrFf9aGROjQzrWxbWt7SkV+OfSa3ywc4C0qshtpy4es+dQtKrcfHZ
cpmlQxHpV6NXWNndkXLQyLarsdWdqxZ+XSr4D3Z+sHs=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd031MlVUcB/AjKuA/rDRJk8WNgsQMefElM+QLiLwIF7hwebsX73PfeCtt
q6YVuQ5LBEHFJJErplcWJgvXi7G1xPXUhAqtTWurBtUlMN1wI2apYzmrtefw
O4ftjn32Pd/nnPN77n3E9bzFG8QYG/73899/449XdPh8vt7P/tcfKTvs/Xfb
hRl6woce3iEcit1BJ34/KXwfBswJBd3CDyDtWuz188JL0DG++/wrwhFInNOQ
cUnYhFOXQx8aE47C8NBE1JTwY+j821p/TzgGe7uyUjYeNbwc+aVNtU8Ir0C9
bfKmWXgljv2Sc6pROA7uzp55TcLxeD1Q9qNJOAERoyHbYoQTUZs9uC9NOAlr
E7YvflB4NU5MBXctFV4Dk+d4tFOcdy3MF5pN8cLr8HjYGyUfCz+FuvsrO6Y7
Da+Hfaw/LlH4aUQuWOzShDegcU3w7eWi/ww2pEd44oST0cfCk2LFeTbiperm
HyZEPwU/rxqKqhcGYgeWnWs3zIHhXVMTEP1URA698JU4L0+F+6+Z1D6Rp+Hb
ayPdNYZ5Gv68E2/RxHnSYTk7HH5a9NMRts7suCjyTTCn5/Z9LvJNmInbntQg
8gzMb7TsrBN5BvqCxhJm883o2+Ob/f7yzZg5SswyEfMJzTPx3RWaZ0H7leZZ
mLyUvX7giJFno6num4nWw0aejbMrn0znIs/ByFuHhr2GeQ6WzIvqCDLWsy1Y
WG/ZeUP0t2Dbu5WTH71p5LmICr4zfa/dyHMx2eK8+uFBI8/DzRW/vXbLWM/z
MHfQmqkZ65kZl0dP34juMHIzeuqmJ0MMs3wkf7nqueuin49Hv6D3L0DyOWIU
4Kd+Oo8CJH1ArBdg0Xu0X4i8XtovRMM7tF+I8pO0XwhHF+1b0H2I9i0IPUD7
Fny/l/YtuErNivBsC+0X4Tg1L8KiVtovwsvUrBiefbRfjK+peTHy99N+MQap
mRW3qWFFm3R+K8apdStebaP9ErRSowRnqHkJqg7SfglGqFkpkqX5lSKknfZL
oVPrpdhzmPbLsOAI7ZdhKTUvw2of7ZchTPp9leNFapQj9hjtl+MWfd96OZZJ
779CNiqwX+pX4H1qvQItb9O+DdHUsKGGmtswl1q3YRd9HrPDRg07LtDzcDss
9H66HVV0HqwSrZ20X4kr0vwq4afWK+V5s61ok+a/FeNSX7GumDkwX9rfgTpq
7kA9te7AQun8GuZQmzTlPpr8PE3DGen5GkZp36/BJc1LQyp1QJPnyZyyTU55
PZRccyKemjvl76PfKZ9HV/KA8nzmQqS0vwt3aR8ufEqtueTfA1fsV6wrDriU
+bthlebvhk/a3y1/3zS3fD+u2O/GRWl/xQG3fB/mQa+0v0fOoVhTzJW+X7Gu
rA945Psxr7K/Ynjl9ZoXzdL+ynq/V95P9yr3V8yqZJsUo0q5v2Ku2K/0dcWB
Kvl9sWrZJsVQrCnmiv3Vyv7VyvwVsxrZphp5vlCsKeaK/Yr1Gvn9BRSzWtmm
Wf8DCu18Cw==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1AtQVFUcBvCr5IO0Rk0b8dWylRGTD+ShKMIHysqKArvLwvK+u5ddEjQf
UUopXq2pMFHQZFkQW6rxAQ2UmGKQXmUszVFp1BRB2clEJ20GjZpyGqeaOqdz
DjM7zG++853/uefubKBjpdk5WJIk7e/PP//Jn5pZ5fF4Dhz/V/0xxYGKvopa
QvfdSRF11MNxIqQ0vJ56FML9j1maqcfi5cdPT/6IejxO9v4Re556Etq7Nt33
qyHWwd2zvGQWtR4xyifzF1I/h7eKPIbPaX8qGr8o3N1NHYTz3S1KPl0fDDhf
fKaK+iX42R47WkE9Hf1rV4TfoJ6JGW+Eyv3UIRihrGwxU8/CUxHRMSXUoTjb
1Kd0UIdhjT3gz++pw1FRFbrmKnUEGmz7aq5Qz8bGCweHDFDPgbfocpidOhLD
V/U44mqJ56J4inHuZ7uJ56HM1TnuInUU4g9cKUmg/flodaV2GKmjYZjj99t1
6hjoLz89KoruD/S2nB70O7EK7LdOvfZDHcljsc46PbuU5rG45Lve9jq9/zjY
H9wOnEisxiGsY/Chw9UkX4Bfv3ozah2xugDnQhzlepovxJH6i3WdbpIvxOg5
D5fdriJ5PCacb+vbs4vk8Sg2xO69QCwZsDHV/wV/mhuAm+u3jaT5IoSU7E0+
s5PkizB2bHH3rR0kT8DyjrDZ5ypJngCT59xKG7FkxLydbe6JtG/EqcIZoV3l
JF+MKG3oo1PE6mIEOXsnjHuf5InQt9Q9MW0ryRPhOtP6bcxmki+BRX824+ZG
ki/B9bbgCvVtki9F9P5hv/RtIPlS9NoTjpeuIHkSljx/pj1xNcmTULN3U8mH
LpIno2nxxJmTFZIn4059wE+Vq0ieAmP56HsHiZGC6OjZeZpM1qdg6ObxW0c4
/rOWgq6jpi0tZD/JhKBb+fvuvEL6JnzTWFyUZCd9E767XzLsR7KfZkKSsW2u
20D6ZlyNKtgxEEn6ZtTdujfNm036ZkzuD13kt530zThcW9kQRu/XguYh41dL
75K+Be2+Zc7GMtK3wN3aGVhN7l+z4FKZh/m9S0UHa6QicgtjNRV7WGup6GQt
WZGjt3R9XU/6VpjcseuPNJC+FVNijCcqDpG+FcFd18ZEfkr6aRjapHs08mPS
T0PXVnZ+GlaXs/PTELCNnZ+OAdZIx7HtbD8drgq2nw5Usn0b1B1s34bmnWzf
hk7Wmg2NH7D9DNxgjQy0s1YzMGoX28/Aa6ylTNxljUy8w1rNRI6b7Wfiag3b
z8KG3Ww/Cw9Yq1lorGP7WahlLWXz65ENjetnI4u1lo2H3PwcVNay/Ry0sFZz
sIq1liOcP5c3cjGTtZqLQR62n4uT7H1IeQhgjTx4Wat52M7dXx5WcH2Z308n
Y4DbT0ZhNWNZRgZrVebP55URy55fk2Fm7ZPxKvf8dt46O86y+8GOn1nLdnzJ
WhXstfP3p9mF+Xb+fJIDT3LzHXiPm+/AWm6+A1ZuvgP97H14HXiWe18OjGHt
E/qSwq/XKfx9QkEYN1+Bi5uv8OfzKujh5gv2KTjAzc/nc51g5PP3Kwu5Ktib
z78/Tch9giUnPNx8J38+OIX7F6w6hffvFOY7hfnCesnFWycYLv48smDVxc/z
uvjvjybYJ/SlAuH5C4TnL+D7smBVsFfYTxP28/2f/wU0izZf
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxVy1tIE1Acx/FppHvx8hC4TKvNMkmtZd7Ky37O6TanexC2qLyRjqAomdqk
NmxUsytNTWzLaebMC/WQIVpoZhkZXR4MxApTwlCTTMtlOKxleM6pDvz58+H7
P/wDhZkadw6Hk7A8fzZ9xn01Vqu17eGK5kT/m4OyHlVCBTMXR6M9H5mZfeHR
8EP812vQOmj55z8PrrX+I3rmAMxre8JszBuxWe352sksgPr5DZ87zJtQ3qVv
eMccjIGIaWEKcwgm/WyiRQv1VkQu8A09zGHImutTZDNvA1db2feGWYhUc7w1
nHkHdMWVvNmr1BEwG2TmV8w70c8vLshk95H4vq77gjfrUagQWIK21FBHIz9U
sWSvpo5Bjuleo7OKOhblH8MuL1ZQ78KT9rwgr/PUu5Hr7WieOUcdhwHHRS/u
Gep4xAocfsrj1AkobY27dkhPnYiOOhm3V0stgmTpw0wAM6Dp71B05xEbgZCX
410SKe1JkL1oEmpAexJWr3KPqQ2nXQx5UHx2py/tYgyVqHwCp1pJT0Zv0X6Z
a5TYmAzbWNYDZTvtEhQNe+T65NAuQfCzI0PCQNpTkPzV5TY+1UJ6CgR3hwd1
t4k5qSg7MVadw6c9FWpP5cmIW82kS+FmOWj2nr5JuhRPv71Vq9cTc2RICqn+
nK5oIl2GJYMxWlloJ12O9vzJ0UJpI+ly7C0JPjb0uIH0NPysa0uUL9STnoaq
06X22dxa0hUIFWvmiwQW0hWY2M4budRyhfR02KI6rp81mklfdqfg8CeHifQM
tH3xd+7J1pKegQJezP33vzJEK10J1QbJhEl3SvQbbj8xwQ==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxVzglQU0cAxvEgVMWxQmlkAKUgIEW8DeKF8CGIgARCIgkk5MCiYsqhgohI
4TkcVQriQcEEjQci4lEFb7QaQFsPGLSlHfFCarWoUevRWqBo7bC7nWbmTeY3
3/73vVELU8SLBvB4vNz3z7//9MfJy3Q6Xc35fv3u93/zYJ78RWsu82C46cf+
cY3ZGn3VB8tvMvPRmolPU5jtsMd+/22OeSRe5/h3NzE7I/xiw18FemoX/M3v
iiuooHaDjl9/5zKzO0rTqp/vZ+c9UFMZM82C7Z7wNgwtdGceB22cjj+ZeQI+
a6pOmsY8CaZnqZr/vmcy6iNzRrmxfQrOdq3S5rH3CVDfpklYzs57oef5paSc
rdRT8cT/+VGncmpvrL4bPkjPPA35EbWvNMzToUpeb1KXUc/AmZrpHmCeCdXj
w47r2PlZmOkVmxnO7IMZax0DTcyzMe7ku+NnWe+L+PYJGbWl1H74NvXm/ZHs
PPD6RGazgZoD0geVOBWz3R+zPU/Ws+/l/NE0dzsXxvY5ePLOdKWL3s/NgXD5
IWk2e18AbksjU8ezPQDxfGXgx5voHogU1Wjhqi10D4RA19O7le1zIfXV7BUW
0n0uXgxNPxxWTPcgxFn4FZ/ZQPcg3Ohx7ZxSRPd5KNzm3bKYmpsHs5jH0sa1
dA+G8iOHYy/W0D0YlkerMpKpeSG4X2SSCDLoHoL0CQmO2hy6h8LLwcU3lZoL
xZJuw1JtFt3nQzVc0PtmNd3nw1Dxi8E6k+5hyF20oVSZR/cwOJdcO+qTTXch
dh/80aaOvV+IHPWNbHd6Hy8cEz84HRuRSPdweNvb9cSl0D0Cwt4xyyq1dI/A
ua1pa+0X012ErM2RTiODiCHCobwhoX960/Mi3N6SVFTpSmwUoVjkIR/jSPtI
mNuGbNlmTftIBDYvLKmwo30kRlv14deX+0gfCavBV64ONBLzxMjLDqjrbCOG
GDUBUuWpFmJOjJ7ErFtHLtNejL57Q9o/30d7CUb4dJl4BtpLcOCtA05RcxIE
OZ49lNNKewn0r5bl1+6g/QL8tjJUP6+U9guws1N42r6c9u/3nlMWZTLaL8DV
0ceqdBa0j8KAwA7pxgfVpI9CSKO088BKYi4KNtdtJ2MnsTEKZuYtsnUFxDwp
Prk5dWCGkPZSBExasezwN3tJL8Wb1hF1Lq7ERimGWT/1jd9eRXoZElaaPIS2
xJBhZ96BWkHKHtLLYN3sYm/VXkl6GZ7aShRcMjEvGlcF1bPe2ewmfTSsxHyF
5YZdpI+Gde9PAlnBDtJHo8FM7699tY30MUjf02DuFrWd9DFYPOV82YMGYi4G
ot0vLmj45LwxBscjyqIOinSkl2NN9uxiZXo56eXI61iqET4j5uQokok65PJS
0stR8fXwe663NpJegYBVWsuq5V+RXoGwtsKC3vxc0isQZXNdrAlOI70CdT/c
8e8emEr6WDxy0O3oGJ9M+lioJ+abef3s7dffx+L7kPVjfWvk/TbGojugWVOs
X9pvnhKTRFKJr4+231DirUCZmtWXRHolio9oZ3oKg0mvxEVnn7utccmkV6Fm
RXPswwsJpFfB+WH8I6cTS0ivwv2xHzZ6XkgnvQo9wddWz/fkSK/Gd7sq01oa
iKHGdEPby0vVuaRXw04f13Tu/JekVyPxZMiwh8+KSK+BKLE9saW9pN/OGlhb
VqQ1GjeR+zR4k+MgcVds9vsH7YWZ+g==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd03tQVFUcB/AroImPNMfxWbaFUkNm+CR8rF9QEckH7LK8H3cXdllQMtR0
NJ25WuP4SFFMcAHxzihM1Kw2g1ha5C0gKfLVJOaAektLSaYoFP9Qp2zqnM75
OcM4n/ne7/mdc+7d51wrbe4ARVG6H//98z/7p6WV+ny+2tP/qnuubfTtnVXc
Cqw19wdUc/dH8/VwVwP3UDSNXeO9yD0cZ+ou3g0oZx6FnV/89Uoo99OI84X5
grgt6NxQv/YO7z+P8saHu1q4x6PhRM/ZUu5QBIXaQjZwv4iTE0Mq13CHwdGi
DJjOPRGfVbQO6cs9CUUJQS33DzCHY0i+f0c/nk/GljZXcSvPp6Bjx+qtq7in
IrhfdV4Af34aIkcFDZrLPR2ndo+xreSeAUd9pGsndwTqT+0d18n9Khr3bD7h
5vcRiT2xeQPP8Hwm7m0KM0dUMM/C0DttwyZzz0Zd7c+fDuT9OTgy0jo7ifet
mGIEnWznnotHwXWR43gfeOr3GRHbmDUgMD9wmI/nUQj399l8rJLlUfjWHnqu
h1mJxoXj+ksRPI/G7gUfTwypYvk8FMbHlozl+TwU9Ls5M4KvPx/d69sn+Nn+
tfl4+UKfZ2/w/S7A2uDR19bwfAG2j1xXX8/PG4Pht5rDg/j+Y1AXETPnAs8X
Yktc85Vw3l+IovAM222+fixSD7kGW3keC2x4s/oPni9CydavG75n1hbh/sOV
HXU8j0PXmKaSYp7HobPUXuPl+Ws4d7HbeFDG8sf+0Sf83hbj+HXB2mLYr4n5
EmzsEPMleHhFzJdi02UxX4qaS2K+DGHtfae/w75fbRn8UffWL2T7UeLRVyn/
qnf/f0Y8Cg4fPp3An4/HN2ev+XvZ/RjxaCi6sT2Yv78EXH698YfxzEjA0djf
at5j719LgDeyquIKs5GAOQ9u9bQdYX0bjka3lhXUsr4Ng4t73rpZzfo2/HT1
ic4Q9rxhw6WMD8f9UsP6dmDfKtvUD1jfjnUhx6+W8b4dZnVA1SNmw47YCV3W
8++zfiIq7350bhWfn4jONj1ZZfO0RGQl7rXGHWL9RHSUvjHobWbFgUDryY3n
meFAbfOsTYEHWd+BmK7Zgc8wGw7Y3xXfTxI+EY0k/CpaS8ID0UYSBu0S+8mw
ikYyikRryTgs2khG/91iPwW6aKTAXyz2U9C+R+ynoEu0korVe8V+KiBaS8UJ
0UYqekvEfhqO7RP7aZiyX+ynYUup2E/DJNFKOr4rE/vp8B8Q++lYWiH20zGq
Uuxn4E/RyMCOg2I/AzGijQzESf1MeT1kokmcp2VioDQ/E+t8Yj8LfUQjCyOk
/WdhsXg+IwuFopVsfCmdPxs3RGvZeEFcz8hGgWhFRapoiyrfH1QME/enquiW
9qfK6+kqPpfmqfL5TBUO6fxOhIi2ODFNug8naqX5Tnk9zQlXuTjfidWiDSee
FG06YROtuOS+hRguRIlWXWiV5hPrLnm/hgvbpPO75PMqOfJ9WoiRI59XJbmW
I6+nExs58vszc8j958r7teTCI91/rnw+lVgj1knfyCXzc8n53eT8bvn3Abe8
nuqGT5rvxilpvhsd0ny3vD+T5IpHzi0eeX14MF+a75H3p3nk71X3yPdrkOdN
D5mfR+YTg1gl1vLk9XRig9gkVryyLcTwkvnEGrHuld+HQWx65e9NySffX778
PEiu5pP3T6yT5w1ikzyvFMi2EKNA/v2qJNdIrpPcILlJcmU5mU8MYpVYI9aJ
jeXk/CRXVpD5K+TnsYKcn1gjfZ30DWKT9JVC2ZZCcn6Sq4XyehrJddI3iM3/
/TcZB2Jy
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw9yw0s1HEcx/FbD5StW4aelMe0aiI9KI7u46njnIc7psSIWzs7iy56kHJn
Eml5WCLlmZS0tqbtisRwUrMebrKJUVus6WGosHZRze/7/22//fba+/exjU+W
HVvC4/EC/93/Lx3NkZKysrLG9kVNCnUfbBeUnHlIkEz3JHBegYz0mbrfN8ir
MaAdc+Bz3RwpWvPMQq6vw3mlusKT6xuhVbQqh7huA6uZOc+lXLeDeu2xx/1c
34zp1t3aplLyFsjN/PWPSshbUTDfrdzAeTueqpct7SkmO0KaFzQbU0R2wvoI
o7nTnHdC4PjneQFnF+xJKb2sLyDvwppT/Gs7c8i7EVY0cK42m7wHpj1VhQqu
74U8pnPyQSbZFTvczidOnyXvg3K5pkegIu/HsyQp31ZBdoPgnTzDOZ7sjnVK
fkdJFFmAk/pGo8xosgdS8vsGL0SSPWEyYkh0iSAfQKNIVzpwiCxEamXF9cAQ
MjDo8l7oImbWAAHV1y96e1H3QnShdWSlK3UvDJlODEvsqHvDaPXK9mRr6t44
aniVkGZK3Qctii+Pxr/dZd0HbaMWC+06Zp4vVGd+veW3UfeFg0l+6eFO6n74
sZAhEtyn7ofvC7kdL8qpH8TYy1n3rnTqB9GyzVn6JpK6CFcfKitlW6mLkHx8
qDBt/g7r/sjTj3ada2XW+ENu2SS6EEs9AP3f7PTlFtQD0Gw8KJ/ob2BdDJvi
j1P1WmaNGD6fsyWKeOqBGClKHfvUd5v1QPhkmjZH2TLzJFDXuNUbautZlyBf
nD2e01vHehAMXnMrLH/Wsh6EtoCGVZOWzLxgaB3sp4ZVNawHwynH+GlOdTXr
IbDKOh23zLyK9RA4mhjqwi+Xsx6Km7wka3XLjUUjFLKV4vLcsBL2PxS6YreG
qHvXFt0Rioiv9s0euiK2l+K91my07OQVtpci/MmR+vETl9heitj9rcW9hzRs
L4Xd65G4P/0qtpdhsNt108QtOdvL0JYepdLYHBYu7mXobMxKerw3VfgX7nyB
iw==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1A1MlHUcB/BHMm3aGpotFpmX+RZLiwIiNfnK+zvHHffCHS/P3UG0Wsl0
jgm1/S2xJFAwQg7UzlFrjqWlxZxUPiZWzjpNjKVm4dvAjQrXhjrdelm7v9//
c9vt9tn3/32e/+//PLtH/ats1VGapu399/vfb+QjPB3BYHD3of81nvLlhdj4
NdIa0k6P/BWQvgf4xqm9JR2NvuVL1nmkZ6HusYTbqdIxSBns3xMv/TAGg+ui
D3dGbMEDY76Ts2U+F/PDl3K80vOwMan19wHpBZie8/3SPulFqEzyagnScbhW
c6y2XV7/CfRNP3xXlMyX4JP6m80bpJ9C7Zn61Zul4/Frct25Fumnse+D7oXN
0s/g8rWQ7875JODVN3dundQVcSJytwULXpR5EnoHriaPST+LcHucZ1w6GWcv
nXrtoPRzWFjYRc9jKToT2MuwKYa9HA/dCpKfxx/n2SuwzGCn4M8dbKChcNr6
9Mj+BTDq5HwlTj+yMerbiMVKWBbErDgm81TYbx090yP7qcieUvNzWOZpcIf2
18rzEWlIT5r58lR5Xuk4cvv1Hddlno7wWr2osTuSZyDm0An3+xGLDFxfnbhh
UOaZiJ4746eJ7ZE8E7OadpbflHkWWlrz1q+V/SykfcTzZeNKVurQYtnPxrRz
nOfg6ChZ5ODsCOe5mHKF81x0XuQ8Dz2/cZ6Hyfc3uS7L+fPxeUeD94acPx9D
SY0PNkb2oxUg/0aRMUfuvwDnqz9rWyznK8QbNUX9J2S/EKM/8v2LMPED378I
Gcc5t2LkOzKsiB3g9VY4viYbVrT1c78Ykw9wvxh79nO/GOG93C/GvF7u22B8
yH0bXPx+ChveDnLfhtkd3LdjrJX7duzaxH079rENO46wtRIsauJ+CaxPXp1h
3RXpl+AC50YJEt/hvgPRzdx34G/OhQMHODccuLeF+06MsOFED1s4EbeZ+05s
YWsu1G/hvgvjbOGCg8/HcKG4jftutLPhRttW7ruxim24cfJd7pei6j3ul0Ln
5yNKMcQ2SnFqG/c9aOjkvgcv8PMWHjy+nfse9Cr/X158wYYXmcr740U32/Bi
vtIvw0W+PspgsEUZJrq5b7JWjqlKvxyCc1GONqVfjlilX4E1XdyvgI0tKpCu
vP8VcLC1SnylnF8lPuXzFZX4mHOjEq8o568jjm3Rkc+Grq7XTRam9SEddyv3
0/ESe1jHTGX/PszheS0+dX74cB9b92G38n74UMcO+Uz/Fz4ksId9GOf9aH5M
4tziV88bfgzzet2v9oVfnSdksuFX9zfsx0Fl/oBqS0BdD5P1AILK/AH1PEIB
/KLcP4Djyv1N1qpUW0yGyXqVen1hcsi03jB5uEp9Plq1aku1Oh9M1k0WJodM
Nu74H85242s=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlHlUU9cWxm8p4khFRQrWarDWCgpGFEeUzwkQRSNzIEIYwpAgJISgdajX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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxVkH1M1GUAx0+KJYnLoVO4Yzcgjg6h4gARkZcvHHIvvNwdxx3BWCRB2ItB
p6jTzf242PEaYcTL7Qg4dnDk6WmoERXCH3loLARCtAKaljqpNl84zCZZjed5
tn7bb7999vl+nj37BRaVZZd48Hi8wn/f/7704fJbzWbzpyOrdDfp/8zDgZGg
0dOM1yKuvkJexHgDvNTjaScZb0JgSPrjg4x9EdLd+XMdY3/8PdWZ92c75QAc
8H5W0cY4CIl21fMWxsE4f+2Szsb6ECi/nbE9YizGEldRPMf2W/Hq967MRMbh
ePqX/eueYvuX0PFGzOPzbZQj8J1L4JhiLEHS+npDL+sj0XfbW+LP+ihUl7wj
tDKOxm+Thtgett8GP7+rFw6x82LgkzHbmsl4OzbP+XmWMo6FsO3dpjrW78BP
J2I4NeM4HBuen1pmvBNf5g+WPmAcDyXfKBYzTsBzigmri3Ei7hZUlrzGOAmV
Brklj90fcN+v2cv+FwcktgQMTrD7JcN/rPHUEN1zyXAatXxRK/UpGDNa6qPo
nkvBRteQ09hCvRTDA83vL31EvRSRXRbdYCP1qRh74H4ljzKXCmPQQvHntdTv
wv2wW4J8E/W7sNjT6Kuvoz4NMp0o+nAD9WkwL1/Y0MJRL4Pj42sTC0epl6H8
7W7Rtn3Uy2GUdjefMVAvh0DQV+tbRr0CHo57w01vUa9A3w5T4fHd1CuhbFgj
v0iZU6Iyyuk7m0p9OiJUYZHpEurTcaUvbO+dYOozcDrONKdZT30GZncOrx1Z
6Sc+E6nnmpZ8zhDmMrHFeGTLgJ36LIx6mgukR6jPguLGJ+HjFdSr0H5d7K0y
UK9C1/7+WU9Qr0ZCSEb50D37KkONUyctroWbhDk13PLP0GshPKrG5hFnymUH
YZ4GAeFxx987R3sNqlYeHZqpob0GsR0zPg+ttNegOmLNutd/7yN9NsZ3hw48
bCaMbNRuXPwwnk+Yy8aTUkfFF3t6SZ+NPwLVV0/8ZSO9FkLpHn7li4Shxbx9
Wnb7cg/ptQju8urvdVpJr0VN9eSQ6kk36XNgt33w9Vf5naTPged2zkNY3EH6
HCw7KwQ2iYX0Ofj17OQlr31m0usgjo0udJ9tJ70O7dPVoT+GtpBeh0B3vK1q
4hjpdWjgJx9NKK8jvR7ji6aC6W+qSK+HMvzlmusiI+n1yLpxs0xoPUh6PVYi
Lt5pExaRPhcloiu3Mn54M2m1z4UkbKvBS3Z4lblclD9j3/TCvCnpH51n554=

         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdk31M1HUcx3/QRMMsjGyE2g44ER0SoCDyoG+5AwSOh3vi6Xj43R0MZDp7
2HBZ5KW1OJBHL+TOSDAbUoONRvk04Fo+VAhsIFn6z5W11SxAZ61yzGrtPnx+
P7Ybe+39ff3en9/n9/uFWA7oqnwFQRj89/fff++fraTT6XT2j/1PC7uGzp33
qSAWcPvgw45XiFfgzEtpKi1xAK53X5lxED+Dr9tHHL8SB2E2obV+rcvL6+Be
WZ0zRrkC9pvXAh4Rh+L+3eqzo3ReiUt/LFOtIg5HXeifFg1xBDJqa1r7iDfj
3rngZBtxJA5POJOUxFFQZqoTv6e+aDxlDBj8kTgG9c/PjChPejkWFxqi/XcQ
b0X/Y1tqT9H1tmF1U42/ljgOVzYkbVpP5+NRVF0TNE75drxXp05VU56AzO6p
bj/Kd0CjqWpzESfiwtqPHVuIk+C3+vDdD2neZCQKLvb8UmC542S8E41XOe9C
aB9nwHmEsQ1wWXi+G7UpPN+NnNnf4yopT0Wba9+rEZSnYvK7PtsgzatCg+pI
pIlyFUbv/Hyro8ubq2G031g17mWbGkFhPm8svV9piHn2F6Mv+WkoTg0MzKI8
HRv9tqfdIz8djx/k82fgg7f4/Bm41s7zPXjYcrbrRcr3YPiv+SwV5Znw3Zbn
v5PyTExH3d+7nPIsfHldafWhPAsh74f1Le0nG8HvOMItlGdjXcZpeznlGkSM
HW/ppfk1ePTy+GQh5Tk4eovPn4Psm3z+XDTc4Hkukqd5nofYq/umgzu9eR5O
T/A8HzNfMUY+Ui7z6+Vj4XPG7nzEjXBfi+HPuK+Fdoj7WswOcF8LleT90+G1
Xu7rcPkk93XQv8t9HQZaua9Hr537ekQ0cl+PZs5uPZRN3DcgnTMMsHO2GTDH
2W3A28e4b8R5zjBifTP3jXiuhfsyFgrQyhkFmOT3ZytAVxv3C/Ck5P0tRGQH
9wvxCWdbIbKOc78QzZyFIsTy/aIIcw7uF2GCs7sIqfy8UIwQiV+MM53cL0br
Ce4XY4izUIIwJ/dLkB2ycc3r5Jfgb+um0kPkl0BUGvyWvg8TbhscpjryTeiO
DfTJJt+EqPpPCxa935fbhIlqyxeh5JdibPjit/T9oxSLLU1haeSXwj4a/yCJ
+ktxYPKj9jjyyzD5xNbFveSXYSJh+ZoY8suQdyKmMYr8MuzfPF9vJr8cT0vu
vxxNXXx/5fDhubtctr8KaDijQrpvWwX2S/ZfIfNFPOCsEDHA+yFiirMoooHP
YxNxkXOPiGgX7xOh4+yR5YJZmivM0hxm7OYsmvGbpN8snafHDA+f122W7tcj
ywULFjgrLNJ9Q8aiRXo9m4x7ZOfdFmmfR9YnWKXnFVbMrejc4Nfk7bfC94Xw
vGWHvP1WqH9aGT9l9/Zb8YN+/pvco95+K0IHL50Kf9Pbb5U+H4+MhUr0S/or
pTlkLMrYVolxyf3Lcrfs+p5K6fMSqqSskDGqpL5YBaekX8Y9S/wPek6+TQ==

         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxNzAlIk3EcxvGXqNQCtQsqVlmODrNMzSuPPdmmzrm1TRqoHVA5qYw8KJua
vIyULidhunQ506VmhgsszbIM0dJAE12lRlZW5uygJV0mduD//9ILLy9fPr/n
Xb77kDJ+GsMwsr/vvy992NjCoqKi6uap+iyYvcBUncI1g1s2ybWvXNtDvTT9
J1NM2xndNx0bRzmfD9e1vZo2rheCF1f03/95eJag0O7l2gVLFM6WKK5XQFVg
deJxzcepTJ00/TztlagNTd4h53w1rn9vHcni3A0HPOTxSzh3R9O+lsXb9bTX
o8XQ3ryRu9+ABsmsGSx374l3Q0MTFzj3gskzvc+7kLY3lhU+tunP0d6IsN51
v1PyaftgXoOD1essbV+87NoZo8qj7QfZh4bhVs79cWwyZP8MzgMgyLmRq86l
vQnxLtNTzSdpB2JbzdO3Nq6D0FCiX2s4TTsY0nZhjfoE7RDId5VmJmXRFqAq
83WjXxptoPvu/i/LNKRZwGfA44f1KPXNmPs2N3HVEeqbEThiKe9Kph6KsuAD
D0cTqYeio8IWZ1ZT34KhG06eh2Oob8EzvsrujoS6EP3GfDZATF2I1kg9E+5P
XYS+yAfrVRuoi1BXcafkFZ96GDwefbYMT1wmHobOk80Gcx9pJhyu9tKktjLq
4cjr9LVaD1KPgHZQpPEPoh6BCLPG0c6RuhjC2RoH03gVcTEeP/EVZd8mzUSC
zat3dhFSj0STY+xYhq2SuARG95QXigLSrARRKQkB0/jUo+DP5zV29FQQj8I4
axw8KCbNSPFp3J7PG7hEXIqdcQ/UE6WkGRm+udb0pxlMxGXIrDWzxr5y4ltR
99xZql1Emt2KCllH8qmIMuJyVFqOp/5SXZxqyOE2OPA+w1JC7uU4s7r35v0W
w1Tfk6PJq17ftqaY7BXIrbeXftTqyV4Bk6jYmPMmn+wVmPySXd4ffJbsFfDp
rYtJXHmG7JVo1PWc1rE5ZK+ErHhMJ3bXkr0SMzf1z1TqksheCe+x2nlVYRKy
j4bTnKshJ7JiBVP7aPjd23MleHqa4A9z0pJF
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxVzQ1M1GUAx/F/mRQyQUYE8nJwICQOA5H3gvvxcrxzHMcdxx0ChogixLsh
4PAQ0Xh/ueRFYwNDMEQIJi7A6kQpk5E5o6GEequcEAoErngJqvE8/63/9uy/
z77Pbw83Pk108FWGYVL/Pf/96aeQ1zU2Nn729YbmeP83g/w/pg/ksX4DaV2p
BlLW28C3Hs7UY/0mppTLiaasDaH5pL5UztoErTdy7DRZm6Pc13t6D2sLbHGs
3aVsoN6BAt1prjvbrRH7ml2IBuuduNa5+nMD613o4SkrjrG2xQjDKath/Q4m
318c1DpHbY+pGV7TI/a9PShqHjDrYO2AR2JJkTPrvUgxFkgq66kdUXRf5N9e
R+2EYfnj0/yPqZ2hJdqafl5J7YL41Z23vVi7YiI798tPaqndINRZ4BZWU7uj
JarnrWTW76Ld1WKUYe+/h2P9jPRAJbUHei+GXTFn7Ymbaz6ZnDJqHgz/Huf+
Wk4NaN3V3etQQqwA2g5dvXz/NO1eqCyK0yjOo90LXY49J9ypGW9894O23VIm
7d4w3JTyU2Eq7T74piHB8INY2n1gs9/B1CCGdl/kDcnzV0Jp90XgL/29PC/a
+VBl8dUKW9r5SDu30GfyNu1+8Cnoe2zMdj8Mnb8zuWpOuz+GlhLLztrQ7g/n
6SyLqxzaA/BCxySoU4/2AAjqxjqb1y6RHghOzuKE4imxIhC87Y7XdYZoD8LL
2ZG5k920B0GwnBM/oKQ9GAmzExH7KmgPhlAZH20tpT0E63bZC92HaQ9BXHvV
yVEe7aEY03tg6+9Meygygoa5I1a0C6Dt4vrb6x60C7Bm2ve8wZX2MOyTlcSt
GdEehtuVmk1hDO1CdBzJlpittm8YQphb7s54NkKsEGKyptTFr4JYJYRKkjS0
FEnMhMPqulv85udtZB+OMv0u65BWYkU44gq35BbwiFXh6F5/ZpzYdpHsRfhx
PVnNTSGGCNbetzo8JMQKEfQXb8YszbeSvQijDuNxO44SMxH4ykY2X2BJjAhI
VNUdAw2fkn0EFAEhGsOBxKoIqMdTaoPUF8hejEQnz/pKb2KI8RDO6csCYoUY
RoO2brozLWQvRm7t5BMHATEjQet6ib39ZmJIUGfFz5cZNZO9BLEzZctjhk1k
L0FAnUeSy71Gso9E/9NigxecerKPxEn+SoCpuI7sI5GhrrLvWjhL9pHonpv6
NusLYkaKmkNm8+alSrKXImbbYs1KRi3ZS1H1Z7PL71ZVZC/FlYPV0nst5WQf
Be1NZ1aDRsvIPgprcXmrzSsfkX0UooP/On70QhHZR8GyI8no86F8spchW3Zj
yjYph+xlONHvufvDw9FkL8Nx/rVT6lf8eBt7GTj6sb1WjpINM3JsfWl+KUGQ
vGHIwTkSqf1wMGvDCjnSHyxc/j4wj+zlkDndUjUZF5B9NPbfGW5s3l5E9tGY
NTS5m3qqmPcPFWksbA==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0g041fcCB/AzISl0q2EbDWPEelsXofhWXqNwHO8cf+fF8pJIhV50ysxa
Wy/ykkYdhTFdopdbXeXYtKbUU8qsdcvJKArpjdZa7r2P3++/u5/nOY/n83zP
9//9/f6YS9YI5RoCgaD7v5///aY/iojC4uLi6qZxDbvlxfzheoa3AB0bR7vO
8tZBz95j5RW8p2Lpbb/AJ/upZyDq34fsDvE2xsbVD2z0eJvgtrpsS0oRtRks
O07MCeJzC6Tna85I4G2JNOUpkQ7vD5FS0j5sx+/boPqrrsYpvG0R+8VeseMB
6o8wOanU3Jr3HBxruNC8hP/+PNiqKy5P4z0fWhW5SaX83sfoGH7k5s17AVak
lbSo+fP/HfdSouQufG4Pm5OdT/x5O0A72tv1Pf75jug2fxnVxecLYTBJ9A99
PndC1XavxGTeznAx3/y7K28XpOeUShp5L4JXjKFOKO/FSP22KHgDb1cYpPxQ
68zbDdZFZfb9vIFk97F8XWoFkKR+1ymEz5dAU1T85/+HYgnOS81+PsfnSyFc
pnG9ic+X4lyfR9BDPl+GiJysuaP0vopl+LKjSmuIv7879t/MnHyDvk+FO3JP
rnJ5lU9zD1gOTVwRUkBzD2iL44PT+NwT1sZjUkEezT3xNKFNr3Qnzb1QW3x1
bNrnNPfC58+rPQyyae4NWfnrN2G5NPfGjvVJi3V30NwHRgOtlkpqhQ+etkTc
vcU/fzm8ztvdydxM8+XIPO5wf3QrzX1RecfhoYBa4Ys+0+cL5Wtp7gfn6Jit
hhk090OdY3SXbSbNV6Dhe+cbJck0XwGjhXX62WtovhKBg6Hr+/l8JZIcsrOs
+L4/TmhffGjG7/vjg5e//dbN3z8AumlrTtXGESMA3iXt0mMc/X4A+mcZNdtG
EKsC4JwwEixYQvuB6FZtTX7mR/uBsNZ6cObtANoPxOzGKe/rudN+ICwea/Zy
/rQvhO8U52MNoH0hrIoeRWIB7QtxoXdQ1a5P+0LYRWgGiIaqSD8IS31rCjY3
EyMIjfG7O1dVEyuC0MyFprruJFYFoXRT2MX21bQvgqLkSmtuOu2LUBNVcCUo
kfZF8LhbVthSRPsi2Hy0IMGggfaD8Vb4SOVGLXr+YEy/8Z3rtuu0Hwyroy/u
O06i5w/GnuRJF5se0X4IVla+ffDWG7ofgiuG9YN50+n9Q6C8f+PFCL2vKgRX
bTo27B6l/VC0dlqG1mrQ/VCcOm3e5HiF7ofC0Cj++xxNuh8KU9/JiW1G9P2H
IVVofmhqH90Pwx+Xm5tMK2g/DI/NSg7q/Ej3w2DYYlNcfYvuhyM/SVyeqqT9
cNhprRNnddF+OD7dd66gMoX2w7HoHc8Zggm0H4FzUsk/vSbSfgRmmGXGdyR+
Q/oRuOW16rLlWWJVBJzscwJPJxALIvFZuWVyqR4xInHpQuO/Tr2pJP1IrO1x
a1m2nVgVib91PrS+dpRYEIVf526NnmlM+1GQqassrO/TfhQ2z+rz9/6G9qOQ
/6KiLnCQ9qOB31/1Guyh/WgIc/X69L+g549G7qSbW+wv0fNHQ+9rR5Pr2+j5
xdDU/On2cSXti9F4zeLOT0G0L4ZG9dCr+QraFyNX3Jp9r5Tux+DAOzHWxb60
H4Pruy5rXNpC+zFwaLrqUzFG+zGoGwjKfP8B3efQ1BDg8V4fsRmHL6Xbu6vn
0L8Hh5lphTX9qSTnOFx9alEovEffDweTHJ+aiLeIlRwMfhletx8VZI/D5OyC
udN/PTJuNYf+fvvoFh9iQSwiezNG0747TPZj0R2vq9NmWE72YzFm1OP1KoqY
i4Xj0IKXs+vpfizWjtyp8ZhG92ORqB12TfiaPF8Vix1VvrVxu8vIfizSF92c
nTVFSfYlaFhnsstq3yGyL4Fx4vPDgz9/TfYlWH/w5LOGuwfJvgT79k7Vm7ef
5ArGSgnaO7pb0rVKyb4EvQY5i+ufHSD7EjjNfZIxdLyE7Esxa/6ZrIxeYjMp
esNELyrT6b4Usl3QndlG+pwUo9syCjadLCD7UgQ/bqtz2ZNP9qX4oP7l/LXd
xCopOtdVmPRsyiP7UmyIC8x9N20n2ZfBsTo9a+zEZ2RfBs+kieeHilaTfRnq
fxE9qjG1JfsyeG8yHhl5InIb35dBEu69S7w8nuzLIDyd5pcXnUz2ZYj54cPw
sxPEZF+GH40XHa3x8BrvC+RY+XGr+IT+p+M2k6NX4lcYWF84bsgx4GSqZbf3
wLg5OYav5WhsOaok+3Ks/ir3gWZP2biVciRMaO9z33h43Co5Agbmadt1Hxm3
Wo78gSNWR06Xk/04FH3rWWD3uoLsMwZjjrEiDhn/byWTqxirGQs+YfYZgzHH
WMFYyVjFWP3JX88rWPVXmzEGY46xgrGSsYqxmrEgntlnDMYcYwVjJWMVY3U8
8/4TmPfPGIy5BGafsZKxirGasSCRuT9jMOYYKxgrGasYqxkLkpj9P/0fW5ye
yw==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw9jglUjWkchz+yVCaTU1HhTJksJUmlCN3f1a5F3bZb99669zZ2BiFScceg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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdkgtsU1UYxy8Ts2XGSWTIGBi7Zxwwx9Y5FGT7F9ZtbbfRdn0/1peI2XQL
ZhkQMbmIyl7yqpSVDTdAHARxw2xK8FUEFJ1RHrE6wFIRswVMJC4kSEZ8xNzD
d26Tm+aX//md7zvfORn+ZuOqBEEQ3vn3++9f+omOUDgcPvT5/3SzjGcByQnv
dX3IOAkZ248lbWY8A0HdXyWVjFOR9FJ6YQPjNNRXL9xypVviecjcO/PC7N0S
KzBt5nDvA4wz8XrK+PX7GWdjfEH/bRvbLxeJxw58msz4cbQU9JB+5+NoFuWF
iI2OtK5j/ARa/u5r/IbxIlQc6ShXsXqF6Ch7sTTEuAgHX9C2LuiRWInO7II7
BsbFWL/qyg70Svwkrs+++ruWcQk+OF2pXcPqLcaPY5PTF7H9n4LyWntjFeOn
MaHQ52QyXoLBR7blNTNeipRL84rVbL9ncFj/Z46e8TJ0/XTkXHSXxKVwzfU9
v5lxGfoOvrrpIbYeMO+/L9gksQiUrJ48+zG7LxValuSUGqX6ogp7p/IvdrPz
L4euLfFcSGJxOYxtG/6YYvkK3EqLvLtGmoe4ArGNQmLBHikvx9B2ocnK8nLk
9b2ydD/z1Vh3bVbGEKuvxrcn4us1bB4VSDVd2pTK8gqk/TxyeoydrxJZ+8L3
3oNYCfMXhIUqtI7RvAq3J2iuQWic5hr88hvNtbh7leZa/BqnuQ4DMZrroLlM
82o8eJHm1TgVpXkNvr9A8xoIq1VD37H51OJEeuyrCTb/WtQ0NI/fYvlKrB2l
/ko8eobur8drJwlDj6LP6Ho9DhwnHNFjYIT6BiQMU9+Ayfepb4DlMPUNEAao
b0QxvR8YkddLfSOqd1HfiPNbqF+HsS7q1+FkO/XrYApmDW6Q3n+kDmc7qG9C
eyf1TSik+4kmfE05YkL0TeqboaP9wIwhyqIZuVupb4Z5G/UtSN5BfQsSg9S3
wEk5YsEnb1HfimzKsCJGWbTixk7qWxENUd8GPWXY4KbzFm3o7Ka+DXd2U9+O
GbU/eGwvS74dWWvPNDe4Jd+O9I35U0Gj5NvRmD8cv6GUfAdMylz7oEHyHUhW
T59TlCD5Dry9J7qsXCP5DnypfEP9UZPkO3Gqh/bvxFzKohM7ab8RJ6aFaf8u
9NLzwcWfV3ThYbo+4sJROh/BjfmU4ebfq+jGHO79urGV8+txnvNlLNbDzs2/
HospCx7Euf49eI72K3pwnOvfg8vc+b3w0/koZAwZe71IoSzK8n4vjNy8vVBR
jnvxGPd+fLhL+1H4+P7gQ5iy1wczdz4fiin3+3CTm5ePv++4LBf8fK7w8/cN
P7/eK2PRL6vvl83bz58nLmMhwLNCxgjw+3lluRjAKFc/gENcfRnHA2jj6j/L
z1chY8jYe4//AdHAk3g=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd03tMW1UcB/DLlA0zhoRsSCJi3XAPAgaB8lAGXygDRgdrS0tLgfa2peAc
k4xoCBr1JjOZUAeDMaAMWRMN25RkM9EYn7vIRqLgIyqizMXqnI4lEP9ZzHj4
irlnv3NIGvLJ93zP75ze24e8rRb/OkmSPvz3899/7U9xDgSDwXMX/9cfhYf+
TNXFD2uWMLPw8JONzFGIMX8wcB9zLJ7tnsjNYt4M5+G/k9uYEzDuWLq9gzkR
ieGqe9OZdRifm8rpPqV5K9Zvbl/8geXJuBn3XdNulm/HdNKvcbdYvhPvlJ7V
pTGnwN/SkXyaORXuSxkJPcyP4I3RlSfeYvulw2RL8lmZH0XU75Gdd86XgQTj
FvOFIc2ZmI5rvXuKrc+CxXn14C5mPVLGPn+mgjkbpyYWRtKYc9DuKl+cHNSc
i8OHvilbO6k5D/oNBX9tZPMeg7QYrath+eN4frLFGt+vOR/ZNwY3GU9o3o1t
qx1x9/doLoDf3dZ347jmQjydORafxXLg9rEvyw5ofQV4IMrec5PtX4RCT37n
JpYXITf5nsBGlhej+RNDzLvafZRipBztuvz6gJYbEHnApctjuQHy8tLsLLtf
CVKv6APXWV6C3q4YzLL77oF0Oq11oE/L9+D83K28Jc1SKfqf29C7zPJSVBpS
X5tkeRmWjFP5bdp5lDIkpv02LbPzlcN015aXVtj8chx86sWxrex8exH8rGoo
RrOyF+djHbGr7PlVwLtm6E9n+1fgyLUg+T0ZEfiZWDGiOCNibJ69X/ugv0rz
fZibp/1KfPQ9zSthnKN5FdZ9S/MqzH9F8/1YnqH5fiRtP3K9gM034c0pksOE
qkt0vQk/TRCrJsgX6f5mHH2P9s1ofpv2zfBfoH0zfOO0b8HqGdq3oHGU9i3Y
FqR9C64cp/1qfPoK7VdjspP2q7G+i/arsZNasmKUGlboA7RvRSe1asUMtWRD
NTffhjPUig0r1KoN0cdovwaXqVGDiW7ar0FtD+3XIJO7vx1f0Bx2RNBcsaO/
l/btmOyjfQfyTtC+A6PUigPD/bTvQAe1VIvoAdqvxbVB2q/FjiHar8XH1JIT
lmHad6KIWnEib4T2nch+lfbr8AvNUYcWaqUOCVy/Dgt0f6mef79Qj3J6PkWw
Wo947vwNSKH3RQNe4O7fgB5qtQEhasmFSLofXML358LXXN+FADffjRGu70YO
d3434rjfjxsl1JKMJmqdjBjuechIp5Zl4fnIeJA6JKxXZazR/cOCJQ8/T+fh
+/Dw62UPFqkVYX3Iw59HFRz24H1uvhc27v5eZHHvg2DZiwhuvuCQYNXLv19h
L/99Sz60c/N9OMfN9+FHbr6PP78irA8JVgWHhb7UiGlufiM/D4JlYb0iOCRY
FRwW9pP8vHV+/nwQLAtW/ML9BauCw34EuflNfK5rwsvc/CZ+vSxYERwS9lOF
PCxYauatEwzB8h3/Az7XHck=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw9y38s1HEcx/Fv/CFtLT9SEaWbZJd++lnUvUh3ft25Oz+yTAr9lFTU1Fku
6lK0Q5FrYiUl/WDGZKmzSk2xJWOYqaSlNKmZpdbP9Xl/vttn3z32fL8Wxaeo
t5sIgiD/+/796dNuLjYYDDeM/zUuubW42rmBW4A8Z+7kfu7pUD8bMFZzW+Dp
55I2J+7ZcK9YKI3inocPnbAs5bZHtEOdsZzbEe4Fvkd7S8gi7JnwUC7hdkJM
YVSHmNsZZV933FzB7YII+zPe57jFMA9PQzO3K6a6FrQXci+HpfWP2vEL5JXY
llgvGeZehf5Ozzj/YvJqDDoOJMQUkd2QFZnU5srtjgjbqDffC8keSI37kL1P
T/ZEY0NrlraA7AVR9Jtp8fzeGw7pKV3f8slrEPxEqejj+7Ww6cxUt54l++BM
oka1Ppfsi24T6z43HXkdxFqZZf0J8nosNwoyn+NkCey8TtY3ZpIBh5B0efwR
Zi0wZnFaouf3fkgemt/omU3dD9J4x5+Chro/6pYKbsHHqPujaUhzqY4sbMCd
raJ0/3TqGzAe5t0+nEo9AO6GW74P0qgH4NBIVvPJA9Q3YtWnmrHeZOobsaXi
yBDCqUsRdV+07LySuhSmrgazGQHUZTg4HJOnE1OXQd+fZapwoR6IX7a+k3st
qAdijqTqYsZEFetBcFtyLlU/zKwNwlxD0OLcSurB+CX83J19kXowXrt0W3mk
UA+BcaD2kcyPegiK0vxGWz9eZz0U4rKXqoxiZm0o7sfm54lCqctx9Pmobt3d
a6zLYUh4vCvjALOgwArF4Jc6J+oK7CyxOq4brWQ9DEll93K26Zi1YWgYa/od
13OVdSX63i18Wz6LGUrsPbRvVsbIFXavRP0Lk2RzG+YWJeSijvIa58tsr8KC
HvXDfudytldBk+tlFTtVyvYq+NhEilpsDWyvwtvozveRXkVsr4byVeztzMwC
tldj7czfpY2Fp9hejZtmeju55jDbq1EQ1GO66ZRE8n8fjoopac6I1THJHzfv
gH4=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxFkQ9MlGUcx19zliWu3HBdenlgDZHQRI5Egbsvx58DDhHun6hcwW26YxdD
FmMqGa+UEKnsTHyVAxyngMDE6qwINylDQHHnTZQdDM3Af4gycJq1ga5az/Pr
3d69++zz+zzP875voDVfv/UlQRC2/HP/++SXuFmqrq5u+fk/mlLvOZd1x0ks
oKEjZnUv8Vyorzfc9xK/gU/HF84MEvvjua0ropNYhgsalV8lsRxW3aKuPuIA
2Jq73ppPvBRDCpvgT/wuPF6Z/+vEQdj4WX9VNnEwxss7VW8Sh+BjVebLOuJQ
CGhVhBOvRFTpaNjoUc6rIAaazS3EYfgpenHegyOcV2PB1OeKpeTDMVw0/EBJ
6ykRvquxspd8BA5Mag+eJf4AfvNHSr4hXoO95auk32n9SDiKBrrryK9F+7LQ
9mLy6xAy8zC/nzgK4ysOJtZLnKOxMyn4mJ36GGSfKSsy0bwKT9qutF6leTXu
TIu5EjHwilPIiuS9CCjaF1X8//6xKCuxe2XkYzHm6RReUK/BYlVAVBJnUYNu
X7bdcpj7OHjrKvIGOItxCBw1jqiruI9HyK+FLwo4i/FIcQ0G9ZFPQOvIlPWv
Q9wnIOLo7YRMOl8iLgXdzL1B+ydC6XPuTqb/o0Vy7TxtE51fi44fC/QO+l5J
8E6WTz3i82IShC98+7Y6uU9G7NDj4Wnqk3H5anGRlfZPgXrj9eBPaP8U/HDR
82EHnV+HryZq+sr4vKhDj89/2TX+PkIq3tlVPVHo4D4VvkDZheOchfWoqgwu
2FzB/XpI2TeyNu3hPg2DA+0Xhd3cp6HufskWpZ37Dfj+9tdqi4H7DWg6/Vta
vYX7dLy2ZMX7p5SMkY7SHXs1p2L4fDpSZlwRE/GMf0mHZ1LmOBbK+wzcSr37
xPismfUZaJbPseY4GIsZOJ/j7pGenmR9BkrnzkmM8zAW9KgVunrvlTCGHrNL
X43+YzZjUY8/h/ZdOfllE+v1sNjatje6G1lvgGfsxLTcjzEMWPisavlKWwPr
Ddi05HzogocnWG9Af5n87ZsqxoIRg+daci99d5z1Rky7WtzaEBfrjZC21eRn
htWz3gh3zb1Z8e461ptw+vAsS/d7TtaboJNvC3+UI7HehP324rFvFYdYb0JH
4TWl+ch+1ptxy9CzJu9sMevNCHC1Pa1dHsl6Mz6aOfNc0uxU/w2Ywt3l
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxN0g1MzHEcx/FbE5K5RJtVUqRCrEQqcp9Od3U96O4qrJOHNkkPK0RM00XN
w5BJ6UjWCEWEsuap8xxr0ZXWmpOHUJGraabEML/f1/+2/26vve/z/23//znF
parXmYlEomV/rr/f/KONKdTpdOV1/9QnWaXVvNWQRXhsfJWYRx6NwTazmi1k
K+gLPqm9yBNhMLw0f0qeBGl9RZzjcW57vM9672hN3RET3l42WpCnovXTDYeZ
ZGfEFo68OoXsggJ75+1XyG548sPnTmkR90w0b11vOk52h33V8leF5Dk48Saw
ooTsgWlDIyRpZE+MGevYfoM8F6fMY3pW0nleqJ38wvsCeR46JaL2ZvJ8JD9T
RXfR3hseLu5ie+oL8MDXydaK7INdYsmXRrIvvBrqfDPIfqirjbW4TV4I51nF
z4PpeS7CjIEcl//vxx85to/UZeTFWNx763s3WQLjwwF3NzJQIo6Nt+HWAmvd
Dpo8qQego+Llfn9+njYA8tT7y2V0vhQnB4r+/3+0UiiEFi1BdbldgxP1JWja
YdZvSz0QKfts1Ef489IGYlxL4M7BY7zLsMVPJ7i/DN/DBRbJoVot7HIMV6xJ
/0g9CB211zN6qAehMimtv5d6MDRlwn0wXO4K769ARIewKzC2S9hD0PBB2EPQ
0insodj9TthDUR9gqvl1lPcwWG4+bGjk1oZh/wZJUmYe7+HILoh7E7OP93CY
+hbJpx7ifSmKZLO8c7N5X4qQTEOirZb3CIz/2f8k9wDvEZApk2dM2cm7Etlf
8884ZTJDiWdlVh+nx/PfK9Gwu2bUFz9mvRItPnpP8QS+V0GWfs1YZcn3Ktil
OrcZOs+zvQqf02v7h/cy61VIObK2PCeBWaTGtxUbpOkjmaFGfaW4Nb/9HNur
UWqe0eowhlmvRmrp05iEyrNsHwl5c2V2UnUZ20ei6Z5VlvXr02wfiYsD1V1B
l0rZPhJ5rlkeDppTbB+FGlffm8VDOraPgn+u0TLxXT7bR2F1d+fGtEl5bB+F
15rZ0W3F29g+Gn2b9gzF94ZJ/u2jIU1U9IWaDkh+A+xIxlg=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxVzg1M1HUcx/Fb1kAahAlZRAiX3o4TjIMDeRDuA3fA3YlwzyRQuxhFbT6k
kUEQHiGIVpyoeHAeYD6FytJC3BQQhgGzBy0LdMwNbknCRCQasFjYw/h9f7P/
9t9/r71/n/9+Qbnb9G8+IRAIXvv3/e9LjzXrcH19/emuRU3J/28Bau49bnf8
Zbc/Zm+4d5VNnuH2gbM/euwB9/Nw3pyp8neQ/VEZayoVcgdicu+OWy5+Xohp
n0uSMO5VGD9p0A5wi/CJl1PTwi2GubTzJx9uCWQdorytdeQQtPUK9xi412Lu
1SNlzdxhKEwoTLMdJkuhuT//UMQdjstnc36/e4gcgczBPuMktwyftR8cLq8l
R2JwOFT0Nu9R2HR0+KaL93UIXyh3ye3kaLRkPx06yB2DkdOrpfP8frHY1viz
6Bp3HL7bJd6i4F6P/t/qOnr4Ph5uHg/CPfj9EzD765mddw6Q5bg69l5ws40M
RJy9MDpUzWwFEkM7p+X7qSfC98a5pe68J8LN7f2OpZ9ST4K45hdZHv3PmoTb
RX7xjgrqCmj6x6e9yFYFjC/m2C7vpq5Eg6st6AcrdSUWPpRsf6OYejJM5R94
Br5DPRmJHdMDq/Kop6DsXExv41vUU1DdY/TzsVBPxbV7laXPGqmnYovw6tCp
ROoqVB9T3lfGUlfhmSXft0yqqKvRP5Fq6FlHXY2mlj8mLEnUNWj9s880p6au
wYmmWxnDCuobMKfPz6hYQ30DzvtN+LYvoZ6G/EeGAtVIM+tp8PLMnK28wizY
iFFpieKFQeobkZITGLm+nXo6jjzVbOv7ino6xiW3l3+8l3oGul6ZGIvJop6B
YJvr7yA1dS2Uszd0UwHM0OJLx6aA4jg6r0XefmPqRRlztxZPtj73cN5Cex1E
tQez2lfQXoeugc2OBE/a65C++bokYuELttfhgvhb1ZoiZoEe9h0Vl47HMUOP
5eqVAfkjp9hej/IVP4Z572Lu1qPtSlH0+bmTbG/A607xkKWEGQZ0xhdOfV7A
bDWgdiZ7bfLuE2xvgLl2LPdOFLPAiKHehoJY8XG2N2JlYPRMhd8xtjci6pBP
VU32UbY3onUq8uXgR41sb0KNbHuOLbeJ7U1oDZF6W5Y52d6Ej1Z3Z7rfrWN7
E3oySnxDrh9gezNEo/adQo99bG/GRclLW/2dxWxvhqrNos+MV8sX92Z8baly
mMveXbQgE3u+WdYgVVTI/wG4A9xG
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxNkAlMk2cch+sRQTGKjkOZREDZAXNFKnelP4tQsBwtPSyFGQWPgS7I0eGx
aIeDrhQJFIFWEQXLAB3abWzuEuoymTrFORIGcwqbOtnw4FCcI8pceN9XvqT5
8uT5P+//6+uZmpm4aSqHw8l+/vv/TR+tutJsNje1TdCgYM0dp6EXzAHm1lat
Y2yPOkPVpHlH8KNPenzK2AntF0yT/AKMrNDEGhkvQtv6gRtljD1wqfEsr46x
FzqCZTFWxkthvnnQpGD8CoZdTjwJZ/waVBs7+XGMfeBgagpyY/wG+sa9XV6c
/ya4Y01hDYz9EG878GMu4+V4sPqLdBljf+R3PXHpZsxD5UuG8s5DlFfg/rYr
62MZB6BoU4nD9oOUA3Ht1AelvswHwWdq+6pwxsEwvSt3HGTzIVgQcWNaL9sX
CrdlByfdZxhcC6JbOxjzEcK7ZbFn/UpEHdr1t4VxOGb6VmoeMBYg7+5JV1RT
BrYF3rV//TBhLcDt/bz5L+ZXYU5R9tGLlLWrUN4v3T/KvBB2AVnjGtYLYf26
Ln20hvoIlKnn9bceoT4Crq29S39g/WpsudEqrGbnr8bNmuG9bux+IvFNTkJG
Lv1+bSTuPPpTtIf9nyi0umzv96f3oY1Ce9X8AXEV9SI4JwYs/PkA9SLUqG82
6yuojwZ/o6fvcnZ+NKQ60fWwSupjkFugS5tFWRuDkr7HMcPl1K+B/GHwfUMZ
9WvgarNF+hioF+OILstq/z71YhjP6D4e2UF9LM7N9b7lkU19LPb2xHhuSqc+
Dgc6Axdefpv6ONQvaYzUZVIfj+WZ+45WUdbGw6ntlzPzmU/AWNOlccNW6hMw
qOl0XpdPvQRL26R9erofEkgKZkS/k0LnJVgYcXXRmJCwTYKhzp2FYSLaS/HZ
zFOyp/60l8I7x0s/3YP2UviLz1ud/2kkvRTDznf6DfcIcxJxrfA8nzeb9omY
kTc+/clt4rWJkPEqvvV9TPtEyPM/KQ1wp/tlyH81y6vQkfYynAy9Ejk6SnsZ
9Is3bllcSnsZ3H8afeqTSvfLobjOLZjd3UB6OZ4VG5fsTyaslWOri+tXog2E
bXKsDBS3zBv4iPQK8P0GRszvEYYCU4wtUms4Ya0C9q47uaLT9aRXoHU6j/us
z0J6Jb5Lumx3OpswlFDMOF4S9/AY6ZWoz6ku2WAhbFOCa+yW9wpovxbD3h1t
8VHEYy0sx8csO76vI/1aDLadO1vsRdj2fH7zrIwP02pJr8KuMTe/+uajpFdh
j2YP74J3NelVuNokuJeZYSa9Crt3tegNzSbSJ2HO7+WLijdXkD4JqbKGfyXH
ykifhItRXUpOTzHpk+B+68FtO6Ge9GoIdSGmga4i0qvR80cpr6t2H+nVcFLF
Tyn8VUt6NfJ+O3J/WhBhTjI0X4YeVs7JJX0yxFnWE6cc0kifjJawucuCHolI
n4wii253+hKNYKJPQX3mtrd8NfoJRgpezu4eevbUKPgPNmRPug==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw9zQ0w1Hkcx/HNFXqkZy5iKbTpSVGe8sGSpRbL7nrYxVRypKOZHFajrTxM
IUQeiki5ck1ubuaSrmjrypSu02Vr4uJ0XYV0heJ60F03ft//f+Y//3nN5//+
/fibEyTROjweb//n9/8vPeqwkvLy8ror43rtZlU+NXUnZx68lfaZKs76WPxN
qkU8Z0NEVarm7uM8B8ckg3mHORth5gfZ6GbOJph7UXH3DGdzdAw4TB4pI1vA
xLtDP4PbF6GDZz+Yye1WsNQvt20qIdvA/uQE8/NHyAKMDAn+6OV2W7hoFUYF
nJdDe6dSICwmr8RAT6ODXiF5FexXlzmv52wH6bXdqtoC8mo4RPYdsMkjr8GF
t677BDlkewxWtmgGc8kOyDyRuqT5AHkt3g+7yiZlk9fhYsvS2XEZZEfkTzGX
ue8jOyF27jHBq/1kZxTEGwut95JdsCj2t69tufNcUTp8v/4Id9568Ctytzty
vRvePGr8cXsmGUhMPD5fnM6sBt4/rYrbnkq7O6Y/NpPeIavd0Z5eq+1Mot0D
cTa7Zjkl0u6BetXPw3vjafdEks8O4YIY2j1hXNRldS+KdiECW5eVLpbSLkRv
zBsdsYR2L1gPzz+0w4t2LyztHPkywZt2b2iVtQkDLrR7o69n58sm0L4BAd1H
9B840r4B4ubpF9M8afeBUcyWrx4vod0HYe5/xTY40C6C6pzuWke6Ty2Co0X2
PIkf7b4w8Y8J3eZKuy/4d59VveDu98NLvYM/LLSn3Q+6ZnFLr62kfSPmH7Je
scqW9o2IvyVMTjGmfROcH0q6+TNo34S2G2uM2ibRLkbdiznv0ofOsF2MpJR1
acJ7zDx/fMgzNDbspd0f1+6mtYm0tAfg93acjetiRgAeGi3a8KmN/g+Ak1fi
aFkHsyYAHzx0J441Ux+Ingpe2Kuj1Aciujp5iqeS+kCIOvujrydQH4h+rUGZ
s5h6CVySVvEq5lEvgeWp0eaogdOslyDa/XpVbhOzRoLnXc89bt5n5gVBJQyf
de4AM4JgMfSgJSyH+iC0Xpl9I3YH9UEYEplWDm2lPhg+/oKyw1XUByM1Qso3
S6E+GEWV7UWHlNQHI7+tqz09gXopasaaOrYdp16KWy1ihV0+9VK0VS6/LY+k
XoryigV7ugyol+Hqd8JpRn9/y3oZegqsajv/ZVbLcPt8SUNdF7NGhnciU/6K
adTLYRpU0rAimno59JaIx8y+p16OTfKtW2+mUC/Hg0bPj+a7mXkhyL5c+LQ0
v5b1IdAurC/uX8isDkGda05D608nWR+CmJ7R9lMTmXmhkF1+7VRdzIxQhPp5
6W1JrmF9KPrOj24+LWLWhEKcnLutbiYzLwy3tFmmD2eeYH0YeF8or3sfrWZ9
GHoNU8L7JzJrPjvDp2ujuIr14ZBlHLXZ1V/J+nAIJaWWqjsVrA9HqeGzWON6
tmvC4X4idmjN6mOsV+Cg9mVzt5wZCriuT23VzSljvQIGib8u7rYsZ70CLiZu
WQguYb0SNe7ef9Y8KWK9EjMWNH40mFzIeiV801okquI81itxrnDZHn5IFusj
UDWnU2A3O4P1EXhyoe+S48o01kdAa+F0SWOtZn0E3s4zLht5lMT6SATHOaSO
TZCxPhJTI9VWI9nRbuN9JCasDXwbqiMftyYSibPsWnWaksbNi8KTq7nVlyZn
jds8Ci3dhp86zxaMG1H4x9y/3/eXIrf/AI/pmjI=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxF0XtMlWUAx/E3KIFFh8tBy5B5CZwyCLnG1fMTAZHrOZwrAWUBUVIYCnXE
MU4gl7gfiMMl9MgBER1K0DnuCDYYBOrsMCskh+jKoJECA6t/GFA2nufx3d69
++z7/va827vz/WMJ6WYcx6U+u/9/0kv1tqa5ufni4IaWBBMq3/x2Zg7KB9ss
tMyWWC/l5S4w26Ksv9H1KrMDpp2OjOUwv4YAJ+us596GV5saR95g3gEv5WpH
CPMuiOeuJPGZnbHlttbzShP1brjY8xq6mffA6h+7lFRmVwzqNv3rwewGtVOW
LqaR+k2c1dxcMDHvwx0Jl7GiofbE+iPDPXe298LoSe/lAGZvzNZkeI4w+8AY
qB/SsO/1xc2CxNG7rPsh17psWcf8FmLvZKt+YOf544bj5PhZ5gA8sRtvrGHf
F4jH55Jez2EOgs9ibnUPczDy+39fU7RQh2DYeVLz/H/sh8nyaZgfswB7l8ul
rzADn2o/39ROz1cB9oaFmdYG2g9gV2/lt/N1tB/AUvBY8OV62kPx9RHbgjQ1
7aGw1/onxVNzB/GjuICfWUP7QWy9n1eUV017GEp4O2Kty2kPg8m2ZsaijPZw
dCq6A3+tpD0cD7uUwuRa2iNQfbLplG0V7RGodDnft0zf5w7h1sx4RFcF7Ycg
CPtgz4sltEfi0iPLUYtC2iPh8ZX5rHsu7YdRlekTvZZP+2E8ued6oeNj2qNg
WlzpcniP9igEG/0cU+S0R2OnYaxuifVoyIf5I0VC2mOguy45USihPQZG7XSR
IYL2WGxufaHiKH1fFYsio+8vsz60x8Es1vrMZ3za48Cbeydjajvt8ciutYuq
sKI9Hu0r3M+FP3WRLoRy1Nxmi44YQsR/5N/iUUysEuJxS+ixP/cTDwmR3qc/
PuFO9yKUlm13+0RM9yIYTH846ucvkL0IbX2nY0KqiIdE6On+bto7h5hLwNrm
W7UBVsRIgLm9tG7uWifZJyCoObnb4jfioWcOCltsUxJzYvBTXYxtT8+TvRjd
f4XLrnYRq8TI4o33+a13kL0Y3wgMJdHmxJwExqWt+hiNjuwluNRwrT47iVgl
QbH84ap6uI3sJeClCz0H9OfIXorvi5XzIw5aspci5e767XcTW8leikDTh6eT
T7SQvRRRR9VjvWoN2csQN/Hy/cTBBrKXIe/4l/s8JPVkL8Ne+5fc+mvVZC/D
yMUosX6yiuzl8FIM9pZnlpC9HNdtOjU3SvPIXo7yywPC1s4UspfD2SZlKC1S
JNjYKzAVsDy1anFqw1CgV9bzwFX9xYZVCqT9vTZgNKsQ/AcHY/2p
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxVjw001Wccx29qit2dvHSUXkjJVEookeKLLuF6ufdyL/dVXlosmpatQv6F
YlQiioaKvKyWsanUyu3ddGq2inKIUlqvs012RmrteJ7nnD3nPOc5n/N5Pr/n
PBYR68XROjweL/X9/u+ki5MXFhUV1TSNUr/b/5mHpu5NWzYwnoB7fNGWJMYG
iEosGd7HeBLG+qDPmfEUeDxP0wgZT4fDsyW2toxnwkDnZWjrAcqzkFEcU7qU
eUuUnH7sVMe8FWKFenoBzFsjK0z3+gDz8xA/dnHVB8zboLJKMcGc8UII+d+8
NmP3F8HyM782GWM7FJ0fPvVqP2V7hGfrNzozdoBZr7quuZDyYjzcPGnwa8ZL
8Kwvsy2ygLIjNg2173qaT3kpjB8niKuYd8L5gR/Cu5l3RuuHvTtN9lFeBuXy
bt6DPMou+PvbGYf+YLwcASM/+zmyeSvwu29PdwtjV5SdNe40Y/PcoPS7drOL
9UB+pMXj8fR9DjgbmZyqz+67I9LzzNxfKXPuiHLZmPCUeQ/M2BPb4816D5wx
4eJnsv94ovqtua3BHuo9YVUxx4XLon4l3A3eTK3Lpn4lWuutSjtzqBfAW2vi
2JpKvQD2gTbVMenUeyHiZO/Hb5n3guphmWp2EvXeiKtNLz62jnpvpBeXLdKJ
oX4Vms3lHvUy6lfhvmJj5xN/6n3QKfk+5T5lzgfuV+P+Ggyj3he7C2UTs4Ko
98WOYzYTX3lR7wfLI3PvLl5GvR9uHmgZ2TqPeiEyTTuPRxtRL4SLV0pNuiH1
/njeJJmjfVdNvD/WVFxC45+EeQGIyFWduPmU+gDcGZq8c2E/9YGY4ul4t/E6
9YG49MIvRdRIfRBuWDfdOE49gtAw0DDlMvVcEO43j9NOziSsDcIFhUP/kXTa
i2DbZv+yopT2IuiKVqoFubQX4Zhhm8g8n/YihMaPW3DvK9qLkTFBp8xqNu3F
yDHJ4YRvqkgvxkKR6e6D3YS1YhwJrDzLDRLmScCPmxaoa0d7CU5qRpKNh2gv
gatgvar/HO0lcKpKimrOon0wNl+oXp2aTRjByLSzEGYb0T4YRsYCyytPKkkf
jFxp4mrresK8EByOKS3PjCaMEFxU6O/t2EKYC4FpRXL4bRvah8C5QJG0+tlR
0ksxfKtcavcR7aXQK6lc+6CJeE4KrVHf/ORewlopLJymjvz0qIL0Mlwev25c
4BzCkKH2u6jkQyLCnAztDQL3gjGEtTLkWQRIX84vJ30oyq8kLov95TDpQ9Gi
U3uxOO4Q6UORglMP+KpS0odiR9KK9oQ0wrwwvFXNvjNrHWGEIeSFMHrT4EHS
h8HmhMOTDaIi0ofB0NS/Zpo+YZ4c7u0ZfC9NIenlMK7rmzfyKJ/0731DfZcl
fy/p5ShxPRfRsyaX9AoE2UZlL/gih/QKiP+5Ftu2O4P0CnQNVViXOu0gvQLB
Zw4IWpK2kV6JLqOjrYavt5Jeie1zi44KbNJIr4TvO73J0k8+J70SrVszf3R1
/pL0KqyVD4TvjUwgvQpiYc1QXo+a9CoMJ94+vqtD7Tbaq9DhmGhWcCF+lHlq
OEV3pJ54njrKUGPtjVv2v8m3jzKnRm2cs8TndAbp1Zi+3/xT5eldpNdgf/jD
6qXpeaTX4OoY3eXd/H2k1+BUk6/GXl3g9i9CbIrG
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlHlMFVcUxi9G6tJQrVqlgOXZgFJLxSrK5vKBiICK8FgeO+ODx2MTiEur
1ZapCIIrLQo+0DqWKJoYRau2iqETE7UuxFrT1LjUiaQaba3UpTU01aZp7nXu
ef+8/PKd737nnjkzY+wVVkc/xtgQN8b+++c/NbPJ5XLt+/Z/6p0pM4NPV2N8
leCB2Kc2m/ShOJ/iPa5D8AiEuV06+KVgTwxWYx1eLZx9cDL3whR3wRa8agu+
tVLUv42rTUED1wn2wzXf5rB6wWPx1R6fxbmCAxBeOuSdZYLH48dHa9x1wYGw
P7hSvVjwBPi2HrizQvBE+P/VYrrP+2i7a+ZJaPjm+cADgifDa3PtxZf+YByK
9AuZLngKArrGBm4RPBUB9ebzQlC0xMyhCIuaFPFkG+cwxIVd/MjZxDkcR0bd
cnwi9AjEnK558Z7wT8Omu+2rZwl9OpJXHu//tJnzDGyMa1jnLepnIqOzof2M
qAcq6k/dj+a6Chh7+z2HqI+E1f7BbafQI/Hkrfn5w4QehcDfW04FCT0KnUtW
LD8mzp8Ft8IB13t4P+osnLq6/HE/0V80/HaH3i7ayvVo7A3d3z2okeuzMdIj
+qYfn4c6G7UdO9w7xHxisN5r9TImzo/B7Y6GX+/z89gceL+ZcfTWFq7PQVOP
j2YR/lhcOnImPVzkxyLpsWcn4/UsDq4B/s2HNnE9Dk/Cdi+v58zisfPosN4N
67kej9i6rJ8PVHN9Lp5FrjgfwFmdi8FlD6aVreH6PDTeO23/qZbr83Cw6o+m
xiquz8fShBfWpLVcn4/4w4uqPeu5noBVq1oTBn3K9QT4erkFx6tcX4CJa3Of
Bwl9AdI3v3Hs9Y+5noiIsxXp43k9ElH7qH14Hc9XE3F+6W7fRp6vJ2L03XL7
kRruT8JvA2rKq3g/SMLl0KkPLtdxfxI2vvDtq9nA/UnocYxS87jOrNgfaHt2
Yx33WxHb7VHQI+ZpRVv/ct8FfN66Fa+0neuMEfuRjOPn+iIn7OD+ZHQHJXW1
iH1JBk66etu5rifDM8f2Qx9nloKQpndjrmzn/hR8Pcjqhi+4PwUPi69PLm7j
/hT0eey9GbKH+1PxcFnJqOid3J+Ko7+Mc29u5f5U5Mx4NOPELu5PxeHheVP+
EflpONHgevk9QBqufmZiNQ3en5tYT8NhMzMbRmwx+22I2mr225DYZPbb0O1f
fs0hnl86PL77e5t/Bfenwzule1dKOfenIyv83p3RJdyfjhtjcp52i/3MgG2H
OT8DG7eb8zPwZ6s5PwP3Wsz9Z+KsmZEJXzOrmVhjZj0TLpfZn4VgMyMLxjaz
Pwu9ZtazEGJmlo31Zka2XK9mY6Tkz0ZEs9mfg0NmRg7cJX8OuiR/DlKl/nNR
J/WfiwtmVnNhl+6fi9ek+eUhUppfHm5I/jzsM7OeR/IVmS0KCqV+FLiZWSGs
KvjQzJqCE1KeIucbitwfWyizhTAIK4TVhfK8tIUkn7BB/MxO8u3yebDLfsUu
30clrJF6negGOZ/ly7oln+wDYYWwSljLl98PnegGYVYg11sK5H5AdIWwWkDy
iV8nukGYOUi+g9yf6ArRVaJrDpJP2CD1rJDMv5DkF5J8oquENVKvEzYIMye5
v5PkO+X+FMIq8WtOsn9Oeb8NJ9m/IpkthEFYIawS1gjrhI0iuT9WTPKLyf4R
XSGsFsvnaUTXiW4QnZWQfMIoIe9/CZk/Ya1Efn56CXn+RGelMlsIo5Q8/1K5
H5WwRur1UpJPmJWRfMIoI/tPWCWsEdbLyPtHdLaI7D9hLCLfP8IqqdcI64QN
wqyc3L+c5BNWSL1KWCP1OmGD1LMK8v2pIPMnulJB5k90jeg6YYMwq5TzhhK2
EJ5IGJXyeYmVpF9SX0l0lfgbSL1GuIPU64S/J2y85H8BEfoXoA==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdk31MVXUYx4+yZsxyrBkZkF58qSZYYCJoKV9eVBQE7uX1wr3cc1/gLiOx
mJPhxDOHmooigi+X1ytgCGxG/REzKw8L5kssrFRmy3VbKzemDTFbYctq7Tx7
fr+z3Z199n2+z/f5Ped3I10VltKZiqJc+Pf339t4tKITPp+v9+L/NJk4w/6j
5V1iBWnWYS2H+En8/fG5a63EIXh22XjbHeK5GI8LLd/abPA8XP98LL6rxeAI
2N4eeKuHdBOmQmsnuklfiNMf+epaWg1ejNyh0TWfkf4idqd0d20nfhlzltwY
ukP1S1G1veFqEXE0wmoO/zVB9a+g2H92/jXiGIS1LUsaofpYJCx8sDWG9OU4
2jT94TDN+xoGXur1fkvnXYHy8xPX+4njsG6wKvN34pUIr/wm9BFxPEw1kbW3
iROwwNGyM0C8ClnDGYN3iVej5JajZhbx62hfHdvgIH4D8yJti4po3jWo6Nij
9hCvxaXomuQ44kREJET1xhID7sczoquN82nAxNV3rsymfSRh9/i+qCajXktC
9ehNzzbSk3GgyfvLaJuhJ+PEq7ef6Sc9Bd2L9v8UTnoK/ii3/7mP9pmKe8ra
kL3UPxVBsyNuVJJ/HaKCnourMVhbh7GxSyeDaf71mKw64w3Q/Osx8OvID0+T
vgHLd/WWrfUb+gakB1/u07sNPQ2Nre7x+Z2Gnob7MUferzdY2Yj6aYtX6TL0
jUgPtT0wG+dRNmEscnRuNM23CYPBd/sTaf50JJ4+ftBJejrq4kf6wtoNPQMz
qzO3TNB8Gfi0OXDzqQ5D34yz5x52PCL/ZlQ1nO+8T/5MrFxS/rOd9puJfdd8
7P+chelRxloW0q5yPRuNlxkjG1+P8PpsVH7BWM/Gnovcb8aaC9xvxtAg95ux
f4D7zajr434LUnq434JdZ7jfgrJO7regNLM6fDftJwdXjnN/Dk4d5f4cTB3k
/hw8PMDzc7GK68hFO2ctF4sPcX8uvJyVPDzmjDzsreP+PNzirOfhhcPcnw+V
M/LhP8L9+XiznvvzkcZZKcBXnFGAHcL5C2Bu4P4CNHFWClFxjPsLMdXI/YUI
4fvVC/EdZ8WK+FPcb0VSM/dbsa2F+62YauX+InzAGUVoaeN+iXWJlWIEcUax
2E8rRjtnvRizhHybOB9saOCs2VDLz6Pb8L2P++3I4ww7Mk5yvx3Pc9btCOX7
UkqwlOsoEeu1EjzB63WpXnGI9XCgXvA7xO+jO2AV8lX8xutNqjgfVDFfleo1
FVu47ldxSMhTsZNzQEVAyHdiEd+fySnuF07M4ftXnYgR7pcTLs5+JxYI38uJ
L3m/gNRfcaFXyHfhnpDvgkXId0n5LvG++yXWXVK+Cz4h3y3luzFDyHeL+1Ld
mOSsSeyX/LobK4R8N1KFfA92CPkeUYdHnE/1iPvTPOL5/BLrHnwi5Eu6Uiqy
SWJIrJaK/TSJ/aXivLqkB6R+SpmUXybdP0lXJdYk9pdJ+WV4T8iXWPGKbJIY
Xrov/wDkrCZx
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxFkAtY0/Ueh5eUEISiiNwKUBARsRS5C+wzQJD7GAhjwNjGBi5uIYIBBQMS
XHgguSNGXLyQFMURNQFliZTmLRVPgkecR+gJTxdKLmpoeZ79fv+z5+HZ8z7v
9/19eLZKksmTLWKxWP988fe/b/pRCOqbmpo+HdTQNDswPuDVfIZZ4Kd0vv9/
rwN3eagPh2ED6H1+8dgvjZRXoMv7U0UNwyZYVRpf5cDw6/i4eWHIgmEr3Lk+
UxzaQHk1spd6shsZtsHrht2tX9dTtkVV/tr9ZQzbgX/o2u505t4eqS+9Ev4W
ww6I77YIjmf4Tdgth/02Zn8jvk1pD59k3tuEGedMQRzjHXFLb3HGboY3w+ge
+6Q7854TqierPDYx3hnPPJuL9Jn3XFA4O9lyp5ayK3I471f11FF2Q9drgg0f
VlN2h8H9Wt8B5t4DwzY3RtfVUN6CG2dFypGPKHvCf8HOsHcfZS+YDYQNnlNS
9sZMz1XT5QyzcWH8o3BVKWXg2Y/yvD/2ElYArj0bHpQz9xz02Z9/MkLvFRzw
9fkXzIqo90FohaPBlXzqfbDCbKjlAGWWLxA6XzjGeF+MXpc73S2h3g8XFlfM
21JW+OGh7EutD/Ko34q0nPxbl7Kp3wo5b7+8oYB6f1h6NuUGMu/7o3zeZ2g8
jfoAnG2K0Hm+m/oAXHGLXUjJoH4b9O4bfsam94pt6Bg8JvGKoz4QZ50etfcL
qQ9E1tfJkWwJ9UHQvnLuyEwg9UGYK9adWMqmPhi3A/qrv/eiPhi21cs4O9ZT
H4KTj9d3O26kPgT1Zk+CR5yoD4W5xZZeN1vqQ/FN5UFf5RLqw3AjLHDJ9PNO
4sNgnRyo94ku9eEIUFfqmrBoH46J8u7UPqbnovkDp7YTOoTBxch/Nt13+JW+
x0Wf5bKau8uIV3HRn/7oi/C1tI9AlOiYVsBm2kdAaJdjk+JH9yIwdj6Re8GV
9hEwte0NDHajPQ+tDk/VId605+HylOSnOXqv4MGoejbkZhjteQh6uGlmNoD2
kXCqW1U6F0H7SDyNSR5b70v7SNgsirxcxqN9JBKkF39YcKF9FGyv/fbLUhva
R+FHt/m6Svr/KKIgbxS7qi1oH4WRAwPFBrPk92Ftx5zY1trMnPbb8Upj7cPL
avr7bcc0eyN/ySPCqu2QOh4OWfwD7aMR4tHsOV5KGNF4a29yt3sd7aPxfeSh
J1of0j4ancHONqGHaB+DkjaOsqqb9jEonBPOZ7FpHwPflqxei4O0j0GWjos+
J432fAS9/a6xMI/2fIRbrW2QcWnPx90TK1Ne8qA9H5ci743qzR0lfSzmN5o5
7J4gjFgMFJ533HqPsCIWIudLbiWnCatiYXz1195/jdJeAKmlx57TzbQXYP+p
k1EOXUdIL4DlKc9n8mDCKgFc5jydyw8QZsXBcd1XBbWzh0kfB5+Kd7eYcgkr
4qBsZx1pL+sgfRw2d+e8N/RHG+njkX6l7CZ7DWHEw2vOLpO7iLAiHqqcy8Vl
P7eSPh7DoU2nbjcQZiXAa8ZsLuhRC+kT8KDvcYGR0UHSJyDvzM7sAttm0ifA
dEo33Xwf8SwhPILv9/687wDphRjnufgdHyf3CiFeVr4xNnWqifRCBPq3y/5r
Qe5ZiTiepJ97dLqW9IlIrm7Tk39RR/pEsBrv7Tr0dD/pE/H2RV6ztn816UUY
e9M7d7izUsNWIghWLn7jyDhhiGCgs8Kpy7pCwyIRjIpczKNLy8j7IkQNp6X1
Zys13CpC82SDF39sL9kTYbCjyPXVYYWG1SLkJnFmp4QlZF+Mw8umPZySi8i+
GLMRf4m2paaTfTHsx9d9dtyRR/bFOLdq+WblpICt2X/B1w17Ms1TNNwqhu76
li03e3dpWCWGyQZBRudglobVYojemxQ8RZGGWRJwIuyHfBQ7NWwlgT13pf7q
snwNQwJerst3/yhJ1bBIgsLvbtY8GCb3Cgm4C/92L2/PI/sSNDrdadNml5J9
Cd7ha99Rae0l+xLMHHR7vCSknOwnYSC3uzg/s5LsJ6GgS3WjV1lN9l/4Ft1v
/tpZQ/aT8PknfWfEa+rJfhKyjUWSmYgGsp8E7VFV9K36RrKfBImX3+zQAPHq
JFz1KW16EkU8S4qfTNZMTPcTbyXFNd0dQz3hzWRfiqVfZtjskhIWSaGc8K1u
0Gsh+1Kk8ISlDac/JvtSHLXbc5J/lXiVFCb2O7RP/EZYLYVOyPM975wjzJKB
0xnvbe3QSvZlyHgt3TC3gnjIMGgilo5qES+SIUDOLzzzO2GFDMbfGnT8qUe4
VQbDfalTD7mEVTJYW/7esbqUsFoG0xlTb8GfhFnJMM6/ZSc2ayP7yRB23t5h
mNDG/huOQn6h
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlAtMlWUYxz/wVqbuyDRhSQFKRIYzhcLM+HM/IODhcD/cvsNNaWWj2Jra
2LeGGwHKHeR2OK5wWFo5gUxZfLNJIBll0phSO0SUszACU2mLLqv39Xnfs52d
/fZ/fs/zvs93zvHMecWc76woSvc/738/2UuzNDY3N5/o/49mgrzX/ZRXzlnB
9LWR/X6cH0DlvLEokrMBi+erb23nvAZ7rk8O3jnK2BURsbZH/DmvR9joBz9/
3sTYA3NTpavMPPdCuLVg0XnOG9Ez33W3h/Pj+Mzo8pcrn/cE6p3eC/yF509i
KnZzwE6eP4XugPPjvXzeZuyYcVz3bmS8BVc2WQ32esZPw3tJ0UE3nm/F6pnW
1b/zfBtqkrOmb3H2hzHQUevL6wPw0EXf4ZYGxs8gNGb803N1jJ/FXLD7+k7O
gWjdN38ygvfbDk/3/roVvN9zmBioKIng/XbgUO3Je8c4P4+Pth33Suf+Thye
GOk9wPu/gOgFS8BBngfBZ8GU28f7Azcmv0wZq/2fNcB5bdw1vxqWB2Psj8WN
A4y1YJiX9byTd4TlIRgIc7lwqpzlIZgtC7l3rILlobhsbzIEV7E8FPZ1biEv
8/OEwWewwDuUsRaGTR+XGgPZeZRwdDiGBx/lfjgWhsYO/crvF4HiyqE9vJ8W
gUtnJn87w88XiaLBN2/Y+f0iUXr7jmma78+IwpL4pV0tLDfC1/nVsi3tLI/C
w28sLT7LWItCYfTyb5w7WB6N9uOGS7N2lkfjq72LOvy4vwun8cPGgTaW74Li
edPRzfMYeGUV7vNh/bQY+C0/0OFkY3ksRifOrplrZXksli5cXnaV9VPi4GKL
+aKH1WtxWNG2dq8/778bnS3Gm8V8/m489klQRhX3TVg52Hz/9w8TXrpIWDOh
qynq6tdsP7oJaj/JlXjM9lE/HjbKWjz8egnr8Vh5mvpmvH2K+mZ0dFLfjDwb
9c1IaqZ+AkprqJ+Abyuon4Cpt6ifgPfLqZ+IAFqPRBgqqZ+IIcp6ItwPUz8J
dykjCbePUD8JxirqJ6GgmvrJiBfOn4zvRuurY9n/mZaMqVrqJ6Pmxw9b695l
fgr211M/BYYGOj8FnpT1FGylrKTiwSbqp6LtKPVTcYXmeiqchP2noYwy0uDa
Rv009LVTPw0plBULvqf1sMAm+BZEU9YtyG6lfjqCW6ifjgbKWjpKKesSKxl4
TfAl1jIkPwNmwc/EKsHPRDPdh5Yp1uuZcBH2lwUj3Tey4CPsPwtuwv6zUEJZ
ycYF4fllY5Kyli3207OxhLKi4kXKHipGhPOo2EDPq6oYF+6n4k/KdlV8Hroq
3t8h1StWvE7ZQ2JIrFrF/WlWzNDz2qV63YoTlB1WDAvzc0T2kBgSqzk4J8yX
crvEeo64L4fESq40X2LkivPUXPE+Wq74fbNLuS6xQ6pX8sTfr0eemENiVWJN
YrvEusQOiZV8kT0khsSqxJrEdol1iR354n2VAun+EqNAmn+f/wYjIfuh
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw9yw1Q03Ucx/E/UAnzRIp4sMNz0oAc3kiHQ8XYZzxsONnco7e8VpkSYhJd
EOcZ6D8ayoNE+ADOZDVjpNyhXYuOrBMNIx/yOuVBD43hA3U6Mg3KJXRWx+/7
/9397neve/8+818rNuUHcxxn++/+/9Lh1zY5nc4j3dO6p6xPuF1rFsyh5Jbo
J7vgUFwd3RSmEByBQO+apyabyU9j4LDeVic4FnXSuYq4/eQ4JO+QdPmbyGI8
uWD2BrHwPx6JYcUfawVLMOwdV57bR05ExlTQvNl7yc8hujAp6lAjWYoDpqL8
HxrIC3HJ2RJ/WrAMxSNF1t315OcxZ8ajXEUdeRG2ynrxYzV5MZqTu7hvashy
vHdbPLRjJzkVVZ7vFEsEL8GbD2PKL1SSFXhwR1ce4SCnIUbx1cDRKvJSuNur
/+wW+jJ4C5PV/m3k5biiuldkFpyOs67Lo4vLyCuQwtlDd75DfgEiSz5/rISc
Ad+FAat0M1kJWeT7vmzBQPmdqZ/bbMw8MHHEres0U1fBWNrl15N5FVr7lntO
66hnQvKor/UxFfVMSF3jUT3LqGfhYmPbFqRSz4JxeG3+BynUs/FEbbRO/iz1
bGy4ui5RHk49BxH9Id+PTR5mPQfrYxepz15j5tT40JN65e9fqKux5lbf5VAf
dQ2caS+PfN5DXYOpqr4v4shcLlIKNLKeL6nnwlVwTBPuob4S13MSXnFUUF+J
Nw5WnKzZSF2LodKyl66nUNfCV93+z183PmN9FSpC4lq8e5j5VdjOL9CfKaWe
B69CUzWRTj0PWaZyR9mNNtZ1GE7/dpZ3FzOvg89ZNTFzKXU9Ut2xD9aNe1jX
Iy14zqkOFzO3Gu6OyH5/EPXVOL+r7JJ0XyvrBuTJx1Rzez+dNgyIFmn2GxTM
vAHZsnPbmwcPTfukAdj8anB4wM32RgS0QYWz7Mww4nj/mfpNMz9heyP2DL7l
nVzvYnsjCpoGAwUxB9nehG2SmqGQPw6wvQmlJz46flfrZHsT7v7W8atc08z2
Jrw7uqJyq6iJ7c1ovHmidv79vWxvxnj3QtvrLbvZ3gzx7/MMWf4GtjfDFv+1
vZOrZ3sLHjc1TLZ31LC9BZn9R9UZCQ62t0B0vjIwlsSzvQVJIfzIqYtb2N4K
i/OZaofqbba3ItKe09na8iLbW3FfHDaDe7hROb234qYpKUpyrUT5L7UgvGo=

         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlH9M1GUcx7/Z2BJYI+bINskDgwEzByFCqPDm+P3j+HH8Ojg47idYhNdC
QFxc3xTlhwoKChyUYHPCzfXzj2og+RVkaARIJbJF7aqNPKdIzlmJa9nqeXie
722322uv5/15Ps/n+3zPz2hVW9YJgvDJk++/v+QjFnfZ7XbHpf9oJfaOrXJo
kLKAh7Ufut+i/AyszYOqyF7CXvj1vMPSTf0GWHzzpvspb8RPQYbaNb8Je745
G2ClrEDT/FxHB2V/3JgXTzVRfgnD5h9SfSkHYtvxllJFD+EgrLsyPrLaTTgE
nRm9l9Op34pEnx8XJcrbsNDfp66nHAqny780hnIYdiSYdlVQfgWmpeSgFymH
I/acQ2yhvB17bqV9+TPdPwI92hPtfZR3wGU7vO9SF+FIfKBzbEo5TTgKF92j
6wOofxVbq+Z7p04Rjsbo4w2eXnT9TvzyV+Pt1U7CuxBYtTw2StfvRuP6mKMf
UR+DxkBbnusk4VgIbQtjy+2EgaXbj+6db/ufReDOgOei+TjxcSiY2tCxQH0c
3JJUofGEBSWuR4VfLTlGvBKuT73aKlqJj4c2XTfb2EJ8PMzTb/ocPEh8AmaW
2/7WEBYT8Efu5CEj9YnQhQVcHasnPhGOm5bXxbeJT0Lwy3+qPn6H+CR83lP7
XOoh4pOxWTN2/WYj8cloveK/1HCE+BTYAs1eyibiU1BY/lrIuXeJT8W0ZlA5
2UB8KkT72S2rtH4aWh7a7I9E4tMQ0R089EY18ekYVgY0BR8gPh1xEV9XG2uI
z0Clr1Vz8S3iM1Dm7TFRU0u8Ch6LmarQOuJVGLMNe1tof5kYuTfbPU7PnwlH
1NxMBZ1fFqT1y77hpF8xC5Gf9TdXHiY+GystIdoVMk9kY+6AwbuTsJiN/dF7
kyZJ/1I2Kv06VL9XkXwOPELcH8dYST4HQ6PuLk96nhzcuPbd0CypJ+XA7bfc
oZ3keQpq3Hc8cClJf1DDTbnv7gi5v6Ia1omlmr3k/ZDUyH5h9XnQ+50Lv9P2
tf8v5OLCUYbFXHzfwrCUC6Fzonycvm95ONPK5vNwn2UxD/vZelIeRlgW8hF2
jM3nP/l/YvP5yGJZykdVG5svwGWWUYCidjZfgBmWpQLUnWDzhfBnGYVoYlks
hPEkmy/E7g42r8E4y9DgTCeb1+AaO19JgyMsC0Xw7GLzRbB1s/kilNvZfBEa
e9l8MRreY/PFuPA+my/G0yxLxdjIrhe0yOxj81p8wdYXtdjMsqRFHduPUIJF
llGCB1z/JfDpYfMlcGNZKMW37HqUIoTLl/LzkEr5+oIOT3H76+Bk64s6fMXt
r0Mz138ZnmXPhzJMsV4sQzV3/jKEcvPXI45lhV42Dz1fX6/HXa6+HnaWB/T8
fCUZO/VI4Po3wJtlhUE2DwMcLOsNfD1R5gcMsvtmQD63vwEr3PMz8qww8vOH
jPVGvl/RiO3c/ka+f0lW3yljwSQ7v4k/H2Reb+L3E03Ywu1v4s8rydY7ZfUE
M59XmPn1kLHezD8/0czflwEzf/8kmXfKvGDhvcLCe1gwzO1v4e+baOHfhwGZ
l2TsXON/AM5z1sQ=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxFz3lI02Ecx/GfDrLTtDKtGVtSZmKSzqvLfaZzh8fE6LCFYOqUSufMaYeW
+8O0qFDBY1sWOS0zqETTP0SciaUkQSoWSZERy8wRC/KgMCt8nqcHHh5evB+e
L8/WtNyDGmeO4yL/7n8nXQZ1rclkarEuySE2uVmdHjNzEFy+EDLMvBzDN/w/
3mJ2Q3ja3EwS8wY0CAsGnzJ7gT8vsB9l9oaP7ERhmZFaiN6LIuElZh/Et/Q5
LHXU2xDAz7tSwuyLU4uSLAe774ecY1/fqZn9MTZtrf1cSx2Al28L9IeYA2F/
82qiq5p6Nyrkw9XaGuogtGWl12cyB+OF1fX3//si/NLosm2shyCsx1a+jr0f
is3a4JAdzGF47btFoGIOR7hS1lHM/hOBm2lJlVrW98C2PnfNAJu3F6K2WR6P
zdsHW8Vk11wl9X64BulHk69RH8CPtTnz38uoIzF7JtPDq5RaDL4Lz+pWRA1k
tBR3++YSGwCH36CQd5J2CTLmDcGdGtolKH+2IHaoaI+CY+WmlJpQ2qMgR8zp
RW/ao9G/Or9f5U57NOaejwvsTrRLgY29Ho0j90mXYtVxe77WRMzFwKgeHRrS
0R6DuC6Ri82Zdhm8syNGLQ+aSZdhTNJaMmIm5uQwn3vv2a6hXQ73vLp0/Zd7
pCugyLpTNZRKbFBgsoizzvTcJV2JmdZl5o6HTaQr8WFqZ7O7qZH0WPhJUxID
Ay2kx+KnjzEvWdpAehw8s/nFyojbpMch8Xpq36MpM+nx+GZZ0advqyE9HuOp
h9s/8apIT0CVqmwhsruU9ATsqh84u/28jnQVdBPqJ1ebjoiXugqFyubpzsJS
8R+pyjj0
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw9zXtIk1EYx/GxVuogMLAskza7l7OsLPO6ny7dmprvW8YoLSkxKRIlh2kr
nDg1rTZLu8w7S00jLRdkamRIWipaWVIthfCPpMIygmUsu+E558Dh8OH7PByv
w2m7k4UCgUD57/5/6dHvv2I2m5u6ZjUlTzuuy7cxC8A9XeUYYHbGi0HPQ5+Z
XTFU1Bb5kNkNxcdT+lqZF6O/8fr8QWZPnHx92ecHsxTqhEtOdublKIpI0Uwx
r4Rwj9O4tJx6NdpfCbZ9ZF6LkknbslLm9SiI2x1qYZbhsfvBhQHMG+Dt7i/J
YfbF8Gml+0/23yZYVenc82vUm9Eh61a+Y96CjrG0X1+uUvuh8lXnKFjfiqpR
35amK9TbYHqxKjmTzfvDNubimsn6drQt2BhsYw7AuMZPEscciOdDogHnUuog
DJzSKZqYg1HT/HWfxUgdgv7y7DpjCXUoEifeT1UUU8sR0lF7x4UZmMkt7osz
EeuBvAKNtbWQ9jDcquE9juXTHobpsnmmdAPt4VBXeIVknKU9HKmrz/cephYo
YMnKvTaYS7sCZ6Q3Vg7raN+BhgvTXXMyad8B7Ygj/ncS7RGwrannpfG0R8BN
6KMcUdEeiXNcUM/SFbRHQsQdiFv2vZF0JcYdYm3RE2K9Et4pIutENe0qhFd7
35en0q5Cw6hYJeJo3wneatD8kdK+Ex/4rJmbL2+QrsYDx1RzQB6xXg17Y97v
ozLaozApriq8+K2B9CjkLErM5kuJBdHA10o/12Dao6EzRryJDaonPQaJPckn
NIvqSI/BM0NCT+A7C+m7IDYf4VuWE+t34bs8XSMZriU9FtqzPqr2khrSY+Ho
TjXdraoknUP9EoXjdqx51uCw2FRnlIyUkXkO9+SGvZ96L8z6EYcuWaem8kc+
2efRXFX+ttaaQfZ5nNf2PwmcmySf3efhJPSw29flyv8CDCVrUA==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxVy39MzHEcx/GLauhQqU2WH/lRVI6knB/dve4q/bjcbxQn6yb5HTI7v2+s
o5gflepcpfRToz+Ioq0uJ81Q4p8z+VHM7xkWU5Ef6/P+mu/22XePPd8vH32q
OnkIj8dT/Xl///QZV+SazebzTYP6JP7fPMS2p3Tmch4G1+Kx722cXfFU3vWq
lbMHDu+Xj67kPBZ1KZWX/9kbASnpt5eeIU+C32NPh4+cJ8Oe7h4ZYCFPRRY/
YUsq131R1/DOJSafPB39pkB9Zh7ZH7YOR7cczoGwrN20eSZ3L8DOrhFz/t3P
xrn8VhzPJQdBGFjtGM55DrZ6ON29lUMORmh1VGHrCfJclJv6hm44SQ5Bw4+4
UO0xcihqiyscfh4hz8PnRxOWd2SQhZhbWRRqyiTPx9JuudjrEHkBMkfw6jv3
kRei53VY2ETOi2BOWf/+6E5yGOw1mZ9d0sgi5CcqV3ZwFkMjmjejahsZSCi7
UR6xntkINPcLshsTqUtgjv/a0qCiLkH9RtuFPTHUpThkD86fGUldih5BjVYn
oR6OTVUyRW8w9XCEJFkv7vWlHoGBIvda2VTqERjnp/NeFkA9EvECvtOPWdQj
ceVTp8DDm/piJFVLGuudqS/GtI+lWYpfVaxHYVlFlaL9IbMxCsObRz++ZKUe
jZWG7cmrmqhHo9064DaqnHoMeqy/nJ8fpR4DaZ//N0sC9Vhc7daVtnytZD0W
Bg9lb/cHZp4MQuvAk+FXqMugsd83XdRTj8PaqNVpqV7U42C7mv7M2lTB+hIU
7Hgw/uEKZuMSiEpuHku2lbMux5sXWr1nEbNRjnX6Kctz9NQVCIrun6C6X8a6
Am13vlwb6cvMUyK+dcz3bLfSQUMJn77Jkpf+59i9EtK2sN3a/uJBW5WwvN11
rySPmadCzqwbXYVyZqjQEtt22hh0lu1VyDiVNFDDL2B7FYqdy3ymzMhjezUM
wgO93tpctldD+K1ksz4hm+3VuMNvbzQrs9heDWmPRaRrPMH2GlyvzXDMWmNi
ew0+XNrHF8kMbK9BsLvOa4NjIttr8CzpYF1ebaJ4cK+FPcSQWtprEP8Gibmc
Wg==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxVzA0w1Hkcx/H/KXc0w/WgELEeknIj5bk8fDwkkcUuyz5vD6qTHvbStXOX
WtWSCOVaqVCekruSnBvpac+krjJdW+poqjHiSLnkiqjurhu/33/u/jP/+c9r
Pt/3327lJl6SAcMwGR/ff7/0UYu0RUVFp66MazDw/2Ywt++/NkK7aoLrZtaT
4e3mFhLF2gy3i+6PurO2QL6H16NvWVtj3aQcnyOsOfCaVtKZxtoeffxw3ULW
jjijGtycy9oJM3MfnlWydsacmd1Ce9bzYDI3+n7VYeov0N/aY5/N2hX15irl
edZuKFdvbDBkvQCvXe2y9IXUC6HbJ+4oZu2OisGcl72sPfDL/KM1w2zvCasn
BXe57O6FrvOzcZ+1N7rOaZ16WPvgYcCfsq2sffHwgnTTj1rqRXhi1+7wVQH1
YnD9lZddWPshJW+UmX6Q2h+Lu80fZLMOQNyYo6YxnzoQ91Y5urgdoAZaskeS
TfKI1cDjyM3HavfSPQjDAbceDWjoHoRJOHcwnpoJxs25lq7bMugejK37T23w
3kX3EKj71nGnqugeguklHlN7ttM9FB2KjDRVGt1D8dcnZzKT0um+BJkOvapw
dl+CBr3mumwr3cPgbP90+bVUuoehJTxl1ooNdF+KQxYrZJUyui+F+6vmrloe
3cPRtnTnHYWU7uEQ33oA3kq6L0PxC/9E4zi6L8OaMaY1NZjuEbDumH/jYBDd
IzB6PT3o5ny6R6KmMDI/043ukfhgnntMCrovx/6Zbc+bPOi+HJaGs/lunnSP
wrKanMhj0+gehRtfvzUJNKI7Fyf+GE63fVtNdi50qxwKmkaJmWjArPTzPdTq
aNS+Fkv86T0TgysBg+9j7hIjBl0u9ad99PQ+BtIOVwPtUWJdDC6E/d0+TUT7
WFwTd68MiKJ9LNZeOvdiy2zax2KO3qi5woD2sWjoyX9TUn2S9Dy8cqlQDiUR
g4dfG71SSiOI1TxInJe0TjQi1vHgatud5j6J9nwknf3+B1VVFen5uNXL09Yd
J1bz0eJwiHMxi1jHh+lo3nedfsRMHPYIzDhekbSPg4e5zR1rDu3jcFtfFm6o
rCR9HMoNbzx+ySFm4pHcmbn6/Y4K0scj8NmnJp1J5aSPR99uf4lGRKyLR1uP
1frL1cSMADVJTQnqZGIIYCE0unNPW0Z6AfoH1o8JFbQXYELakIfSj+xMAs5Y
/R6ScJUYCahv8p5iVUX7BDyXNuwMvkisS4BelO+yQE37RFjAz7S09jjpE8E1
T57eyDlB+kQwNYXce1dKSZ+I3wZh6aYpJr0QNqeLa/gGxBBCebKusMzoMOmF
cBqpuzn0qJD0QmT4ZnF+qiRmRFBNsL+UskZLehHKW9qm6vyJ1SLsMv5GLxPS
XgSLCBenXrNDpBfDLHTRh1kVBaQXw3hbv+ez4VzSi9Hk+CYroDmP9GKUfnbY
zvTnbNJLEDmrPuzdnizSS9BRWj7j9UUN6SWY4pPYvKOR3OskKOt7uWr/1QzS
S3HVxr/Vec5e0kvhYeDreWTTTtJLoTNIU5pEq0kvRWtOv408LJX0Mkx+GjjC
aZeQXobm9Vt489asJb0Ml0sE71AVSnoZ5KPy6LFyYeB4L0dx3r7M0Berxw05
rh0VDKXabxi3Wo7KwXRvn4Ht49bJYay2LHbdvYv0CjzTnJ/hzc8ZN0eBibam
G+uyiaHAlyvmDQhEeeNWKNBiax3CnVhA/v/x/uP/OvjExxUYeVvtGw1t4D9J
rKmU
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw9zg1MlHUAx/FHnJpdAhoiGzgQDjCC6+Tl7pSX+yEcB94L937RLMUNNGwa
UCpd2Zln43RhnBx4JIjS8TKwc6LFYiNQhyOI3TBokIFCMqWFqPFmS6vd//88
27Nnn33/v/+eTXsOavK8GIbZ9d/7/5c+5rcqHQ5H8w8ezYpn3IbpOtYMnIXW
FW7WL0Hj5Cb2sPbFaxlvOFys/cDMfbMhknUAMvxcQ8msg3Dpx5efmFmH4N4q
v7yas9Sh8H5ayh+qouZijWhp8gO2R6DgzRq5nfVm5Leu1v7JOgrOott2Peto
JFavip1hzUNyGqftAXs/H/Kpnroe1ltw4KdB62b2fCy+3DKk3MD+bxxM98Ij
P2V7PB7fTGwbZfcJqJW0782qpBZg37HvhpV2aiFsY7vmbtmoRdgat9R+u5x6
Kz4KaBQufkG9De3xgeP5pdSJ2DPhxX3FSp2E+NmgAOcx6mT0yx2FFZ9Tp+Cw
xjWYw1qMyPd/V0xZqIGoo/YKHrUZ2CnI6ztioj0VxaYpVXAh7akoPy6Ny91P
+3acmGhJ+OcA7duh+TirxbaP9jQo52pPlxhpT8NES1uHiJpJx9P+i7PTCtrT
kTIQ0y6U0i5Bv7s3qj6BdgnGTnX+cSaF9gyUCe73lSXRnoGrz0ZzgqJpl+KT
/t3rOkNpl+JcZ8g7DdRMJu4sjPduXEN7JhqLG4/en2siPQtrpQvdDweIzVk4
Oz+S1NxE+w48/1sz/+t+2ndg8fqVFo6AdhnaI0KWB4tol2HnyCP+8Dra5Vg9
IOao3Y2ky8ELq/7eWEbMKJDwdufdX+JpV8Ar51SBabqBdCUSRrpeKK4Rm5VY
sjzOrC+lPRt2YRlMR2jPhl+5d0fPopN0FeTNre/62IihgrvA2VfuT2xWYbFm
sSO7+2uPu1SYrDgUY1MTM2qkBluzORP1ZK9GetNV2eXdxGY1JCucedZLF8le
jea/ZCUly4kZDXwtAm9ezAWy16Bbf5dr9q0jew2mwm9xf7txnuw1CEhLnQ/c
RMxo0fXo+eXX1xJDC5kI/GV7a8hei6LwOx9yRr8iey0k1w0zKxMdZK+DyTvm
54biKrLXge9qNvcNVpK9DrPjrRLxgwqy10FbLfAPe3KG7PXoFfrEZ3FtZK/H
w5vlJwInT5O9HlUnV/pEa61kr8eroYciYsMsZG+A5Nv6bYevmMjeAItuafTG
tYNkb0CYa72/SWYUe/YGhC6Tjj0bz/WYMeJcdfX64Y3FHsOITEvRQn6tyWOz
Ebz3XnA+yz0u/hfK+uKN
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlntQU2caxk+rWGuBKsYthbakSGkKLasUC2LRJ1wKCsotQggRTi5cDOsF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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdk39M1GUcxx/kD5tjWRoJG6tDCfvB+uEd/SL0rfLzQIHjjh8HHN/7xa+s
2KyJK+K78QdKWYKlHCi7nC5uLUrzZzT4hq6YpSBjQzcWJ0yXytJV/7jaqNa+
j5/Pc9vt9trreT+f5/N5nkv2veUILhFCTPz7/e/X/Oju/aFQKDLyP93d8Hhz
9+iIZIGbjsVb5yQ/gPmrb945KvkhnHn7dP1FyY9gKNmaek1yAk4k3Ixt7jU5
CVVdtw/PSLZg1fcn962SvBpZZ9c0jfSZnIKl22qyEw6ZnIqUlrmip/pNfhJj
5xt6nJKfRsvM8t/mZD4Ng7b4gcaDJj+L7kbnnRuy3vNwv3sqpUCufwHO3Q9/
Nyn9OtgTc3emSLZixSlsm5D92WAtW1J5VnI6jjq22yKSX8T+P+JTj0t+CZGY
ticGJb+MSOvdnYVy/1dgPd4Xmyz5VTT1Dy28LtdnYHn+O47V0r+Gk7mtA7PS
ZyKQ19UZK/16tMfeS4qR/W2AvTp+7JicB7DysWWLA+Z6Hdjz1fTALZnfiCvr
/l76i5nXN6Iw0Gy1Sr8Jk7Gnd5036+ubsDKtd05IvxnTf/Xcf1/6ZizEhch7
y0JbEmE9C+89R302hjOpz8Z4EfU5SPdRn4O2HdTnYlk39bnYG6E+D/vGqM/D
j/PU5yPuV+rz8fMN6u2wX6fejnaWL8DsNeoLsH6W+kKMzFBfiAtXqd+ChGnq
tyB7ivqtaL9M/VYYl6gvwvgF6otwhPYrinHxB8Iohm2Uri/G58OEjWJcH6L5
EuSdofkS/P4NzZeg42uaL0HLFzTvQO0RmnfAdpjmHXD207wDtz+l+VLE7KX5
UmR8RPOl+Gw3zZdiirJwIr+T5p0YpKw7MUHZcGJth+feMz1m3gXPlx2ZiSbD
hfQPaN6FIcqGC4uURRlKP6T1yxC3h+bLcIKyUYZE2p8oxxuUUY5J1n85/qRs
lOPSxzRfARebXwUWKOsVKOmi+QpcoSwqcY7+v1CJlE9ovhI5lI1KBNj9uXGA
MtwIH6B5N+YpG26MUhZVGO+h+SqsCNF8FR7spfkqNPfRfDXsB2m+Gp2HaL4a
BvVGNS5TFjVoZfkavp9egylaz6hBGqvvQRdleLCdnlf38H4MD5pov6IWiXQe
qMUxNr9aZLD51eJ9Nj+Ns0Xj84fCmsbnr2tYS88TVtjQ8CjlqMLCiyhli5f3
Cy92Uda8cLH79WIH5bAXETYvL+ooRxUWPsRQtvgwzN6T4jWfUt/H7yvsg4+9
Nx8clKM+/h6FHz+x+n6lfz+fj+ZX6vv5+cJ+ZLH+/Xw+UcWLAGysfoDXQwBr
WP8BPj89wO8nHMAMqx/g/UUVL4KcLUG+H4L4ltUP8v30IEKsflDpX+FokM9D
1PG8pY6fB3VKfcXrdfw8YYUNJR9VvKjn3lLPPRSv1fP56AqHFTYUjtbzfkWD
0n8D//9A8ZrCeoNSX2FD4aiyv2jkbFEYjUr9RqV/xYcVNhSO3ud/AP1JqOE=

         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdkwtQVFUYx69Y+chUxFHT0lURfDakCFqKf0AEBOS5yy7Pu8uuC+1YNDQ+
spybOqRRpIDAwiqb+ABJSMtsHMNrTj5nxLGmfJSuBk4v8pXKOOpkk+f0ncPM
DvOb//l93znfOXes7Y00h5+iKCcf//79z/60rGq329186D+6Ma+4q21gK2cF
2uh3c49x7ovTrm1jTnEejO4+0+vuch6Kz0eG1Y+uYzwCW07XpvTj/AJWDe7J
2cXXG1C69NC+ds7jENexv9SfcyCCbX4zV9YyDkK/4dXGcs4T0RAf1TyK82RE
t+0/O4D7U/Fio7msgvNLsI/S773POQTD0nu8GZxfxpp7Hetnc56OC3VDOlM5
z0DtuYK8n3m/UGx1DM6+y3kmkqOKzrdyDsNqV1VMWw3jcJTHTg56xPNZmNI/
6LNuns/Guo7hE87wfq8g/70ITwNf/yr2rfx++Z+c5+DgZFPAWr5+LlJ2T+3+
i887Ap2uJMOb9YznoT3gwZWlnIGDO/yTMzc/YQ3o9ezFp6o8LI/EzdOJjzw8
j0SVe8Kvl7gfhUHBu8zbGWtR+Orv3sPncj8aTZMCA07yPBrxh1Y0pfP9zYcl
4siMNWz/2ny4nhuojuPnicGPZbfLc6pZHoPzh282aXxeC6BeiekJZ6wtgH6u
1/VjPI+Fq3ff5svcj8Wykq6JCYyVOIy/fK27kedxGGT23LdWsjweIzujIs7w
PB43i52ftPL6CxFwzf3/96MtxMZOwkoCmq/SPAGrfDRPRKDx9gYTm5eWiC92
F/5xjudJONzwsOwA95MQeD/s7Us8X4S9H7hCKtk8tUXoNeXs0VQvy5MxJ8ZV
2MHnn4x7dRVHzTxPQfGeJWdeZ4wULAsfWbK8ga1PgX/kGr+vtz1hPQX1XcMC
W3cyPxVfmq+Xrd/F/FSEhPrHz25ifiouRh9vO8Hq6alo37LZGMz7pyF4mmnW
kS3MT8OpJUkPJvD3loaOW6udFsZ6GkpGh2bX8feXjgGfenp2MkY6Wk7W9D/A
z5uOX9a2JI1g9fV0bH3Gr3U+YyUDwYZpmVdZfWRg7axp3qBG5mfgrXfu1PTd
wfzH64sbh4zdznwjfuheZLjTynwjjpfmt0Q0M9+IsO2Hn/+O3a9uhP1Dev8m
/E4ZJlR8RN+LCQnlhHUTij6mfiaMG6ifiVrKWiawkfqZ+I2yYkZeBfXN2EtZ
M+NWJfUlVixoqaK+BTs3Ud+CC5R1C05QVrLwbTX1s/BaLfWzEOqmfhaWUVay
kVZH/Wx01VM/Gys2Uz8bYZSVHNzyUD8HQ2mu5eAqzfUcTKKs5GIj7Ydcqb+U
67noI/h5kp+HUYKfh62Cn4dj9LxKPjYJ589HJGUtH6eE+eXjBp2voiKcskFF
Yg2tp+IbyqqKVZQ1FV7KXhV7KOsqnqb1fRIrVsQJ/a3wUIYVFsqqFe3C+7Bi
PD2f1yqeT7eK78VnFd+LYoONssEmzg82hFBWbeim9TQbBtLca8NPwryl3GfD
Q+H9Foj9DBKjACVC/wJxv5qUeyXWC8Tz+gowRji/XTyPwY5myrDDSFm1i/PV
JPZK63W7+P36pFxxiLnBId4nHHAL/R3ifWoOLBbuX8p1Bw4I/R3i/SiLRTZI
jMXi96NKrEnrvRLrEvskVpxSf6dYH05x/6pTvB9Nyr1SrjvF+fmcWCf0LxTZ
IDEKxXpqodhPk9grrdcLpf5SfaVI6l/E/X8AG/d1sA==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlHlMVFcUxh9UKkEx0hDpqgMVCi2xlkVxK9+wCYgsA8OwzTAzrKVqoWo0
3Xg0KVEEhbJJXTq2tQlpoNRYA/iHz0SmRkyxGFRKa8dSrCgSIUDVUmib5p7e
+yaZTH753nfP+c4987ytb+kKnCVJavvn++8v+8hZTS0tLa3n/qMH4bby6dK9
xBKa6+50Wohdsby/ximNeCme1K4p9yf2xPQognoPM34avUf2DIQQP48zXolf
jTYz1uD2+c6HM8Q+cHLp3L6BeCUO9IW6zzQy9sNsQOQCXQNjf5xfeK3oZD3j
l9HT3tHVQxyI/I6izj7iVRgO9DJd+Jjxaky5x14pqGX8Ggaf7U34gTgIib+X
1RbT88G4t9P71NJDjEMw3vbo7QXEoTAER37oRM+vQe7cmHM36WvRX3ri69vU
fxg8J77sGaf+1qGi09gdTv71aLQ1nP2ojvEGHP/M/VIx8UZctsfctND5mzB1
daC9kvp/HWGlxcd2EIfjrxsB52LJD7zy3G/fFzNdBl61jypVNUzXoq7riz8u
ka7F6SKP1d3UXwTWLVoQTHnkCHTVz270pXyRKP3x5uwQyydH4sJ8vMd90qOw
St86F9PE9Ci4Df18xIOxFA0lROv2C7t/ORpRk+euttI+xGDwbPSEH9sXOQYp
9srrf5J/M7a1aTrK2H7Km7G7Iiv9PdrXWNy6F+dTQXos3hhyzagkPQ52aXp6
nu2vHId9J5PC3ic9HsNBE367yB+Pg4sujtB50hYsXjkyto/0LbDf+Ny1nPQE
zO3eYXKh8xPwyHl/wi3a/614uCRnppDmuxVxj6sfXqP8ibBPHj0zyO5TTsTU
6RfGS2ifkvDNXZs9kOaXBMem3sHl5E/GovAqVy9WD8m4e//dMTeaZzJyLu4y
PmbzVJLhV9izYhndXwqKqiNKrrJ6SIHPm1dcAyhvCurKplN9GSspeMfomRxE
+XW4XvDd/A7G0MF9aq+8jfw69F5eY6B5Kjr4HWrh3lepOLGfY6TiFM9yKvyr
OFZScYtnKQ2hB3h/Gi7zLKdBU8370/BS+8hANd2PHmU1vF+PZw7yfj3WD2jL
7hxnfj18n/h2m/5T5k+HTy3vT4eeZzkdK+r4+ulYWM/3b4BnA+83YJxn2QDv
Rt5vwOIm3p+Bep6RgeFm3p+B1hben4HcI7w/E8XHeH8mJo/y/kwoPCuZ+JVn
KQul/HnIwgjPchYCeVay0PgJ788W+0M2WniWsxEi9J+NksO8P0fMixwkCPlz
sJ1nJQcugt8o6jCiX/Ab8YHgVz0vmWAU/Cas5c+XTVjGs2LClODPxVFeRy72
Cflz0Sb4c9En9G8WdY0ZTwnzNIvzNJtV55sRxbPNjBeFeavYYcYeniWLeL7G
AiehvgXdQn0LfhLqW7CT3webBVqeFRU7LNAJ+2OFlWeNFUt4hlWVX8WyFYVC
fqsqvxUP+Pk6rNAL+fPEvJo8cV+RJ87XnKeqnyfOw5aHXqG+ih0qlvLF+Wry
RR0q3axiOV/8/9lUrOSL/TpULBWI+6RRMVRsLlDl/5//Bobd0Iw=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlAlMVFcUhp9tKrZGqpQqKIanGOJWIyKiFuFHQARkmQEGmGHgDTPDjKNI
rHVJVfJApKKyCsiw2GlirNQal6hpReuLWouiTa1oTFw6am2tu0nbVKnpknKv
914SQr7857vnnXNvGFdUqre/JknSg39///tLflRji9vt7jrxPz2N0XXvim+n
LKEieuxXr3gI6nI9fTmUhyMixnhkDmV/PJyY6PahHIDgM1Uh6ZSD0L/D12Ck
LKPX9EtJbhvh8Xi4xtJjbCc8Ae0VZUGNnYRDIWWenWSjPBFVO7/79Sitn4z1
IY/bZ1KeipbIF47MDsLTMCjpWWwm7T8dyyNOblzWSjgMB6sNYZsoz0D/sOs+
JbQ+HBHnOqcEUp6JRbbJOjPlCOS3PvnUQXkWAp5erl1LORLdPveY+WcjvPnP
WwbKczA0KhS3aP+5CNTPGPE2zd9HIHTlWZSjYJp1P+oK5Xno9FvR8JLuMxoZ
bc7Np2geg3P71n/uRxmI6fHvbdw+wCpQOi6wp7GF5LFQL4UtdzaTPBZlN5KP
zKX5fMiVo79PbSL5fJQ/PnUydBvJ49Ca1mez0zwOaUmfNe0lLMXj5oWI+lGk
Xo2H/dAYdTfNE2CO3PPgR+onYNiquyP20/MXIK2jb+0G+n0LcGn37aovaJ6I
G31DT59rJHkipO4rj3ro+Qux60R/60F6/kKMf+fsYD/qJ+HB/hnPBlE/CU3x
rn0pNE9G67VPRsTR/slI+eZK9BK6nxQMjWm4GUD3m4I1d8Pfzab9F2FZdKsl
tZ7kizBcvjjpTg3JU7E1pPM3J2E1FRdfN5cG1ZI8DSMNB7S5m0mehtKpq4/f
/Jjk6TishZz9gLCajim3NwwJqyR5BhKi5p1fsWqAkYG9l9M3RpWS+gzog+8d
e7JygLUMdMkW3y7q6xDu3LPp0gbi61Be0d1TXUZ8HdS45z+NLie+Dsf2LDe1
VBFfj7F/NQ1LXEt8PYyHq2v/WEd8PQ71/Oz/jOSaHtemfDtrdjXxMyFnPKws
/4j4mVAqLkc203kzEXTm+M4xdcTPRLfnTsFguv8sOHxSE3zJPpGFC+ve699C
32MWaja7X/1/1LIwYQvDUjbaWEY2/mZZzYa8lfWz8SXLkgH3WYYB02pY34BD
LGsG1NWyfg5C61g/B/H1rJ+D4AbWz8FLNpdyMZ3NkYurLKu5SGtk/VyM2sb6
edjBMvIQ0cT6eVjZzPp5yGhhfSP2trK+EcFtrG9EQzvrGxHQwfomXGQZJuR0
sr4J/ixrJtzm/Hzs4Px8rGdZzYeJZS0fp9nvkcy4yzLMqOF8MzTONyOZ61+A
OVz/AvhwfgEKufkL4MvuRyrECpZRiKvc/goxnWWtEEfdrK/gEcuygpksQ0EH
ez+Kgh+2s+crMLPsEVgT2KugjGXJggMsyxa8wb0HC0Zy/S34mmXVwn+vx4LV
LGsW6Nn5vRZ+H1IRn8tFiOX2WYQilpUi3leF3CP4mpB7hVyy8u9dtvL3Cyte
svMoVlxnWbUinpvfyu9Ds+Ipuy+vwJINftz923DMXP9m5UjS34YPHQkvOmp2
D/S34a3z6XdO/T7Aqg3Pexn22Pj3pdn4+/Da0MW9PztfL9v5etixiZtfYNUO
Nze/kGt2FHP97cjm+hfzLAuMYv58pVjYv5B7ivl+msDeYvRy/R38ebIDIVx/
B3+filCvCuxx8OdrDn6/XoewfyfPspOvh5ArTn5e1cnv2yOwJvhe4XxpsdB/
sdBfYGUxP58q+B6BNaHeK7DkEvbv4nO4hP4u/nxVyD1Crrn4fXld/H6kJXwu
L+FzCLkisCqwR/A1IfcKLC0V+i8V+gu5IuSqwB6hXhNyr8BSCc9yCe/jFf8D
70kxsA==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw9zwsslWEcx/GDWjQ2wlYdMyQidERRxE8H57idCxpdNkVIzCXCijplCGkl
jstkOJ1SIqJok5PcKm1GwyjGMpNEbdZqiy7zPM+7vXv33ef/f949puEJgZHq
HA5H+O/9/6WP7Ji8vLz8gWq9vrk7D65cWmTNgVypCt1eQVsT5kPtXA5rXSyb
5XQXsHkDFJ6Rmliy3goRP/nCqzLaRqg3+Lh0qpS2CTQxNVwgp22GUp5O6iRz
c2ikdyXxWVtgorXoQjGb3wW99LycuRLa1ugrbve+VUzbBm4VOYJC1nb4FD3/
WMGah4ia1fcxrO3RskVL2XWb9l6MjZWmTzF3QJ/KZknM2hFROdbHRez/+xAW
OBw/y3w/NvYpCkZZO2Emu0tlyc53hrH0bFMK2z+AJo0Gqzx234OQZasedrD7
uqD/eu+L8CLarlALnnC0ZX0IyytyifAGbTfE5vMs5nJpu2M2y654JIM2UO/S
P+KaQloGBGs3pR1Npu4B8S8j5Vo8dQ9wuYKZkjjqh1HdViAaD6N+GD1u55qd
/KnzIZw0D5U5UOfDcOGrTs8O6p4QtTRWqetT94Tmc/GJ02bUvSCfsef91KDu
hbC5TTV9WtS9Yfx0dOejxTri3nAxPP8kaZw0R4DOI/ylpDbqAlxMbJj4UUld
CEXHTGJkLHUhRq98d9aKpO6DaVvL+ZQd1H1g5dzicW3pPnFfpM0ODcS9Ji3z
hXpWbZnfM+p+sDQNWRt0pO6HPfzGku7Ge8T9oW1wJePPBtIyf9hqXXy7O0ZJ
PABt3JKo3LS7xAPQrZuaK+UqiIsANeXvCMda4iJc+mI8XZlRQ1yMaGVl56pf
NXExkgrjgsI+3CEuQc+hfF/XgYr1hgTbeteq9GLkZF6Cz7zkdx11N9f7pQT6
rR7eJzPzyb4Uijwbtdrmq2RfiqzVDP+VN+lkXwp7g57N8wshZF8KQVD15czf
Ce5/AUo9bmY=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxV0g1MlHUAx/FLCmJHTdEB8XIKARoDBKEDeYkf8nbAccBxb7yFoqDIGHAZ
ygnjyQg8BKwDhAuUiASi8WJLwWGTAYWoXTGRFJoXNbJykQ5hIzSj8f//V892
e/bZ7/999uzZOWbmS7M28Hi8nLXfv3d6cSln9Hr9p1fX9TDk/+Zhaem/fhGx
h2XpVcwbYT5uslPLvAUF23rSEpht0FH/62khsz3awu8fqW+i3gbXiUHRBmYn
BL1WlnWikdoZGfP6gL+ZXXFTwO/dws7vwOYR1eeDzG7ITh9aTWF2x0xrQFQl
sycGU0Wz3ex5XlitCBZOnqH2xsb2zkI+8y4csv0zJqyB2gfGMVN3Adt9kdFr
zdMwv45mb0fb88xCLE69G+rMej/cslQfe5vt/qg6XiP1Zt6NbDMPRSs7H4CR
CPOSYuZAHC4K6RpgDoL7qMvBP+qpg9Gz6Ht3so76DZR1ZSoesT0Exi+bXzZj
PXB5/1LQm9Qc8PsD3aaf2PuEwrD1apYp/V5cKHJF4yoe+557kPrCcKE9Pc/t
wZCtadAwe34Yxgstlq10dA+DNjhbLK6hezia9wn3tlBz4XgUJi5eraJ7BL6r
yJlOq6B7BByuext7Kukeia+qF3S7qblIuMQJ6i9ydI9C3G+BOQIN3aOgFjz2
mS+muwiJ6u2fNb5FdxHCYy9e0xXQPRoLz2vSD6npHo0Z83unRvPpHoMrA23l
pXl0j0FTX/+U5QG6x0LhWfLKeDzdY3FX25dmKqa7GGXaH3snIukuhmWlVf58
BN3jYHgpb+JOCN3jwPU6/uAlo7sEZzWCK7X0PCdB6Xv7Q62d6B6PLP/8rwfs
6R6Pvc3lHxjs6J4AvzujNXabiZGA+x2ug+lLXeR8AjLT/SV1T4mHE/BQWD2d
0U/MS8SC/+qlW43ESMSxBt1UYyHtE1FqEXbKM4n2iahWC0eX5bSXIqHbpPF6
Cu2l+CKts7D0507SS2FYcSmzukA8LIXRfmHsgQ0xLwlyvmLR8kkH6ZPg0Cex
MTlHzCVhzi72Q2vDedInQTk2684vIebJ8H6w/tXj9z4hvQy50xdSTjgSczIE
Fuht7G3bSS9Df/eyR7z+Y9LL1/4fdpqhMWLIEXPb8bnFHcScHILclrZnDh+R
Xg6rnSZCgds50iswtzJyQ1nUQnoFvFXtM8/MmkivAHf2W8nR2XrSr/n7TRat
p+tIr4T08l9SeYqO9EoMHjA43nY5SXol4v2MN/ke5aRX4rF2UsTXlZBeheIG
328u8YpIr0Jt0HYfp+ijpFehUi3Z5b/vIOlV4Ie6G2/oE0mfDOcn+UcMXpmk
T8ZKTepyZ3NWyHqfjOW5d6rL3Lh1DyfjqeaXraHGynXzUnAtr1dbZVob8g+h
+xBb
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlntMlXUcxt+uti6GzlDS2YHKlSsltLLMfBBFKZQDyFUuL4c7cuQgoFKm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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlHtQVVUUxrf6R6hY2oSP0fIKmY8KfKCgpnwiiMhD3nCBC+c+AOFeAXOi
yabcWRkqCD5ArkCeacoEy5TShBLOkFqNZsxkhmnNcdQ/ZKYZGnUiX9M0dbZ7
L/5hfvOtb39rrb3PneaqSCsazhgbNYyxf/9bfzy30e/3t/X8R4NRQcvmxh0V
zLD9nqwHwNsSsvhnwWPx2KjTx84Ifgqbj0ax1wRPxPCukhUNgqeguKdqwoeC
bbj05sz32wQHI/Tm7SVhgp+F+2xX5Jkmi5/DrDGnmh4InomDBf0DJ0X9bESM
ODTOJ/gFvH3qZt0PgkNx+Zme17sEz8Fbn3wxtXqfxXMxbPf0KaMFz0NYiZdX
NVs8H6/Yzz0fJjgc5rH7rfNF/QI4J3x3YJPghbj3bXjRoOAIxNUNdAYKfyRG
vtc9/qHQF+Fw39agPtHfYkzsjT3/u+AlOJniO3dV8EvovFu36LLgpbhWNSHn
kuBl2OIJbK4UHIXi/QsCbYKBD8KDvXesfXIgIdTZ8IToZznir84oa7OYL8ff
ARe1UaL/aAT8ceHTcS2WHo2IjjFLo4W+Akt6htx2i/kK/NQVvfEvcX4MZjv4
g2siPwbdFzfMu7XX0mNRcdLo/NJiHovjpUXJteL+VyJk6cPpJxotfSVq3V9t
vGMxi0NVRfvkJOGPw4XJWz7qbbD0VRjZeNisEfoq3KtxdQ8JPR4jv9k/4Ku3
9Hj0Nu96+pLobzXqr89s/V74V+OGo6MyQ/SXgNZDmxP9Qk+A5+UDd4NFf4lI
GvJsCbfyeCIO9DU0c6EnwTm4I3Not6Un4cjn1+On7bL0ZBTMb4wLEfMnQ/Nc
aRph1bM16D/yYk3rHktfg18cEe1V4vwUXF/f3+Gx+kMKHgaVJ1SI+0jB12f8
j75/IwWRvyVrq637ZqkYCPz1fLHFSMXx6uw/m8V7SMW7B0tOzNYtfypi2m9F
vWMxS4OjTTofabj/scQ8Db26nJ+GWS0Ss3T4/bI/HRd2yf50zK2R/em4sVX2
Z8C7TfZnoE9mnoEF22V/BmzyeSwTjTIjE8tqZX8mTstsZGLSDtmfhdsyIwvn
62R/Fs7Wy/4sTN0p+7OxU54X2fhst+zPxqE9sj8b0xpkfw4m7ZX9OXhS3ifP
Qf8+2Z+DN5T927GtVfbbsVBmbketXG/Ykaf4c1HYLPtzMVpmnguXkp+Ls3J/
LA/dTbI/D3XyPDwPiTIbhFk+jirz52O8fB7PxwyZjXzYZWYOleHAj4rfgWK5
X8OBGKX/AnUeFKjz8gJsUOYvQJrMrBBzZEYhHlf8RDcK0aXka3hVZptGviei
a5raL9dwRWZdU/MNUm+SeubEAyXfiUFln071PWqEuVPdp+5EuLJvoptOhCj5
LgxT8l2qDheZ36Wez13IVPIJGy6ST/zMrebZ3KofbvU+NLd6Hner70snfoOw
6VbnYR6sd2/s2BTd/n++h9y/h8zvUe+PE9Y96vsyPGhT8gmzIrXeVqTqIKwR
5oT1IlQr+eR8k+isWGVbMZmf6BphTlgnfoOwSepZiarbCIOwVkLmJ7peQuYn
ukmYrSXzryX5hDVSz4mur1X7M4huEp2VkvkJg7BWSuYnuk7YIGyWkv2Xkfwy
8v4Ia4Q58etlZP+ETVLPvCTfS/IJa4S5V/191b3q92iQepPkMZ+q23yqH4Q1
n/o9caLrPrJ/H/n9I362juSvI/mENcKcsL5O3YdBdJMwK1frbeVk/+Vqvxph
Xk6+f8IGYZOczyrI/RMGYY0wJ6xXkHzCJmFWqfJYwjbCcwiDcAphrVLtr5Iw
J1z/iP8BrKMCjA==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlAtQlFUYhn8dTCbMqekyWmQLMk1jpqJcTfMFFhVZYdllWXa5/bvLcjMx
FTEnZX6RGJO8QAIuMrVNZUOTXczULOM3IytsLLDxkuCOWYM2FAUJjhjd5hy/
c3aG2XnmPc/3feeyhLlXWbzjFUX57p+/f7/ZR3M2+Xy+tvb/aWDRyAOft7Vx
VvD4+bLm9zgHIze1o7+L892o2bs/LrSF8X3Y+1dB4gTOUxDRcLByGudQhIcl
ZZ3nvgFXVvfYjnAOx9AF811BnCNwZ2m0oWUP40cR/HPUrnjOj6H88onhtXz9
DFyI90z8kvNMpBUf+3qY8yxcvxIz+innOfCOPH2uh3Mkdt5/a/A057moXeM4
Wsnnn4dR50OHKjhH4eQ9cbZOztF4daBi/SD3Y9AZdoNwLN69lLhqiM8fh11B
P31/ez/xSGn8pWxBM+P58B1wBU3j/CQmrT7jH2livADa/NqcJM4LUX3Tcj2C
13sKocH9ti6eL0Lf2o8/GWtkDLSmHnacZKwB++vfeH3FbpYnwJTT0T3AWEvA
5XMf9U3m8yTC3GuM2cDqa4mYObg57hSvn4RT7V3Z+3j9JKRsak028tyI6ppJ
YQ3cN6KhY+HvT/D6ybjxcO+DK3mejJbZxgnNPF+Mw07f7ferLYapnLCyBDue
p/kSdNxMGU3h+VI0HvCcXczzpSge7urs5+eXgsJIY4KVsZaCio2HQky8/zJs
atp3dZixtgxq9vQ/L/E8FX0/0v6pGAzQ+Uy41ktzE8b30Hw5DvxA8+XIPE/z
NEw5S/M0vHWG5uno7qJ5OradprkZm78hDDO2dtL1Zox9QVg3Y6pO/QxkHKV+
BiI/pH4GXnmH+hkob6O+BTWvUd+CzJepb4GpmfoWRO+mvhVfvUh9K+7YRn0r
4inrVrQfL/vthJ/5mWinOTIRXUf9TNgp65nooazYECn0t+EIZc2Ga5R1G9K3
Uz8LU3dQPwtDlLUsxO6kfhYclBU7WinDDuMu6tuRUU99O+obqJ+NP16ifjbW
NVI/G7WU9WyYm6jvQOwe6jvwHGXNgSrh/hyoo7niREIL9Z2o30t9J9Io605E
2+vmXt3O/ByMhlTNfkZjfg6KNlnuHaxifg7sEc8GWjYyPweN3/r2zHuB+blI
3P5mfEgl83OxpfLY2xMLmJ8L6wez52xJZX4uLh78dWlYLfPzMKtoKHxsDfPz
sG7D9HEmlmt5OF5t7V5Rw/w8/Pfz4vvPFxn5WE9Zy0eAnpeejxn0PJUCkVGA
lZS1AuwUzr8AfsFX8Rllg4r3hXpSrqri/WmqOJ9fhY/Or6vopxxQMYfet+LC
LZobXHhEeA8uTKasumChrLnE9+OXWJf8gEucR3GL8xjcUn+JVTeOCvfjxlbK
fjdswv7daBP2L7HikfbvQZHwHjwwUlY9GBDOX2K/B+OE/h5ECf2lXCkU35uh
UKyHQnG9KrEmsV/ydYkDheI8ild8/waveL7wivOpXvE8NGm93yuery7VD0j1
lCKpv8QoEuurUq5J7JdYl/yAxEqxyAaJUSzWUyXWinFR6C/lusQBiZUSaf8l
Un+JVYk1if0l4u9BlzhQIv5/UErF3CAxSsX7VEtFX5PYL63XpTwgsVLG+W+W
nbH4
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdjwlQk2cChn8pu1ihFi3lEHVRgVCGIl4cHvAKclZAIOEM8JMDVlFREAXW
YrgPlQrhCoWKIALqOkUHWxAhLdqCgLNtPVhFzVitIBSraFeQynY33/c3NTOZ
zDPP93zvlyWihECpFsMwbb9///dLP7LwcoVC0dylpl9cdn+my9vPMQOfE7Dy
4Xg2fKeSteI51scdvyg7D44NsD1at6CGY2MYufjUl3O8ELGu7b7JHJvh+sb+
5EyOl8LVK8WP5dgcccyT+slKypaQbSm5mMOxFbLXvX3qLMfWKL2kXe3G9TYY
8HJc9cf/scVXehXyae68HWoa7qXN53gFonlX2m0rKK9E1kWdFy7llFeh6ZPa
f6aVUV6N07Ps80Y5vwYRY1od3hzbQ6fY3qmdYwd8r/tgfifHjrD/fl5fG8dO
GFD0nDHgeC0qftze48u9Zx3CM6990MW9dz3sxMsP7uZ4AwwDC/blcOedwTPe
LLzL3eeCTcdDeFUcA3Yph/jceRnQUD6sd47rN8Lkef/NXM5vxIKP62ZellLv
ihQDhVkWvU/mir6UHb1rufvdsM9k+vBf6ftkbshc9rlQxb13EwTCrnlbuX4T
fqn8rZonp94dZ1u1tn5wkHp3pNp++/few9R7YK7V4wXZh6j3gMFYttlgAfWe
qA65m2FURL0n5LmeFd+UUO8FW/7cY8X0PpkXFsWtWVBI9xhv8FQ1hQ751HtD
8cwx/Voe9T7o6Bu0a8ul3gd6rctbMtOo/wiKLCPrA6nUf4TFomT9piTqN2Ps
65GfTtLzss3IN+/9sWA/9b6Y2drd1ZRMvS+2GumE1++m3g+Bt89b+2+j3g8d
TjeEsykz/qjpnaPD47w/vNr4/+7fSf0WvJAuybxPPbZg2OD1eiFLz//u91yN
6Kes3IJt5bcEI4G0D4DLyuaR2T60D8DgfN7kWQ/aB6Bq2bP1D11oH4AjZtG9
FvNoH4jLVk0/h+vSPhDpQzfbm+80kT4Q1nEPS5N6CCsD0WY+XCySE2aCcDXt
iv6cMsIIQnV2QuhENe2DUH5hpOxiBu2DUPQ4L+jXd2nPR+pgS2RMXyPp+fAd
K5iTfIOwjI/F7/vo//QbYSUfGaFdsx0NaS/AHv5Uo78z3Rcg7dxa92kLui9A
qUeIZcNyui/ApXkXfFsdaB8MicpjabcB7YNh+o9T/6l7SPeDEfz0h/unj9L9
YDzs5N1N9CTMhED4VPxKb/QE6UMQ2lA6/oUx7UPgZvFgKuca8coQfDL6oONK
C2EmFPFZ9YdOt9I+FLHWyUnXXQjLQqGdvv/J+bIG0odiyaLhhGpzwkwYTFxb
et1WEEYYwh71/Dqxi7AsDOK9VfsDbGgfBqe/1L036U37cOSYXnqSnEj7cJiN
rnwwPHWc9OGo2NU3FDlDWBmO9yRXLuyQE2YiwD8zHF57p570ESgctpSf/pmw
LAKNuzN3Rt0mrIxAy5iDybvrCDNCzDowlP6suI70QhyZqvP16D1GeiEE3zg3
hu6jvRCie6NNbpXEM5F47fTDhunFtI+EiXufhJ99lPSRwKuk5vy8atJHYuD6
+HjiW8QzUfjSTtu2eU4t6aPw9sy1M2M2tI/C0qj21+nHCSujIM8/0SN9WkP6
aPjp+GbGj35G+mi4JJX2F39NvCwaO3S/y0hI+JT00bjfNevyjHUl6VkENVrY
u1fJ1WzGorr7VWcdW0LuY2G1QRafZV6sZpbFdudtG6cjC8j9LLpviy3zHWVq
rmUh8Cu5l2p4gOyx2IOyOqOTcS7/ZxWLjqO14zds3dXMxKAwtdJ2ctcmsh+D
qyNTWQFDXmqPGGxOZ1UmR5LVzMbA/8uUrMCCdDXLYjCRtHBaL22vmmtj8OGK
bt6tv32sZmUMrAzTVg3lZpP9GHT2TOxdnXWY7IvgUFRVsWKySM1mIogU6wTu
7xwk+yI4xQr+ZXT+CNkX4fHCxxmnFsjJvgiJNnlaVd+WkH0RhEI2951jZWRf
hE7d24tOehJWiRB20Vh6mSXMiOH83XOLD4sryb4YxedMFVraFWRfjBH7r3o/
XV1O9sWoWN/q129KvEyMl/rncpqTSF8rhlucSmtunILsi5ET8UXP/FTiVW+c
ZyTwM7o54L2Q7ktQ8Xpno08ZYUjwcnBxz61l5D5WAu1HhsqBlYRlEsDsJE/1
nO5LYHrCwPutR+R9Sglu3pqbMRFKzqskMHgxYm4kJ8xI0V/Vlbg8pYrsS5F/
2MZ0zTRhSFF0SINZKYwParBMihBNrpUislCDlVJYFmiwSorxPA1mYhGfr8Fm
sbDRZLzBbCyaNVkWC4nm/bVv3KeM/fOeKhar/rQfhxe5av4vT3KsyQ==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxF0H1IE3EAxvHlTF1YVkgtXdAsmvRiqbVZc+7xLWube9P+sLJMezENE1RS
l/NypWRpFrbNMlksq4Fm+BLYm5X0IhTVqj80TDMxsRRDVkbv4f1+HRzHh+89
d8cJUw/od7txOBzV3/PflRzMFnNNTY2jY0rj8oTjuZW11ByMt8h8flB74db9
nD4r9WwYShanPqb2hdi/qJV7lpiPb94DmgJqAYR+RqWZehEcc/hu/dQBKOcw
ng3US2B6ZBpZQ70UOyoq5iVTB8Jqq78lOEe8DNv7u4v7aF+BRsPs4ULag3Cz
Kfv2Z+rVWP5UsvAedTA6RyLHBmuJQ6CwfwpMpg5FybbJvFXUa7DTN+u9mu7X
IiMoQNBJLca7RGl7DLUEetHmmVzqMHzcIvvtot+7DoOnEqIOUq+HMOzlEzm1
FFW+RTwNdThKBbNqGPr/Zfjpyo/4/78i8OEX02WilkNYucDLmxoYTXy97QQx
A2SG2FKdtEeiQOJR57SSHgl9QtLQXvq+KPippMZm2qOwtLrDdM1CejSyjAFu
X82kRyN3h8WaeZr0GNQ5+JF51aTHYPpK59dhYk4sjmRXGIbOkB6Lg44k5SHa
N+B61YB9gjyP2QD3stLx0CrS45Dd4vgeQnscvpsU10ZOkL4RnktEJdHEzEak
7WqYn1ZI+ib0oOvYnjTSN2H/qLOjSUO6AjAy6cnhpCvguneee1tGuhLuucWr
PONIV4I7d37PoAfpKmR2i9f3vrzCdhXyA7K7VlhZc+LRGrgrw6YlPR4DzbwJ
n2DS1Si7/pbHn0a6Gur2scKUrZfZrsGN8vCmZ16sGQ3yXf7iGZZLbNeirWjf
HZ6kfsrQIr13u0j2yM7er8XzO8czg39dmPJdLdrtBWOvGm3sXocXorGLsqt1
7F6HlIVBb472n2X3OjSaz3kJoyzsXgdpz2RbBaea3evx+EFp6UO/k+xeDxef
6brypZjd63HVENfQnb6T3evxJYdn7D6cI/8Dp8GBTw==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0w1MlHUcB/AnrSALF8wJpq5LAdGkSIFSQb7gqXgcb8fxegccD5CjZGQ5
X6jkaZKgZJK83cGJN5IplJjIlkDis5XMYlHajBgWoAQmoGQ4odbr8vnz+z+3
3W6ffZ/v/Z7n9797RswzZM8SBOH0v+//PpWXlFJps9kaLvyviZDM/cvzGpkF
aIXK3E5mZ5RdXXLNuVrxkyhseH7vHOZ5eMLq1Kll9sCd+35DX7D+Ikxfrgh7
lOUaFC021n/J8iW4NPb6t83MnihsH2z6mdkbdXrd6Ix94GE3l/Yxr0DRLpdw
PfNK1C5rjSxgfg4dPuFVIrMf8p/NzXmL+QUYSt7cl8+8Cuv95v+6lXk1Btur
yb78sT/+MesZ5gDcOZd0cTZzIB4vnF0y4xfRfzNwyoX5Jfh+E+qwWxWvQfSt
h69GsnwterwGa79jXod7o3f/6Gb7C8JWn6I50ywPRlV9QOt85vWoPt/vvoM5
BM5TO11n7h84Gfr3ApNiCbiid9n3CctD0RZZ0POaMk8KxfdTb/fdZHkY3tll
TC5jeRiWr/74jL5GyTfAzdfvcrtiaQMCEwesk+z+tSh207b2svla3PeKOTXz
+9mIwMLgs5+y79+ICKn/xnY2fxOCo4JafqpS8k1IOO47qVMsbIZ0wDZzXtJm
hBwjFsKR10zzcGy/QPMtWNtD8y0w/0JzHU6M0FwHz2GaRyBoiOYRcDt9LnjM
ruR6HOmnuR6NP9J+JO710TwSO3tpHoU1Oc6mLpZHwWuu5isPtv9oPHXXuWgV
2380CoYX+hpYHgPXkyV4RTFiML7js9/eZdfHYLGuKa9esRyD7okbAZNHlX4s
ai92GoZZPxYtB+tuf12n9GNRfP4H95frlX4svL12l3d/qPQN6NrmFVN2XOkb
sNt/7JERxZIB3XnN4+XHlL4BQ4tqp0srlX4cllnJPhAH8QO6rzgcOkgsx8Gd
WjDyOYxoopaM8CyhfSMOUAvxuE2NeGS9R/vx6KWW49FyiPYTsOJ92k+AmVpK
gPdh2k9APrWQiH5qJKKhlPYTEXWE9hNhKqP9JHxUTvtJ2EMtJSGugvaTcIJa
SMYoNZIRUkn7yThFz0dORpuN9lOwsob2U1Brp/0U1Byl/RTMoxZMuE6vhwk6
rm/CWfr9sgkLqQUzxun9wAyxmvbNiKe5bEYJfR4hFZNVtJ+KK9RSKg5Ty6lY
QC2kYR3XT8Nerp+GioFXfXMuKf00uO6xO7X9qfTTMdJw/XfbX0o/HS2xn+fe
2tb4oJ+O67OsyR1ODyynw87dvwUD1BoLOrj/kwUT1BYL//ySyg6VZQuW0v0N
WPAG3a+QgaepNRkwUCMDodQW1fVSBn9+jgzMpbmcgWvcfJUFEcXUGhE27vcg
8udvEaGllkR+Pw6Rf15ZxEPcfBFu3PxM/npNJvy5+Zn8/8WSyd+/pLJDZVnl
AZWFLHRx87P4echCAzc/i9+PpModKssqD6gsZPPzNCojmz8fS7ZqvsoOleVs
Nu8f0xDgfQ==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlA9MlGUcx1+orZiskZOU1Dw0HSMHlIqImV/5DwcIx3Ecd3D33nvcQS3C
pVEus4d0jFBRjD93AnmzJlFbWY25pcW7TFLboFUr26jOXKa5CrSOVcKytffh
9zxsN/bZ9/f5Pb/nz12i1mTxRSuKcvb257//xh9z9ASDwaGR/2lyc5p+Y2kb
ZwV3fNQ628H5bvww3NW8k3McWobyz6icF+DgqafvnOu3CI6G4oy5fktwbPHQ
b7WcTRg9l7hwOeflaD4+8Ece5wdR8fZ46jHOq/DQ72w6g3MSJlY4E9oCBifj
xdK8yCTn1Ri7vu7JWF6fgjznnu1f8jwNBYez3ujg/DCcKVffzOD8CC5duX4z
lftrcL8at3QH57WYd6L/WjevX4dn5rmmvuKcjr97lqw5z3k9UuvavjnDOQMT
z2W7i3i/DYg2P9+7n+eZ8EWsPbs4bwROnP4lndc/Cmtp15TniMGb0LA9GN/d
Z/BjmGl/v/Fyv8GbMfqUc6ed1wMrj2/YEWf0Y8Cg9VZrJs+34EJxcO59sC3I
WU1YyYJtNkDyLLRME1ay0bI7/s8oox/Lxq/x1M/BoZW0fw72ptM8Fy8U0TwX
I3aa5+HnRprn4eQemufj0yM0z8e5YZoXYNvXNC9A8jWaFyKS/WEga8DICzHy
E82L8MV3nQNjfH9FuDK+YHabUa+YsXtae2LxUSM3IykhONHB82KMRzof0Lhf
DEuMf9E4P/8SJLnc/3iN+2clMOXPznfw91AK/dTNu0p4XorUqurY8l4j34rm
l5tu6T1GvhUzyM19tdvIy3B+NLHwqsEoQ9OPqwInDWZleKl9eJfZ6KeX4cDj
mc4LvH857vVsav3LWB/l4vmy2xx1Mfs9o59ejpipG2ovn9+C7tdIPSx4/Sj1
LagMEtYtGOym51+BlAPUr0BhO/UrsJCyXoFLlBUrPqcMK0YE34rofdS34i3K
SiXi9lNfYlaJQcp6Jb6lrNgQK8xvw1nKzAZzB/VtCFFWqrDvIPWrMEaZVSFw
iPpVWNZJfTtmaA472GHq26G/Qn07vu+ifjVOU0Y1Wun9sGrE9FK/GvPpfSoO
FASo78Be4fvqQKSP+g70DVDfiXf6qe/EJ7SeOXGR9tOd0CgrNfiAzoMa+Cmz
GgSF91cjzV+L+4T5a5FA98sk1muxkbLiQi1luFAs+C6xXnehUfDd0vm5xX7M
jXcF343Lgq+K85lUJAvzqOJ6qir6TMXHlEMq1tN5dBX9lMMqVgjn58FnlE0e
8X7gwTLKqgdpwvvw4B7KIY90Xx60UQ5LuaKJbJIYGoYoq5o4L9OQQzmkifvT
NUwK+9cQJazvFdnkFd8XvOI8qlf8PWRePCus7xXn0b1YK+xf8pU6TAjrS4w6
cb+qxEyqD0msSxyWWPFJ9++T1pdYleqZxCGfeF+6Tzy/sE98D4pfun+/mEPK
Vb/4e8GkPCT5upSH/eJ8Sr3Yz1Qv5pBYlZhJfqheWl+qD0u50iCySWI0SPuX
mM3xv3d7Yh8=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxVy38s1HEcx/HboemHHzOVNWt+r7Cmc0d+v+7ckd8XtsqacrqpMGZlU5eO
FY44Lr/OjyROfoz5lSnV2VpWadb8SEVI/rBmmIkY/ZrP57v13j5777Hn520p
SQqXslkslujv+7fpyKNK1Wp1k3ZHyz7/m4UD6eclNxjr421qt7KCsTHapKUt
A4xNIf29JHFjbAZ/nvbjJcbmUBdwh0YZW6CjhG+iz9gKnTG6X9PKqW2ga3Xm
cwtjOxhVzd1cKaM+gmdOM1u5jO3ROjI9t8TYEY3TP1UTzP0xLHb1p2wx3Qmu
hkUN5kw/jokvVo46pdQc3BFkKMYYO+Og1HflQTE1FzMZly+qVNQ8bGam5IKx
C5IWGsv5SmpXlIqF2dH51CfAnpPW/7hL7Qaz8LqVNQW1O/b0qbJ5t6k98KpF
+dozg9oT5XnDVbEyai+kuml6c69Se2N+3dbhUCK1D1ZeZFf6n6MG2h2GObPB
xHJgYLTnfoKYdj6aP9TGxYto56NQ+L17ryvtAmhylmrszWgXQIZQjna7kXRf
JG4qzrKp5b6w1ujrmc7TLkSBgseOmaVdiOuf3lj09NEugiZLW7JaSbsIRtFT
A8lJtPshcndUjrU37X5QFr/fGN9Puz8Uo5MWuzYfke4Pm1aXjalKYtZJtAsM
RGMBtJ+EyYLWzn6igfQAPM5IezmbQCwPQNz2uEKqR3sg+F556epwDemBmL5l
fLg1s570IDztdO/t+lVHehCcWE3x2VHErGDIWJODIZyHpAejyDl5X7pOLekh
CNIzjrUtqCE9BI4tYw58y2rSQ3H6XkTWhqqC9FBELnMHhprLSA/DYpEwd3W8
mPQwcC88eXcUhaSLkd8ZZlfcl7VjiGEy0nZF0iEj/8UwFHjgW0L8jvvFWFP1
uOoNRvjs3J9CtUHw86n1az5/AHB1YZQ=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdkwtMlWUYxz8xla1y3sVyeVADdQSKN7wQfxGPIMjlHA73A9+5ARJJzaSm
LT/TrKGTvCFHwT7SQDJdRix1OD8px7SJmsbBWzspotNc6hTLcF3W3tfnfc92
dvbb//09z/NeTrCzzOIJUBSl89/vf7/so+VUeb3exmP/072Y9R/GuLZzVuBN
jC3fxTkQCR2P1j7LB+FJ2NLTX3AehjVBbUPtnINgjTfe2sZ5NAacfCOqlrMJ
o86e6FvBeSym/todonEej5+vd2++xDkEK7TuvWN3MJ6Au+E7yfyTcCmYchjM
/SoDDnAOR96asg1W7k9G/80B327jPAUtK68lZ+9kHIknr+wICOD5VKyL+OXT
KM7T8LQnfmog5+lwDqpIaeb9ZqByiNc2ifNMhPccDjtZzTgK5em767fwfBbO
jes45eM8GyNntsdu5jwH15o3DB7B+81Fc27M/Is8j0aFc9ZvWTx/HY6V5dl/
8TwGR8IK2kJ5DrTb7FGrGWtAkOuG/T2+/3mI6Xr1TlUNy+fh8N+jmzbxPBZR
XavmNHI/Fhd7W48P5PXnwz+l9MJ11l+bj5u10x7f5PPEoVpf+UDnfhwe3jkW
fJ7nCxAxe+aF77i/AFNyvOR+zRhQQlgzw7eK5gsxbCvNF2JvA83j0XKU5vGo
7Ty37AyfPwHL2io7zvL5EpByi/qLML2b+oswt4vmicB1miciqTnyYBHPk+Bb
PiPQw/Mk1LVHjnTyfDHmXqb+Yhz30frJuOgrKz7B7kNLxrpTvtE2neUpiBqy
v+I+z1Pw1RnqpyL6NGGk4vxJ2i8Vy9sIG6l4+Qfqp6HkOPXTsKiF+mkIOUT9
NDz6hvoWzD5AfQuu7qO+BZmnB195jvsWtNT3Wur4/Vgx5ss/ljYzhhUPtlDf
ip820v5W1H1d5p7M3286nk9w9C/fxfx09DwuvTH9c+ano23sn0VH2Xka6Qje
OLFPYi3zbbjce6qp/DPm2zA0Qj+bXs98G/bcDj52tYn5Nrx0t+vNfQeYn4HY
3qHLrPuZn4HQkOFLG9g8WgZwv358dR3zMxC5YULrasZKJjreL+ifwf6fyMS9
1+zuOWweLRMHbzu+/53tx8jEpltPS9/ZzfwsfNwwqvVhA/OzUPFie72Z1dey
ELR1YtXaPczPwu3hj32hvH826vp+ZF7BzgPZ6Cv837JhpmxIuZKDQ9vo/efg
hSrq5+CD7dTPwds0V3LRQRm5qKmmfi5sXurnonMH9fMwoIb6eQiirOXBXEv9
PBRTVuyYQRl2cb1mF+sbdkTvpH4+LHQe5MNL59XyMUSYPx+V9DyUAiRRRgF0
yloBWoXzK8BDwVfRj56XScUIylCxnrKqolCYTxXPV5fYUOGk+/OrmCycvwNj
KJscGCichwNPaT1VyjWHWE93YB5lQ6rvd6CR1lOcIpuceJcynPhE6O+U9u9E
nLB/J44I+5fq+Z3i+Sgusb7JhWlCf5dYX3VJ/V24R+9Hd6GP0N8l9vO74Kfr
Fbfom9zie4OUq27R19wYJ+xf8g23+J79bvE8FI/IJo84PzxiPdUjno8m+boH
V4T+Evs9+FHoXyiySWIUivOrheJ9aRLr0npDyv2F0vsrEt+LSWIUietVibUi
sZ8usSGt90usFEvvX2IUi/OoUq4VS/0lNoql/UusLJHe/xLRh5SrEmsS65Jv
SOyX1islUv8Sqb+UqyXS/iXWJTakev5n/A/Ls88h
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxVzQ1M1GUAx/E72gxYpBUUA5lgvBVnoHK8CMiPV49Djrvj3nkpOcHAt0IF
miL/CEHkzePk9MIRgiBopiGlJhsn6ZQTZuAipmC4hAgTUQHzPRrP83c927Nn
n3332+OSulmaZsHhcDbN3v9eehiNwWg0tnTMaTL0/+bg+z9d23JZW8J3+9TD
bNYLkJnqHp3J2hZnpkfdX3V7xBhe3MlhvRCON3dtXcHaGV6jkqBa1otx99H9
qELWrljwk7504gC1O3qmTrtVsPYEr9Fu+0bWH8Jpr9UHr8zD7qD9iR2sP8LQ
H1kv61j7QMQNrPJivRQWR65GNeynXoYXn99fNp/1ciSreefqDNS+yBDM6C6z
nY/OosGjvWz3ww39bWcn1v54efzi8m/2UQfAcrrGa5GeOhArNfaqd6upV+Dv
Z/PWRLM9CM1XNM1JrIOxc0sJTJXUIagY+TQ9tox6Jf6J5y4a2EMdij1efgXb
iqiB9Rn4q3MXMQN0LIHjpnzaw+CnCNv5pID2MJyzFAnSvqI9HL2N5h5mJ+3h
OPlx8MJvd9AegZ7IkwImj/YIZGZXdbfn0h6JB8Ez6QNbaY9EpGv+uPtntEfh
ebELo9fSHoXhUachDxnt0eic4Nu8ENMejSfbUk5oImhfBQ/LyajnfrSvgnhe
33enqDkCLOZ7nFDOp10Ao/mo/ODjZtJjsMEqSJdyi5iJgXWX6XHSTdqFuCXP
ynf7hXYhRtvKHKxaaY+Fbn32yUfUTCw8VzqaPetpX43tZieZtpj21egaP245
oqQ9Dlpu18T1ANrj0D8/k6+wpl2Ehhvt9WUDR0gX4VnIxv519cSceDQek395
1Zv2eKQ0Gfunp5pIF2O/b3LC0j5iiJEoKrRX/0rMiNGubfA8e4LYJIZ3n19F
ny/dSxCutj6om2okewmujbdLMuOIGQnOy2NCBmyITRLEXS+uPb7lMNlL8Ump
T3l5ADGkSPrCs7tb2ED2Upx9ao5+MllP9lK05HAt3jlPzEnASwd/k27qENkn
oDxQ+mb0IWImAVmXBqta3YhNCdCaAi7tU9eRvQx8zeFTHWO1ZC+D/96GMNf+
GrKXYfJu5lPbBiPZy1AsWmJeYzCQvRz+v6U2CcaqyV4O0b2kwbd1xIwcasWy
NbdH9GQ/29t4PwtP68hegYmUg+nSikqyV+DCj8N2F1xKyV6B2I1rz7iEFpO9
AnlhqqnfZ3aTvRJfD9utfb+kiOyVGPHZHJhqW0j2Shjtrtnw3ssjeyW4laa0
Y/rNZK9CzoO8gZjctWSvQvnFFsu3kokZFUw1/RYlDsQmFZxtQobv/JBB9moc
bbpcPxa1juzVuGJreFixPpns1ah9zSai9w0h2atn/3/9nvoZP3Rur8GiKzua
pAr1nKFBUTeqOzXyOTMaFNa0msO7tHM2aSDWbSjw5maTfSKEQ9UHJLwdZJ+I
S5Mj9jO8gtB/AecmNHc=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw9zg00lXcAx/EbpczarJc1V2cZojCJvCxyfynv7/e6r96uuyhy10mmN831
knntXoQwul5SraXpZDhxRqRsvWCdJYw0LekNS6daadvx/z/POc95zuf8nu//
eT6T7eJGarBYrG//u/9/0kshKSopKTn985wmOWcmljz6kTELK/vfnItivAgP
k78x1mCsi1OHwx4MH6NeBnm7++CfjD9BWcuS5ycZr4Sv3NssnrEB9vNqPeuL
qQ3hGSF6uYvZjVG20b6BzXzPBKedFpW4Ml6DqaTu97uZ3gyJTeYxdkxvgclW
n2dKZreEY1xd3V3GVngUXeRypIh6PazNEljbmN0a48bRjZ2F1DaoahWn3S+g
3gC28vixKsa2OC+P6HvB2A43Px/M2sfYHl06LZqpSmoHpGbPlPTkU3+BpJYG
sTKPeiNmtdj/iJn3HeGov/TDBhW1E1LN+Go+s2/CD/wF19lM7wzLTqOg+8z5
HMTphHRwmf8BrN69tJPRXgFUWU2U7s6i+2YMqC5WmWTSfTOSJrLc1iro7oIc
y9nx0SS6u+Bjp/lfRyfSfQsKTMsM3+yl+xYcteQkhO6j+1YMWWlVJ8vpvhW6
4+lpBV/S3RUXHmttk1ErXHFkk8S+O4LubshxHJY1iejuhurJRAOlgO7uiIsa
L3EV090devemOLf86O6B9g9sY5dSKzxgkmlhobKnuydGvTQz9czp7olsv56x
0lV090KKZ/mShZp094Ltzh7Vb+OnyO4NaxnPeeAascIbFc0u6Y0X6e4D6fbU
c9lNdPeBxE0j2buQ7r4w9WNfequmuy9u/OJk5FpKdz84PN1QuSyd7n7Qb594
WJNLd38szVaoNXl090eGg4Gt2o7uAbg6sF7vzAJiBEB36oROzF8nyfsBEOyJ
2WN0jbgtAM3a8Vy3BmJWIKyuicbSmogRiNj+q7/afkP7QCR1dI0e4NA+ELO/
i9/TfltLei6eeImsVsuJwcXIbJtF5eMTpOfCsFpfhzVM3MaFdb3Uw7mFmMWD
i2HjHVYyMXjoOxgrj5PRngftw4HuOxbTngfjBbcGtpbXkD4Ieu+EDeyDxAhC
/v7a5jpVNemDYJjlfGh5JHFbEObd1jA9+1MV6flYtPOKySp9YvDR7R11I6a1
kvR8SKO2qUx61aTn43poWgonmpglQGxXuzp6HjEEMBtUF5fePk56ATp4gkKn
4QrSC2Dz+Ppw2OVy0guReGphvVU/MYQYXamRH7L4O9ILIXfT1darJW4TovNT
R+WrujLSi7DuefmUx41S0ovwQPtegHF/CelFCFDuvjUtJm4TYc2L9Ko4G2KW
GKw67ellpUWkF0Mqyte28ykkvRj+Z/tye9uPkl6MPSfdz9qeJmZJcCllYzKq
C0gvwaibcF3fWB7pJRi7czFNaaQivQQXhC2+ka+PkD4Yav+KoZawXNIH46O8
N+YW4xmkD0b/Xdl4YFca6YPxN9ad77qcTPoQXHliyOqtUJA+BCs6/GcufE92
RQhS3na25947RPoQsF9XTWpOJJA+FNqbn9zmHNhF+lAcymEryoIiSR8Kr2mH
oR2OXqQPxUje9qS18CR9GLAqXv10hTfpw3DHZdBRWMrlzPVhiH8uGZ4Jlc+5
LQzmpiPz/5DtnjMrHH3xfPfJ4b1zRjiUN4uXhxxUkD4cFvnHuxJepZA+HGkZ
lcWt9amkl6J5x01cUmXM2UCKiZGaiOoKYkgxPfSV1hXbzDlLpZgx7N1gszqH
nC+FsQav8diz7DmrpQjudRA4zJC9TQppz92a5E1Kzr/EdbIc
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxNlX1U0/UexycQoHkSAhnq1JGiYkgKqIDC3jw/yAR5GGOM8dsTadIlYA4U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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdk39MlHUcx59arpQZtI68mbOznKGhUVoCQb6POxUQ5DjuuB9wd8/dcUZj
aWs1qDl7cs1FRCgm3CHmYbmJkOda5UTIZ4GlgbehKInnoDkc/bButjb7g9mv
PV8/3+9tt9tr7+/r+/58n+d7SwLbrKF7JUmK/fP991f7KO62SCTSffp/Sq7r
ffN0yQBjCbovs20HGD+AOnNx+G3Gafjpmmf2LuvwSqxr9QhjPXrj+fOf6tB4
EYbu5Lw6xNiAlfrE+ZcZP47aiZm04H6NlyLe2HjUyfJl+MNY9kgf4wz8lnF1
+mvWtwILBp7+eZBxJg4W/XrjBONVaDcNr40xzsJ0sKlsC+NnkBIptB9h/Cws
hwbtixmvxvHhyd+PhTVeg6359519iPFzmJcV70u0afw8dl5JaZlhvBbuljM7
wu0aZ2M8Oxa+wvIcmHIbDi7ep3Eu9J+e7PSz9S/AO9JgUhnnoT+zp22c9eej
3/75hIHN+yLcPbs+bmC8Di7v9tcusfWAcY9twVaNFaBrZWr+TpYbkTea0N+v
+YoRLaWXxiS2XwEC9T1Nt5lfgOaheHqS+SbkKiOLZlhuwp9zIuS+mXErlbBi
xsRCmq+HOZPm6zE/3pu+i+UbUPB9f/Jdlm/AV7XU34jc7dTfiIwnj9UvZ3kh
JvJa9y5leSEKwvNe72LzF+H6NmeGnuVFuDlG9y/G7Rm6fzGOmMeX5bH7uQm1
N2i+CXXT1C/B4es0L8HkjzQvxTuTNC9F4zWab8bCqzTfjIEfaF6GlMs0L8Mp
bn4Lvh0lDAuK43S9BYlhwqoFv3xH/XI0n6F+Obq/oX45oir1y6EboL4Vj56i
vhV3vqC+Febj1Lei7ij1K5D6CfUrcGg/9StgaaN+Bc59QH0bBhupb0PO+9S3
4eEm6tvwEmXJjg7KsCON7q/Y+T7VjlXN1K9EK2VUYseH1K9Eegv1K5GkLDl4
hgPDu6nvwCxl1YHDe6jvxFgr9Z1Q91LfiTrKqhO6j6jvwhv7qO/CnDD1Xfjv
+jDfBYW+H8mNJRf/eutWt+a74ThAfTdGO6nvho7mUhViNEcVVMpKFXy0T62C
sYP61bhJ50M1P69SjSZ6HrUac9up78EKyvDAQ1nx4AJl1YNOup/kxWeU4cUT
XL8XD9J5VS8/r+RDgObwIYuy4sNjnO8Tzi/zuUHmcwi5LAv7y3x/VFivypil
807J/POV/IhQNvixhXsffv55yH4kufvlxz00jwqs+rGG6/fDzvUH+PWGAN8H
geWA0C/kUSFXhf2nBJaC6Ob6g8L5g6jn+gVWgvz5okF+HjXIn3dK8KUaJLh+
gSGwXCP01/DvL1oj/N8Ff0rIpRD6uH6BEeKfjxzCe1x/SOgXWL3LfwOxGuLY

         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlA9MlHUYx19I0EwNMR0WsCNcKTHFk38ZxJc/IgIKd3B3HHBwd0iEE//E
bs1W9o6oZCgEJnIgyEyGDCZ/lApFfSv6I3ORNk8sFMLNVejE4Wo2kmzt9+v5
vbfdbp9938/zPO/z++0C7Dv1he6SJDU//v77yz5ydp3T6Wy/8B9NxZhKDLOj
nCVMLM3/vo/zPCwr7vOJ5OyFG294ulz1jJ/Bnitnlvjw3AeVv3c+WczZF+fu
3WmN56xB4/K2oVTuP48F27qLLh9mvAJrVh0c28rzF/BoVbX8NOeVmBM66Vdb
xzgIzds/TrFxDsbO8nc6AjmvxqkBR2ngIcYhuFT1sPxWDeO1uD4wX3PnIGMt
vuuMHHyJ8zokGrTuYfz5UER3hLnPVjMOQ1LJe+lHqxiHY8a66+wPHzGOQObw
5Xf7eL1IRM5L2OWqZfwy+m//0pDG8/WQ9i2ZnOb5K3hfV3nVzuePwuv+ZxfU
8H1Fo+Ka49Juzq9isd9yZwLfVwwUN+8ZLWdgadRQhD9jGVhodJL7EIubydtb
A3kei66Ra4PjvH4cCj0doU80sDwOgxL149HgRViOh5/dNr2N5wm4cXLI7snz
BBQWeB17xOfbgA/LowO/4P034MDPsTMvcj8RphXtt0N4noiKdXtSb3J/IwKe
m+heyOtvhK8h8dhi7ifhp9/6I7/kfhKOZ+zI8+P+JrjGHB072PvKmxBefHfi
Hs+ToX9tzdxJ7ifjSNMf2hhePwXnPRxdEbx/CpIC3S5qeZ6K0pXf9H7N/VRU
NEWdC+b5Zsxcp/vbjEEX3e8WPJsffPXTRpZvQdQVmqehcZj6adBO+evreZ4O
8xDJkY74b+nz6YgeJKykY/UFWl+HrgHq6zDnc+rr8PYp6uuw/iT19ZDaqK/H
X59QX48HLdTXQ26kfgYeHKZ+Bh7WUD8DRZXUz8D+W08ZPZuYn4kSeau5t4X5
mRhd65IsJ5ifCTPckqaPMz8T3r3zm8tamW/An/09pROsHgz4O+D+Ra9m5hvw
gcY0CsaKAW376fxGlB2g8xsRVEXnN6KEsmJEN2XJhLeqqW/CGGXZBO3ekRP3
2f+HYkKQ2+5fa/n/SRYW0X0hC9G11M/C6U6LzsHul5KFuK+CisoZS2b0eMyd
Pcr48bZ8fXNP/8j2IZvhOETnN6Osjs6fDW8n7Z+NkQbaPxs19LyVbJiaqJ+D
cMrIQc4R6ueo/Bx8RutLuVhEGbmIFfrnivMpuXBSliwYrqe+BRGUZQtS6f1U
LNhLWcoTc+ShmrKchxbBz0OP4OfDQ+ivYjkfZsqKiiUrllHWWFEp1LPiPGWr
Kpet4j5arLgr7EvF41bYhf3bUEpZY0OIcB420bfacIaybEOo0N+GKeF9beL5
jduQIJyfXZxfY8c+4T7aYRD62/Gm0N+OUaG/ihW7OO+4qr5UoOpfgHahvyq3
qnJZxS3/P/8PXZVoBA==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlAtMlWUcxr+SRboMR8RlQh4IVOwCAVkIxIPc75dzAc7h8p1zuGiS0hqJ
ivUZTG5yk4vcgqPlJq3GRgYbbfDhiiYajCCGZNtR59jMW2u2nM6y5fv2vu/Z
zs5+e/7P//qdz9uyL6v4aUmSJh5///0lH8XY1dPTMzT5H92NjK7P1g5RlrBw
LvJSDeVnsXd0Im2R8gY4n7y70EjZBRnXq21zlN1xT7fFvYmyJxYvz856UdbA
0Xsw/Ug3YR+0O61OVp0g7IvvOmve2015M0KW9iQ3UN6K0nHP+ZEuwtuw/QPX
K7cov4pHpkunQjsJv46AteFHz1J/IEIdtwzmUX4DfVW+rVbaTxCiB9yVAtpv
MAK75wK3UQ7Bcq5y2ETj38Rqg9+Hm6i+HaMPIzZ6UH4Lg7vby+dp/Ns47x3v
O0Prh6LjRsn1MqrvgJt1xPiQchg8NvYy9wpHwBqWI1B7tYfhd9A4xXIk3j3J
MjBWzbACVDhXXk3oJXoU6ufHVpr7iB6Fa3//VnaGsLQT+4L9DjpSfSdOV83W
rlA9Gi89yploIfmUaGzf5H9vjOaPwTcOz7n4UD0GlwsLDKdpf7G47Xc7dJT2
Fwsno/GHn+l943DYYeb7KLI/JQ6v2ePvX6X7jMdNz4W6OyReiYfbauTnS/R5
SEDSSHr7AGElAV8U73A9QPMn4tCDM1a/DqInwuf39ZX+VE9Cw/iV1CBaPwmR
RxqlSZo/GU4djuVJbURPxvxg0MW440RPQcuViOXCVqKnIPH+ej8DiZdSMfPZ
Be8XqJ4KT33YnnDCUhq+9Ar8Y6qe6Gk4WPGrz406oqfDp2LvulvHiJ4Oa3VT
USxhKQPXQp5Z+8vRJ4wMLGsDvvavIvEZcPXfHRz08RNWM6DbfD5w3RHiz0TQ
8vApB6IjEy4Hpu+cJvmUTEy/eHZnGIlXM7Fy07JwcT/xZ6Fjw6a/Zg4TfxZK
G6c/aagh/iyUrdfUDdcS/2NeqXTraCR+Lb49VB69kTC0GM7aGoUW4tdiaFeN
VE3up2qhy4h/pb+Z+HUo39UfP0X2BR00x9j/gw4PWFZ18Gpi/z96vM8y9Fhl
WdHD1sz69bjGsmTARAvrN2C8lfUbMNrG+g1oO876s7HIMrIx0M76s7Gmg/Vn
o5dlKQc/sowcVHSy/hwsdbH+HJw7wfpzcaib9efiQg/rz8VyL+vPRWg/6zfC
5VPWb4TK6ooRa1hdNWKA85vwZx/rNyGNZcWECJZVEyxsP1IeOllGHq8rebjF
zqPmIYrz52OOmz8fH7H7UfLhwbKajxRufwX4iWUU8PtVCpDL5lcL0MiyVCjU
L0QIt/9CvMz1X8jfS5LxFcsaGU+x8ZBhZ3VZhp7LL8TbZDzP3Vvm92UXWDLz
rBEYZv4eshmB3H3MfD2bGXXcvGZcZtlu5vuXLChhWSMwLPw+ZQtiuPkFtlng
zNW38PuxCyxZedZY+Xqw8vlkgRUrf1+bkE+18vParejh6hdhP1e/SKhfhHGu
fhG/T0XQbYKuFvHvA7sQLxXzrBEYAsvFwvtFYJsQrxZjiKtfLMxfwuuaEl5H
Cf88yQIrAtsEVgW2C/WkUl7XCIxSPl4u5ftTBN32v/4PNeIgOw==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw9zWtI01EYx/G/Eqayci/Ce1Czhg0NLbN10f10Om+bZtYm6lxkWtpkXhAS
paYuMWdTu2gzkmVZFlSISVim2RIDyevKNH1hOBHE8oWgr7Sic86Bw+HDl+c8
e8/rTmc7chyHv/ffS48+rclsNj/r/69VSfKWtW6cmcNApo1fy+wM80RmZzEz
H07Ln22FzLswUSOX8lqoPcGf3fzRyewLE2+sJvg+9R5otGq3GWYBXgmyd+Qy
78O513bhMLMQ2973p2nYPn+EGEpN15qpRciYTjd2MwegiqseWGY+CFWW8ovy
HnUQDuT3jdQ3UQdDe7NgNIn1Q/hmrxPPs/nDkAk/zCXfpQ5B+a7NixuN1Efg
cKUroKieOhQ3lnhnVA3URxHm4femlFmMMt2kfI3NH0Oo/6LRz0R9HGuXW8Zy
2H8nELJl6fNjPolR1+D5zGrqMBi9dHO3r1OHY6l90BJbQS0Bb6NEYyujBqx6
jcBbR6wH+C7dvXNptEfA124K16TTHoHewcC8HNYjUVr5Tj+koT0Sq2499ZOX
aJeiTZGa7cK6FFWi3un8cNqjsG7qEiwKaY9CYpR9qsqT9mjYxj2dpn51kB6N
kbejHeVDxJwMEVxPBa+Hdhlai5UeQwbaY7BSrVm4lUJ7DK4amrbLXGiPxcfI
dW1Qy1PSYzGrmJnxDiTm4tBalKXif31CehzUatEw1MRcPFTfG1OdXdtJj0fl
wspvb+lj0hOgzNA617k/Ij0BDy0/3Xc6t5Eux8v0T7kpkxbS5RAXvPCyNj4g
XQFJn8PKxCkz6Qo8V1ut+y/cIT0Rjm61Je7GBtITkXF2S2QqMZCeBJ/d6z45
4kLSk+CgUgY2j+RJ/gDezz6Q
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlAtQVFUcxq9aomM+RhvTzGHJdAoMRRHxlR+IoIgICyzL7gJ3d9knpo5m
WoZz1SwfiDmZCqntVAOhYablixiuKOloGGnJ6Mi2OqY5jolNKhEy1dQ5/s9h
Zof5zXd+5zvn3HNvhGOh0dVdUZRr//z+/c/+NMu28vLy6vr/qG26s1/H1g7O
Cr6pb24Ncu6FhbVjYto5D8CpFYGHZzk/De/Z12ytnIcgzBzdMIrzc6gNnRs3
hLMBRU1v/Xya8/P41L9svZHzC+if28uWynkULPFhlk7OL2LMx6YbL1UwjkRU
cVONgfNoXNpk6OrgHI3+z1xvGf4h47GwlA29kcXzGJij4sNv8/nH4Y/5hxd/
yXk8Io7U3b26g3EsykYPu9nMeQJ6vnk1P45zHNJibxX6OE9Ee/KW/cO2M46H
pbLv2+3bGE/Cs65SNZqPnwz3+bWDJ3GeAlNIn9bIeSoeBe1dds7TUDJ5+oVH
fP5XULNvyhOHOE9H0uJ1e4fzPuBAWNj8jA/+Zw0YWbXk0n7GSgL2j4rSU9n8
WgIu1/Uetov3JeLu0PLH90dLhO/PHeQ+zUDXfcLaDPT7MTIvkp93Ejq/tl7k
z0tLwspPxlWN5PlM/BBJ55+JExMJK8noMYfmycgpoHkK2tw0T8HtpTSfhehN
NJ+FYuveM0G+v9moP0jz2Vh9mvqpOHSZ5qmYcovmc6D+SvM5SLxJ8zQ8uE7z
NMRWnjr5Gc/nwneV5nNhC1E/HTFBmqejtZXm81B6hebzsIauV8nA8RbCyMCq
i3R8BpoX+poHsfujZyCimfqZONhE/UzEn6F+JvrS89IzkX6S+kao9dQ3IrmO
+kZ8e88xeOdO5hvhDSZEmyqZn4VjanrLhADzs9D6RePaC3uYn4WxkS3mCyzX
szDwSOZ39l3Mz4av8uDLWxkjG+e30/5sbNxM15+NA+vp+nPQcwNdfw52U9Zy
8DtlPQeDNlLfBA9lmNBKWTMhsZT6JlRRVnJhndD/2Db2PiMXAzIe3l/0PvNz
cfTEvGBKKfNzUVK3vPpBGfPNCN5Z40t7h/lmVBW64lZuYb4ZZQ0lFUffY74Z
JSeemrFoNfPzgOt1Fd1WMT8Pfa4t+OqnpczPQ+e5PW2dK5mfh0lZNYkp3Lfg
VMzUipnvMt+C8Ht9jndsZL4F3d+Iu3RtA/Mt+EXZvu/iOuZbEe4Z8ci4gPlW
NOqvb6ldznwrlh+ePTyK91txruZOxEdrmW9D9W/jzxjdzLfhuKf3X6qF+Tbs
7gouysxmvg2DGsPWHGb7VfKxe29ZQ5PG/Hz4V6R9XsvXn48n23MX9GCs5yOf
3i+lAJspowCRwv0rwKuU9QI0CH4hVuygfiG+p6wVorqc+oVYUkF9FUbKBhUO
ylBxlvqqimOUNRV3KAdUlAt90vwhFQlCv11kg10cD7u4XlXKNTv6UQ5I8+kS
h+wIF/od4voNEsMhnp/qQI6wfwcGCvt3oI2evy5xSGLFiSSh34kRQr9TPE/V
CbfQ70Ss0O8U16NLeUjKlSKxzyAxisTxahG6Cf1FCNH9BKRcL5L2L82vuKR+
lzgfXFK/xJrEAZfU75L6JVbc4vkY3OLzhVs6f7d4HzSJA9J43S0+r5AbV4T9
e8T3yeAR54NHev88oq9JeUDKdYlD0njFK+YGr7geeKX9e7FM6PeK5x3wSvdP
ykNe6fx9Ym7wie8DfNL+fdL+feJ6AhLrPqwT+iVf8Uv794t9kFj1S98/v3g+
Ab/0vfVL/RIrxSIbJEax9P2RWCuW+iXWJQ5JrMwX2fCY/wZwagxP
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlA9MlHUYx9/+CMwK3I0QODZJ0ZIhIEgYoXz5f4jIHXfHcccBByyDFrFs
iGi0l5rZknHgNeQQ4kxXMUeS4RJJetE5EMw2/BMMF6A22zS9FfinVKK19+H3
/m673T77Pp/n+b3P7+5eKqnMeeNpQRBc8+//PuWXaGl2Op2dP/5P7oS3BqcS
JokF1Nc13FK3yuyFpIxzZdXES7A3zNptIvbFCfG3vgny/fGpKj28lfIgLH6/
vMWfOBjP3/+zLZB4OXITQrQHiUPQsWjX7VjqtwreuHC2v0XmV/DFV0M3zuyX
ORRV5988lkD1YWg43PP2faoPh09V1J7rVB+J4JlJ+0HK10IVeasxhuZH4dzX
o1WDlEfjj9Dl9gVeh4gdhREamheDzOTDbWuIX8W7s4HqPVQfi5/qykfTKF8P
berEUT/i13Daf8XxtVQfhwvjZ7dvJH4dGdqJlvPE8Rh/athnYd8bEDtonogi
3ghLr2CoJ05AxVjowwpi4PQLv1fqZRaBxppqrz7qn4jIWsfQZZnFRAzPpW0l
FpIQfeL6tr/lfYpJqEnq9jQ2y3kyvvRYOSTJLCZjvH9nl532n4KZv7b98w31
T0F8tC3/NvVPxTMVAxG0TzEV5lm1y5POn4YW1PaqKE9D+/h4jzfl6eiJe/Ty
EsrToeqdvfwi5RqMWO8dukjzNSj8wWv3NM3PwKVrWTdHKM9A3GSQtw/5m2D3
uOig84qbENexc3o95ZmobF18aIzyTLjd8bafqf9mqNcZn31C+WZcO7k1Zo7y
LCwN6DtVRvvLgm/HO52aJjnfgkBVSveAQ863YMI/+jk17T8bA4lhBjXl2fBz
Lj1QT/218BM6fXfJDC3capeunM6jRcDV2MBqmSUtTJ89uFNLvg4x2VXBGvJ1
0Hvc9D1Fvg4OP3sg/b4kHcI9CyQ7+TnY/d102Mfk52BN8Sef0/2KOfPf/w+C
6P6k+fy4VqT7EPSYq3toPkK+Hjfwq3GU5utxr/1R12ry9TDtGG6Lo/sx4K67
yXGXfAM+fLJo1WPyDeg/Urv9Cp3fgI4ryZkh5BsxpLsTKZFvhH/UnOQg3wi7
6diGhfMbsWx1uovOI+RipsG58P+LXEQ3MizmoqSJYSkXl/YxLJjm74P1Tahh
WTTB0cz6Jky1sH4eclpZPw/fsyzmYWU76+ehjGXBjKNtrG+GeID1zRhj+0lm
LGNZsOCxk/UtiFTMtyjPK1lgZOuFfLjZHPnQsCzmY2Y/6+cjgGXBigd5pR/9
ckb2rfiWzUUrRhW+FX6K/RVgr2J+AboU8zmWCqBSnL8QJxXPX4j3FM9fiBLF
/grhrdhfEbe/IlxlWSxS7ksqUu5LsGEFmwfblPWwKfvZOBZtGGHZxbHE8RTn
C8VKDuYYHNs4Fou5+RxLHE9xvlCizINLuPvgchuXixy7uHqJ4ymuXiiFUzG/
FJ2K+RzbuHqRYxdXL3H51AL/C/LyfKE=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlH9MVWUYx0+6tLUMx5qVa+uUpqwhE0V+aDe+KPJDES9wL3DvhcuBe/nN
rTVa6wd/vE0tw4hmBlwQ7plkxfwDo7UpLjzNH0tU2oK2HEhn1XBOMeesNHVl
q/vyvM/d7u4++z6f93nf57znPlP1cmH1PE3Tfrv//fc3+hHejnA4PHD8P7qe
7vhl2uiUrOHwkSsz3ZIfwsLYHQtmJC/GRe/f9kHJj6EvPtO3V/ITSFwf5+2X
/BSeXObr+1SyjsZdx1p2Sn4Wr7oWLfJIXo7e7kuvp0pegXm7mvPzJMdh8uhL
bydJfh67j8b+niY5HsGJZrwlOQHj592RLsmrcSjVF/hLciI6etJuv9Md5TVo
Pxmb0yPztZh8eLRxbv9JWHsm0ntF8jqY339eE5B+Mp57s3dwWuYpGGipiIxK
TsWOztID5yWnIWfdhbT50l+PLzpbXSslb8C5tqtdf8r6F3DqZs14mswdmFg8
Hdch+UUMvXtn+IasT8eeqfT0W5KBU46fHFNRFsDx20X6XP8M3F0anrsfIgMJ
N7rIfdmIyC3CYiOuLST12iY0L6H+JoRzlrqy5fqZGEqheSb+yKX+ZkTKaL4Z
ztdonoXDH9A8C6s+oXk2jozQPBsxP9A8Bxsu0zwHZy7RPBfzZ2ieixO/0nwL
Jn+m+Ra02zTfiphpmm/F41M0z8PoBZrnofVHmm/D7ATNt6FtgWMsf380z8eW
nTVr3oiyyIev4uxwv8y34/S31N+O5NN0fScaviEMJ0IWrXei5GvClhP+Y9Qv
QMxX1C+A90vqFyB7kPoFmD1E/UL4DlK/EOMm9QsR6qR+IfL3Ur8I5/ZQvwhD
71G/CNdeWTU4Fon6Rehrpb4LyxXfhYuUhQuJ79P+LtyhrLmR0EZ9Nx6hLNzo
p2y5EaL3VSvGinbqF2OEsiiG+0PqF+MqZa0EfjoPlOAEZVGClo+oX4K6fdQv
RefH1C+Fs4P6jK1SlNPnoXmQ0kV9D0YoCw9mw9T3oG8/9b3I6qW+F8mUhRc+
Wm95cbKH+j4coAzGwod4ypYPDsUvw+Vu6pdhN92vKMMyZf9luKmcv/z+/zP1
y9X5CMZWOZbQ+Wh+Nj8/vlPm51frLT9WKn4FHlT8CngUn+VWBUxl/4a6f91Q
zwdD9Q0DtrK+gTCdj2mw521ggLJtYDWdt1aJKso6Y1TiacoGy0UlMiibrN5i
bFfiUaV/lbpfvQpTlFGFe5QNxoKxyXyLsc1YC6BG6R9AptI/gOvK/ANIUvoH
8IDSn7HF2A4gVukfVNfXGSOo+kaQ9Q+q65lB9f2xghhW+gdxVulfrdbrjFGt
1hvV6vwEY5OxxXyb5VqNyjpjMDYYC8YmY6uGnZ+xVquyXqu+T6hV52EwFqze
ZGzVsveP9dPq1FyvU3MwNhiLOnb+OnXeFmOb1Wv1bP6MUY+xu47me5mf/d+f
5YKxydhibNez+9egst7A+rPcYCwa1HmYDeo8LcY2Y61RfV56o5qD5QZjwerN
RjZ/xjZjrYndvyY1B2OD1Ysmdv+a2PlZvc1YC7H+IXb+ELv/jAVjM8Tu/xz/
A1q0djY=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw9y3lIk3Ecx/GnKLQ7pJGl5C1mkWnqunQfbXPznBbS8UfOIsE/OpZFadnW
hkeWFB6zmdTyPgoro7RpljZCMywkJRUtDzJNKUuN/bEO/H2fB348vHh/P05H
Tu49tpDjONm/9/9Pn/qQTq/XVzXP67toILvJXMubw4TB3fc6b2tIi8c0l3iv
xoO+UvvfvNdAaBZq43nbQp71R7+Ktz1+HbIqOcPbEdxhndCvkOyMzi1ozeHt
ioIKc8c4f++O+uGAeI+bZA+U6N4vzNeRPREf7NXyI4+8GRdnWue8eW9Bc87U
lE0OeSsyVoTvaMgme+OyS6B10VWyDyYszk3vrpG34XSp2M0pi+yLHt37zGot
2Q8O2pf5ZZfJ/iisnG3YkEYWQla4+udH/n47HBvtfC0q8g48Dx130CaTd0Lg
rk3qSSLvwsjQ3Yi2s+TdONHedkCgJAdgxdoLiTWJ5EAIe02bqo+SRWhLu6pK
2E8GFAMa9Y0wZjVw7+siyTNv6kHIyU4dTXakHgSVJtU5yVzJejCaPG3Ca0aZ
1cFoXOz2uuUt9T1Y0G2V/riL+h6kzexz7WmkLsaz0Y7E9jzqYrQPCauWpVCX
QOzV+Ul6kLoExbWm3I5t1ENgynvycMyKeghcflbNKborWJci4ezz2cynzGop
LCvfjEzHUpfh/rkznhlfylmXwXW9enJpPTMXitRIG9WFw9RD8br/QLpPXxnr
YVjCOWh8BczqMOybvFJrlJWyHg5/+zrbKJcS1sPRP51yfp28mPUICEWfx4K7
7rIeAaMld2XvRmYuEnGGznTBKwPrkcgssVWm2DFzUYgX2I/sFN9mPQovVHXD
yYFFrMvRdPHhHQeTnnU5+iVTyopvBaxHY/KRtN4pO2/eiEaD2aszoegGu4+G
8JZ8/NyHrHm/iIZx3CAJrNewfQy6FYPX3MqVbB8Dn9bjd7TKWLaPgXFR83KT
JU40v4/BhHR4UKE5JfoL8Xd2ng==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1H9MlVUYB/AXtY3UCJthlFtXU0fkSjFFEeXLLwUEgQuXHxe4vPcCgq1G
rFz9I5zUTRQJEIMuXuVO+zFkTcViaBlvBGG0ZRLLlWCXBqtZMpdguGZma+/h
OQ8bY5993+95zjnvvSxxlVtLZmma9u2D3//+mj/C3uR2u9u6/9etqFkD9x7O
ltbQ2NA1u0LaHy843ojfJx2IR6fvls7kC5G0oPqRmfWegGt15MZPpRfj+pqD
y8OkLQja1Ob8UnopQuoeDz4hvQz9N2u6z0mvwJNfp/YNSocgfM+pQEM6FIG3
xxr9W0yvxGZUTjZKP4/DJT0hidKr0NIcnJcrvRrvtV75uF06DAkTFb0hR02v
Qdkn/SO7pF+E83xdRIf0WsR8kBpbcsz0Ouij9lHrcdPheK22obBeej2a//Hr
e0t6A5bMtp2qko7A+aqi2Am53ka0LvwtYZHHdCTunBwcSZTn34Sz4X5R3dKb
Yd/70NIceZ4o7HsqdGin3C9wKf+l9VdNC2D32HO4Jp+PRsehpgFhWkRj/jsB
/vfl+jH46+7y/g0yj8F4gJt8nmIxtphYxGL/SprHPXj/NI/DlLuv84bM4zHq
pHk8ft9F+1uQUEfzLTjuoflWZJ6h+Vbs6aZ5AvZfGL44LvefAE9v5ZUUeb+J
cE4O18e3mnkifqiY97pb5klYcMll6zQtkuAZ78mOlPe7DcE+On8bblyn85Nx
YITmyfj+Gs1T8MePNE9B/lWab0eSo3ztlNz/dvz9ZvlwhdxfKn5yDFyulvtL
xeCd5M/OyDwNr97+M2jMNNKwNyj0xBzz8ybSMNRL5hlpuPwFnZ+OsovESIen
i+43HfM7aT8dczto34o5p2nfiqk22rfi2fdp34rpVtrPgOdd2s+A0Uj7GVh0
kPYzMHWA9jPxa2/YR8nNZj8T3/VUfRVhWmRi2c8nbZGmjUx00/U0G2bV0Pk2
tFMLG+5TGzYUH6L9LHxIjSx0UYss6LW0nwX/t2k/G15qZGOSWmRjBf1+GNmI
q6f9HDzdQPs5cFGLHHQcpv0c9X61XEwcof1cpDXRfi4aqY1cTFNrdnyuvD87
7rlp344L1IYd847Sfh7y6PcdeWiguchDRfDcuMIGs5+H9mO0n4911MjHbrqe
yEcttZGP08r/lwL8oswvwMtKvwC9dD9GAYaU/TtwjhoORLfQvgOPKed34Gwz
7RdikhqFeIVaFKKS2mC5pmOQ2qKjRnkfOm7S+bqOb5T3o2MV3a+X2dBhpfax
XHMigNriVNeHE8PKfPa8cLL5TriV+3LCRu1zwkfPp7lUW1zqfcMFP2W+C7fo
88KFZ2judanzDJe6fx+zVqSe11Kkft5RhDZlfpF6PsFyL+sbzD7W14pVW4pR
rcxnuc4s2PNelhss9zFrJaotJWofLNeZBbOX9Q1mH7O2Q70/yw42n1lnFsxe
ZoPZx6yVsvOXsvml7P2zXLC+l+UGy30s18rY+y9T54HlOrNg9jIbbD0fs7aT
zWcGs84smL0z/hd7KaC2
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw90AlQVHUAx/ENCi0IUNakGSCgVCSEyIMbfuxyyLocy3IsCw6XoqwOEnQq
2ooHhwYrI/ehLDcOI5QcFcLKgqYpUIBhZuWYoGADBHElWA3//39n3ux85ve+
7/3nmcUcCtyrweFwkv67/v+nP7k0r7CwsK5zRZNukvGe8yXMHLS+dnRMo4h6
NV4+1ZT0kO36mKvuuhrBzAXPeFWbkNkQNVULKi1mI7TfPpixm9kUwifmuj0F
1Oa4Yx95ej6f+h30Xe3eocP2jVA/b1g8y2yBt7O3afGZLZHWenltJuut4DqZ
ekHAbI2MyT1aQ7nU76FBb1CniNkWP+wzr0pmfh/dHyxrfZtHvRVWcSe1+9nz
tuHggPELIfN26B9bzL7OzrMDwqZtrlfYbofihIF9Irbb44a2xgCYHeDjzm1p
Yu9zREmv8A9Ndh4nyLJGMqbY93MGt8p7qpvZBQPHo550lVC7YpVDbW1nMbUb
FFXfmQ6x+wE9ZZ6hbimxHEhNc/E/yc7rjjVryyM3Usvd4aLdeCTmHN15GGms
sTuroDsPSencwxHUHD7e5U/v88qhOx9ZGw4on2fQ3QN2VZql/M/p7oFRdf0B
gxS6e6JJEK1XeIjunvBOdWxSJNLdC0aO5dUGbPfCUVPz0hYZ3b2x1P1JZV0M
3b1hU9byUq2I7juhmnfeI3Sm+04o9DweP7Khuw+kuTal0Wz3Qb6Vd9eZTXQX
IHavSecabboL0DT+auxPunTfBf1Za4F4qZbsu6C0nymYmyXmCGG6x4S7OEF3
IRSuGcq2Obr7QvF0/1CEFn2+L2Ibb47L6P0cP9zprOAq1bT3w2C538yPHXT3
h8mW0P1ZiXT3R6rhYY/tPnQPQLJ61tJoqWbFCICmRVdcYT+xPACNN+6vH+sl
VgVgysFQZ66emCNCX0iLzvdf016EluTp+OwX1aQX4XbO6LXfGolVImS1++5P
syfmBGKSn7++d6yK9IHY7CL72S+eWB6IfyTK9iQesSoQeSa9ZpmKStKLobxk
dNPYkRhi8FqnrHkjFaQXI/jAwwu2E8QqMV5/K6fm10FiThAiO+5XvOFKjCDI
Pn62nBKnJH0QOI/s+scTiVVBMI8/83R0ppz0waiOT3fQLLtI+mDMl1dedIgm
lgdDJvDzbGguI30w1gn/3qKbUkL6EAzfPRNqOltM+hA054eVmMqLSB8Ci8HK
awGbiFUheDw9femrFwWkD0VfpDBn8TNihCJkOdNkXUcu6UPhV/eFi7k3sSoU
6vTL16Ofnie9BGYHx6auFBBDAp/5353+ekIsl+DNgcbV95LPkV6CnK0PdEZL
z5I+DOJyfaH+N6dJH4aehbu8hIUTpA+DrfaHqRJZKunDwK8eGt3scIr0Uryy
/OxIs4ac9FLsSIhabqtPJr0Uf340v0H3yzjSS5GWUua0IA0ifThqlz61/EUS
5bbShyM+Jzzh3kTyiuXh6C9Y4NneOrZiVTj8DbL6ImOPr5gTgVs9Nr2C3SdI
H4EHw+qbsuF0t38BV9pUyw==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxFzAtMU1ccx/HLYjKmTkRBRkQUUaMoAgNfA8aPIqiUdn2AE1JFmCAKClOC
dhi8OoaBKlDQ8ipaBJn4muElijx0usjGnJglKhpCRBS7ANuCytLOzIXzP97k
5OaT7/kdt/hUVcIHgiB8+e78/6dPjDGUlZXVdUzoz6DO4HtnmrgFjJq+ytJy
22JP1aj2CPd0yPUFfu/3DhDc6y9WcH+CodXbnj/idkHp2PlUH+55SBEChaJS
8nzM0B6708G9ADe9s4cM3Ivwpr9R/oB7MWZ6SZKXlJM90LIz414lf38ZXMw+
+Tru5eht23j+Grc3pne37n9eQvaB9dcKXyf+/qcw9L3NyTWQfbHC1d385gTZ
D8b9LzwWca/AHPvfJ7lyr0SPNX785HHyKlTaNSSlca9G3ECDXXcReQ1scuRt
W3j/DHfdemSrePeHV2BdVVEhOQC3nOrMtbwH4sfXS02Pi8mfo3jBldSn3EHo
vy8mm/RkIMrJNi09n1kEXk8d6v27gHowDrYUN6XRfTEYS//aEfHoGHUJEg5U
Tnqhoy7BmKtxOOw76iG4GusQ8PUe6iEYPPrRVlkG9bUY6VVHJ+2kvhZNg89m
jWuoh2KT/dj2hHDqoTioTdxl8qUehiWjI46e86mHof5uaqHGn/o6ZLr03MgL
oL4O/hXfJC50pr4eMbnOrVPsqK/HPKPjY6n1LOsb4P5zenf7T8ziBiQYnwjX
S6iHwznkSFn+AerhyNXb280+RF2KvBi9550d1KXISfm31TGMegQepk81qhXU
I/BMt6X7hoS6DK8au6osy6jLcEsoD97+8nvW5dhdHTtsGWYW5fA8PThb6kH9
CwxYTokZhbWsv3P0NPuUkTOsK7B1oKazOZ0ZCjTamHddDmUWFZDH6epaemsm
3KmAzGv4fvYlZkGJZjeHMRsbZijRuc8cUJ1VzfZK7O7SS5KenGZ7JTSbZ/5S
484sqNB3IW9yq8nE9ipYldv+yPRmFlXoiLV0NZ+tZHsV3mqsTvHx5WyvRvu4
7W+CRynbq1Eb83Rv+7cGtlfDLN4eGG3Us70ac/0PfdjQpGP7SJyIu+h8/Fw2
20eiPyl6Y5GLyPaRWCm1/FPSpmX7SOg/zko0eUazfRQKcsXbjpc2BU3so5Cc
aezzm7t3wmIULmjrb2p+OBz0HzgyxTc=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlAtQk1cahjPtgk5HLLobkVYBdxWxIkpFMFXwRRKkXJMQCAkh5GZVumhx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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlG1MW2UUx68Y7NwHhYmTD3spG+LmZEEdG4wx/jBeBhRGW9pSKHBp6dwM
c4CJRpF4zbI4YICu0lJA1mQTZbAp+zAWDXIJxkT3kriwBRRjh1EX5QPbjMZN
NjXmHs5zmzTNL//n95zznOf2xrkPWrwRkiR9/O/3v1/to5T7g8Hg4Pj/tJDh
S8m1dRJLaHn8tstMvAyfrL442UQchTuLs4Fp4hjEqD7zLeJYJPz199gSr0LR
fXfopR6NjTAd8JsHKF+HxLpYwxRxPEbODn9hpfUJ8P65aY1KvAE5J12j87T+
aTzqu765nfgZjP1qaewn3owt6fte7SFOwiV53jhO/CxOzo225tP+z8ER3fxh
XK/Gz2MkdC8vqU/jLRhe33zvMK1PxvCXH5xpI96KaxGjq4LE27D/58sTL1O9
FFzdGfvDfuJUXD84cXYl8XZcacTMfLfGabBG9bD72oGKxviOb4nTYXpwbG4H
1duJAzd+3JRI/WfAV3bLX0w5EH4ruLSfAnzlYSxloiWV55mIieJ5FvIWulme
Be8dxtIu5Bq4vwuRMdzPhvVqsnxTO5+Sjaa7RztT6bw5WJwxfBemPAd7X/t+
40rKc3HhBb5/Lta8wvfPw5kjTdujtfMreRh6j+e70Xg+efYb8nfj69x9hi7K
8/G223LITnk+Aqfm6pdTXgD5dMFwPfVXAJPz/KFo6q8QJvexZXbKC1HXPHo6
QLkJ9+Mup8wFtNyEw2unf4qnvAj+6K5TXvKLEHH84alIn5YXwxD1Rv5H5Bdj
6KF1v/k0lvagv/DNG9so34Pm5LUdl/xaXgJT4Jq5Q9sfJdj6y5SjntaXoCHD
dtOusVoC71BJmpv6M6Ph9bb62+SbMfkZvw8zEs8xVs04N8Lnb0HEEGNY0DvA
fQsGTnDfgqH3uW/Faj/3rfjjGPetyDrKfSsmW7hfiidauV+KDZyVUoxzVkvx
WBv3bWjhDBsuclZssAr1bZjhLNnR0M59O1wd3LdjgrOqY8mBhE7uO7DiHe47
MMhZdeCRd7lfhuV8XihDsTA/HatlqOIsOcV5w4l+H/ed4v9NdeJuF/fLkRbg
fjnaurlfjmCQ++UY5CxVYLqH+xV4kj8fSgVaOasVUPu47xLXw4U5nisu9HNW
Xdgo+JUwcEYl6gS/Eu2CX4n0Xu5XYZGfB1VYwVmpwlN8HmoVRvi8pGp8znNU
IyzMrxq/8/VqNSJ5Lsni/I06howrnGUZTmF/GX2cQzJeFPqV8QA/T1jGeuH+
apDE789Yg0zhPnW5XINZYT46DtWIz4eqy8M1OCLUd4v9GN3i8wY39nKW3bAJ
9XV+SMeqbn1Yl0seLPB5GT3i/cODbKG+jhWP2F/Iozu/Lg97xH6kWnE/Y63u
/LXi/GQdK7W4INTX5aouD9fiU6G+V2SjV+wfOpZ1rOg45NW9L5b4H2wc2MM=

         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw9zH9MzHEcx/EvNvwhzLLVRsWiTl11RJfrx6u6ft+d2zXadGiXmyRSSx2H
dJe14pzo11Wb6KQzhbZWw3CzZWc7zPqDFYeSdVoL0XJmWJ/397O9995jz/c+
6zRFKu1CjuOk/+b/pndmd6PFYrE9mtd0/BynN5h4czj/JLy4n/dSZOXmHG/l
vRIViZ0BNby98XNg56W9vH2Qr4nJiea9BsND7yJ+NJMDMCsI+bCI7+sR3SQb
2MQ7EBFd20sNvDfi3mjd6l7ewTg5VlTWwP+3Cctstshc3qGoeV65RdBEDsNl
p90w00iOQMJXe9SLerIItdq1DwMbyJsxtra2eKKOvAVOs0XsvEiOhLX55u3v
vLeifaO4N+gCeRvcHX6ufN5RmLBGLhWYyGJ0t1XHmWvI0bg2vM+6wUDejiNf
NcZpHVmCb7GzC4bKyTEQtukHPx0lx6Ll/rPPF0vIcTA8CXUfKiTHQ3fudPjj
UjKQ7dm/Kk/LfAaI0I/3GclcAvJMssHPauoJ6DkuEd9Po56IqgGhQBFFPREl
V4790oipJ2HslKNEFUY9CQ8qFPKcEOpSmD09rhNe1KWY9Gx4afChnowvak1Z
kKeL9WSM9r4xBkwzcymwB3bsOviKegr8q/cKRf3UU1HUfutulJ56KlyiGNHN
GOpp0P5p7vWeusF6GgpUhRkzJmYuHX0fBwvfKqinI3tZWcrwYuoZqIt15m+7
3sl6BvwLpuxLVjBzmXg98tQ30n6d9UwEl9uNB/YwczLceV8hCRuysi7DH7e8
y9/VwbocvrJwteP3NdblsB5M17Z5MXMKDB+DvEXVzroCRo/jyNXJNtZ3wP3L
x9sssbC+A6qs7qrllfWsK3HYd1xavdw8byhxq/Ul59adZfdKeHRqpS2uZN6P
lRCK5vwcI4fj/wKHEVwU
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlglQlFcWhRvjpESdDC6AUaIdRUUEZQ2gMBx2XED2ffnpBRAYYBBwAIXW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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw9yVtI03EYxvF/XrQlsw2J5vIspR1sa6XLNt0e5+asZocZMbQuqk1IosyK
FlaugyGjjCVtbbp0WbMFhYugC7WEqWhGhV0kBHUTFU3QWEUHk4p+7/+Fh5cP
3+y9hyz2BI7jlH/379M5qz0+ny/8+L9mdDFpfa2fN4frSf7uF7yF+Gbv1fXz
lmBg8HBMz3sRolprV9M1cgrGv6e0WHmnYWbJROO0l5yFQvHLicV8z8HuIeNI
mO9LkW7+qbXxPReTr8dMDg95OWpk03Wrr5BXYvJpXX+Lm5wPYfC5MOEiWY7k
2aJasYu8BhHHuDuxmayEdMqT9+AceS2Cotm5UBN5HTLb5vya8+QCRFZ07hI7
yYVIlg1Ebxwnq5Dz7F5ragN5PU4VD2fs30cuQlXgYUP6DvIGcL5Gqb2ErMaC
kVThcBZZg76+wA+PhFwMi24nzL9vM5fgjOvgaOwdWYtj0a8VlVGyDvOn7tw1
B8jA4JdQXLGH2QlMzRt9s0xNvRSft8psuU96WC/F2bd52zdtZub0SAxnWra8
D7GuR1zVJlJpmLkynJS7uiott1gvQ9qJ+qMC+03WDWiXBYYuSLpZN6BV8EtZ
kx9k3Yhtl6qrbBs7WTdC2tEbl3e0s16ObMX9iHWhl/VyJNVZTme8crNuwhHR
2MeCq82sm9CjXvVB8OkA6xVQeA2P3Jcduj+Tteyf
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxFzQ1MzGEAx/FbDq1YhdTmZsRIpxLXIV3/X693XbnuUqFVNk3JrDOVtJQr
s0ol100vQtxVugsl7LBRJwxnTVY0i83My646ttNlK6/r/zw923/Pvvs8v/1X
7lXG73PgcDjSf9//mxxVcl1jY6O+Z6a+M/dExudXaHPQ1apWXqDtiFVcYWEn
bVfIzYu6z9NegqSuIdHs3hO1Hk11WbR56AzUpalpr8Ap4UhvEW0vZAS0F7TS
Xg3+i1gnM+01yD22dL7zOdLe+Dmemzj73gdl3Ms/d9Jej2+lmVNDtP3g9GHK
aKO9AZYTurUm2gEYe790nob2Rhj7lowJ6f82Iah8VPKWugAu/V2jc6kHQimt
qimmLsS4Qaw4SnszEl6+6yyhvQUJHfUlIXS/FZ5tU4cvN5EOQvMlxs1OfRts
NdYnhdSD0atzkyqpi2BbeMDJj3YIztRfv/iZNgMBI9by6B5YbNZm7CeuAlKu
TvENDcRDEVD58ab9LPFQ9Hmee8SvJR4Gbe3LZ89qiIfB5C7bnaQmHo6RvunS
/mri4Ujkjp5+XU48Ah+4FRHpJcQjcPi57a4mn3gkTMG+Aucs4pHwmfPKrj9I
PAo5joMTqgLiURCI99/mFBEXY0e2yt33CHExdLe6e1yPE5fAea5Lv+kQcQlG
LAZ7RTbxaFjs9tBracSjERwyPGYVEJeixeNTtJVHXIri7uE99wfaWY9BWWHn
w8yTbKtikGdwuCE4SDwW2RNq67oU4rFQiYT+kQuIb8fTO9K0GPUV1reDJxq+
lLOIbY4Mfss5k+qONtZlcJH4V8772sp6HKqtGem8NWyr4nB2cFn0puIW1uUw
Q79FE6ebaciRGTbwWJiqZd/L0aK8k9ow2TzTvXLkz/eo6hecZ/cKGP/8ns7h
NbB7BX4w3l8u2DTsXoH09l9N70or2L0Cj3ZF1TOWPHYfj6IHfK9eWRIzs4+H
/s1kMhNexvwFbJp+PA==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlH9M1GUcx7/G2ggcRljpZIWaLMUxIPthUL7lhwd4cNwdv+4X9707oLXK
3Mhic62v858EU0DEOzW6tRIpm3NuhX94foWoGQu1P1RYzjN1tH4wstRcxfq1
e3g/z22322vv5/W8n+fz/e6WBl91tNyjadon/3z//U18DHdfJBIZPPU/zazb
NnXnj17BGqqnM6dnBSfjRyNjOfYn+H587V9heUvkCzFwKbX3pOBFGF16o8wr
OBObAsmzFsFZ6Pp+u20mnOBlGG87ebld5I+hKqd/Mio4G2mFH8ZXif7HsWhP
pfOcyFch9GXfZ/eKfDWux4rKLwrORfbnO8IxwXk4bp098oDgfJzQthgPCi5A
pGB09ULBT2Bg8M2dftG3BmmBn4a6BT+JH9yFr10V93kKmft++fNXwU8jvTPX
7hX8DG7np/a0CV6L3w5f+blE8LM4+4I7ZW4ehZjKmCjKF1yE9Ly7K+f6nkNu
62hXt+DnMZzSZNsueB0WFFxY8p5goHViavFDif0MwHYrJXOB2H89xvzt1+4T
+Xo8siV1KEnkxVg50u3KE3kxzm++kjMj8hJ03A3PvV9GCYqTI/S+laL6YWKj
FBXZnJdhfA3nZUi3cr4B8z2cb8DwJs4tuGVwbkFJP+flCJ/gvBw533Begckp
zitwhlmrxM0bnFdi5DrnG7HsO843IiM2cW7bgURuRftlzq24OMl+FTx3tF0v
JdYbVdh8gfNqHOPzGtX4/TznNnjGObchMsZ5DbZ+RYwaFJ7h9TVI+oLYrEHs
NPt29MXYt+N1aZ522D5l346rx9l3wHKUfQe2fsS+A0cOse9AV5R9J1xh9p0Y
2Mm+EyM72HdibQf7tehnRi1OMRu1yOhkvxYfM2t1mGZGHSak/jrMf4d9hbV6
9DCjHqPMRj1O72K/Hi/uZr8B87rYb0CY2WhAXjf7DUhj1hqR0sN+I/r3sN+I
pF72GzG0l30XPuhj3wXrPvZdOMvPx3QhbT/7brx/gH03bh5k343bnJtudLzL
vkdmeHBU8j14mdn0yH2aF0ukfi8u8fkML/Yym160Sef3IcgMH+J8X8OHazwP
04djzFoThpnRhMXS/Jrgk3yFNT9ekXw/dku+X+n34yCfT9Px399rgrN0LGeG
jhler+volO6nYx6vjypsKvvFdUSYtQDqpP4A3pD6A0q/st4IwMHzjwbk52EG
8ChzPIC/pP4gxqT+IFql/iDeZtaV3AiiVLp/UD6vqXA8KM9DCynzDynzV1gP
KfcP4VupX2EzhEFp/iFl/s3K/ZtlH0quK7mhcFRZbzYr/c1Kf4vMWQpDYb1F
3s+Yy/8GdLDY3Q==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1A1M1GUcB/C/FqW9OErnikpPJbyF+UK8hIh+EeVNXo7jOF7u7X93wtFm
tVYzobL/cllCSKxAjrcORacLyl5czOX4h+SMt6xmC7J2jWaRM0BJ2nSuWruf
v+dhu7HPfs/3+T1vd8s8z5rL5iqK8tW/n//+h/600ka/33+s939NbXowds5s
J1nBqxNRHfvI8/B51ULXc+RwTGZFx50mL8KF2uOtJ8kP4PBrI9Zp8sM4PlG/
43GyASf2xzZNNIW8HDtnrpgiqR6JgxEdj5aRo9A987w9hWzEXSPD1yrJj+Fq
efoJN3kVegfDsszk1TgQ7Qy3ktciSp/XOkReh5Qxe/kNWk8MNnYti/RS/QmM
3pvwQS45Fu7EHVGLyXE4lRnpvEmOx+2uLx65QU7A77/a9l4mP4m++z5tGCEn
4qfxJa8MNIe8HqOVlom+lpCToK+cO76nLeQNSF3kj+6m8clYc27wz1v72whz
3u7u87SfTTgdNx4TIANtPUvfOxeyBhTkV3/XS/kUHI0YG04L9ddS0Dy8wniE
6ptx1rHXWEv5zbg0dHO4m+ZPxUjO5GRPaLyWiurp8Z233scWrPksueAq1bfg
+h27Mv+g/Fasr7rWtITqW9Gz2zhbTPk0+J1tXf1UT0PDPXWtP1I9HX1VZ5x/
h85HS4cxY2FyP51nBjosNRvmt4fqGdjzxsDXZ6ieibE7fw5/nfafiZhDVcYk
mj8LfWGXZp6m/WchuyFvl5vWvw0RF6c7e6m+Da5K82gn3Vc27rbd1pVM68tG
+/fPTKdS/xwcDVtc9Qv1z0H8D372fc3FuvPMWi7c3/B6Hj4c4fU8BAd43YTV
Z5lhgvFLPt6ExJ1pptGQdROaT/F8Plp7eD4fvZ/wfD587zPr+Wg5wvNmvHCI
582Ib+N5M1Y28bwZ4Q08X4CpOp4vwMf7eL4Af3HrBXi5muctuMINC4pqeN6C
IW7dgsa3eL4Q17lRiN9qeb4QM/t5XrJiRYawfiuWv83zVhRy61YsqOf5Ihzm
RhES3+H5Ihi59SKkvcvzxZjNyLI3hn5PUIyL3Fox6g7wfDFK+H0oJVjbzPuX
YFUL71+CIn6fegn0Vp4vRSI3SlHLrZWinVsvRT2fX7HhIDdsSBb62/AQt25D
v5C3i/PBDpeQt4v70+247Od5h7R/Bwp5XXOgRni/DvE9K04k8fOFE/O5NScC
wvk74eBWXGIdLnwk5F3oE/IuZAt5FTPcBhXfCvOpYj9VFd+DpmKcOyDNp6vi
ewmqSBD278ZL3AY3prjhxgJ+vqpkzQ0Pd8At3ZfkoBsXhPvziDZ48CI3JKse
HBPuV3JAmk/3YKnQ3yO9H6+YN3jhF/p7sULo78X9Qn8v5gj9veJ6da+4nqAX
g0L/7aIN28XxkKxK4zXJAcm65KA0n1Imnb9kSFbLcFLoLzkgWS8TzzMozaeU
S/0lo1xcvypZK5f6S3VdqgeluuKTzt8njodPfB+qT9yPJtUDknUf3hT6S1Yq
xPkMFWIdFVJ/abwmOSCN16V6ULLyFPkfWs6Dvg==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw9zglQE1cAxvFYD6pUpIgIAvVGscAAgihR+bghhiNAIOQggkJb8OAuFouL
HAbxoESBgDaCgFC1goHaUWzjCDXUUYs4XlisB5jBcmirgxS17fDe7szOzm++
99/dhXHbw+I/4HA4zH/3/096MeIylUrV+POERjxSXjbb7WXNgd4i+0ws6w/R
9mP3OQVrYxzVd/76TwW1KT7rdHC9xtocvT5GtYtZW2HRuYVdZqwXoDDjpOpp
OfUiqD8PtzjEegn8MyKaPmHP28CouMzAnfVyfGlcJM5nz6+AmyhuyVnWdhh3
G3GZxv6vA2J6azp4rB3B6x2qN2Lf5wR+gmlLFds7Q2q3zzeb9UrUXP/O6AfW
Lni+f8f4ozJqV9xf3jM6+TD1KtSrw3valdRueH4gXlVwiHo1rho5GYwdpF6D
wpEbQU6l1O548agt+gy7c9GdZRqr3U+9FqnFq+7v2kO9Dq0hsf6NBdTrseFW
fKsJaw8cnim27SqkBhJlMxya84gZoHEgYWV1Lt094ZCdt02zm+6e+PpExiQD
tvfClO/TXnLZ3Quj761PBrDf80ai/R3javb93tj8sM+yn+19IFs7lvMkh+4+
ONw5qaTrK7r7ov5U87WSHXT3RX/w6rqqFLr7IZUvzt+UTHc/9CS2v1Gn090f
f5uk9ynS6O6Pxpw4K+kXdA9AgvT9+TlxdA+A0+Xe3Gk8ugciS+GlaBLQPRDy
sWz9TwF052FEU3s6xYfuPNRc6X6cuY7uG6DnPjW5a0/3DdhrtjVp43K682Ew
pFk21YXufDS/8JzvsJTuQagdvF0bakv3IJw+snRXAdsHg7/7WF6JNd2D0amb
UvXMkO4hGLjQJ1NNonsI6gqKk83GGsgeigfv60rnjhMjFM6Or1al3SVmQvGt
mXOy7A9ibSjeaQu12lu0F0B/x3t3n472AjAnlP17mmgvwCXP9VYt5bQXQO1t
r+rh0T4MJUmC6FlGtA/DVt2c2by3J0gfBi+V38rzHcTaMEgOWm58KCPmhKNP
WBBSa0yMcKTMK89n5tI+HB3p/Mlng2kfjoFct/Kp9+pJHwFNkbOZr4gYEbj+
YHruilnETAS2qY/bnbaqI30EasxvLNYztaQXwnWLjXvm/eOkF6Jh3FD3wJDs
jBAZybGt9kVk1wqB7JveT3YRcyIRnFglzLtI+0gEpP6maKQ7E4msN2+edTrR
PhJtoYvaL9+sIX0U5AvUtr9riRGF4c2j+crqatJHIevKDN5M5hjpoyAdEs32
4xFzRKg4brN40JIYIpSP8wu716hJL4L1x/FJkUlHSS/C4JFZL95qj5A+GgPG
3hV17ZWkj4Y0w0Ks9CJmovGXsnLy9MoK0kfj0wauwWZ9OenFOJMl/0XTQAwx
TFuH382bQc4zYhRpHv1ZNVxGejEGsy49T7U8RHoJSrn6q9cciSFBwIVNawwt
SkkvASfQ3MV9tIT0EiyZvx6X7hWTXorXlY4Jt7GP9FI87no3nD5HQXoplp6a
Pd3UeifppcgxfzUSKEgjvQwVhnd6dT7bSS9Dotcyfnz3RtLL0M6V2Nl+w/OY
6GVoDRLZBNunTJgTg/SXTBvXc+eEEYO1acWu4kxmwkwM+vU3dNU6BeljUB+b
qWm6uJ/0crSsGxYW6Ikhx+3K4UETSQnp5bjXodzy7CMl6eXofj3Uoosr8/gX
gy6XLA==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlAtMU1cYx4tmBud0Q4w1w4XHHCEggoKozMkf5FHQ8iiFQin0AoKAbBCj
URT0QtgEUQRGkCpgUcGhMrUTRc2wm5vicMI2QTJdVmWZr4Tga2Km2VyW83nv
adI0v/zP7zvfd+65dc0o0GRNUCgUp199//tlH1HfYDKZOs7/T2NBV0N9gj8n
ViCpzCtwnNge677xnrh+D+N3MKlZZbZRPgOOj6fNHCCehcKDJ9t3Ec+Gxe7B
ua+JXZCo33pjLbEbyu841Qw0Mp6DcCFKsCd2R4A49XoBsQfq3KsbUsn3xGxx
aLCK+puL3Pw58THE8+Dw8cyEJcS+8JyR6uFJ/ny8fUV5ZoTqL8DEpvNJOZT7
4XFP5LInlPvDtTTxygPihTg2WqPtIw5A8cOaU8eIF6GusLvkD+LFGA+r6O0n
XgJno7o4jDgQloBb827uZvwhlnn7r9FSvhRu7j8HP6X8I6wcedlQR/0uQ3Dp
cFMBzRuEFOeulqfkAyeO21V/wNaLwL2B4x2vn3cwDCVeXi8oD0ZRfb5jI+Uh
KKv2v0oshsCyT3d3CdVfDpPFcdFPDSxfji9/wPeXyQ/F7B1JQ3+SH4qzkyPu
rKM8DN3ll9rtWf9iGM5d//SZmuYJR2Ppm0FKysOhTN7f/zf5EfB1VTs5Uf0I
BIScPnmbchUMK2p/8ydfhdVFJwvvUx6JwbEWv1HyI2Hvv7Tam/aPwqziqlx3
8qNQlIvD5ylfgYXma4dy9rJ8BUbP9FY+YaxYiTj9t7H9lK/E08lThJnNLFe/
um+LH/U1sVyN4VqP4w8YK6LxxrOHR7ZQHo27+GztdMpjoHp/lUZH9WOwf1ip
vEd5LP6ZEtLoxhixsPO509pK88TCeaAt7whjaywsIeM6JfUfB3dTiKfAcsTh
Yl70WxPIj8PzE6bX/y/WOBzolLBCg5I2CUODyFYJixpcbpH6GmwwSf14vNcg
9eMRWiP149FaKfXj0fRQ9esaup9aZB/MaXuXvT/QIiOmy2ioZ74Ww0XBBW41
zNdi3s6U0vEdzE+AQ4/PeuMu5ifANzNNd7GC+QlIUUelVzG2JsCYf/tw3Rbm
JyLP7UI3tjE/EXP7elb7kZ+I63aVvwduZn4iGnoffdVcynwdTh+79v78cubr
oDLnOQQwFnU4tdbb45LIfB22Xdk6YSpjRRIebRx6Gb2e+Um46tehnZjN/CS0
CYeHwtOYn4Q6i/p+oJb5yfil9oJlMJb5yZj6/FBzTzzzk1EWnV9RqmZ+MrqO
TppbpWO+Hkdr225uSmW+HuYIx622TObrYa13GBn7hPl69CrCD3YbmJ+C2+2b
Qs8UMj8FC9r3+XSGMj8FJZ31g2d9mJ+C8vmm7c0a5hsQEHijx5DDfAOKNytd
j7L5RAN2Ns+5FbyU+QaManv+8vBlfioqww447Q1hfiqce7dHdqqYn4qdmhct
eyKYn4ofvSZ/165nfhoyNtxt8l/H/DSoYrpyg9jzFdNgKxvY+AXdvzSM7Jbe
fyNsjdL7b0S/lEUjQqXvi9UIO9n7I2DaHgm7CMiQMgS8lK4XBPRJWRTQIWWz
IK9vFTBdyjYBY9L+FOny/lzS5Tm4XEhHgmx/js3pMMn2T5f3a0vHTdn8GXJ2
4RgcCxyLGfL6Zo6tHNs4VmTirGx/jsGxwLGYyZ0/x9ZM+XnYOF+xipufY6yS
9ytwLHJs5tjKsY1jRZacXThGFnf+HIvcejPHVo5tWfLzUGSjQrY/x8iWrxey
5ecrcmzm1ltf879d2/XZ
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdkg9MlGUcx1+zNbVylqy04TzS0HNQShSeKH4PURHB4+7g/nLcey+nidVo
Y2yp071ptbsIEXXIXTbP/mDswFxGGfPG22yuyJwRRUVrhytBs/XHosGwVWv3
4/e8t727ffZ9Pr/f8/yeJ0Ops229TZKkjn+///5TP9XTGolEOnr/p1/X7pvI
OnWTWML0X+778zzxDOyW1/i+Jp6DgfDNF9uI0zC/uDstRDwPfVcvxMPE6Xio
zr+9i9gAR33IM9XvQbQmnMduj6Z4MdTA3ienOBNl/SWZn9P6pWhI689/g3gZ
rlt+PnOaOAtXHvA3ppP/MG50h5f8QflyTPvNLIHyFTA/8lqxTJwDT690zkL8
KN6y1hrbyc/Frmrj7tmUP4bnns7wfNOW4scRd8T3d9L6PPxkb05cJV4JU87b
rkPEJvT/tW/PVL4KQ8Mn6zOofj5qs6cbeylfjcmJ4Ya/idcgs+H4V0FaX4CW
kWedC4nX4sj+77+bRQw8s2vVkgspXwW6n3Iv/oTqmRF1R6beh2rGjQLGUiFi
6TwvROLW8KiR6q9D7Xgby9fh3Tdz77pE8ynCrQMnEh+mWC3CeGfPt/nkr0dj
3cAg1VPXYzR7R8kKyjdAsnVbTJRvQN42vr+NyM7JeeI65RvheYnnxbj2Ot9/
MbYneL4J8wZ5vgmHR3legowRnpfg/h95vhmrf+D5ZvRc4Xkpjs+tc59rTeWl
eN4YNTWnWCrDwqUzlgcpL0OoPboIlG/BxJ1Zg/dQvgUff8nrW3DHF7y/BUcv
87wcxkuMUY72i3x9OVb2MdbKMZZYcLGQ5m9F1kfct2Kvxn0rCuShz86k1mtW
dJ3l/W3Ifo/7Nnxwmvs2vN/J+9swdJL7doSck31K6vywoz7KfTvGDnHfjnfC
3K+Aib8HVOAyZ7UCcxu5X4EwZ6kScc6oxJyXuV+JFzhrlTjLWXLA0sR9B0Y4
qw7EDnDfgdpm7jvRxRlO9BzkvhNKC/edGOcsuXCezwcueA9z34UmzpoLO49w
340Frdx3Q+asutF8lPtuNLZx3yPeFzxoeYX7Htw9S9kzeSrle7DzVe57EecM
L34/xn0vmjhrXhg5S1VijioxV6swwPejVWGMs+TDNWH/PkwI788HhbPmw70R
7lejlM8H1ZjPWa3GMmF+Opb8mCn4fp3vF+trOpZkxDgbdAwdy7J4n6qMfs4x
GXn8fjUZOzgnZSwSzh+Ajc/HEIBZmGcAsznLulzV5bEAenh9LYBtnJMBTBP6
K+J9GBQUcYaCXM6yItZTdX5MEetrinjepIKI0L8Gnwr9dYwa8TyyjtUadAj9
a8T6mq5eUsdSUPQNQYSE/jqWg2J9VccxHWu6+kldLm0l/gewQbld
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd03tsU3UUB/ALYpDMECEEp27SAUODiGOrxQ6Bb8fWPdhYH1vbdW13+5oC
LhBAEHB4CQEX2YCxB2uHs/oHsBCU8FiU6LibQhbYIygjPgirIkHR8FCBKSBq
zO/w+90mTfPJud9zfr/TNiWwzBYeKUnSkX/f/32yl+JujkQi7cf/1/X5uuLe
cZvIEm7I91cvJz+Ck3si9y+TH8Oq/Q+9+l6UeQJctmXXDpMTsbHf3HaXnk+C
Z8wvFxOorsOceR/fcZMn4+2jnx1NbmWeiknVuXMPUH0aMvzNa3eSn8VBY94n
75Cn47tN1iN2ys9Ay1uzb4bIM9Hb8VxfITkNW+4ute+l/CwcyQgauum86TAO
DJ2/Tc6A7sePcIGsx8qBHQOF5BfhvDHeHycbMK5xXzxKng15yyu3HvglOCYY
U6M034jBySeTmsmZmPX6kHM9nXcO9MYVDSsp/zKS7u2Uishz0X9nKDGLPA+u
h3u6VpDn4/eNH9a7yEDK9CWDe5gVoGtw6/Aomm9C2OG9aKC6CRNbb2YGW1g9
C4eGl0ZLmJUs7D0zt8pE9QVI3bph/T6qL4Dx1HLnEzQ/G5O8CSE/9c9G0fai
jkgzq+fgWG5TfzKzkgPz2WdSdzWyuhlrDjiTjcyKGWP/qK3vonwurC/09q+j
/rl4c33+scV0vjykj64uSKT+eai4PuRp28Xq+Rg/9fjUJqrnI2VGwfcW2k8B
DJufv2Ck/gVIzwob9HS/hbCbfmpPo/pCmNdlJ5jofIWoW3blymHaTyECBaP0
l+h8RVhwLuV2OeWL4Kqptbqp/yIknIs8+P8qi/DGWc5SMZ6+5ds/SP2LsXaA
r1vw92nOsGC4h+9nQTJv1YK2E3zeio7u6mudrD+sOFjVsKqX7U+xQvl8dfun
zKoV0acufxWh+9nwW40jZwnbB2xIuXZif5jyNuQ/mT3lKvt+VRv6ey5U1dL3
b0fhF3/e3VDH8nb07U71PVrP8nbYNpw6l1TL8nZ0rhz5eOUOli+BozNDP2kb
y5egevbo90cwKyU4ZFkSymT91RLMjHakDzSwfCm+PXF5z0Z2XpQiq5bfXyk2
81ZL8Q1vyYF5dfz+HajaxucdWLydzzuQvYPPO/ErbzjRWM/nnTA28Hknrjby
eRf6eMOFLU183gVLM593YfouPl+GMbxRhi95K2X4Osrny5C4m8+70foun3fD
zFtxw8BbdeMHIV+OM7xRjjbeSrn4vFqO14S8B5da+bwHh3krHnzAW/XgL/4+
khc/84YXTbwVL2zC/b1IE/I+HIvweR8ivBUfvPw+VR/mCPuvwHZh/xXoFvZf
gYktfL4CB3hLsmidjCnCeWSM5y3LGCGcT8Y93jEZJuG+Msbyjsvi/SQ/Snnr
/MgW5vs18zVWNM/H/IgL9/XjOu+4H3phfgBrhPkBVArzNZY1VgJiv1hA3I8a
EPcZD4jnlYLi+XRBMY+gmJeD4r6UoLjPWBDnhfkaxzWWQqJ1GiOE08J8jRWN
YyHx96xqHA+hXZgfRo0wX2NoLIc1/w9NPaaxqnk+rrFUKVqnMTSWH/gf5/7v
iw==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw91HtMU1ccB/DLTKFFgp0uiFtRaTYR080WdEMd8C2PgpRKW9qa6Jibgqsr
Ey3bjDrthUQmIg9XW2whwJwwadhMfATECWwYhkqEyBAUJg4fBDGKm3OCjZsL
55yb3Nx88r3fc3/n/HFDN+bos17hOC7j5f3/k178OqfL5apvndZE7PWpMyP1
zBweiRJs5cxCJIy8YchgFuOO7+WcAubX0N5hs6QxB+OTh5OR2cwS7PNvCjEz
L8QT70PDR8xS1IZVxS9mfhM9yeKxXcyLcNozmd/BvBjCQom1lnkJzjeuCyhi
lsFyzHruIPM76M23GiaY5RhQTdr7mBX4cOm/Pb5u6gjM+6IuL5s5En6ypNNb
mZdhSCp4ImVejmtDvYda2HrvoufseOUq5vdQfmfJ5sIj1FEIUmRKSsupV+Bv
e7ip3kG9EsFP/zg/zrwK9oHBULWT+n243Q0tzw9TR8Pd/vrH29n7MYgQpj6f
yxwLvismTGKnBuRTaYevfkPMA5t0j9uXH6K5EhM+zVvGS2muBHp/jQsvo3kc
Xg3vvNVE5+Hj0KTe0ypk+4mHJ2BA6Kbz8fE4Y6l6PMrWT4Cj7K4jkOUJcEZ2
mVPY/hKx3dy2N5TOyydCfiNPLjpIcxX+Ee2/KzlAcxVUB56du7Gf5kmIfhrU
+EMJzZNwoT9K0FxM82T84rd3rJutnwxhV2+Qgn1/Nfp+EvQ56X741QjKutxg
ZeedgpX3lNVKNn8KZi3N/8zLzleNCHEUf52drxrywsiBLjovlwpTdtSx+Xto
noqLzWOe47tprkGJe4Mvx9NcA/d8xc05X9J8DSoqWzoXWGi+BgW5M2QvdtI8
DaFiQUuDmeZpkN7z2XQ7leZa+Di07SEyYmghDujY0O1P39fiasxwf8DPx6fd
psWOjOy3ZziIOR0enNVvqbYQQ4dBqX3IOpuY16FadmqZxo/2dXgr1wBx0fek
r8dvOdri6p11pK9HhzHMvzWQmNcDtq9aLymJ2/T4sXPttyXqWtJPx4KK6Ezj
QmKkQ9Qd53L2f0f66dh6+/6fAhC3pb/8fxX+dcJ6lPQNCFyv9mZ5akjfAM0u
ueOkrYr0DTiqGrwymldB+gbYKr3ia8Mu0jfiA8nEHOe2ctI3Ap8OJ3o1dtI3
IitkSjprtIz0jbjg+d2n8VER6ZvgrttdoBd9TfommItn7nDV2EjfBK13/cgR
LpP0TShVSK8Ec5/HTvfXInduRc3QqX2x/wErJtzd
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxFzg1Q02UAx/HJWaaZIreSgA4nFGq0E2bjRWS/wTYmTtjGXrCjCBAlkXZB
EhrBXwSh5MUhIBPNiSEvFpLCbUoanQdHWEEKMaTD7HipNE4yuOjlqG7P8/i/
e+5/n/ve77lHkGzSprrweLyk/87/f/pxr9RYLJbmz516ILGFL1PXM/PgMF6/
1cX8BPSBPvY2ZlecnOsuH2DmYzKss+VjZnfk5fzFtzF7oUqWLjnMvAZfNk38
cpt5LV6/q9rvc4LaF+F5vrnpzC/ATTGYVsa8Dhu99zgesP0GiHYH3nyVdX/s
m1L2FzILUXhi9cpK5o2wce/dz2YOQMKP4pp+dl8gFk3YFI/eL8LQZ4KeTuZN
6JFesd9lfhlP3sv1mmAWozsy+XkrcxDMy4vz1zMHY275mYDh49QhEMxq+uaZ
Q+E/PDzVVUO9GbN/LBWnVlGH4R/rSGJBJfUW1KYqLyqOUoeDi72i4ViXYJmr
zvvAMWogO2n8pS5qDrAd0LU+6lJUnq3r0NI9J0VmR+/8TTPtEXhq1bELl8to
j0BQdNoz0lLaI1GWm/hJSQntkRj41oVXXkS7DJd4dgiP0C5Dkdjj2nesyyFM
WpzWdoh2OZ7NXeEZw9GugMvB215N1JwC7hGn8sVZtEfBz7FFuOkN2qPwbseR
xvwdtCtRV1PkXWygXYna4MMZShntW9H0/ZD/qijat+LcGqPcZzPt0SgX8a9m
SGmPhsktsS2e9W0whQtz9vrQvg0qlca662naVVgpSlmQzDaRrkKbV0dF9Qwx
bzv25Jl7xx20b4evNMHT/RvaY9Cwq/YLWzvtMVi0QZs/VUV7LC7Mih3tKbTH
Inuv4fEQT9rVWJvRP596sdFpqFFbaviqoZ6YU+P3ozsCI6KJu9Ro3ffzzNTY
ObLXIPDgaJTtQ2JoUJ6VzU/TE3Ma3DctHR972ED2GkyG7HzsVzdinhb81sKS
T2Ufkb0WsQuZPTeaz5K9Fto565/Vg/Vkr8U9c7xo0JeYFwePn/rSFkbOkH0c
EvrrBNOnrGQfh2bbzueGVKfJPg4+PQXXO1tOkr0O2aEjD6eXEEOHssm+8z8s
riN7HS4ZRsOyLBay1+GOZ/Bb9q+Pk70edyaW3GhcXU32egiq140VxpjJXo/u
yzb7gEsZ2evxW47cz7XmfbI3QDyT3JsnLiZ7A0I9aqNWhB4iewMCrFe9Tr+T
T/YGlBYEh5rezCR7I/xa5oUfpOwmeyNeTDB7aoKmrzn3RrzW/rZIfj5d4twb
4VZROarM3e80Lx6zFRG3/l5fKPkXt5/wDA==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxFkAlM02cYh6vjUFmUDZFOgcFEHEwZp2Bh9AdyikApV6G0FJAJKnKIZAps
5exEI1IOOVWECSrKlDHG5rSo6JgixIAoXmgqUVFi0InitYPv+9bkn+bJ8z7v
+8/fNDZZGD+Tw+EU/fP8+09/8siKqqqqQ6en6SlfJC0PGGDMwcbfHS2OMJ6F
kUanieOMdWFq3aXwZTwfwq70xccYc9HdmqwlZmyIC7v1JjczNoFZ/+0PChl/
Bq227PRSxmbIPblEcoCxORoy773/f9/niI2rj3tWSdkSaZHzfeoZL4NtGy8k
js1bgVdoHtnLvDU2pr93SWBsg9Hn1zym9lC2hfJLp3uvGNtB/ztH51LG9tgg
jn0YwtgBsfaGm7sYr8Ap54Nrhtl+R1y2KKq5zt7HCS910tX8asorUbL+6PEW
xjx8bWI5fpfNOwNaPjndbJ8L1r0+ndfK+Ct0pk79MZvNu4KrcU5Dh+3jI3WZ
bVUn80CPop+vol4OCNr83vaxeTds7bSq8GTeDec/5G3rZN4dl2MG9S7VUO+O
whJxrU0t9auQlG+1410d9atg6K2z9CXzHojOCM9yoCz3wOA3Av88tt8TT9rW
K+LYfU8UF0urTzPvBa78xcdm7L4XTB6M7dClzPFGypn9TjtZ743KyLgVnux7
+eCsekNmYjn1PqjmXGlcrqTeF7e0rcbEpdT74jp/SD+0gvrVWL0u5Yol/Z7y
1Ri3sBnOYe/nhwS1urmB3pP7wb/rjKiQ9WtgHqGT5VBG/RpYF+WcnVlEvT9M
rx2p+mg79f7Yfl6keaOA+gBsev1p4/Ns6gNgdNe4RjuL+kDsqnyX55JGfSBO
Pnqi9JJSL0DuU/vkAR5hCDB7aEFUtSudF2DUtNlZy46wSgBp22vrRDPaB+HJ
jR6jcnPaB2GwU08o4NM+CJqDi5PtltA+CMlqjtVLeo8jxDyjpH6FKe2FcNzK
09yrQ3shUn4rLaieaCa9EDPqdeFwnzAnGAMWNp4jY4QRjAbeormyvwjLg3HI
22LflsO0D4bDhNvIogTah+CnpbddO8S0D4FBvI+ejgPtQ8BNnUyKN6F9CJLe
5i9fWddE+lBoctf2bVIRRiiyA+/oBrYRlodiNPHHbQb9hFWhaLOdoz7VTvsw
pHxSqbjkSvsw6PlNtalrD5I+DJ0P7+6tVhJWhcGjP//qg+8Ic8Jxs6xl8Hbf
D6QPx8V2B3HDUtqH41RN4YvJA8SrwjHCzdmyL58wR4TGjvhvnXmNpBfhYq1e
Tfc4YbkIzZw7vWlVhFUirN0VYF8eS5gTATcXg8zKJtpHwC9D1G29kPYR0O+I
7aj89QDpI3Apo+WaIrue9JE4rpyyWFlHGJG4fzgttGwFmZdHIvih3L11mPaR
aApRntPb00B6MQ5mpSreLSQMMY4pcl/4aNNejPaJgp9jPMh+lRgnFmjPsDai
96PQ2mO5sXHOftJHoTem6fGy8WrSR2GexqEWU41a0kfBZrT95quOPaSX4M1k
5QndyQrSS2DQ2qN+yi0jvQR/VhT94n1PSXoJGtYZB4/MJ8yRguOakVJxpoT0
UrydcxGam3aTXgq3wPXCWf1FpJdCUjtWbR20k/TR2F0ouGBZ9z3po3FFP/kW
b5LMy6Px+JZ9r9cbOemjYXx9oCbYI5n0MqzS1Ml5NNeS/x+ayGDnapyb4CWZ
ZshwdNhwiDtgO80yGSRDKZkjgqxplsuQED3zWeJQzjTvl2HLwvo3ypKCaVbJ
MOvkvB0nnIqneUQG91LfOq/ikmnmxEDYl3fHeFsZuR+DL66Wawyihv834THF
XQ==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlQ9MlGUcx1+hBk1xZK6RujoM0ymWqKBIwJc/Isq/4+D4f9zL3XGH1QiV
aK5W71gF/kH+CMgBwm1liMXUYuqExTspkcDZTNdtsrhphDXnFGzmFpqtvc/9
nuc2dvvs+3ye3/P7Pe97BFveNZT6SJI0+vTvv2/toxS0Op3O3qH/6V7smY7G
XZ8xlvB478qYcsb+cK89abYzDsRoYELpC4wXI7Xl1oa5No2DEDH6MGyA8TLE
N4cleI5orEPSnaYqC+PleDvjyqGKVo1DcMKVPFXK+DWcq578PpDxKlQXKP1v
tGi8GsMzH38ywDgUPu5zf3Wz9a9jX39f+TDL12Hlr2fdW1n9MHxzzDd4gvF6
RA3rl33Jzr8BV0fSb1cz3ojJWlP3dcbhGJu97KNnHIHh0z/FhLVrvAlun71N
XYw341Gju7OBcSQCanqrwhlvQUBX6M0FHRpH4ZnrtQ98j2r8Jj58ssQ0n3E0
HnVeHk9nfgzafr82r42dJxYJ068ErWH3BeyfWHq3UmMF6J6NeOLP/DgsWT8Z
lKrVV+KwcObT6RF2nnh8G+0frO/U8ng8rr/74k1WLwGZBmtRJNs/Aeva0wPC
Wf1EVDz/43uJLE+Eefk/vX4s34ofXt7sDNHOo2zFW7/85qOy8yVhsNLpfX6V
JFTVEJa2Qemg+Ta8c4zmyWg+T/Nk3C6w/uzNt+OLLYHj7Szfju8Gp9wdLN+B
P291zDFWdqD5hu+JTpan4KM7fse9eQruW09d9PqpqPEkRnrzVMwcbHjI6klp
+HxkzW5vnobqnu4+7/7p2Jm6q7KL5em49H5Vsnf/DHx9hfaXgYkx2r8e05cI
Q4/Bi3S9HsYLhFU9Yoeon4m0Aepnov8M9TMR3TP7d4L2PqmZWNFybWgte78M
CPmK+gbsPk59A2bpfakGPOei9bMQSu8XWRhtoX4WFtRRPwtT+6ifjWHKyMaq
/dTPRh1lNRt+VeX36xs134jxA9Q3oucg9Y1CfSNiKEs5mKaMHKw+RP0cpFBW
c3CKspSLA/XUz8WiBurnwkhZzcUNylIe9jRSPw9Lm6ifh7rD1M9DWTP183lG
PhZTVvIRTO9DzUc8ZakAh1upL7BSgAdHqF+AvjbqFyKunfqFqODe90LMdFK/
EINHqV+ECMoowkm6XimCH+cX4Q9aTzJhPvf8mXCW5ooJc07qm2Dh/GKcpzmK
sZDzi+Gh/arFyOf6N+MlOh+YcZqyYsYmzjcjiuaSzLNOYMi4QFmWcZXbX8az
dH+XjA+4ejLuUfbImEf7lUpgpKwrQSI3D4FlYb1SAjtlVwl6uXmXYA+dp6cE
E1x9C5/rLPz8YXn6/4rWt8DA3Y+QuwRftfDn8VgwxtW3YhHXv5XvB0IuW/n5
KVb++XBZ+Xmrgu8RWLLx63U2PocNG7n6NrzK1Rdylw1Obv42ft4egaVSfh66
Uj6HwLKwXhFyl8CqsN4jsGTn1+sEhp1fLwus2Pnn02UX+rfz9+mx8/OSHLyv
cwj37xD6d/C/F4qDf75cDqG+kHsElsp41gmMMn4/uQy1XH2BXQKrAnuE/aSd
jP8FjPZ99g==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlHlMVFcUxh9F61aIWqOoKCMCbQixUFChqHyggqyyDcuwPQaGbWRrVIob
r6TghkUNU0AhjKlal2hrXYjF0mcXo1IXDGrUovNHa4yiRVKpa22acq/vnvln
8st3vvPd5dw3w1gab3pLkqSRdpL03z/7KYYvmpub9//wP/UH1TQP89/IWUJv
VtLdNzwSodenuFdzHovPg5+0ruM8AU7t7o+2cnZCTGhr03bOzrhuP/3afs46
POvJ3NnA2RUhw9/uvM3ZDceqfukzcPaAU/WUijE7GL+PaIdZufacPdGv67nS
xeu98PO1UTMucp6FJveruy5z9kbvgkmRjzn7YJfl64YXnD9El0f99ZG8vy92
JbwwP+e6H+7qnU0enGfj0MqytibOc+AwsNg3lPNcJOXXfry5ibE/Oq7EDdvN
OQDftHX1fcvrP0J60IYtb/oFYvTNIxHenOfh3PrBm5M4z0fgpuWuA7zfAuis
tX5+XA9C9Ykjs104A0+7d09sZfUK8Kp3uSWG+4OxrW9+oT2rV4Jh7LH/6kuu
h2B05TvKSnY+Sghqlt+YdIH3X4h453bHDdy/EIFue6M+4f5FCOjYcvUDnr8I
7ueD2jq5vhjlJ9fmH+H6YqTbHXDcx/VQJDzeMauF66FIzWvWzHMYfE431nhx
PQxulgmDThamL0HctI36EVxfgl/dno490cD0cLw1s93OdRvTwxE9+VL9nq1M
j0CJr+OL2lqmR+D4XcVvzWamR0L9O8k/9DOmR+Keq4+b26dMj8LDM+9KhyuZ
HoWG+1UbV1QxPRoOz/2H19YwPRqvT/xU/if3x2CEw/aKKeuYHgPHgOZVEZuY
vhSnKp5cu1XN9KUIuHPv9pgVTI9FZ8YFS2PeECMWwypXj3cBq4/Fe3vum718
h1iNRUP0DYfXHswfh9Mv1/Rvns78cQh/9sC9fSrzxyHkr31t417vG/LHwWVe
XR0GhliKh95z1xy7F0OMePxzL7rj6ETmj8cS78gagyfLj8ehy+v/+D6U5SfA
MyyqxJDN8hNwq7jbblQx8yfgvLy1diCD+RPQc+zlWTmN+RPx+7arB8qNzJ8I
95Si7Dky8yfCu+5l+Ct2PmoiOkbnVfYamF8Pua9omoXlQY+KqUHDn3O/Hi1O
ZyYnL2d+PXz6uywrmS4l4aBzkcdgGfMnoXzQ9ZrPGuZPwtlE7+6qtcyfhCjZ
oe/cauZPxt4FF42WOuZPxsHO8weOsflTkrFJ31g6eyXzJ8PL36n75CrmT0Fd
6vH+LRuYPwX3T126c5jlKSl4tH7EpbNs/tQU9Dyo+DGJzbOUCt9b8rix9cyf
ip6dmvenpKK7RcNqKgpate/TgDAtwyDWKwZECH4DArQspeGoNg9pyBLy0xCj
ZTUNY7QspaNM8KdDEfzpmC/40+GyQ+vPgLeWkYErjVp/Bjy1rGagWMtSpqgj
E4GCPxNRgj8TGYI/i/izsLpJ68/COsGfRfyy6NfJqBf6yZisZZmwIovrtcpi
f5XoNhnDteuTsjFXy7pstGgZ2TikZTkb/cL+sqFv1uYTVrMxU8s2oktGGLX3
pyMMwrJRvG/FiGAtW0m9SthmRLwwPzliPx1h5OCVdr1yDvZrWcmBo5Cfg++E
/ZN6G2EpF11a1uWKecjFQyE/FxuE/FxUCOefi/FCfi7shHzCkgl+Qr5JvC+Y
kCfkm8Q8xYRmId9E9m/Cb0I+YSlPZF2eeB7IE89LzhP7K6TeSlglbCMs5ZP8
fJJPdDmf5BO25ovrVYluIywViKwjDMJygbg+hejWApJfIN6PjbBUKM6TjjAI
y4SVQnL/heT+C8n5F5L7LxK/B7oicd5AWC4S85Qisn/CKqm3FZH3Zyb3bybn
bxbXL5vJ/s3i+7GaxfWqhG1mkr9MfE+6ZaKOZWT+iK4Q3UpYJWwjLBWT7w9h
FJN8wgqptxJWi8n8E10qIfNPGCXk/ZeQ8y8h80d0lbCN1EulYn8dYZSK9TJh
hdRbCauk3kZ0qUzUxxLWEfYmDMKxhGXCZW/4X3a83L4=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1H9MlHUcB/BHZku3IuacNtbmZVREBSqIFilv4PglB94d3E+4u+d+kdOJ
Y80aofRoxC6TEink+NV1YxbzV6zGAjUeAjudMpe1ZUHuWOn6Qy7WP/3Aslp7
vn6+X7Ybe+39vL+f7/P93u5R3x5zMEmSpLF/P//91/4UZ1c4HB4a/18L+Y2N
X4Z6mSXs+KlhSmVeho2r5rvvOQWXsgLJ+T2aV0K3pqr1deaHkfJVT1BhfgRt
E3JDSq9mHVKKE+ktzGsxWNFyq5M5DaH04UQr6z+BrW0fmzKZ03H98Lz9BttP
Bt7I6g/+wfwMXru+0DbLnImC3OQb55jX4ZO03cO3mddjxfkvrmUwb0D+sgOJ
PDYvG9HxD/ZNszwHup9fPX2CeSN+WZqUWs6ci7+vFl5sZN6Ezn2JoWTmzThp
jAXmujU/h9ITg1eaWP48Vrbf2qlnzkP1/T3kvl7A5HyYeAuarlJvRddJ6nxM
vkkNTMrECtCXQ/MCZH+U+tsFlhdg6eLdiRjLC5GWN1T6J8sL8YD+lOEuy4uw
ZzVdvwhZaXR9Pb5bT3M97iuheTEaikLNoywvxq87aV6C0wdovwSBAZqXQj5F
81I8O03zMtjnaF6Gh1wDg3p23+VoWZyZStK+j0o5Hl9ysdXK8m34OnEzImtW
tmH/6tRjVSyvwKeHmkfdbP0KbJ6l8w0wfU/nG/D+tzSvxNlvaF6JsTO76r39
Wl6FDbkzUzOalSqMTnsuG49r+XZU+qLpDw5o+XbEJun6RmSOE8OIkTE6z4iD
I8SqEdGkjKedR7W+CXO/n3HOd2h9E/oyzuNDzYoJrjt3JqwhrW/C2eXJHReO
aH0zFjOjL2c3a30zPh8xjNdpuWKGvHbHXvZ7opqF7281Bg7R/Vcj6S26/2rY
qNVqXFq+94fb7PelBldojhp0Hab9Ghxsp/0a7H6bzrfA8Q7tW2A5QvsWoIP2
LYhRS1bs6qR9K869S/tWfPYe7Vuxqpv2bTD30L4NSi/t29DUT/s22KglO/b3
0b4d7dSKHU9Rq3bcpOtLDn4eHIhy8x3YQq06EKP7lZwo4PbvxHFqxYk11KoT
67h+LerDtC9YqUWcnpdaiwXu/OpQRo06DB+j/ToYqFUhl1xwcH0Xfz+KC09y
8124xvXdcFHDjR+5+W5s4vpufj3Jw78PPFjCvb8HOdSqB39RSzKGqHUyxrjz
lOGj5y3LeIm7H5m/j4jMfx9VoR8XcsnLr6fz8s/Di2RuvmDFi8t0vxHBqhez
1HEv/36Sj39eJxg+/nxkH17hzteHx7j5Pv4+VB9WcPMFS37oufl+fn34+f3K
foS5+X7+/SJ+4f0FxwVLAeH+Awhx8wXLAWG+4IjwvCo4LlgK8tYF+fUg5LJg
RXg+IuSq4LhgqZ7v6+qF9xcsC1YERwSrguOCpReF87/nfwDeWCKS
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw9ywlI02EcxvE/2mGWNEklTPHsnnmUV1p70m3q5nSbpbNcpXTKVFqXWsYk
QzpUKrOZebUsp4gFRlHCXIVBmrUgKOk0wjARDzTIbnx//xdeXj5838cnK0+9
247juMR/9/9Lx7C1qrq62myZ0ago2nuBrpQ3h4A523+28HaAMLlwWwJvAWT3
lo/0GckuuF+nUbTxXozksa1OZt4e6K76+LmItzfSrwo0Ry+TfXG7X5I7h+/+
CErSDrXyfRlOW14GFVaRV+DJWExc2CXyKuyLKBtN5S2EvvOubhf/fw36xoO6
EvgeBN3X5lZDJTkY2lsm0zveIRD6LXr14SJ5LWzRB11CLpDXof9scVpLOTkU
lgJ9nRPvMFQ9mpj2O0cOxyt/wb7vp8gRCFHtWfKrhByJyHkdbZkG8no0SAIr
dMfJUZha6fnOvYAcDUdnY9/bfPIGDDVYPkcdIW+Es33Gjk85ZBHcysRa1S4y
0BGfJXfTMBuAq09TbK5kbhNGT3aK01Kob8IbibXMR0E9BofKe7Ndw6nHoH7/
pNYaQD0W7XZ56VsE1GPh6/58oXy8mXUx5rtJBqd7mA1i/M6fGrjbTl0Ca82x
WKOZugSygSHOoZq6FPoH9amvC6lLkTW3t+H9XupxEF6s8IzzpB6HDdrz49cF
1OMRP7yi5Io39Xjkrn/mXDp8k/UEvNysLFdZmQ0JqFlu7/XCTF2GiE5vO4RT
l+FMmsfkj1jqcmTe31mxREhdjj3q/DsaAfVEpGiSdowX3WA9EY02aUSAmJlT
IDQ4Y7GxqYl1BVZ5CO0OezFzSSjQa2ZbtlxnPQkvUgYfzx4wsZ6Mh57+1tpv
11hPhumcrbQglZlTQtHh8kWT3ThjKDFim5Wp665n/5WYm/NzcmqkdsZdSjRV
rj5RFlPD9io8N6nk6WeNbK+CyNGnaVFYJdur0F/T0/9IVs72Kjw8MBboHnCa
7dVwkEe2iS8Xsb0aOcuW/qnV57K9GvZeDbe5daGimb0aE+bK+c3SYtFfOCh0
oQ==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxFzwlMk2ccx/EXFCXOA5UBMoeVoAOPaisKcowfh8hpS1uullJ0Ip1TAZUg
hGk57FAClKtaNhlsiCg4ZAgs8aA6rxl1w2vGKVXxjBiHgso43Bae57FJ03zy
+3/fN529JlmSaM5xXPZ/3/9/6Ucj1xsMhoMdo/rbZ23h+BfHmTns7HRVdDFb
4k7etdNyZivsbx7LDe+ltsbzoRkej5ntYHv7N749u5+JYLNZwmZmHoJfH57y
E7Mjtj5JbP5gJ5xodymcWkk9F6bLeoUZszNc+YWlZ9j9PGxosdz6gHkB3Dp8
/vmemY/+OSP2H56/GDc7zusbmQUovm2pu8QsxHB6zsdO7H1LkDch64tDbHdF
cn/X0272f5dibW+4wMi8DMbhXOs2Zje4pl4/l8zsjsybxrvbmZfjae6LIlv2
fA+IzTmNP9s9MfjUUrKF2QsLk35J1OmpveHkKIycxfbPsej6u/a2CmofZJ9X
q3nsHuCpJ41V0l0DiPaKj1Wye1/UFTlVicrp7gu+qKnFWEZ3Pwy8db9YRK3x
w4W+t34h9J7zR03Oq+oUtvvjqqG2LKeU7gEwnVHaL6DWBIA3plVyq4juK2CX
+fsjrY7uK9AUbbPybAndA+E5Tau8z/ZA2Oo2Te9k/UqY/rj92fJ8uq+EYOOZ
Yd42ugfBG0usVEl0D0J+l+j48Dq6B+PK0Tl1fWq6B0MuFgmesT0EFztTfpVL
6B4Cq8FPHU6E0T0URwuk26550z0U9x/ILdSL6B6G6jTP7Qf4dA9Dz5uZpe+p
uXD0tt3QpEyiezi+7D1plWpF91VYHRCdVDWZ7quQ73KqYtfrerKL4LrMvNnm
OrFGhG//7NLua6W7GOWnxUJRATHEyHEZdDolp/dilAz7Xx0KJTaKcXBNfZ5K
QPsITHQYrMXIAdJHwDa9v3NcI7EmAtNj3ZO2q4mNEdgz8c4nr3yIOQm6qrvH
jRXSXgLLhR7cgID2EvTtr9+81Zz2EiSPCGoCOupIL8XzyktHdqcSQ4q0c32u
HfuINVKsalgclnGF2CiFYUJ51JRS2svwYmnFuLNa2ssgW6HO4qXTXgbP4zeW
O35Nexl0SabiLBfaR0LtbGrfp99P+kjcLHgZWNJXS/pITE1ZtNn6DbExEj13
jvgdayTmojC5Seobce9H0kfBK6szcR2PWBOF3u/MtjTV/0D6KMh6Zvy89GUN
6aOR0SAN6nYjRjTmbjqyd30LsSYaD9KL8m6ZERujcSVv3Xsrt2rSx6Cy6lzr
ns1VpI+BcHXGtflvDaSPgQW+GtpyqZL0MVDcdTbTxpKdi8W94EMjTg/1pI9F
/P214Q29ZaSPRcq91ztzRTrSx8KiJmSC5bxdpJfDYcdA4rRnOaSX431di8UY
92zSy3Gwvlbr8ojYKEfhjhMbtAlZpFegwqu1LLOM9grcDT7ZLBTRXgHfXK+B
QmqjAt4ego7uj9Skj4PDYUXbXym+pI9D+YU9adahUp/RPg6OhgC+ReCGURvj
IOkPWLBrdtqoOSV6go6ZSmKzRg0lVm/M1JvJM0ivxLLJdsV2i7NJr4SNeESc
bpdD+niUj/lm1rsSYsRj/ZP2hESvnaSPBz/EPv/Nw3zSx0OmG9I9TigkvQqN
baZpElUR6VWwnt/PbbMpJr0K5wWm/CC5jvQqZA6O391QUUL6BJzSOF9OLSjz
+RenyJI/
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlAlMFFcch8dqYguNRUTqWadaDqm0iHii8kMXFZF1WXZZ2OWYvWA9iKCh
1tLoGLFS0aqIIAjtekuQggdIbNVBJFINiCZqI1o38YhXIpoUFWNtm/Y95z2S
Dfnye9+8/zG7n9qW6Z3vCYLQ/s/n3//kTzaXlpeXV5/5j7qjWBbwzf2conrK
70OwxOZdp+wDvwGVzlEVhP3gE9D4JJLyEDSPK1V66PkR8E5YOeslZRE+4k+G
WMqjERZU+UsN5c/QM1KM01EORJD04INKysF40qE9eJlyCD5B/7t/Uh6HUqX+
hJ7W8wWaS/o78iiHITqkeNAwyuNRuDfH6xj1w2H0uAet20l4Agx5OYs7KEfg
jGfDyQDKE9EbXJ+joTwJFYf9sxopT8aLW9LSWspTUHit66POMsJTMfCCV2M2
5WmQfcfe8CslHAkpPto1kfrTUXX1ptBLeQZO2eo8P9PzM/G8fsSSd34Uaju0
mtOUgZ7qQ0ujiv9nGZjWdXlPBWEhGklFbeG5JSSPRvFbk/4hzWehpL3aJO0g
+Szs2+S3N2g7yWfjcEu2/1bC8mxsSt8Rco7mGkxwfZuy9geSa9D/4pIrHUUk
j0Fud2Bo8BaSx+BFfufqt5tIPgfte8IvObeSfA6i7rR5+ZPnCXPhWxYYEUrz
uXCUaKrGU38e0sO+rN22jeTzcOqKfH0mrS8W4SfKzv5F5xOLptWBu0H3Mx9b
Xuz6OICwPB9Dp/zaQ+clxEHfZ2W4TJ8fh4C8aeO8CAsLUD3D1jqS9rcAEdda
bzfQ+uPxTDtkufg9yeOx5Vn2AM06kmvxuM/LW1WEZS2cMddMzTLJF2L/475t
FTRfiDzdj8FGer8OTfdf10wk+4MOJd0+DftpvzocO9pUpyes6PBo3vqzaRuJ
n4DPn14dcr6A+AkYvtgekPsd8RNwYGfNuUnkfiUBMOpa6jYTX4988ehyM9kP
9Hij+Bb2pe+LHl0Hy9/9Hil6xO1XsZCIZ7tVjEREDtT1e07fx0TMXXLvRi1h
JRGdNekRLtq/ATG/y+27ColvgKFDezd4DfENaBgeknslifgGzNx4od9TifhG
FBT8URaQSHwj9jVPX3Mrg/hG2J35uf0sxDfCdcTruI+D+Elo3OzO7YohfhKC
6uKbG03ET0Lo3ZqC1GziJ2H7mH0tWvr+mtBb8PrYsq+Ib8KO818P372C+Ca0
+E8I9V5FfBNaR0cef0T6E5KxIfBhUBudfzJuT60f7b2B+MnoPTV2yuD1xE+G
9p7LO4bsW0hBRo65ayh5X5GCwdc/rH6wlvgpKDZJl16RepUU6KRDr1y0fjMO
nB72Wz5hmHGkTLVP2Yw+5er9m1GtZsGCop3q/VsQVqH2LehVs2KBpVLtp2JV
ldpPhUnNciomqVnhWEiDon4e0jBfzXIa5F1qPw3eahbSsUJdH9LZ/uR0GJn+
ORYysJjpn2M5g52PkoE76vkKEiLVLHIMCZPVviTBl6lPYutxSyhk6pXYfXgk
2NQsWNlctELPzMPKnpe4XLZilJrdVgxg9m3FTXU9HiveMPOzsSzasFLNsEGj
ZsnGPk/mzrttyGT6t7Hz8dgwhrnfjm71fEWOwbFkh4fZL5e77dz3xc7W47Gz
9QoOlkUHex4Odp+Sg3s/HShn+udYceAkc7+DnZ/gZFl04iJzP8cSxzLnuzlW
uPMeLhcyufs5BsdSJnd/Jtufm2OFO+/hWMhiz4tZ7HzB5VIWdz+Xuzlf4djD
seBi9yVyDBe3f45ljt2cr7i4+7lcWMT6IsdYxJ6XOJbf8d/cEHql
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1HtQVFUcB/AjNloRoqIGAzbrA803gkipxRcUQdgFdtll2QWWK29WmV6M
zfiaC9qICspbl6I2Sx1xyMSstEbulK9JpyaGpuIPvIyMoz0xHaqxIps8x3N/
zDDMZ77ne373nLvsjMIXbCUBjLH++7///eU/qrvN5/Md6/lfw/FGM3wzLPtR
DISlVdQJT8Ske0sTSoSnIOgtTwmEQ5G+YMVf1w5yRyDyVs+ZcmETFsbPP2EW
62fiSHut87DIZ+O1qCWpNcJzcMh7+eIl4acRY3kx3Sv685H2456UYOGFaI7+
wh8tvBgNbYHjR0U/CiETRs4uEvlSjIyGHJwqHA2r5ciYCOEYXI+edydG9Jfh
dv82b7dwLKaH3Ap7mC+HxWtrbTvAHQfPjdU3q4WfwaVtpfubhZ9FxJiol2KE
VyDoQuaWE63cK1FTGdnbK7wKNU2+r71t3M/hicmLPc3CzyPuXnHnU+3c8YiP
Sv+4WpwHePzopnWn+X4qcL6yyhIu+gnoqr879FMLzxNwdWf+XCs3S8SfFwev
ftnE80S8OehZmdjI89WIDXq3vWofz1dj6ObQ96yB52tg8f9a8ojor8GnhzPc
KjdLgmlaY72dr1eTEBYzZd6A2H8thoP+uPe2yNdi0fHk7GqxfzJuLLm5yyX2
T0bX57md10Segq2Xz60K5PupKbjY03DiMbH/OrSsXb69QTz/Ong7xzaO1vI8
FZMWbExy1vA8Fderlod8sJXnaRjM+Sd8/8s8T0PAewV1v5fy3IwJ5zY7hkRu
xke2vR2HvTy3QN+tfPatm+cWRM7btfEdM8/TseXkuKEdKTy/74n2yD6RZyAw
b2pftYvnGbiTcT5vfBHPM9G759TwGeWBkYnYuB3O4Fy+PhMfDo4dF57zwFom
zLc/SVrp4X0rOvYOuNr5elhxek5yQhjfX7XitwVdbXV8f82KyuAV5V4779tQ
pp9vTuLnhw0+31fd5ld434a74wpT+zfxvg2mlPdDfxD3m4XexNnnUvj7RRZC
3/A9/L5SszC9TbKWhQv1kpkd3bslw44n98h9O+pla3YE7JX7DpTJhgPHZasO
HK2T+w40GeZnY/s+uZ+NzfvlfjZmNsj9bLwqmznhkA0nrshWnfiuUe474WmS
+znY0Cz3czCjVe7n4JcWuZ+Dkwfkvgv6Qbnvws52ue/CyOty34XyDrnvxjb5
fcGNPnm96sYpQ9+NQ7JZLgJlIxd/++R+LpbJ1nIxV35elodK+TzIw3bZah6m
yeu1PLgM/Xwck/dHPiYb5ufDYZifjyj5fpgHhbLhwc+GvgezDH0PamWzAqNR
YJynFmCMoU/MFKNNCnmfCoZlK4rxeVQFa2T7FXLfZL2uGJ+PrcdZw/z1uGI4
D7FCrBL7iTVincxjhcb3Zyok90msEKvE/kL4DPNJrpOcFRlzUxH5PBUZn1ch
Vsl6P7FGrJN5rNj4PCZiFJPzE6vE/mIyn1gn+7MScv8lxvOB5AqxSuwn1sh+
OslZKTl/Kbl/YqWU3H8pOT+xRqyTeayMzCcGsVJG7p/YT6wR68SsnMwvJ+cn
uVJO5hP7yXqNWCdmFWR+BZlPcqWCzCf2E2vEOtmPecn/n5fcv5e8f5KrxH5i
jVgn+7EN5PO/Qaz/F9+YzGA=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdk3tMlXUYx9+EPyoLL0ODZHg0IgeO5Gpp6BcP9/sdDofLe87hXLBFkZb9
QfhWkCZhgkYcrHXCVuFik5okOOHNlhmmDGaNLYwTwVwRi2babbVq7Tw8vx/b
Gfvs+35+z/N7nvfdYH280L5MUZSxf3///ff9aRWdbre7d+R/Wtx552xEv4dY
Qe5g3brzxLfDrzGmXyNeicnnl2XPEgfCGHRl+T7iINQMHErNJA6BOSDxWiSx
AQ1he/Y/Q7wRXS2ZazYRh+HX+CzLauJwnI12jAYTb8KPUf5vLXT5OAITfZ+3
RlC+GQ8aTYdDiaOQ19H+VRDxFmSMfnl3GnE09O4z3z5JHIPAoPFPs4hjcW6q
fshGHIdt/b0pMcTxiI4ZDtpNnIDfpt1/VhNvxd6WttKniR9CgGerfx7xw2jz
c6xKIt6G1t6Pn0ol3o6C0O6+HOJH0PGutaeROBEJNz0/2bt9vAMX/DuH1hz3
8U7cOxvs/IFyYOMB99L+NWDAxVhJQmgOz5PgX3Fsrp3yXbjj59FmYm0XRkaS
I5ZyI86mNa04SLkR9c33N09Qnoxp88zCKOXJOKBmXK+kPAXGFBygeWspsNXe
CCmiPBXX62OnjJSn4vTbKy8v7TMNNy1X3txMeRoWnjud+we9L+mYvzgXfsPH
Wjpm1ZOT85RnYN3ygc+mKc9Ax8D7vSF0fiaeSGwaWqQ8E5EJ4d+kkJ+FoGtn
TqVTnoXY+JkmP/KzseJiYONS/9nYPRmw9lHKc/DS3Mnv+nz703KgjreM76c8
F3FX+X5yETnB95eHhDGe52F4lOf5cF1gjHys/4Q/n4/L5xjr+Ygd5H4BTgxw
vwCzH3C/AGof9wvwwnvcL8Q7J7hfiCMe7hfC9Qb3C9HQyf0izL/K/SJc7eB+
EQwvc78I4fF/dx2l76EYYXeNxw76GMXYgEt54zTvYox9uGpmsMfnFyNgrW66
RX4JnK28fgm+4KyVYK9QvwQNbbz/UmQd5n4ptnPWSnGKs16KCc5KGX7pf3bH
GPllGH6F+2X4+gj3y/B7O/fL0cPnhXLcc5T75ZjjuV6OW5wVE1zHuG/Ci3wf
mglRfF+6Cdmvcb8CD3RxvwL3ublfge+7uV+B8de5b4aZM8xI4O+LZsYh4f0x
w4+zUin5lWg/zv1KfCTUr0QAZ6UKDt4vqpDO76NV4TF+X70KwcL9q1HFGdXi
fLRqNAl+NTyCXyPmkFirwXnBr4GJ96eo6ONsULEo7EPFbfx+qpRrKpJ57lHx
F2ddFeflVbFHmJ9FzA0WbOEMi/i8KrFmwXrOHguswr6k87xSPcWKKd6vwSr2
DylXregV3k8rFoT7S7luxUHOXiv2cVZsKBHq2+AW6tvE70G1ifvQbNL8beJ+
dIm9kq/UIk6oXyvWQ63oqxJrteJ5nlqsFu4vne+VzlfsYv8Gu/Q9Sazaxflp
dgwJ9e3iPHXpea8dl4T6Dmn/EkNi1SH6mkPcl8ch9qM7pP07pPs7xXkZnNL3
J+WqxJpTnI/HKfarO8V+vE6xX8Ul3d8l3g8Sqy7xPM0lvu8el3i+LrHXJc5D
qRNzQ52YQ8pViTWJPRLrS/wP6dyU5w==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1AtMVXUcB/CT2bQyKWcbMIorNEPWTAslQ+DL+yVwL8/7hHNfPCQlybTF
1k7kBAO8yuPqhXCX0WaYtVDLiQon22pFRUgtxqIOkc2RS6VNZ5u91s6f3//P
dsc++/2//9///M7/3jWu+iLvEkmSxv79/Pdf/1Os/kAgMDj6v24k85bQuDS6
fYZ5ORIu9d+eZn4Yp/OSG+eYV2NgaOLjU8yh+P3OvrEvmCNw4u0f177IbMCT
r+9pTGOOgrRzuyOF+QnAd+7dr5nXYvXu4d5W5hhs3Lqs7XPmWNR3TZ2bZ34K
P0+Nti16PQ5ebLj9QY/uDTgfXtkf06t7IwJbjo8GmJ/Bp7cmv0ljfhb7wzyB
eOY4TOdu33GX7b8JT1+cqTvB9t8MLbaibyVzPNY8eq0lhPk5fBVx2dLOvAXv
T4TdfJX5ebxz1d55iO2fgMQQ++Uu5q0w7puM7mBOxFmj9cPDzElQHmma9jMn
o+PqeO0AM/DLVFlMgt5PAX47PXtvEuufgl17zgz49PVKCpIGz4a+weqpaApJ
NrH7oqQivsV3crF/GvonEqPy9XkpaWjWVozY2fzS0Xlz9vpAn15PR0zb4xFt
rJ6BXXdGd2exfAbCa9XqcH29lAlz4zKH/6hez0Rx5Ka+Zt1SFm41BBbvs5KF
wWZiKRsTb9F6NpqWhEYNsHwOjAkPRfuO6PUcuLrXOWx+vZ6LOK2+/YFuvZ6L
TMv85gdZPQ91TWNye5dez8PwvD87g+2/Db/+RPtvQ/UMPV8+GqZpPR+1U7Re
APv3tF6AP7+j9ULkTNJ6IZaO07oRf40RwwjPZ3S9ERs+IVaN2D9C8yZcOU/z
JkQO07wJhR/RvAn1p2i+CKknab4I9w/SfBH6Xn5l72P6vNQimP5wzq1g8ytG
9vKhnX/r7wfF6LrkyPHo81eK0bKw8OV1va4WI3iQ9i/Btwdo/xLEvEn7l+AY
tVqCWWqpFNWtNF+KHmqlFIY2mi/FcWqpDOvbab4MHdRKGc5Qq2WI5c5fjmwf
zZdjhFopx6pDNC/UJTOu0TrMONxB82ZcoVbNqOukeQsOdNG8BReoFQs83TRv
geyneSt8R2jeiiFqxQrtKM1bURqgeRvuUsMGG/d9tuEFatWGC300b8cCrcMu
/B7YcYzL27GOWnKgoJfmHYjsoXkHxuj5VAd/XqkCLdz5KxBNrVRgnHt+wVIl
WqlRiTlufpWIpVYrhbyM96gNMsK49yHz70eW8Rq3v4wd1EEZ93HnFfbXZP55
JSdeovMyOOGihhMrqWUnP0/FiSrqoBOruHk7cYPr78Q9XH8Xb4OLXw/BsrBe
cfH3M+hCHNffhXRqzSXcXze/3uBGgLsPbj4vu7GX6y/Ug4JVNz8fzY1Brr8H
P3D9Pfx84eH7yR5+P0Vw0CM8vwfDXH+hn+Tl+xkEQ7AsWPHy+we9/POpXv6+
aYKlKn7ehio+D6EuV/F5RXBQsCrkNcFStdBfMATLghXBwWqhv2BNWC/VCP0F
Q7AsWKkRnl+wWsPPUxPqUi1fN9QK/Rf9D614iuY=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxFzH8s1HEcx/GrpYm1MZKUpRaZyvyonDrdy3GOO+fXjotWOB2TNf0yGWtf
xKnMpXPqMuX8OGr+SHGJfvrR2hKNUabMdmdo2qhGMuvHfD7f3tt77z323N47
FJkxyrUcDkfwd/9dOkxCpU6nu/diVXP87n0KDwNrDgTuSyP/bYmh/Da9grUN
9AZF513W9ugbXpw6w9oRUcFbupSst6HpdPtoEWsX+BVNBrmx3omZ3pXL8lvU
u5AYb7ukuUntBufHkcXRldTuSCrgLp3QUnvAKdbONZn1XrxJjG8f0VB7YuKj
nfbnDWovZNbK1T7Xqb0hFcwO9JZR++DRKblDKNt9cbtvfUx3OfV+bKhJm9Cw
/w4gdaLzWhzrg1ij3d02XkrtB9FKTVWWmpqLhOVZrYjt/kj4zBhNKupDsJDk
O81nUx+G3pjYJWfNg7btYXlcDnUAMHDlZGkW9RE0moWq2AxqPpStYxJJKjXw
bavLunQlMQMUppVHL8ppDwQvycFrhUd7IF5Kv18SB9AuwExLesW5PbQLwItU
pNk60x4EoYjHFXJoD4L1/MzR+U9NpAej5Hheg66PmAmG4ur7KUMh7UJ8sOLq
Mi7QLkR1c2JEDp/2EIwta8+qN9IeAu8vnNa3c42ki2BueVWQVUzMiMDVPm0b
XzaQHgrvod/HngUTM6GYXpBb/KhoID0Mm3L71HY8YiYMv+pGNSpZPelinC/q
n1Tr60gX4/nCWHW2oZZ0CQa321T6m/SkS/CVMfX0SGpID0dH7rLS1HyH9HCI
B1ytZB1VpEsx9mDE0vqdjnQp7BeGfVUmLekRMD/xNG7O15AegWlNEDPXX0Z6
JC4yzqklRhXpkbBNkfHzXueSHgXd/VnHQVnyqhGFcnN2q3t9Cv8Pv4JW1Q==

         "]]}}, {}}, {{}, {
       RGBColor[0, 0, 1], 
       Thickness[Large], 
       LineBox[CompressedData["
1:eJxdlndUVNcaxUdE1KACyouSsYy9KyooxsIGFGzoSBHBwtCGDlMRfZaJDTtF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        "]]}, {}}}, 
    AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True,
     AxesLabel -> {
      FormBox[
       StyleBox["\"t\"", Bold, StripOnInput -> False], TraditionalForm], 
      FormBox[
       StyleBox[
       "\"\\!\\(\\*SubscriptBox[OverscriptBox[\\(r\\), \\(_\\)], \
\\(t\\)]\\)\"", Bold, StripOnInput -> False], TraditionalForm]}, 
    AxesOrigin -> {0, 0}, AxesStyle -> Thickness[Large], LabelStyle -> 
    Directive[Background -> None], Method -> {}, 
    PlotRange -> {{0, 1000}, {-0.05500000000000001, 0.5}}, PlotRangeClipping -> 
    True, PlotRangePadding -> {Automatic, Automatic}],TagBox[
    GridBox[{{
       TemplateBox[{"\"All replicates\""}, "PointLegend", 
        DisplayFunction -> (StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[1, 0.5, 0], 
                    Opacity[0.2]], {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[1, 0.5, 0], 
                    Opacity[0.2]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
          False]& ), Editable -> True, 
        InterpretationFunction :> (RowBox[{"PointLegend", "[", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}]}], "}"}], 
             ",", 
             RowBox[{"{", #, "}"}], ",", 
             RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
             RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )]}, {
       TemplateBox[{"\"Mean of the replicates\""}, "PointLegend", 
        DisplayFunction -> (StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0, 0, 1], 
                    Thickness[Large]], {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0, 0, 1], 
                    Thickness[Large]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
          False]& ), Editable -> True, 
        InterpretationFunction :> (RowBox[{"PointLegend", "[", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], "}"}], 
             ",", 
             RowBox[{"{", #, "}"}], ",", 
             RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
             RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )]}}, 
     AutoDelete -> False, GridBoxAlignment -> {"Columns" -> {{Left}}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.702030141207961*^9, 3.702030175836627*^9, 3.7020302378821487`*^9, 
   3.702030404975274*^9, 3.7020306630798283`*^9, 3.702030767795496*^9, {
   3.702030806322263*^9, 3.702030849085206*^9}, {3.702030920292411*^9, 
   3.7020309411688843`*^9}, 3.702031248885127*^9, 3.702031312736662*^9, 
   3.70272927107448*^9, 3.70273035679858*^9, 3.7282167745883894`*^9},
 ExpressionUUID -> "b9f9446b-d5c9-4912-85eb-cd1adb5caf23"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdz3lQ02ceBvAfUUSFFkFOuRIQEIrcKCDIo8ihIle4kigkIelu8azUETww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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0w00lPkeB/BnUUQ2RcpbTV5KQovSm9aXQiHv768zwwwzCLF145aJbSWl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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1yw9M1HUcxvEDh3KbIglM6fhzHJw6OPFCkYvj7h4ODu6EO+/vDw5wJWrF
0DOFiVqsY112DBcNqHEhV0rnXCt3gxGiaFQGi06pQ3YZhMRYJCpQTImoWc3f
57t99t1r7z0J5UeMB4M5HE7Zf/f/T6/0k/PJ7tVb8FQLisMvt8dL5zez5kDt
U889GCWHYnTxM+5sLzkcTX5ui+gsORKJ0mNtnzrImzByektVWyU5BnvbU2a7
LGQ+woJ3+IekZAGcTxbkLgE5Cb9M+FvHQsmbYe3db+I9FLLeCs8Znd7uJyfj
xkRls7WbLEJgXJl2201Oxb0T0ceynWQxPva4Sw/ayM+hiHNfVV1MTkOFIEO0
U0LegeCikuthfPJORAyeOhRYRU7Hib4HDUPTSax3QZg0/r7OR85AVsiHjVGd
ZAlcu+KYijby80g43sHX1JIzcW3D0muPXyRL4WzUPo7QkrOgE5abO9PJMhhs
vsIDfLIc0x/oZDVryAo8Wtpbf3UukTXgUz8zdXGYtR1Q9A4XxPVQz8aQ4r6g
y0M9G2ldV0qSndSVCFqfO++1UVdC5hdDY6SeA5ndNQk59Rw8me5c0CRSz8Ur
ii+Hl0Op56JpPOjnU4sCtqvw/TcNyBtjbVfh6O8pwo0D1PMQKJ5z/XaReh5W
DsU0y5qp5yM1s6Ou/CT1fAy+6tkgraCuhv4rpbiplLoaVk/OWH4mdQ06zs7x
Up6lroF9P3fdpZUEtu9Gxap1b4jvsbbvxmzp5//U3qFegPmohwGmj3oBrF1Z
plg39UIE13lT+xqoF2KqMCRUXENdi7ztR2vMZdS1uJzJ1C1qqetwfMF1/oqG
ug4Z7rHeyVTqe1C1aeDSDJ/6HpzZd+4H1VrqesQ1B2m9i/ynhh6H5Wl+ySRr
ux7bIutHJr5j3a8HNz3cYe5kzTGAuVnmim2hvQG/Zt9diX2T9gb8MSp0eatp
b0BP/Y+nly20N6I44k7RLTntjUj+6OuN5dtpb8QFXveSTER7I5ie22FVfNqb
cMTqvN7Po70J1TPnirLCaW/Cu5L4n7QhtDdhbYtj2v5XPLs34+aATRX1J2uY
cbLqbkzcMGu7GcwX0W/VLLPuN+PbyJGIFwK0t+D1SsWtqUHaW7CmwGdrv0F7
C2TKfY6WbtpbYNS9J+FdpT2D6I5HL5W00p5BvcH79wEH7RlsE8001r5NewZt
Ia0T3Hfi8S98S3MN
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd03041XcfB/BfEiKrhJTSmYcepLOkB7HyJg89UJ4Px9PPw+E0SmGLtnLs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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1XtQU3ceBfBLtCiFIlTlJUoIkEV0GQHlpcIhoMQqb0OA8MhT2spCEQTF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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1Q1UVGUeBvAr4GhgBIEogjEiZiKiQIpgxsOESojIIDB8c5lhBmYGV/Nj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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlHtcjdkax19F0oUYt1Ta5ZIMUbkVTT+l3JJql+55u9/tvelMYegtQ47O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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1XtYTekeB/BFBiOpXCqithRJ01FJN/RNRbmke0ll7127+400yG1NjNwv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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0H801Xccx/EvEguhgyE/b0aUiiTk8nL9Dtf9wXW5dFqlYrW26tC0+J6a
y5aYMKsZO1ZDquUsluRnpyHRlJNaO0WqnSnmxzr6ybazz/uP7XvO93zP47y+
z/P5nq/9pl2yZE2O49L/vv950qU6VelSPt8J/2rCP3r6WKHlE0dmDk38mpGX
/WRdRI+m6o3/SDZC5kGDxuYysglMeP2JnoNkcxQIjRIfp5KtMNbdOV6oINsh
+3Jf4CMhWYCCzdM9dc5kB2SkNxjsMSI7ImjqwG+yqXeYl2L/Ifeh2kGyCyRv
HllpdJCXo+/czLy2avIK+F5r9nTKJ69Ci3NJb+cushsK02+c6ZeT3aGqXXpq
g5C8Gm4179d5O5A9IFevTvNeQF6DBM5Y4v6HA7MnNpy+b6h7k7wWdeqkZ65N
ZC+8sBAFhJeTvbForuClKofsg6NbIx1KdpPX4Wcf1btPYsm+iLieVf/DWrIQ
g6KBlZPWZD8M7XGxrdIm+8NU+KLBb2IJM2CctDQq7QYzD5zXF3xU3Uh7AOZH
DrTJjtEegE1dgouredpFyM1Q5z7YRrsIKVkW8/ojaA+E3VG/Av3ltAdCWaxn
02hGexB+7+n1Pv9awPYg7G/VfKh5m5kLRn3+I0nlRdqDccJV32vf17SHoKhR
2f+WmvYQvLxmeK8nhfZQlEkKy59H0R6Kqdt7nXvW0h6G6kOjO47Y0R6GPJth
H7Ee7eHYWCqJWfCnPdvDYaqjU9J7l5lbjwv887GzDbSvh8LnQ63hctojIH1w
RXPFYdojYOj+ZkidRnsktrxq3l6kpD0SCYtzAnd60h6Fk2M7Z9sFtEfBcG48
xVKbdjHadxzIvDJsx3Yx7gyoi8QPmblofPzNeK72Vdqj4YblA26NtEvgoZXy
yvY4MyTYunBVaV8GvS9B93Sn1fAm5jYJ7Ixnil4HUC/FTKhTeJ0X9VLUigTP
R6yol2LU+mTNMh3qpej4vPa6YNKW9TI8C3dRvOhihgxlWSrP4CPMvAz9V790
qE9mbpPhM5OOZj6aejnWtYY6aphRL4fv4Y4y0zs2rJfj+0qpf+tx5jY5jMxy
duruYeZiMDsifiqPY0YMyi3mTLfbUx8DV+GKmNbH1qyPgfh0fnByPTMXC9GJ
W9WFucyIhbH5nVmtJGY+FuvaL63Z7Ul9LB4q9cu6RNQrMF61rDRTj3oFajaL
izdqUK+A7pYHJSffpv5/5uIw6P306tCgFevjMCmuc7zcx8zHYUHmT6nW3zK3
xaFoZXeNWRUzp8TrLyaFn3xAvRLZd1c6q9KoV4LX/HXUMIh6Je4NmaujBdTH
47HrQq86G+rj0TSxt3SJFvXxONd5PowfW8z6eGTnybt72pm5BHyVHlZx4xIz
EqBtYD3oyzPzCfjOQ3brVQH1CXiv60LLzUbqVRip6Oqam0fnqyDI23a/wYnO
VyH1aVb6lJS+XwXLKnnps+30/YnQKJ5usSYjEeYhZyLOFlOfCPtFmTZaBdQn
/vd/cUmwCK3YLz1OfRJMfpnM2HeN+iTkfFqraH5jhb8A9nbuMQ==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxV0H8w1Hkcx/Fv4hAG5RyF3SzO6cfRVYTyIis/8mvXsnbXrrp0V6tikikz
ac+vuylpCl1TIeF0mtwpVzfK9d2KGtd0qpMcbUo/9VNSXaHr5j7vP+47s/Od
xzz39d3PfqcvXydJM+I4Lu/D5987XcqGg16VH32K//Q8qEnq4PTysQczh16j
ckubq2QzjJR2GFWcINvArW9haHgF2Q5jAwGYUUh2wKZHgxUN6WQn2Awu2Tca
RxYioj3g4RxfsissZllYx7mQ3WAS5OO71ILsASOd9UjdU3dmTwiywxo3XyV7
oTtG+qPyOHkmFG0lYysqybMx+cWpJnE+2RtRzRPguZbsg58LkhNNE8lz8ObG
nYEDAeQvYOhu1dq5kufCILAum2pOngdlQhmODrkxz4eotCvr9y6yLwydofr7
LWQ/FJoVyJqryQuQcdL8G20x2R+f7R8PO7qeHIA1Fx3z8pTkQJi037z7UQB5
IabUr9DlOpIXobY3fYfAiByE8o689WP9ImYgovfX+UGdzDpALSyPvf0L9WBc
7K+tulZHPRjP0idV9ZdQD8G5Fe0qLpN6CALzTrqbyKgvxhP9V96j/tQXY+7C
boOlgHooiq5lvFOOubIeCsdoiUXtfWZOjFWNy6RRPdTFcEtPzSzUUw+DvOP1
8cw66mHY66Xlq3ZRXwL1JckVXT71JfAOXlOvW0s9HNdqUlsGo6mHozEw4dxQ
EPUIBPXcbzUWUo9AdU9DmMiceiSGt3b9XflqOuuREHccqVtwg5mLwrtjx/2f
nKUehaKNV2MfHqS+FDLHs51226kvxaVhK0XuJurRePR524mRr6lHQ2V6cO80
MfUYGA+HGG30pB6DZUdbFBssqMdi/61nmtd3hKzHQpJvO6fiNDMXB0/bU9/G
1TEjDoWLNc3dBfT9Dx7VmiZkM/NxCLBqctaraB8Pyz6JaWQ47eNxzqVE3uFN
+3gUbRUVWjnTPh5Xnu+2zzKmvQTjfrWdIoOA7SVQHJ7o3trCrJNg5Fb4Y/k2
Zl6CydXvcoPWMXNSzLKvtTfY016KI5pDhtV/uLC9FOEdEX32Rcy8FNbquEVb
Ypm5BOizHZzyPJmRgC/DtEP6m85snwBZ3vfGO48x8wlY6TxNUr+MmZOhtyeH
i45hhgy7Lhh8KsxoL8NOvlXvfs+J7WW4t104knOGmUvEpNz21c41zEiEw4ah
jLJ8Zl0i7P10E4sW0D4R/hGXz+uEtE9CsYsVf7l1GtsnoeTN+0Muucy6JGQk
t3XxHsx8Ek63lO4os2Hm5HAJHm+OfDWV7eVI0j8Itqxn1snx/raoZVcZMy+H
VG23rTycmUuGyuI3+b4ptE8G9+faTO0DR7ZPxgETXnI+h5lPhk9gjfBtNDOn
wAS774bHxxzYXgFBRJtLaSWzToHO4Td8p4aZV0DtNfJSK2DmlHA3vySfffcT
tlfi+au03P5qZp0SH8es9L13gplXok1fc51fzsypcGtG2hmLmbRXoSR7S16g
wZ7tVdBZvy5Qz6O9Csmbn4qLR1jnUuAHkRFeMCMFOVve6rUNtE/B8Nv2tr6/
mPkUiNMGjhXvob0aP4wdEnjsp736/8/XqXGmeIdtjSv9vho5WaJ1h4Pp/Br4
PxrQ/bSbzq/B+rLGzeY8/X8Nrtu+cFyVRe9PA/OQC4MxWnp/qRCbTRx92cQs
TIVmTVPVni4H/AMDKB7Y
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0glQU3ceB/Anl0XAWpQg1q6JVGwbpAoCCkW+gEK4hADhCFdCCKDSlVWg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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0n001PkeB/AfQuW5LclDxmPW7cHmoSh5e9jxUMR4fh5mhq6SUkdd2hp3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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1yWtIkwEUxvHNZMrAqNhIxdBtOnVqma6867NN3XSvOjMSEaXCLh+qhdHE
Sht4KTKhshKJ3ChBrCSLslqpeW0kXmpzIWGEmE1ETWZCiHah9xx4OPz4iw7r
9x1x43A4SX/379MVPrgna+YF479+pHSkJU3JF6SsOXi+2DyeYyN7Yr1c7ZVn
IW/BW2dpV5GJLIAgwtLRU0P2RlSjRFV2guwH08DE6Rc6cgCs3CmDOY4sxnS/
0rc1gByIV7/6+dk8shQFrcGzsfNBrEOwGOk1p/lAluGnVmANt5DDoW0P5Xbf
Je9E7lLD/ckqciTC1u5U+58i78akt+cQoyNHIfmZ7FtdDDka2keFh76IyHIU
5yfWD/LIe8C3T5hWFwNZ74X+TGd3wQQ5BsVGe3xVFzkW0/WGirYWchwMB4+p
Pl0ixyNYvOBY0pMTUOjjEKbnkxNR7RvWsy2enAT7jEtg9SEn46Z5qHRsEzkF
k8b88ZVZCWvAuv/sm41R1kbAtOq/HNFJXQGXT2hOnZm6AvPLfFyooa5EybWR
tsoS6ko88dOVv8+krkLu9SvcATl1FSr6dn3X7aCeCltjwci732K2p8IZ3dzt
NsOak4bNTcMvn45RT4O7QyLkP6SejlJHn+TqberpYFxF6pZK6mo8nlYcjT5O
XY2VleGLJh11DdxfW8bmEqhrUFt3y2ySUs/A8uX1opDt1DPgMCbagjyoZ2Kr
plzCrInYngmnsCHP4GTN0cKscN04OUVdi/O9ZYzBRp2BR+zXczOj1BnwZpVC
8SD1LDD6gQPcXupZsLZXJ9RaqWdD8nmjSfpRhD/KyvqS
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0XlMk3ccx/F6IaID4sGQChSQQwUiTpTCKh8O5RCklFIKLYddcCBWXNwU
Zc5nHLOgRCWyzYpX3dDKkFOsGrcKKiCCIgoecx64OaJcXkGHsi37ff/Zkzx5
8srneSfPL4+DKlOSOpbH4+X+c//7pEtxXDf3gIkr/tOg/zG1+vauZy7MPDyZ
lqq9cZ1sisWv/K/fPEO2hGlFeoH6CHk6ttSLLrgXkK2xUFRyc6OaPAuZr70a
oqVkAfp0aU7vfcmOuJqM83GO5NmoqdJGVZqQXXDf6Lm/vNeZ2Q1HPYfbzdrI
cyHxq3hiUUd2xw6JVcjLUrIn9I4nfv41nzwfC87Zu/Skk71Q2FRTWiwhL0Da
GFXHYyH5I5jvSbiidSAvxIMdsbrJU8jeaOTOvynvn828CHzHc7dKOsmLYVS3
HOw5Q/ZBfkOEducPZCGatI578jRkX4y0Glzt15L9MO+wzdtjUvLHGMpO2OAk
JItQZDPT6qwdeQnsT+PiJFOyPwwa/j1JvxMzEOxnVZfdzswBqgTlTylnaA/A
qH2lbegR2gNQkrm33q2Q9kB473IO7VHTHoh6t4zdn4tpD4LhSOimjIW0ByF9
xsqzlVa0B6O3tU1YN+LI9mAEZ03N++MxM28pImxrczuv0L4UW0MGct6fon0Z
gpJ6dPv20b4M7p3nTz/Npj0EDelcv7OC9hCszRsK7gqgPRSDxsjnb2fTHoo8
axfZ6/G0h4E/w+Ka318ObA9D6/o3UeUPmXnhKGpbW1bfSHs4OpzrJm+spX05
nvXXcJNLaV8OsVNs10gB7RFw2SzVSTNoj4BuZsfj0TDaI2Gj+aa90p32SHCh
Bk2kOe0rwPPe+PIVj/YVOL5v9ybfIQHbo6CruNwVe4OZi0LvZi+/A+W0i/FU
s2jdiW+ZIUaV5EFmUha9L0a/mjMTq5iNYng3mNwJklEfDW5Kt+XWZdRHQzi+
ar1oDvXRmNj4crXlWOqjEZba93vzZXvWS1A3dcNpXTEzJAhx2jOwWsbMSXDb
MOHSI3tmowSqFQ9PGh/asT4G9YvMjfdKmBED6y354+z9mbkY+HVUdqSN2rI+
BmfVIr6ug5knhcVg4c7aYmZIYV2U7umxhpmTwlDW9Z1cSr0Uxc2/ee03pT4W
poPbnXc4UB+LvA/kgi9fzGJ9LLRWc9LzDzMb/2eeDIfe+Wz3yWeGDMLnLfPF
gdTLMDCscmixpV4GC0tD8fp+PuvjYGkxotK1MSMO07xT0mr1zFwcIo/zS6/V
MRvjoFzVnPhnEvVyyLqNJrbTqZfjjtxu1d5fbFgvhz5jxvtjemajHCUV2+SN
Lcy8eFTfLbrXkc+MeFhO6Cm0UFAfj1PD8+VD/tTH49nKskMXvKlPQFnDuUur
m2eyPgEe2yL1+lZmLgFpXXZVtT8yGxOQt2Slh4WemadAF6d9fVJDvQJb9CWL
FSLqFehsmjXuzkTqFXi3anNW6lVr1iuRrK4++P1NZiiRs6Zv+9FuZk6JpoAq
s0cNzEYl7h789LOCcuoTIa4WhMkM1CfCbF5u4qRB6hOhMlQJG+5Sn4iobo+U
ScPUJ0HQW3vy1n3qk1ATUJDzZpT6JBT3pbl95Uffn4QPswd8vv6Czp+MoIFw
15xcOn8y2h1EASGxdP5khJkHGSS7qU9GRnXWuk9eUJ8C/sWYzPHh7H8IUnB5
zFVf12j6nykIUfoLNKU2+BtSwCa+
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0gtUTfkeB/Cth1JJmgq9nOSRJFORR5O+SfSg9/t5zqlTp9cko2Eaxlaj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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdy38s1HEcx/GvHzVLpsaixfzo8nvcya/8fMWd8+s4p8v8iENFa3WrRa0U
/bCVRjIViepWQjfJsExMU5YfWZcflX4t1g+F6GyFoZrv2x99ts8+e+z5eVkk
yyW7NBmGCf17/7104qoVduUrrbGkSb9TVbyf3RNWrBmUz3JDXAbIOpByrwj3
tJDXwK52+JdNJdkQN3qVtbILZGMkiJJ6tNLJJvDgzLROx5LNMdAXs6EvgGyJ
Y3nCkVh7MgdZdfCxXUu2wmX1s5r22U2sbZC90WL6zDDZDrk7k8sSn5Id4PJE
OWqtJDui1PCDNL+QzEVwSda1usNkHl6vS7OPlpGdcW7cW4PDJ2+GLpNW7uNA
doFrzj2ZzIjsCvHQlnjhPIe1G8582Ftw8SvZHcP6Bh8rVWQPnL97fFHeTN6C
/uL3O3Rukz2htmn5/imX7IViP3+rl/vI3rDnC1+VbCP7oH1RIZl3JfuCE5hv
IjQj+6FLURD3XoMM1Ebnz46NblxyNrBKsPeh4wvWzFbsy7hpNtJGfSv8o6ba
eyuo++Pk9QXekQLq/sj0e/zjkpx6ALY3tk4qpNQDUH9fltnvS52PRk/T7lO2
1PloaU9VCYyoCyCYyvwc9tOS7QK4hoj0tF+yZgKhSrkzn9dJPRAH10tdohuo
C9FUkfP87FXqQnilcyMOnaYeBA9ludPQAepB2D/eYcCNoR6MygHjeT0+9WBE
FI1ohvKoh6CguajP3Yh6CHrkzlWJDPVQ1K3U52l8sWB7KOaOirzcBlkzYZjO
Me2If0Q9DCtUqhrLauoilPzOaxKUUBchfSZb3XCAejhSb0k1h+Kph8OjYWGP
diD1CLRGKXVrHalH4MGJhdxIc+pidA5ypudWs4YYvbIM/d2L5ux/MXy6rFTx
v1m3iaFVX1fWrWbNRMI0QZKcNMYakahxiEthJmj/n9siYVa2W21L/xkJnMdK
37z9RnsJCr0Xnd4t7yXL+z9pxDVF
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdzQlQlIcZxvHFIKKC3CiiuKuIyBVQRAEpDyoop9znsuwBCOVqJQYnIlkQ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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd2HtczNkbB/ApRBFpJeU2uiBaUoRIn1LCKhWxlTJdpqb73EOrnaxbLQqx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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdy3lM02ccx/FuyTaxBOggiFKLHK3QDHEcHpyfVii2Am1/9FgVIU5wWUBr
oJIwjtV5zC7ImsxRJ3J5wZQM0M1NhhTRRWFZCJ1BN91AHMwhzKmRZUBxW/Z8
/9mTPHnyyvv5BL9p5gpe5PF4ef/cf186W86ekDa8vBL/6Y+UjrSkn2KnJcw8
KFranFdc5EVoizyjHP2S7IMW15X+yXqyHyzL3rN9fIAcgMyv3THKIrIQznWV
aj5HXoHmp293TSWSQ9Ah7++JDCOHYUdeXaNzEVmCuKo7sU8mxczhmGt6fP6j
QbIUD4UDfY1fkV/D+9Lx3YebyKvgsD/Kdx8ir8aO7UXCu2by67gZn8ntNZCj
cSdnPtGSQo6BcCTrSG8oORZv2CZyA73Icbg4MB+vnAljXoPmXaaJ6THyWvjP
jbjqrpLXoU4W4lCcI69H+jHhvht2cjwc4w+qs0rICRh42KlR68mJuDh3rT81
mZyE+9dFggsh5GQseX4zKtaDnILyT7KO1f4eygxg9avtr7iYrYArd40l4zJ1
GZ56RJS1tlKXIVCcMDd4kLoc7v0ldZpC6nIYd219ZuKob4A3coyJ0dQ34EBo
QIl1KfVU3M749nHkYuqpSJgt5/vOhrCeBv8LU16Cn5mtaRjPj5Ys6aWuwOyI
ts9+kroCU76mghkb9XT8MHzVKSumno6oBZ+VC3rqGyEaNweFJ1PfCJ1Qu7B/
OXUlZNIPHnEe1JV4a/L75VueBLOuguid4EvfuJitKmicamf059Q3IaCwqr3u
BPVNuK82PvuwlnoGunKranJKqWegU1rjJ8ilnonBuM6hJlDPhK95+3V+BPUs
tGzzNHULqGdhL7dbdW9mBetqDE30FdTfYraqYW/a2lXdQ12Doe75z2ytzNCg
ZrR9Z3sN/ddAHpPiubOCuVcDd1JKaZ6K9lrctU/w4qNor8W1+fN7isNpr4Vb
lSQZ86W9FrYy81S+J+05GMSr/qp+gfYcqhobGhb3BLE9h+/KBJW/Hmfu5RDz
461K6R5mXjZ0YsfzSxpmZOOXaVn+F360z0bBwTOFxb+J2D4bFZbbw4puZp4O
axcGAs7WM0OHwkN9Bl0Ls1WHYW9Jx9hp2usQeM5ke+kw7fVI7TrqL7TSXo+2
sArHsn201+NT76Oi4+/S/n//eQZArH/gY6O9Aaf6T5byLbQ3QGLpOLK0nPYG
8COCbrjNtDdi83jjer2D9kZsuzf65+Za2htRJLdf9moW4W8wYYgy
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0HlQ0wcaxvGMopyKcmhZqUEEVGQB8YAglKfchwcQbgSSAK2VFWvbiNJd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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1zH8s1HEcx/GLdGrkR27TdctV1xHXTcmhjns55845zv1YzGgV1fyhZIxN
NYyp5a5rLbR+0NgNlxKVlNXyY/WH6MdoUk35VfRDkkq/tb7v7/bZd489P6/P
qpQMw247FoulnT///vQl2ap9Kxd5478+ys7yih06JoWMWUipH/XY/pjsCHHA
MXdTG9kV9e+fTE9YyR6w6/0wvquU7IkLo5NhFzPJPMQ0L041xZP5yOvPjazb
TF6N4U45t5ZPFiAsRNziwCYLwU4Lcb43sZaxDzwLkwZf9ZB9saGDc3quiSyC
tLTrm9NZshhWUYVIUET2R7Mq32l3GnkD3rWGWZYZyRux4ssMxgPJAbj0cn2l
gUfeBEXxcU2oPTkQPp+7m2feChhL4Jlz1Dm6nxyEy8uz+ta1kYMR3nmtdaSa
HIIM74O/9GbyZljVeawfueQtCClRHupLJkuxaLLNzFGRQzFVlXgqXUwOg23W
kt7rQZbhzI/pq+1/1jAGcg+L41rGGRcAgS1tgbfuUw9HPM+/MP8G9XBIDwx1
PqygLkf3XbWz3UHqcnhazPLa7dQj5t+rlPrJqEfgqULj6uZNXQFj4yclx426
Al484aDt12qmR2LkxVbH/FHGBZHQpra3mgaoK+E/cUJv7aCuhONGaU91HXUV
fG+XRC6wUFfheO/Nlw7Z1KPweyphTJhMfd7vnfYa46irUahdyikPpq6GVrdL
qfWiHo1yif3ASnfq0WCJpGbF7Cqma8Bhs8t6njEu0MDyVbDwXDf1GHSNycoi
6qjHYP/CRvbiU9RjISjPcL5eQj0WopmoJUPZ1LWQsTJzRhKpa+Ga1lAzGUU9
Dh7FT66YgqjHoUF1YIfGl7oObwRlZdVujKHDZe4OeZY93dehqUTix53j//cd
HSRHfGwfpxiz9CgVPhoqGmMMPVxsE/HcYcYFenzfmcA2P6e9Hl59+wzFj2lv
QNVJF53pAe0NaMp34b7uor0Bwj6rcaCB9gZouqUS9xraG6Guu7Tt0XnaG7GH
P/ezsYqPv19ANKk=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdy39Q03Ucx/GvKT9UhDRBNJQxGeCGiDCpprCXY+AYCPsB2wAJpTCS44ea
Xp25hsqpYHYgd2qdKC5TEZNQxBAG2sEiJRV/ZOYUleD0OH5IKsyQ6vy8/+lz
97nPPe71efpk5Gky3+A4Lvff+99LJ7XysLDc0R+vNSCdu69k2ed9fswcyu3B
SvFNsjOetrwan9tAfhMPYht7bpjJ01FuOb5jZRHZE1fLJPbufLIX5l7J6lqs
J/MwNcyp1i2czMfUI22KlzyyL8o/Gm5XOZD9wF+pNzzuFTAH4JM2nWDWTbIQ
q2/uH/qtgRyIOn6NcGYFOQjz8qXTGorIweBtrL+evZa8EEf9j8rkenII8kRq
0zUZORTxAltVmYgsxvOj7feUb5EX4aGpO6LB7sscBgFna82/T34Hmac3jayz
kt+F7Ht3vxWV5PcwcVNpR90esgQ5RdOczhjJizH7/MW1aRnkJbg/brTCNY4c
jmfmKMe/xeQIfDlrpsf5OWQpjnuGl9Q6koGmr79BUe/c1zYBcYHzLS8uMXNL
MWckMKL+DO1L4ay4Kws9QLsMlpEPuzWf0S6DWNLpfjud9khoe65qPJW0R6L4
1KT82CDa5Tg2+9zkMhfa5TCey8oSDvHZHoULw9MXHLMxm6IQuiZ40mEr7dFo
7NS/6j5FezR2OuRcFu+lfRni3fZJZVtpXwbej5lrdq2mXYHzjRnbJTG0K9Cq
0H7l5097DEaFJdGeU2iPgXxrDX/ckA/blYjSfVFnvMFsUsL2O+fNNdEeC5Vr
wPE/TtIeC871UMrmg7THwXxVutdrJ+1xWHG3s/fZOtqX4052VPX6dNqXI6ez
akLjYtrjEVL88IkxkPZ4tPB+OWSbTHsCHBIWdozZeWxPgPXTQxvlPcycCt+t
Gv9tdiszVPC7cUR7u4r+q5CeVz34Vylzswo/u6x3Nm+mXg2fNGG7Yzb1amRH
nhi2qahXQ7JlZFgmpV6NpheBpS086jW4vK8pLn/Am/UahG7vn7HlErNJgzqR
692aNuZmDcJntG/aXcjMaeGmuGdukVGvhWDC/jHR29RrEb1q2KLsn8N6LSo8
fij9oJOZS8SM0Y4p8mvMSMTzoIn7iyqYTYn46XrIvLLt1Cci0GNb4hox9Uko
rLxiuehNfRL6/ow96zs4m/VJkD3Ya0k9wNychIxFT/R2IzOnw68vM+483s0M
HZaYP7YObqBeh8Ed3bkpOup18HfJGjyZRr0eL+vGCsalU6+Hi2DP6SMJ1Osx
Un5QnmqgXo+C0banoyrqDShxni96Eky9Ac4DxYJdPtQbsFazobDLiXoDGq2S
voBHXqxPxpi9wPdyPzOSYQgb6Hclm5LhuCBJnNXG3JyMs5O1C+5bqU9Bf5dT
cO0F6v9nUwoEufWiWyeoT8H7QzFG9WHqU5HnPsHzViP1qeDbzI+qn3nhH1qq
yjc=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1HtYzPkeB/ChzmKzKdJFLlOrFJXIrVDvku66X6aaaqammplcUjqRtX5Y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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0Xs4FXYcx/EznnQkrahFuRySFolMHCIf90sknOPecQ5aF0vR/YIjptvK
VI8W67KclqxSJqTMKamIUYlDjGqZogtRaTVrz37fP+R5zuN5PR/v53d+PwZR
qwKWKHE4nJyPn/9+0094/nGTIyoz8L9eOj7YGlSn+cyYmYMtKjXvy+6SuVDT
68r0KyePR1I7937ZMfJEWEZot59NJ2uBW1lz4N1Ksg74ue4Bl4RkHjzz9oyu
nEc2hElMQsobA7IRPIcy9nG5ZGOoS/cLVj6fzvwlegYbR1nfJZsg6+6pP48W
k2ch507jQpej5NnIKPf8XbCDbIGttbZtu1aR54AXvKR8qYBsCd5+q7GGduSv
0KlQXu+gR7aCzFplp6UyeS4c2jolGk+NmK3BGdh6uKWJbINzjg4ZKCXzMb79
iypVGdkWR/y1O1x2ku3wgvuYrxlPnoc1ybaN1kFkeyTMMxkq5ZMdEPy+WxFq
QJ6P1Eg/rywu2RHTGzymVv81jRlISjF0u9TALAVGaRQ3WBXT7oTm7sHd5j/Q
7oRce+mPoxNpd0ZZSp2SIJp2Z8T0p8ab+tLuAuvAljOONrS7QDHWJddDl3ZX
nHB7lTBamXZXNId9o7u505Dtbii/7Oe9oZJZ6oaQmjfF8Sdod4dxN7eleD/t
7vDuvNUzGEe7B+y7fW6fC6TdA48uf5Ca2tDuiesmji2z9Gj3RO/l165fq9Du
hc9Nxcucnhiw3Qtqg3pmefXMHG+cSnRSmJbR7o3UuGUa+w7SvgDrLbLTZJtp
X4ASfqrs0FLafWBmXl3f7UW7Dxr4TyVHZ9Lui57PWvqVPqfdF4Nqxw2H3/LY
vhDRhYo5wk5m6UJMuqqsL6qj3Q8+WRW1e8/S7odN6tkFvZm0L4JMFuorWMGM
RXiceyda05v+fhFGtS87nzOXWb4I2DhgN1OLen9ECp22tXOo94e5+rW0cSX6
rPfHzwYKf+uDzHJ/uNgvd3ssYuYEoOlRLP/0TGYEoHWdvlW2HvUBeOuYJezo
12N9AHa8LtyVV8XMCYTNPzVa+YeZEYjsMflNU1OYpYGIFzmlr7WnPhBmDrMF
FV26rBfgD1U1S7MiZgjg3aRz69s8ZqkA+TPiC55vZ5YLIMlcZz0tjnohrjbH
KLW7Uy9EmnoIb+srHdYLYdF3ekV6PbNciImtfZs31jJzgvCwvqpCtoIZQTDg
9Vp9N4f6IHwwzdDP/3sq64NQmZhnerKWmROMh0MyZf9DzAjGpNDbm+bYMUuD
caPoZvUmXeqDkWw23OvFpT4ER17MOjVxcArrQ1BeUH2i7idmaQhSxO4lB+OY
5SEw3NAta7Zk5oSiwFSP7/pSm/Wh0K9Kv9fcxSwNxbkhjb2Gz5jloajf+3qP
82FmThi8pjTevu5KfRhWi5KuGPlQHwY/HXGplS71YeA9+fWCokOL9eHQiBW0
qjxnRjgUE/q1l69llobjdGPIpvshzPJwaK5ecCUukfoIWA7HaFccoz4Cqs43
ny6MpT4C6EgKn+BOfQTcc1T7TppSvxj3p604fsOY+sW4oN3VMdAxmfWL8eGa
/u6iVmb5YvQUHe6wyGfmiKBZaWA2+SgzRHhbohasc5N6EZaPeytYeZJ6EWw9
GlFYQH0kHiuVrN/3kPpInPylUfGml/rIkd9H/ok5YohMBgdi9dn354lRIyro
/82G7iNG5BWp9hhNZrEYwSoDbUFz6X3E6BzSE26zYD4mhu3F5I5Js+m9xLi+
NnPjKk/mTvEn7ycZ+b48ycj/FyRQk/MczbfQ+RJse1SRkOJH50tw/uyqA7PD
6XwJUtYUmdd60/kSpA23Baio0vkSvLCw8y0coPtHIfPRmi3Ob5h5USPfH1FY
925GQXUNszgKa1tzb05Q0Pt+7I8rf/98Pp0fBYPqvu38mXR+FJrvJdbssqfz
o1DXl55klED3j0bnu1LOmWS6fzROFFbl7rhL94/GcNbF6IcPtPAvlamTbA==

         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd03lQlAUYx/E3lRASNBIQATkM1yMxBUIQ5Aeicbnsct/sgaFJSsaqaeoL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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0QlQVPcdB/Cn4CIhIoIicsgCnkBARBcUkS+nXMqxLMdy7bK7QEJNmIo2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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1yw0s1HEcx/FD81Bq1iSVOOTIiCsPJ10+R3k+7v6nmlOtZ2Q6PdHk4bSx
ikVarCfdaGqnKGLFPLTSA63rKJGQSURdVnpcUq3/97f99ttr79/HdpuC2anP
4XDEf++/l06MutS5xNAR/zXhd7v7yoSpjseag9hurV3hU7IxfpZZ2EfXk81w
5JJx/3EV2Rx1gpEGxTGyJYrQrKlSkK3Qn+9vWSQjc/FlbF7VNQHZDhZx6ooi
LnkJAvkfHWcbknkolG5OSh53YO2EoV/V9Uu1ZGco+OZTPXVkF+QxFkGT58nL
8LJsVu/RLLI7uOUf5jXvJvNxt3am6IOMvBx1r0Yr9gjJK2Bkms3ptSV74E1o
eNOwEdkT73puTGe/X8LaC2+flOfLO8jeqA32XWfZSBbAvFoprykj+6CFKfeJ
yCWvRP2jyH2pSWRfuE7EmtVEkVch2aSqLsaXLITm+M0szWLyanS25swdMSD7
4fSjj6lGo/asAUPbSvepNtZKYLNjD29/FXUR4kLOai+epC4C/0X3HOeD1P2R
dsGz/eoG6v5Qd5llNgmpB6DYKeNHoh31AFjx9BbdM6G+Bq7xj9Gns2P7Gmz6
+b1N18uasxbDHVsuC5qpr4X/mS7tw1LqgTi43aFVUUA9EDsEnY/dUqgHweah
yQuP9dSDEH+oT3jdl3owyvVMi+XW1IPxbOrQ729TtmwPgZyzQKceYa0MweE7
KeHJndRDESJudfNopB6KeNXngskS6mGISrPZuyuDehgyO1RMVwL1cKwcMa5M
lFIPx1Yj2dVcEXUxpo+63uIvpy7GjOI8Jwdz6hHo1gVs36JHPQLRepYRnAEu
2yNxqqH2m/w5a2UkBtsbJ1MeUJfg2ViQeKKBNSTw6kg741pD/yUY8h4oMDjH
ukWCfGuXX7JjtJeiaePrnPw02ksRl4v7+jtoL0W6/ISwNoz2UiRqHnQGC2nP
wFl1d/42N9ozUKVbvRrk056B17iN5JM77RlUfB1YOG1NexkOGMxKSFzExR/0
aTz5
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdzX1MFHQcx/ETUA5Mx6jF0Qj1BDkhRT2VC+T48HDeA8fDPULeyoNJKWge
tIilnEcMEs9MnuISxoYNS6YMzlwq2jw4PerMvCtRNNbCnoZIFywBmVCt3/ef
fttvv7323me/VYX71UV+HA7H8M/996Vj6DoZ274kBv/JlxI/VKq0jK9h5iCm
2jHd5SFzMS8IiOu5SA7B2BGTq7mD/Bxci4oCdtWReQhy87sTysgRaBg8/VZ3
PnklWgar4ralkPmo9xiDyleToyDIbN55M5C8BvyxbF/+RDSzAANfdaXYbpNj
Yb/+noV3kfwS7A9vzJ2zkdeDK+OV7Koib8CXnnVrXUXkjQjZyhkRKcmbUHzd
/EaDkCzETKJJ+2c4eTOyS+rjRHNRzFuwwG2cKhklb8XD+NqvX3CTEzBic7vS
7WQRKu3DlR+1kF9G4hCvtMNMToRgxTLnvt3kJFxpsI83KsnbUJYUO3tBRE7G
QFKhePGLZDHu538SlbyYnAKT16GQTq5mBh5wr1ndd5gtgOfZHt+BS9RTEeln
WH+zjXoqOs61/cx/n3oazk6brbfepJ6GmntBBc4c6umILwl+ECqino4WgXl2
H596BjolU2WB/tQzMNIbET4zyWddAr3e3z0xxGyRwHnN3hbaR307nDM7h5o6
qW+H4+CPi8I+oC6FcPjWYFgpdSmMSeJXlAXUZSi+YywPkVOXge/9MJYvoi7H
7KvamifR1OWQNR/wXV5KXYH9v7S31v61inUF/niks5wZZeZk4pvwI/1eN/VM
fNx57PZ8L3UljGutdyNs1JU4lPndUXct9SwIaz4Nrt5LPQsB51sXDr1GPRuf
e60X5BnUszFdtydPwqeeA8eyZF7MUuo56M0Xu23jK1nPRfke4WGjhxm5kC2R
GlROZksuTlf1hb19lvlqLkJOvLv8VDXtVdjd5FNw9tJehd9qTS5VAe1VkPc9
Y7yrp70Kr68bNYultFej+J37Gr8NtFcjWl6ROvw87dUYON7+2ca5FWyvRlNe
RGXvBDNHg01XnvjDzgwNngaeSbCfYrZosFnhOBbQSHsNkFX3vSGN9losTD6q
tYbSXosbeXX1h7m012K89WmFZi6S7bXYcnnw8fzvzBwdzh/8tls1xQwdfvii
f8fYPWaLDur+4ELlT7TXYcdVr0HiT//r//e/Hsvj2y+ZHtNej4rjPTHyXyPx
N9CPehc=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1y3lM02ccx/FfVYpoOJIRbdQAFgeCctWiFXt8gKpAWyjtz4PLg2N4IWgk
6qqskolmECJjiTCugop4NBgRFa/g8UeNVwEniEbFTcimeKZCI1FnfL5P8uTJ
K+/nMzMz35AzjuO45f/fby+dtONNwfXCQHzXW9Wi+9pY48sAZg4DnNGtz06e
iFORzSl1Z8lecDwd4gS1ZG9ca1IJu4rJIqSa1xzwXUeegduOslurtWQ/8GPu
AzcjyGLcynJ88pxOnoWG3Kl8j4AcgJ+CDs++8s+PzLORd8IiFtwhB+PL6v47
pW3kuZhaPdjdUEMOhV29Y7SjmByOOi5kX0suOQKXKuyWKUayBN6VvM4kI89D
4dYd4119yFIIM4c8siaQI9FULsr2Hp7FPB9V5W88FX3kBTg27/HImitkGeYH
/3Io/DB5Id7Vp8cqy8hRqHHlUtu3kBch7TdL7iOeLEdmx4GTajlZgbGOgJxS
P7ISD1x63T+7klW4fyMypu2tPzOQsif7pqSH2Qw8d9NdNp2nHo3QRHtgq4V6
NPJ7/3SN3kc9Bul9g21RW6nHYCSdl75OoR6Lpv4qaYGCeiz6D0a4nAqirsav
gjlXhz2oqyF+I2o2jopZXwxJhuGz8BGzeTE2R3nc016jvgRDVWma1CPUl+D3
tTnr/62gvhTOsVeOjF3Ul6J1+OwFv/XU43Da61BjbTz1OJgK1ObSIOrxeNVX
8q7LjXo8BiM/ZNk/zmQ9ATZV3H+2fmZzAkIEPtOVNuoaiM5vqp5kpa7B1ZFp
O49WUddCeeZFi2g3dS2GTm+UeqVS1+GJIrPooZy6DnVyob3Hn3oiaqTF5aVC
6olwHlGrSpx+rCchTynplj1jNieh9eS2KRsuUdcje8awNdzCDD28y2s5eTX9
16O37OinOhNzpx5/FUl8wzJonwyd5ro+cCHtk9GwQdERFkL7ZIR07U3f6UL7
ZJRVNiZYBn3Z3oAwR+8PzoPMMMC6xzG5ZDuz2YDH7baiLBlzpwHtjQVPzk2i
vRGFF/Vy2agP2xvxJS+jsKWd2WxE84N88d9/MHcaEfre33PVSmaOh2nMmrd5
E+15KLw8V5yLpz0Pm3WOuzOR9jwGXCTbujW0X4Zgy/7mn0Npvwzau6uED1f4
4CvfDFwI
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1yw9M1GUcx/EfUChYIngkHhBy0GEEN0DuwpPgAx5w8ue4/9RO2qJgQDXU
yvL4dxLa6hJQqkFiFEoDEXdyDiEkIFsDPZZAk2JGkSDz5CayIcP4U63n+2zP
nr32fj6BOUXqXGeO47L/vf+9dAznm0K/cg3B/5qP9wqxytocQmYOlsKFYd5N
8kZMCEX9BZfJW7D4xyzn1EDmYewts/zPCrIP+A0zB9UFZD9M9wp0D1TkHbhv
uHa2bjdZgDvziTV6X3IwViYvPfOFC1mI6Ijyj4bmnmPeiRa79sr8KDkUxcMt
TsYuchiyk3m/GBvJIqTqN/x03ESOwEjnWr1XATkSkjb3shYFOQq9sb/K3HaR
d2H457LaMT45GrLFExdW14KZxfg7V1g3MEuWoHLgUn6TjfwipCWiTlkXOQaO
oDhLYz15N+xfGteqSslSuDj3XF7II+/BSIa15Ydkciw0UuMx1xDyS3AMpW6J
5pHjoLjydt74ShBzPB6Fanzcp8iAm9Pdq/GDzCag9OsPb0raqSfggqVeEFBL
PQGjzwd9H2Skngjeoauh116lngibR9VRgZz6Xgzsj6kJCaO+F3f1D5f6PKnL
ULZtLOHIuoB1GRxRs6fW55i5JHxzbtC7+hb1JEwWZ2cOWakno73I01p9mnoy
csITDnuUUk9B+cXqFEUu9RTUvtAseS2LuhxTzkfyRpOoy2HL9BoQC6jvw3jd
aschN+r70HF0JbD7cSDrqQifybHen2A2paKvdUNV+3fU02DZ3tPq20g9Da3e
k/yaMurpWL73/mP3g9TTccbQFtVkoJ6BhezC30oU1DMwPq+e8RdRV+BhfqXx
ZW/qCnTvDNZtX93BeibOH44cnJpiNmVixrNXVfQjdSXMVYv7DzQzQwn+nOj0
ex/TfyXShWGjm95h7ldCl+R142QW7VWQxk7+bhfTXoWtq/cmG/i0V6HCjNsx
W2mvwoTf09v+cqe9GtIb9UuvLwWwvRo+EnHp9TFmkxrYPDt9oJi5X42NluWK
T+TMnAbrtgBHYzTtNehvELsGe9NegyeXPo+MmH+W7TWoGDSIXrEzc1qE76l+
YrmLGVqcuejSucnMbNLiXctZ6RuFtNei+9ydN81K2utw3TfWQyukvQ7J5U/Z
3DbTXoe+knzd2gN/ttehh+f7bdxtZk6PT6ct/A96mKGHzEXOPaplNukBO27p
mmivx2dulSPNJ2ifhbSO42Y/sz/+AUA5gGA=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxVy39Q03Ucx/HlqQmCCk7bDQh/IYJeCAgoc/DC8dux32zAIBWoKYKmoRTp
/AYIghnmYSro0HHBqXeQPyIhrYUYyo+FQM4fgaQBWRIeiGllVtfn/Uefu899
7nGvz3Nu6mbVGxN4PN7Wf+6/Lx39KbO3abIn/tOjUIe+z92PPFzIzANXucsm
7CJPwZpPWiXrL5BnIK0jO7z4OJmP6c+v5LQVkgUYjt9+zLyB7IpLltUTbsjI
c2Bf5TwmWUaeh4bOJTUVQvICtMSJ210nkhfCXDEkdXrowbwI7dtqBzXXyd4I
blCdTjtPXgLVj/L81HLya3i26q7vXCN5Kcak/TargeyLteNTE/JlZD9kfGM0
HPAn++PwgYImiYC8DPcH3MXbeOQAbF50Z0nZ0ALmQEyfYZjgaCUHoSgvSPGk
jrwc5aIRcXEZeQUmTnW80WskB+OVyJzytnSyCHHjRZFrZeSVsK80CgSBZDG4
WS299m7kEHjbqss8JpFDce3ScMuF4fnMwOCHd7ttXcwccHaBwSe9gfYwTHHt
yCoz0R6GXWsPGd4uoH0Vrk+/1FCYTvsqfHDKxVQto12CM0n5Dl+voF2CrXcK
b3TNoz0cNjf/iKiXaQ+H8EB0zOyxeWyPwIi+anbe98xcBPam7G91aqY9El88
f2HT1NIeiVlhT5vyK2iPQtbVd4425tIehXsJMxuLDLRHQ7s8179SRns0co6W
3Lbzoz0G6wSpxot82mPwYFnP6N3RuWyPxbW//EIqBpm5WGTU7Djk2Eb7akw6
Zz7tdJb21bB9uSHkt6O0S9GTHbTJo4B2KXYcExbUZNAehy2LFPNvqWiPgyjf
t+NjMe0yqAbkwj432mUQPy967Dw+h+1y3PJ12BR7k5mTY6GH3ZjxK9oVEGR3
1v9qYoYC/SVBjgX59F+BP7sPfueQwWxRoId71KTUU6+E99MfNvtKqFdCdJP/
sHkx9UqsMWu80qZSr8SVzpL63ZfdWa+C54nhsSnFzFDhsnxIvz2AmVNhmo+p
8a0nr7JehQAHvq+ylZmnRtKpJlPF+8xQY7ngSEqYkJlTIzV36cneUTfWq7Fv
5sCx81eZeRq07RnqHqphhgaoClhxZiczp0HprtIBqR/1Gkjf2+cz6kR9PNq9
lPzB266sj8fGnLqdJ/uYuXiUz/basPsEsyUe4p3SXnkxM08LYY360Ph66rV4
6b5xcGM09VrEPX3mp86kXov4JuvhGBH1Osj/KH838ZEL63WoypyxbvJHzJwO
Kv5Fr5Y6ZosO4s+sjtXVzLwEtGU15zXXUp+A4y9Kj5ScoD4Btf1xdfsLqU9A
vWhrui2U+kRobZbJbnzqE5Hyc+a9EWfqE6FLjb26xp/6RPzOWY8H66hPwpaD
deZf1NQnYWRc9vjJHOqToM99M+AnT+qT4Pz6tFmtgdTr8akpU5u8mHo9NHua
2rNXUq///3+LHi2Sc4G5dtQn49sH90bqJ1KfjB0Wo4dV4IK/AbyA2Oc=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxV0H801Xccx/Fvq4nIKk4JufcWJtJiUVw/XnKRm657L5frci8yjYnq7Ih+
4Cu31q/TStNYh8Sy9IOk/NjW3Mk5+rGy0NrOTpFxEkm/VFq1tbPP+4++53zP
9zzO6/v8/PERrVqrTH6P47iCt+9/X3pij1c4lxl9iP/10H+T4rIm+L4jM4cp
+TnBMZ1kY3yV5XHTv4E8DR2+ZseCS8mWkGXlhOVvI1vhy0/eeHSnkW2xb1Bs
l6EkCzG0r8dlyJM8Fy3o/dNYSLbHjIPHLdqNyI7YkykPOjLiwOyERWZ6I9NO
sjNsxv/ONjSRF6Ck7vUu1wryQjSb10tu6smLMFXT17Ehg+yGrXXLU35Vkd2h
lCebHfMhf4wDVrHyawLyYkCUV9jwPtkDuQOOJ1sH7Zk9ERzSWCz9hbwEza5/
NaTXk5eip/PpTI+vyV6QTbl3sS+H7I17xt6ub5LIYtgWPq3mQsk+MHW0Uue7
k32R3D2gdxCQ/aCV3o9QTCL7Yxcnap0xMI8ZWNfQGJV+hZkH3I3DLVvP0B4A
sUlDSnYx7QEoEoy63tlC+zI4P5y32TuV9mUozLNYXCajPRCny29Mr1tKeyAK
Devj3Wxpl6Bu4xanrRztEoy3fFP96fBctgchI03QN+kGMx+EWU3Pk/0aaQ/G
hbznJYKDtAfDxGV+zW097SHI3qvfKEqjPQTmm9X7x8NpXw73+RmHcrxoX45n
s7wfP7ajPRStIrfr5hztofDzN+24dVfEdilS2ySi3i5mXoo3w2HCK020r4A8
dmJqzLe0r0D3mbnTLhXRHgbfE3lL3TfQHoaSH6ZXZmppX4nvCxJrJ0poX4lB
/z9GkpxplyEp8Wy+vQXtMqzK9JKaPRGyPRzDY5nNn/Uz8+HgB4yV2vO0y8FP
3SmpqWKGHJC8aDmxg/6Xw+XuVYdXycwGOUx0bpccgqhXwHo0o/yAiHoFTr+c
0+HKUa+AladHzuUuAesVmF05tlpTzMwp0f7KJsv9c2YoEeiTGjSgY+aVSHGu
mCcF9UqMNrWtyBRQH4Gh3ln95yZSH4FaaPdu6rFjfQT2KY5a5HYzGyJg/OSB
yxd7mLlI9I5lF/eEMSMS57xEJ20mUB8JkZOZxaQXc1j/dg/xO1zVzMypYMRH
Dv9exAwVTEzP7EkLYOZVCDpV7FzhQ70KhRdvu5UaUx+FNpkd/9t9W9ZHIUhY
21Z5kZmPgu10hX1RMrMhCt6h19t5ITMXDYeFR9f9OGjD+mjsVJ+PK73GzEdj
yvYLVdYHmA3RsP2ppH+7hplTY8fV9Jnr7alX43TZmqg4F+rVyLkqDt4wk3o1
ykYXVFuOWbM+BsmtjfLDDcyIwaMusaGvhJmPQZL8VNOz48yGGCwRq352OUy9
BmKzf4a2lFOvQWnhoXL9Duo1SLNdu7hYTL0GcYkJNb1h1MciXVnSKLSiPhYV
CyIslROoj8WTO9uORN2YzfpYeL5Mbzlfy8zF4UKYZbyqghlxCJi8+9a0emY+
DuNdaydLsqiPg271kXwjnnrtu4YWZQHXd8mk1GtROJLilCumXouRjkdrfBdR
r0OV+l7KEn/qdXhcGWMQuFOve/d8gw6h5oFNyv3Ux2Noa4GjRQ318dD7Jbp+
UE19PCbf2l1X/4D6ePQXtRUMfkT3l4B2+bHOXD9mYQK+U90865FO95mAsy9e
P5pTaY1/AVgFEQg=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxVzn9Q03Ucx/EpghhkWEDigCbo0CUB48dABF7iBOTndz/YMPrh4FAZ4eZF
GRfFBLqYR/zIU2aF/BTC/BFxZOeP3aJBhV1Rpnjxw6l0KmHhBJmep9X1ef/R
9+5z33vc8/O6+6zM08kLFvJ4vPx/zr9/+nKPtokOuwThP80kfFOWedd3WsjM
g/PXrneGfia7Qvv8K4NHT5E9MKG3LRA0kT0x0FE1OVZBXo64Bc7vvKwl++LF
+KvW01lkAZa0xoqPR5EDsNplZNbEJ6+C7+WRN193JgtxzHxVFfHHauY1CDZx
7fYLZBHmPni/eucZ8jr0vfXoF20r+QV836ET/WYkh8JR2i24uZschhsxdz/z
zCWL0XDwO71TIjkc/cby9qIgcgQC+6yZPR7kSHTfmWlJsq9ijkLs3H7Rrl/J
EnRe/9y84ww5Gl9Oawbq28kxeDJ6aY+rkbwes/0+3roicix8xelDkgzyBkyX
NC05GEGOA9fbrRPyyfGoKt/whOpRIHMCzoeNLXObJAPNJyqiG/qZDUDiUN66
pb3UN+KAyHSys4n6Rszpr934di/1RPBDu8xbtdQTse/TFS2nOOqb0DplLKyL
or4JTj8Up5xdTl0K82PxzZRF1KUoO1wYH/N7AOubURvp/lLHJWbDZtwSvhZQ
1U89CSb7hUL/XupJGDtgyrW1UU+GOuDP05GV1JNxZVzsNVJMPQWCXdwzD5TU
U2C/XLL2vIT6FgQUJ5TlBVHfgrj7wa96u1BPxQo3x23LXytZT0XatS8Gdo8w
89Iw5Sh9HDZIPQ377Vbr6BHq6Tgmv+h9r4F6OoZ33LdKDdQz4GUPmR3XUM/A
zpnyLCOoZ+KQY3JZWyD1TIxOPDwx70Y9C04e90Kb5wWsZ2GR9MPgwTFmHoeW
gWcLvazM4OBeWXkyrIPuczhypd/uW89s4dC4eFoR9TbtZagpcfloIp/2MiRv
8ywxp9NeBu2eUcXCUNrLoNtabbbwaS/Hu3rxmlo32svBFbjXO408x/ZyDLk3
9BUdZ7bIkdEklNhKmXkKjDr0jecEzFDgVkhN3e1Jf7ZXwFZp267pYbYo0P2U
yf+TcmaeEnW5Hxvr3mCGEmWDw9fDlbRXoimhdJ8tnPZKSCU/mXWutM9G60Uf
idOsH9tn41zJRPrTPzIbstHy8IFGU8NsyUaIprkgbg8zT4X32v0NXB7tVfiq
81JjjpL2KtTKbNNdItqr4DhbMeURSXs15vPX1wcKaK8GTz2cOreW9mrszW/v
sMfSXo3tfnx5l4b2ORjbpp8b19I+5//vM+TAh89VRxj98DePh5xi
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0H9QzHkcx/HvuWOi4SokqfSDuI5dW6gr9Or39mtr21/V1u4ouXMd6lBq
qU1OM+VwuEyOOh0VI10ruouywnGjKJsuNdxe6vzYsOguP+44N/d5/3F25js7
j3l+X/P5fr8uKavj0kZxHJf/5vr3n37KI5Ue5WNm4T+Z/SWCdVn3h9yZOZwZ
OJhyw0C2QGuAwrj4R7IVfAX8/KYD5Elo9ek+PraIbIcLQoGT9jOyA55/x2lt
48jOyL2eHVLjS3aFuVCzIsaFPAMrRgTj+y3I7lhubVow5eFM5tkoC9968loX
2QOHNR6B7U3kOVi4aJImZh+Zh6Tqkj0T88nzsGaL953iVLIAW0rsG4eFZE9s
vWOu7OGRveB24ryo3oo8H14ZSpP5jxnMC2Bjm3T3tz7yQqjm9U0xtpC98XsX
38CvI/vgmPSdgqxS8kd4oH78dd1Gsi94au+5p1eQ/RC13KMlVEReBP3s/b1y
HnkxYl9vKNljQ16C4IPFFYPP3Jj9cSTYV3VsgAwUbUha9qyNWQt0FN7afqiB
egCW+eh23y6nHgCLYN97EwqpB0IwUly+8xPqgbhwXHbXJZx6EErqxmVE8qgH
4ctVW/7WjKEejNVXGmc6m1xZD4bSLkHX1snMhSA/7NGmV43UQyA8Ye08VEk9
FKKaH/ozi6mHYqVzxY1fP6UehtpLN81XoqmHQfNVdvY+T+pCBJ42HODsqAvh
5WysDRpFPRyjddMv6m66sB4Ow/CplL4WZi4CSzykay9XUI+A26lxipJi6pGw
iCjiO62mHonOobCf4mTUo7C0NWSCyo96FFxvPOr09KAejeZzw9frx1OPxu4z
/tU5T51ZFyEiSzywq4NZK8Lnl2Jq0hqpx8BubcfJh+XUY9B0MifVooR6LLI6
NqaNymZGLPb94u3Yk0b3x0IfoUmZLGXWx+K1JuvwWR7txbhfbdCKptJejDbt
i/q8W9PZXoxTFYnvXa5l1osRvd/d25jDzMUh/qHnSDOPGW/s5tDsb3Ji+ziY
rvJTHG8z6+Ng23ok42o1MydBetGQV+1SZkiQvL22pncO7SWY/MXg9Wmtjmwv
gU2ypYK/iZmTYqylbmt6ADOkuFYiKv5gFrNWioHLpuHOFw5sL4VEYimt7GHm
ZOgyvX9x6h5myFCfOWg6msCslaHN2NDnP4H2Mnx/sUGofTCN7eVYGWo9seFn
ZsjR//zgu+IyZq0cTafNt+fmM+vluGCTvtkykvYKZD8JiJL40V6Bbou81BgH
2itQ8LK56v5ze7ZXoOren5tj+pi5eOhyD+1fvIsZ8XgUVmCUdDNr4/HY4Kfv
L6N9PDJ7/7IKU9M+Aeuap+fW+dA+AXUfOvkEm6eyfQJ6X7WbBq8w6xNwfGce
b8c3zFwimnWRTsJ2ZiRCEFg189C3tE9E2d7cBcPltE9EwbbSvo+P0l4J25v+
TWtLaa+EavmBgjFa2isxNjPaavAs7ZVIr1+fkfqU9kk4djVH7OtNz58E9Sob
35E59P5vdX0S7OzrZxUaaZ+MFnn3gPtLOj8ZXNeqzPS7dH4yzvdE7A0apPOT
//+9OBWc1gS7dj2mveqt76fCSKpP+w4T7VWQLepdNqOXzleDL5/v9mSY9mqc
W1+aV2FLz69GlePobQa5Pf4BcWIcfg==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlHlQVFcWxp8ouICKKAwalAYRN0JU3MCFTwURRPZ987E2dEN3ixoXQnjJ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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1HlQ02ceBvDfugq4ROQWBTUiCiJFgS5yCQ+nKCAQroQzB8TuSqsCgiMK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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0ntUlHUeBvDXcI0IwTIGCMRhBBEURREVgvUhbsaAMjAMl+EyM8zgaisC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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0glQU3ceB/AoilqrFYR4oUQQQUEWQUBB5UtEBeQI4SYcL4Fw1LUIqK0H
+mjV9ajtIog7QiviUFA8EErR2pZYSVtBW8uKznhSQQWKLboUC1ba3cnvtzMk
M5nMZ77/7/u+9yazNZlK7UiJRFL73+//fvmjOlk2/2NTexjU6/ONmXeNy89z
yRK0BynHWrawx2L7268UC+rZk1DypsQvq5htgYNwyQx5jz0VWV/cOSZNZ1th
ofxi3YZgtgxZLoUnHriybfDO4d4vV85iz8EbXcu/Sx/Fnou35lV/suuJHdkB
Af1WW7ZfZc/HyScbnrSeYzvh0aKohqbDbGeoFLkxXdvZLtCNbN5clcZeiJQg
8ehtBdsVLy2dL+e7s91we7V3bcd09iIkNDRMHByaQ3aHYmNJel8H2wNnRjuE
FTSyPSH0ZNraVLAXI0OTdadyP3sJrt+oTFu2ju0F/+nnF8wLY3tj9tYx24Lc
2UuhnTA6z8eCvQwf+v8xbtGALXk53PwerJV1sn3QqLxcuOcqGyhTxOx9eJYs
Aq2v6gqCCjn3RYQq0sdlG+e+yA70V3UmcS5HxX25/fZAzuVo+iqvqtGB8xWw
zwj18jbjfAU2fBrgPOFPG8r98Ms/pt7t7SCLfnDQ7hzXd5XzlWjyvCB1q+d8
JX4wN1l/ppLzVbjiWGQpFnG+Cv0RF/Zp93G+Gt+uLzf3zuB8NSZPm1LvGcq5
PzxTlznscOXcH/M98nJSZ3IeAMfvq7rtRnEegIbR1yc2P51NeSCO5t8/oWoh
i4EY3PzR7oX1nK9BdpZ4bP8xztdA6X8z9f2dnAdB2HvfTZ/GeRASYt843LqK
82CM0P+u3+DJeTC6XcsHH83gPAQ9JfM8Xw7JKA9B5smj9y4/JEtCEbgprKPg
OuehuOU4snKomnMF8hd3Ne0pIUOBx74PXs58j88rcMQz3c06i6xTYL+r9m6x
wP0wRD5cUPROIvfD0CI03Jrjzv0wWFk3up6Vcj8M3vr1XVIT7itxaESvm7ba
mvpK+OvLmx6lk0UlUs3kj48vIeuU2PT1s3WVfbOoH449/TX7KvVkhENlG2o7
eQ9ZDMcL+2emm6zIunC89vWJS2/em0n9CCw9nvHts41kRKBwS/5e+TyyGIG/
zTjyXbYpWReBgayAdL86K+pHovnDjdN2CGREYsnzKy4KOVmMhHvc1E2dHTOo
Hwn7udbhO0vJkihULz/vdT6ejChYxv64eaEXWYyCujDiM39b7kdBd6DOxez2
dOpHw6WtOyGyjoxoPHpeu1hXQxajsaxG3vnP02RdNG7cDL6evYb7MShzCrdQ
juB+DFbq39p60I77MageMP/A5uk06sfgPz/tOhbVSpbEIvfcrUMhaWTE4jfz
FymNc8liLCyu3b0y1DWV+rG4czQta28VWRKHS81lS4XdZMTh3JnMQmcVWYzD
83+NH3r/1ynUj4PUS5b9ei5ZosKEvpKuNSVkqOD1c7t4togsGlmnglPtKFOP
D7gfj4ybds7j87kfb9SPh+UUd8dr73I/HiHfKxor0rmfgI9mHfqqeDn3E4af
FxMQ9Umxa/Tr3E/AWueXD1quSKmfCKe645F/XCQjETY1Y4/og8liIsZcsi1x
6rGkfiKaBzv37S4nS5Kwwqn1B5NdZCSh/FCO2QWQxSS055k7rE/mfhI8eh7f
OzWG+wIWtRx42+5zC4NlAnSO8qensskQ8Mu6xt/c+icbLAjI/fjfX0h/IosC
BtQ5r/LqyKUCuoqyfU/7kHUCHhZ7uN8pMDe4TcC7HZoDHafMaF+NG9r+cQ4X
yDIjQw2f6L74kBlkQY2cKm+fmrJJtK+GWY+FtFc6kfbVqPS9rP9m2gTaV2PA
6eC2ir+Po3013A48feGrI0s0w3OZBvntOVvlL8bQvga/Lhkckjub0r4GvbU/
vsq1pPOiUb9UA+uha82Le1+jfQ2uTe/tLpxEbtPQ/3ss7ScP35MlY3f+Wq+t
1ryfjIqLt6RNVqNpPxlBnjvq251NaD8Z401Ob+kueOZj2DeyLpmed8DgtmRE
x7meybb502BJCj1fv8GyFLov+sDIAp9/bDgvpgy/fqnR9XRGbjOyRGu0rx1+
fWiN9o0sGrnU6Ho6Lb2PEfT+tUbPn0r/Jwm9/9ThfaT+/37+AoBP+gA=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1zA1M1GUAx/EDmsNhwtxZyMsEDg20fAOMk7cfnMdxwHEv3EWBYsIRlCvs
sCEZegXGS00Fm+NNRUZkUOekOoOMQzQG6EzI4mx6mUbyGk0LhYxe5v/3bM+e
ffbd7/HPytflOItEouf/u/+/PBmtTauOLXgKj/R7zLb+DGXw9ErBItjuP1bc
P0i74sC0U9bgF7QHLnwuMt44RotxNKlYpNpPeyJfNVZ04xXaB4vecjkYpKb9
8FD9bcxkGB0AmdRcsHYZHYitYfXtLv+sELwSl04OPdN8mw5CSbnzw4UD9CrY
8yfcyyz00/C9u/SS0xF6DSJHvWPdi+l16Fbg1vJsej1a08vGnlPQGyBpyjD9
vZYOgWOLbY+zFx2KRId1Q6MTHYZ6jTLZfidQ8EZElFbJxcP0s/DJtFnLO+lw
PJBF9G06QUthtJ6KfryC3gTLmhnfztfpCJypfjevNY2ORF+pct35aDoKDz6s
zbgsoaPR2rtv+6lFdAxyjO9Fb5mSCAZyrl0fcbMLNgOF22/eO9vBHovK33Zn
9xxnj4VidNvkN5Xscfjr8pLh7/awxyF7n6Og7UV2GU46Cuu0MnYZpub1tZZA
9s3Qb73m6nBj34zlHnkfN/0ZIHQ5bqd5H17gEGyWI7PJo6H+HHs8dvxclIlP
2eOxrMPt17ZqdgUWrg62OErZFSjRdneVv8qegLQQTcBXGvYEhHaNG65uZFei
rvbr9e9I2JWIfLKmxsuDPRGj05aOA3/4Cz0RDbusp9XjgkVJmDC1HZ65yJ6E
hsHJ9jufsSdD1yt5M76OPRk7C9JPzJexqzAweO6Maz67CvLCie9nX2BPQV5V
mGKxij0FQ0rx3NVQdjVqxeKWQ0HsahRciffpeoJdA//Y3Io35v0eGRr47r5u
y50QbNbA0ytrPHhYcLcGOTXeWbLzgkVa9OwypdhPc6/FVM+Ol91buNfCM/+n
Qz8e5F6LkrnK8dK3udfBr7pzMtzEvQ66sp0f3MvlXgfJRXPA6nTudejf67LE
KZn7VCxuNL0mTeQ+Ffev9FXslXGfiuqPZvZfkHKfigFjRPsnkdzrMbI0IaoR
3OvRO2sdOhLFvR7BL93yusv/uvWomnVrtodzb0DR2M1mWwj3Bpyde9/bJ4Z7
A35IyPtyRM69Ab8YW6SSOD/8C9Xubbk=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1AlQkwcaxvHPHgvKrYAcxSICUqRa4opWhTyAQS7DGQIJR86qC626UF0R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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1yXlI0wEYxvGpWR5d5q3r2LS5xHLLPFP3TLep86hUtDTywkTzaGEZBmU2
FGtZLQfiFRtelVkYmf+UBzEThcxuKlwpU7yKaH8ohRX93hceXj58Odklibnm
LBYr/O/+fbr0OzrvlrVe+K/vosrbwh+jSzzGLPwcrE26OUG2QpLyvdO6XvJm
pBmWO7obyQ5YMyxptz1PdkFQmvbI61wyG5f9xwuaY8k7cI6dyeoTkrl4dfzC
SKAr2RM50yyBenUnYx6Wh8UNlkYyHxfFK12yF2Rv8KNDvGp6yT4oV/zSbmoi
74GLPvnGLSVZgK0mod9yIVmIw6lDqx3J5L0oz83fXRZM9oOD3Yz90W3kfci2
klg8sCD7w7fYMBgz68k4AAZH9lXFS3IgHq60hR57Qg5CTUeb71wrORhB+seZ
fSpyCGo/2/SXnCbvR9GYa2VlOjkUGaNGjUZEDkNJo0Jo8iCHw1/NKTXZkEWo
883I7DR5MAbODlS1GiYZVwD3TiQ6XBmhLkaV5qnZtfvUxdA6S036JuoRqGdr
2j9WUI+APEx7XZVDPRK2ZQ2CuweoR0L/Va6z96cuwUFBp92MO3UJUned+cYz
py6FNfdk7bMpLtOlqN7SzV+vZ8ySIVtl1Fl1UZdhbnY7/1Ed9ShkiC+9zVJS
j8LMBgV3uoh6NKQp1T15CdSjUTxWkCITUY+BmW5V7exFPQYLk28OTThTl+Nd
/e+eU9bU5Vhc61M8NM9heiyUhWETWUuMK2JhDHATGhaox4HbUu6WP009DpFO
zbGSL9Tj4f5clTfwiXo8HEuLNMYP1BMwz9OqZVPUE9BvOb5xdJGDP3kE9gg=

         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1yw0s1HEcx/HLKJeEqEiG85RbeXaX0H04j+c8x5BiHpZ5KmUjo9EDNUZo
pW4hMZWn6MHJUy2UYsshWtGDVrLkRjM1tWr9v7/tt99ee/8+hjGHg+IVWCyW
59/776Wz/1YNt3KtGf5LLngzOPrR4qspYxZ64uPSv4yQlRHffbmuXUpWxwLb
eb60kqyF0BidpMIzZG3IBUclHUnk7Ujkp27MDSEbYDJZ/DxOQOZA8vaCMNCI
bIxWFdfkMmWyKcwzh53OzZkw3oEBB7ncQkbmovn9uyx0kneitVVjRbeabIFn
GSf1q/LJVpAl/liQp5CtIZXIJN1BZBuEb1bfZ+BItkXJoqbXRQOyHSxFgoFy
ZbI9xmoKi5QWjBnzMGJyvj5ojMyHadPyuq1S8m4IS/Lm5dVkB5g3VqzpLyDv
wYu04rjxVLIjUpfaxhODyU7om7nUNcsjO+Pq/dRTLvrkvVieftDZvo4sQE5f
xq/RJSPGQHN++ETGBONcQLFpOFixl7oLopVkHSaN1F2wYnrd1rOUuiui1O4M
j2RTd4WG+auy9QnUhRBaz1umiKgL8XlKYUrNhrobBnukx9O0qbvhbNTd3LCf
HKa74+a21ZaWOca57lAe7d4QMUbdA1Izg9tDHdQ9EFtVYaJxhbon/ItPHLPN
o+6JoeaJnpIE6l6wFi/V8kTUvVDOia/St6fujf6nK5xYDnVv1B45MPZdlboI
q3b+odmLhkwXoWnw90HJB8YsHzTMfGO/fkzdB7PttY33mqiL0adTF6FaRF2M
1V77G7051H3xabJtKj2dui9UBzLFrsnU/aAUaRRUHU7dD5pci10iD+r+kEXy
i7r41P3BtuJ5hfCoB+DRNDsrm8sYASgsUKo7pEv/A5A+f604bQvjhwEI04sJ
ZmvTPhD1m1RPq2jRPhCjw3zdlxq0D0S0odqTBj1D/AEJaR/Z
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1ywlM01cAx/F2wtTAoERMsGzlbDmUCjpbbGX9cZSrHG1BmQfxhA2jNGPo
IJDByMaIwTVlgqgBIyEEyxxkA8a2DI1ErG5ag1oikei0MokIQtwysy2MZf/f
S15ePvm+X8g+i7noNZFIZFq6/708O+0d0e2vR+B/vdCVeYQ5op4pBIvwm6V8
sttJr8Dgl9Wpj/tpCWqHVobsP037w9/ji4CGOjoAWxdtb5wtod/EhecxT8/n
0sFonLesjlLToeh6vCWoW0qH44PKTTXb/5ELVqDQZ8WA50M6Esrb7tLcUToa
zh/7NGt76XWIP6pa9nULrYQiv0d9toqORbF3ZPtXu+k4uO/7Xrck0xtgtcp7
cyLpjQiyqlwSH/ptHHc0yY1z4YI3oe2K57TtNq2CuylQfvl7Wo0ZvazsQCcd
j21rnc2yRnozKlqVzZfKaQ0O6RcftO2itehyzE7N6ugtqB4rnDgspxPg90OU
6dpy+h1oUvz1koUwwTrYaoq8Slw0sMH7RMDQiOBa4EHgT86xbvZERCZIFMVW
9kRYVw15jx5hT4LfjHh4cjt7Enb4upZp9ezJUIdkOZ/GsCdD+5nMFSFhT0FH
Z6lduRAq9BSopcnpf44LFulhaJx1tX7Hroevdf7YTAt7KrzmP7H//TF7KgJn
pOJXh9jTEDWtsvWY2dMw/OlHzUVq9nRYTrxr+FzKno5H/fdUXR7sGai2XzU9
mgsRegaOvJTtfXlfsCgTx2+Udg2OsGfiju9NjbiP3YDCOh/V7yfZDUipeau+
oII9C8sX4qe+OcCehd6O987pstizUb+nYrYgjj0be8dVSdJo9hy4n7SflknZ
c/CX5eCitxd7LtY7i+8Ei9hzIS578WzrfLDQjZhwO+rtk4JhxHDVrWMxPwuu
NeLVhY5vBwcEXzLi6BqPUdM57k1Y01Ow830b9yYs3JWf6ivn3oTS2DlN64fc
mxBxxuumM597M+xTLl1vIvdmVE4/7Ly4kXszzoQVawPSuDej5I9fClvSuc9D
oxj6aS33ebgqiU1o28x9Hn51NGRMrOc+D8bQ4anBddznI9swYoxY+v8v1n9D
ZQ==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0HlMk3ccx/EiOuZ0mwfjkqOIHKOiUg5Fp3w45EZKW0opV+cBHhzFgwlE
qIBo0A0NGPHAoYiKoghMJxGhCCrIVHBGRUCUyaUCE9A5IDKX/b7/7EmePHnl
87x/yfMYr44VrpvE4XAyPt3/PukKPnfS8vhn5vhPfzquUUoMD/SbMXOQ1+QQ
6faA/Dk2qnFvPL9CnoH9Rtbjs46TNSFW+j62SifrIKvNJH1kA1kfNX0OSfEi
MhcPzgecr3Ugz0Vxt3TsqD55Hu5ppXqMTyabIere4NrWV6bMFogOKPtY0ky2
xLhtiX/rr+T5WFs8EWydR14AsyM7+VlK8iLM7k2qEK0jW8N7V3uHth+Zj1yP
XX+72ZFtYMXpdqnVJ9ti6pn4/RpTyHbQHVk96UPfPGZ71NREn8i4Q16Miofc
gadl5CXozeu933KM7IDyiZ/MujLIS9HdN5yTs568DMlPRs8u9iF/B73cy5dO
8MnLcTCp0X6zIXkFzhTPW+8/lewI1Zu4a6WvTZgBu2cccfMDZiXw4rVFm0cF
7U5wUv9BR/8o7U7Yq3VqOy+RdmdEZOf6v5PR7ozOTa83yEC7CzZef+qcYky7
C96fyM/P0aDdFTWW7UVxvXPZ7gqe73ZeZzMzZyW6Ti3PnqikfSV4NeeQUEC7
G3Kasi7tTqTdDbxtv3hHR9LuDtuYlZEaAtrd0dBsdXj3Eto9EC6dKVzGo90D
rwrUJgZn0u4Jm2rTtJPjxmz3RHqH5fGi58wcL/Rr6WjL7tDuhbqFQ43el2n3
hjLPW9l0lHZv+L20KJ6eSrsPinouWyiiaffBQ01tGxMp7b6o91r6Wxxo98X5
ksJJCiPaV+HriYENelNoX4X+iMzu7F4u2/1QldSUadXIrPRDSsatcy3VtAvQ
aX0h7K9SZgjw4ouGxLf59L4A9W4v++OzmFUC9AQ4K9S2Uu8PC3vHVh8f6j9Z
uK11zIR6fyy7qejTUqfeHwlbOvQN7xuxXoi7CTN39BxjhhCfZR7ckRDFrBSi
0/7m9EeuzCoh+mbMTlWMGrJehJEx3w9TOpghgrqrYPPqG8xKEbhO6Wt0w5lV
Ilz80aTFbz71YiiH31c686kXQ1MQWqvdacB6MaYHpyhqiphVYrTJFe/aNzJz
AjBwhncoeRozAiCvuj05/4M+6wNgwbsk7f2DWRWALD7fwOgxM0eC0zai7PJy
ZkiQlrhzi6OEegk4/hEjFaNzWC+BULPy29slzJxApL2v7g5KZUYgQl9FdQ7O
YlYG4ljcQ7Ftlx7rA3Hwwm5pbQMzR4r6Rde27rvLDCm6hsqXqMqYlVI8a+uJ
zMqlXorCWGsTM3fqg/Dm+9P5dXbUByFDw5H7lTn1QaiSPHppNqbL+iCsrb1i
ve9L6mVIEGXOr59gO2SwH42uvl7CrJTh6q0WY1sF9TL0338btXwRMycYfvry
q7YG1Acjb4d+RGG2DuuD8SQyJ/biBWZVMFZomRaP1jFzQjBNxXVcmMSMEOjO
2bT+UDT1IUj7hptyeA/1IUg20C4c6qI+FOtMrdVWNFIfCkEp11NylfpQVFUa
itXfUB+KSodBbD5AfRgKy24W7Pmd+jBceTxsO+s29WHQvNvW8LGP+jB4XovV
Hlaj7w/HUEGQyohP3x+OAY267J/d6P+F44g7P14nkP5fOFIMJmxiYqiXw3Xx
oJ1sATNXjrPJvjEec+i8/+1yOVwGvcxT0+h8OTTa95aWDzDny6GjV2qe9lwX
/wCR0DVx
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1yw1QE2Qcx/GFoFiNF9k4QCReFNZEEORFGi+/CYwXGeyNTRLUdiBvsVqI
wkQOUSFKO3xpEW8RnJ7CaXQ3ObwKh6FQVzYK7SyuBEZHZDrDUoKiup7/c/fc
c5/7Pj8/7SuKAjsOh7P73/vfS2dnT5ewY2UQ/pctQeQ/G1ozF8jMwS4vXozz
12RHWK41b26/THbBnjOuXQstZB5+3//h+E+HyR7YcPTXZ/YWk73R2Jr7eVsW
2ReR37j77Ysi+6OpLfqHTb7k9TBc0gakOpADsapMYV2e28AswJ7CgXudFrIQ
wsWsU9zL5GA0mU27ee+SQxAWsOaE00HyZuhN1/NeLyKHYeHVB41PZ5LDofft
E9yNIm+BRv5dxyZPcgTeN0jeubK8njkSvTXOG2d+Jkch9UnhsPYrcjTeCJJK
7frJWzG6jicztpBj8JlBGSg6RH4BDd388aF8sgj6yEFzfRo5FvlDW+zWhZHj
UCqukPCdyfGQR4aWrL0fwJyAb/M8Tl24TQamWi7uE3/EXAtEVCyJM7uoixHS
35/o1khdjENCOKCA+jY05YxdVcupb8PS7Y1b346hnog4W1nJQ3fqiXBJvZXh
zqGehOmiiZKACX/WkxAsKnMzDjNzkjEjn65/8zz1ZAxYlyKqTlCX4Jxurrej
nLoEfsY+ZU8O9RS0ij06q2Kpp2DET75mdi31VNzXW+p6/vZjPRVqfr5u0MrM
SYNNd+PIhS+opyF33vPxdB/1dJjuzBrEJ6mn42T0+JCxkvp2HPbJ4WZoqW/H
Gcvx5vQs6hl46Vqy0y4R9QwM2ILmhgTUpdAa6hYNT1GXItjUPSaf82U9E28V
N3w/McpcmwnFDDckyUQ9C9JJ71uyTupZULYfqKhtoi6D6YPwB92VzJDBJqiZ
TCmg/zJUFRtlrTuZzTLscLujuRlPezli7PvK456nvRzu4bkqmxft5TjtPdp+
fQXt5aguTbg5NfIc2yvQvcz75Ph7zFCg1/rbVF0tc60CY/vPr/7xZWazAp/6
OzcGxNJeiXae98heAe2VuNf6V6Vy0YftlXD2kZ2Nd6W9EjYRx37Qi/YqNJyd
1N14zP5DBen8l9V/PqS9CoVXE+1fu8JsVuHjPJ2Zf5GZk43VB6qbPY/SPhtc
V5ODsZ722XBxbyhzLKd9Nh45WdSOebRXoytheGlHEe3VUB65u/BLKe3V4Fae
O6Z/kfZqPFlhSfwjifYaHBMcXLgkpL0G6fMrn30UQXsNQq1txRK+D/4BK0p9
YA==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0HtYzPkeB/BfkmsRUaE0FSGhwilC79JNTPd7MzVd5lI4xyVb4uins3I5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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0gtUzHkfBvCJRCopd9NmVBISWpfpwjzdSJLu032muTQz8p6lKG8tRqJl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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1HtUzHkfB/Cf2GyN3EtKum4S20rCEL1LuUxKU5Ou6ldNM7kTedKzth8P
UU8r1JPr2llUlt2UVgrLuC4tNloV65LsLtuyjbuNavc5+/n8UXPOnDmv8/69
v+/fnN+ZsU9YHJJkJAjCpb/f///kV/SBPa67jYfhHxm8F4i/bPvjsTNZwKL6
iicratnvQ+2vy86vZPfFepXCw2I3eyC6JQd9mr6ObYkT7Wl7FixgD0FZryrT
aBXbDuEZfWWeE9gOUFj5ZtTbsp3Q3/tth3dPtjMuf71yttGTD8guqLlllZv+
I9sVZT98bys7wR6JyXLvFM8ithuaX2cMCM5hj4I83/EzpyVsd6g/ejQ+I5I9
GvMUi8fP8GV7YHtbUe+jzuwxyN+ZVbiqN9sTc+VRdbeeOZHH4qv8MV8ua2CP
gzRi1NQiPXs8SlOczvrvZ8vhUjO9LiCHPQF5Z08O37SYPRHFDk7xunC2F374
pNw+bjJ7EvY/2/gw3JY9GfMHGW2fasr2RkvQ1QeDDY5koET0KAmrI0tAwf1T
oz7+hnMfyGQBtf/ZwbkPNlUbNiet49wX3gr54eMLOfeFSYGjamEo51NwR3n5
8bFxnE/Brlyv4EPWnPshp1h4Z9+Dcz+k7tztG/CzA+X+WLx3T+WGarLkj6Yt
r1JjDnM+FSuGerY47uF8KspqFo6OzOZ8GgZs3nwybCXn09B9bcuLQJHz6XC+
tvjJpOmcT4e1393K30ZyPgNnDru43+zF+QwUpS6reu+xPeUKHPA9Pdqqniwp
cGbRkpA+33IegGEnq5tbdJwHoDROEaIq4Hwmhghuq6vSOZ+JmyUd6SEazgNx
wn1RS+EszgOxM1vwCRzFeRB66mN6p5hzHoQw9fXSYQY7ymfhuzTdCr+HZGkW
5FeP6y40ch4MS4d8S+drZARjS43Q6l7B1wfD8d6H7wz7yPpgKFovpbtmcl+J
HZcvTNGL3FdiuKbJ6tkU7iuRFva2LcuZ+0qsu2nspjHjfggKsyd2ZL21pX4I
Dno5JLucJUsh8D6x/PfwDLI+BM2/DZm8Rk0WQuHh69f61If7oXAvz12UbML9
UJjXGTy/bBpK/VDMjS0defU4WVDhVtESc6ONZKiQ2V9T0G0pWVLBdVB1UIkp
91UwlLxcl1JjQ/0wPIoZ0LqrgowwnC41e35sK1kKw5XGwvvKYLI+DPqn55ZE
W3J/NkJDZao9DUOoPxvn5rm+OLKNLM2GxXipe6acrJ+NyJrBfQqbrakfDo9L
/psW1JERjklHrpoVFZGlcPgv/d/juyvJ+nCcybSOUkVwPwI2vtvEVH/uR6Dp
iixRem1F/QgM9Wn/RvGKrI+AvdPoazMuk4VIdDQ5HtuST0Ykrt4pD72Txf1I
5DrN2jUxl/uRmHnKpKIokvtR2Dgxf/hqU+5H4VyDYseUXwZTPwrtYRY2/20g
66PwsmdzkbaMLESj8sJN+zFLyIhGt4Ebnre3WVI/GoWHz+/dUEvWR+PEssi3
YyvIQgwq6p+P6f8dGTH46XPt0qyD3I+B7d5P1wwL5H4MHtwOWbramPtzIK/K
uGfuxv05WNtxO8TYhPtzUH9jVXW2F/e75EIslt/ae7FfwyDqxyKgODtC1pv7
sZBP+xGHD1Guj4VHnk3ZJ9vJQhxWlinfuKRzPw6Z7keH1geTpTjsmPXnPbHD
gvpxuJBz5l8rTpEFEbtT998a5UC2E3Hv9+LU8F3mdJ6IHXZH+vz6kCyKaE95
/YHJebIk4mC/Pyydy8k6EW+X6jICk8l6EV4vT9/NiSU3ijjtuNZFcCAL8X9/
t8yhlrcH0n48io/XW1QP4f14BC3r+++C85SL8YirPxJbm0aW4rE+/Vzam11k
XTxi3reStsnJ+nh8Jt1I71MygPbjUfbM6vP0ZLKQgNC6rJzrNmS7BGy9n9Pt
7tP+tJ8A92PWw5pSyWIC8pIMeTHFZCkBI2wsBmvjyboERE87ZdpaStYnoGnn
WM+f8siNCbi00s9L7cz7iV32E/HzvOET2taTkdj5fsVEzI/oqUzcSpa6WJeI
gPKnCuU4sj4RX+y7aJ5bx/uJsAg7crxsPllQ41V2yaA5L/rRvhp+Ulqb+3oy
1LD30WaltvelfTWsLR882ryFLKlRYdj0kdWV3rSvRoeg7BCX96H9LnmjGoes
vzp6PYByIYn+78l2STBLGT2xdo0Z7Sfhw0luqlO/ksUk7Lu0d4VsOZ0ndcl1
STCyc22VHexF+0lwVBTURe03pf0kzL9YebK2Skb7Gmxa273y3hzK7TT4c+SW
j4sXmNC+Bobya22rzMmiBtcqb7xoeEN9SYNXZlWr33nSnk7TeU+vgW37le/H
G3i/Sy5oMbK8h/HYjT1pXwvb6YFyiwPv0b4Wyhz3ET3W9aB9LVrkre2+bsa0
r6XfC12v09LzNaJ9LWTdv05vzutG+10sJHe2XXLn85Dc+X7ELpa6XK9Lxsxx
GUcfuHWn/S7nNybT83nn/c/+XMqfev8FHvFRsg==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdzn841Xcfx/EvitwoKj+S/AoZp1Nik1HndYhS1jiH48fBOc45blaLtWrm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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd03tUTXkfBvBdmYoIoYmok1xGk0MZeZX05FLpplKq0213Oac6JzRkoly2
GGKGt6bJJJc59U66CTFJF+aUGkYvb8ZKY2bhMJaEkWuD6fLOLN/fH2e3Vqv1
Wc/v2c/e+3Rs4tYEyfU5jnv09+8/f9lPREWx3RHD6XivZ2680mfouMfTyBzm
c70D7u3Mxtgm0ahO1TKPwszp/Z43C5nHIl/fdebqbcwWKHm9o0OdzDwRbv/b
83pSELMElj+vc7eexzwZTtfSJbMsmaegMtN0Z6M+8zTc/T5446nuqeSPoFhd
3FDdzmyHjKLttfwZZnvErDkwx/kQsxQuBqfsa7OYZ6NSerlSqmB2gMHndY9D
vJkd4dN3stDGgXkOhNR0y4SxzJ/grPU3Xzi8mUKeC7vpNdWFt5idsFbfMcj5
AvM8wPfSo75S5n+hfpKRtf9XzPPhJc3I3rOR2Rk3o8fcN4pmdoFz1+1OFw/m
BWjv3t0tnc3sCuPtsqFzJzIvxL4yl5oqfWY3tJblrOn9w5YMhPxVpJzXSRaA
gCt1Zq1nWO6OqRkD2RZqlrvj4Pig9NBsli9CgXdp08NUli8CL/gPOoWwfDHc
ttVvPODC8sVYHv84rcOK5UuQbzbdv384y5cg/OXzMMnLyZQvxabsaLtzt8jC
Uqgs5I3ubSz3wIZzJ3v6T7DcA472Syqy8lnuiaalRYcXpLPcE3y1vZfJapZ7
4c6DTWt3+7HcC/2GiqdWDixfhrbafr8KC5Yvwyh7B8urgzaUe2NH6huHgodk
wRuReN5m1s5yH9R2z7Z9VcNyHxytOViVV8ByXwRn+PGnt7LcF9GfafTcVCz3
w95G5y2GUSz3w+5rXkL6Ypb7g7cZebFyEsv98XBKfn7xaJYvh+3IwidGvRLK
l2O7VP3OtYPMBcDL0DMisIWMABgulVfurWPnA1AqPa1IOkTWBCCt01GelM36
gfDZf8tx2BbWD0TDrMbbQ1JZPxBFMzpPewawfiCKfz9Q0j6T9YPQnm3hyxmx
fhBM/ysd7vyrNfWDEJzYk+d3jKwJwnemtXqZkWRuBXrOtvistyZjBRrNEjbz
o1h/xd//71/lhrZbUX8FGtZVy1FO5oJh7Zv8Z/4GMoKROazy0L9nkYVgxHuo
njfdmUT9YLRld13vKiVzIXAvy2hpziQjBLG5651sV5OFEKg+n7Lw05msH4Kt
3w8pdLBk/ZVo8sosOMqx/koEGNUVP7s8kforkZs9tKJnG1mzEl2Tz99Q+5G5
UGRtuZo/+ZUl9UPRtqolq+U4WQhF08TzR67XkzWhaEjoHdJQSebCsO/NYJnV
FtYPg15PXt9gDOuH4VTZxbgse9YPw+Zp0Q03TVg/HGPyiurLuyZQPxznTvxU
cqWILIRjxrHce/VryZpwuNRzVa4D46kvwzctV0qCG8iQ4a+KR+27NpEFGTZX
d+b7J5I1Mhxxv7bH35v1I3C+0SrY4IkF9SNw0f3ksHvNZCECvyR+veZ4FVkT
gaa24gX8TjIXiV9GvxifnMb6kVj8tDx/VQLrR6LDp1l214b1I6F9axWSNZv1
o6B9d5ar2sr6UbC7UWVmXMD6UZg0Z1eHdRzrR6Gg6YjBrpWsH43cYoOcpwtZ
PxovCkwGvuz5kPrR8L8a0FKaRNZEw/70EEOnfWQuBuXKwxb2NWTE4LdBy4aI
NNaPwbRNndcueLJ+DJoulOjfCGd9HlbZyvJX48gSHoLxnC0v75vT9XgML58X
2PgtmeexMWdsxzI9siCymscP1gctDg8la3gUSmpGPuga995aHtZefvPNK8hc
LBa8brr9ZTRZEou0umbJBW8yYuG/blTm/taxtB+LGjfFm00pZCEWkcYThIL5
ZHUsuma82OgQMIb2Y/HF3pKpVQZkrSjn4lCbejRcOo4siUP+1P5w7lsy4hCd
7dHt2kLm43A6dd1L2QayIOqr4xAe0+wlC2P7olwbBwePwjrvK2a0H4+WAM1B
oZ4sice9g05zf8sjIx7KtDdn9ELJfDwWOPruMuVH0348zB5qmiuDyOp42Lgn
7l4/MIr243HU1vvXT5rJ2nj4efzYet+VzCXgu5/+85lJmintJ2BxcJ/TBx5k
JEBfYvfOpHI47YssiKxOwExXafAPD0bQfgLK3C+0/jierE3AuYvOTz/6nc5z
cox+Mtb8mTnbl8P/2L6l8ho6D5F5OUasdXS5nkUWRLlarnv/GjlSFuWcMy0i
a+U48yxn1oQrZE6hm0sUuDEiO+mtP9tXoHdE3ba+uez5FaJ9he6eWmSNAq0v
R66QfUp9rQKqS2fPX68zof1EDB/TnJ7aPZL2E3HC8ljtzz5kJEL2ca7X1Q10
nk+Erff+G7KyYbSfiEutrulp9ca0n0jfrw9oPxGlDZ3mlyeStSJzScjY+q5J
VWFI+0nYfOR6o/ldA9pPgnlITUO1Sp/2k7Cu0sXtVDFH+0kwMajKeJSnR/ui
viZJ9360opxLFu2LjGRUH1/ztTSCno9P1r1/QWS16LwmWfT+k5Gzw+DsnSh6
f5xS97xEiZ25KudMayPaV+pen1fqPo8gytVK3felUSJU5nh87eRBt/f7SvTM
fzewSNr73pxKN5eoMGfvH3+6a96+N0TmRRZEfbVK9/oakbUicyn0/e2j/RTd
HCm6nzefovt5Cym696NO0b0fjcha0R63SndPsoo+F477P2BR498=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1ywtIk2EUxvGvVlqWZnlpQeRcOtcyK1061+ae6dTN6xZphUoxKC3SUiK7
0qJULLW8JCUp04xsVJoVhZBdLHLSbdmNTAwkG8Wac6UtMCr8zguHw4//eQP1
u9Ztnc4wjPrf/N/0skwtoia3EExpVBG4RCV2/yZgzaDL9DFI8Yo8Cxc8XkUq
b5O9Ea7WzC81kn3h8eOla3oZmQu11e3u8l3kxdhZx5vtsYHMwyPZxYxxKZmP
1k8q19ZAchDe+cw18tzIAjj1nH7uaDBrIZq8XtT4vyOLkFsZcCb8HjkU0/jx
49FXyGF4mCyZ2VpDXgXrybaS5YfJq8EtYHLitpHD8aS5ZfCEhhwBz8fSzMYw
shietWZZkT95DcyXqtUVk0GsI7HbPVQpHCFHoau//rv8GVkCi8g3QHGTHI1u
/iGZ1UiWwn3Lms7LpeS1cE4M/HDmk2XwjBDapZvIcpTtiOyYlJFjkPRmWWxO
MFmByfLzwrNzyUCrc8aYv3PplA1Accfe9soPrBklmKf1tuf3qSsxJ0qfyVyi
HosKm/zlnnLqsThu/6z6UkQ9DvlzqpXRG6nHYVHB5ooINXUVfgYofXtF1FV4
nTtQK/GiHo9nW0ySB04+2+Pxh9N6cfw9ayYBi4qbXJ3d1BMwIcucJW2jnojG
q275MaeoJ+Loke6q3v3U1ehTu+eJs6mr4adY71+ooq5BboOjsG41dQ043uXc
koXUk2C4dsf0hkM9CV23r0cNjQSyPRmdtgbLkIW1IRn6guyWrB7qKRC0x+i+
t1NPweA8uX2igXoqfskbLa4q6qkwxfXzjQeppyFyh9l7n556GlasNL+waqin
o+fr+nPeCurpsBwbrroqoq6FI+/4gY1+rKGFyja/qtCH7rWQ9wks2b94U76v
ReittwvyxlgzOmRUbj/NcbCGDhHBzSHXR1kbdEg7Yv9dbKX/OtywOR6Kh3n4
C9uMHuI=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1yw1MFGQcx/EDJhjQMGGIvHOCnLx3vJ16wI/j5Xj1uDs4DuTFfAnSeOuF
ljE4dQLGKrSojQgvLitv4zUdgSgnGai8GE7ItgsKHK9uQR6mEFCt5/9sz559
9n1+boeLZMeMORzOa//e/146B7VNXo2mnvhfSxET3oIU/8XdzByU2mYuv/uA
vBWzrXWeAV3kbdg8lGPmrCbb4O+BDWPfKrIdarv6u4eLyI74oEdfNaAgu8Jy
JP/CPSGZi7yFRr3Ig+yO4/enh0IsyLtxZfvivPixBzMPG05yu6xRshec/KK7
678n++CGV51e2ED2Q8Pr6lN8FTkAURVZvSbHyC8jtn9Tt5lE5sNDYfdFdSA5
ED0b9VfnHMhBOD6ZqXXmkIMRbtDy7j9yZw7B1pthOdb3yKHYzvW4U9xJFuB5
734fVzV5LzZyjexVp8n7sCY1BOXmk/fjBXf0mMvJQnjWrLVw95HDMOHy+ZvN
buRwrF+vO3loCzkCDudLwmQzu5iBJxr/uyaDzCrAsO1q0bk26pFIznw6r/2Y
eiT4X4aMZZykLoKB51Rhk0VdhFMj5ooFEfUoPJPFCc28qUfBXiAUFjpQj0bl
ePHawXUu69HoSFi4G/w7MycGlUGDP7bfpB6D1k1L1YaWeiwCfB5OSmqox4I/
n6iqKKEuxuN5E606m7oYzZgN7pNQj8OYyw/9o37U49CnG1+xsKQej3fWowbz
ltxYj0e5VXijZpiZkwAR//paVCv1BBzpKIixqKeeiMFL7ucMldQTEetrLc1/
lXoSvgqyHnogpp6Ej5K0377hTz0ZnsHvNZrvoJ6MW9Ve3heNqR/ALyUhj/z/
cGX9AESW1T8tjjFzJMhbCj1ReIO6BB2/ileL1dRTIC0zl47WMCMFZwrtpo8U
0P8UiJ7qpyaUzLoUFLd/d7FGQnspPuSt3F4V0l6KkexrP6t20V6KAHecFlrR
XorO3PLAsWUXtpdhRutr4A0wQ4b4yy1ajwZmlQya9/fUzR1l1smg+8bUtimd
9nKcn45/wvGgvRxvX0sRCp45s70cfQl3Lu/sZdbJ8eJLV7Z8WsnMSUXccJPp
tJIZqYhxMBvzEdA+FWe03Esj9rRPxUiayrr7uRPbp6H28NxkZDcz0uBru6z5
rJRZlQZ+Z0szN5RZl4aBqZWIMnvaK6Cfteni/eXI9grEuLbe0txmVimQ0y73
7lIz6xRQvFJblfg1MycddrHNiS2f0D4dYlQvcwppn44pK6v5trdonw71uqBG
cJb2Siw+1CgjL9BeiZXVo/V7ymivxF6jtqKRcNorMZ49xPMqoH0GjKbLZ07E
0T4DK5NTpTuyaZ+BxPE/NTuDaZ8BlbF+wSqa9pmY+M2uUsJ1xD8KvbFj
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdlnlUldUaxj9wTEEhEARRjgSFiKAYhCMPICYpcJhnOMwzHOAgoJkfzpoY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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1HdUVFceB/CH0pSgoIgCRkZAVAwoYEGR8AUioCDSq8gwdIYZCNZFXR4k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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0Q1UjPkeB/AhLCqlq+hFTekFN1HIiupbK6JXicmUeqZ5qW7tKszBYHus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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1HtUk+cdB/BgBUQdYCc3yyUB0Qq2OKAogvgFBAG5hHBJQgjkruLaqoNS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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdy3tIk1EcxvE30bDoYjTBwkKXs7A0tTJvs2c63Zybm29IdI9pdJGWN0xz
0CqLstJJLEtFp2ZGZBbaxVKb6SIsu0xXThNNSE3QEjSLjC70/v7pwOHw4Xse
d/Vhdq8dwzDyP/fvS2f7jQqv0tkr8U9fNuVcarPPHffkzKD2u+14iJXsiL4E
b+NgI9kJwtEq6ddKMg/TDh8HKy6QXZArbp6QpZJdoZR8HPm5jeyGUx2OGbkg
87ElrWquywqyByb6raG2OWRPFJ4wBKgnBZxXgT1iLub1kL1QGiu8Z2whr8Gb
BKG+rJrsg6ix0OwIPdkXWfve7dqdTvaDKaG84eF2sj8cJoa8ysTkdeh01fws
XE1eD3XwSUfrQvIGjDLT/aXTHpwD0K9edtDSS96I3WxFq72ZHIjEkSvvZt0k
B8Hqem7SU08Ohrd6f/ejdHII8kuSO3q2kkORk6/rux5GFsL5QeaMjU8OQ+eL
U8Eh88ibMNJ+N6ru6wrOQLyo+7axl7MOWHrW92qyiboILoYm6+Ia6iL8GG4z
/SqgHo7uHTWBljTq4ZAkFTDNO6lHYLlkToBOSj0ClmxtVrgPdTEcjWbVZyfq
YqRqG05Lp/hcj0Src7l2j42zLhKPv7+ylDymHoUWn8bOhnLqUSjq+PS0/gx1
CeLt7wZqjlKXoL14qXvDHupSmHf5NDEi6lK0dNl0ej71aFSzgjK/WdSjMcTb
fODbuDvXZWi8f8ZifM1ZJ4PlmjKj7g71GCw5diUpy0A9BoquD5dfHqcuR0iy
Q1xkInU5BlqLz+fIqStgXFt6KziIugLisUV5KYupx2KB3pD+ftKN67FQzr/4
qtLGmVGCie6yT3lCXYmUiUyRoJ66ComuYzW+Rs5QIW+g9lBtHv1XodK5q86g
42xSYepoTL5MS/s4rNbwngVqaB8H/5PTze37af+nD3cIZvbS/j8zLNjnbzeb
D9CehfE1jx+bRHsWp+3G2HQ17VkoCuyKehPd8Bu7y0D4
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd03801Pkex/FvtEVRUqEareTXlmtpk1+z6xVr8jMzGGOGYcxwdMVuuy6n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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1HlQlPcdBvBXQMMRkENQERVR0XJVUOSQ43FVLjmXY7kWFpZltRwalBgv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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1y3lI03EYx/GVWMuKLLQUZjmbK5fmtTxy6cdrTud0iuuPln94FdM/pGyh
qG1gWV5UppkZGnmgQoo185omFV54ZIoHZRriVZhGSIeZFf2eLzw8vHg/X250
YnjcVhaL5f93/m16ytpHgtJtR/Bfq17ctNWoxk98xiyIT/4s6Boms3HxUL9C
2Ew2xkx3r6b1AdkEMZ/N3++6RjaDWl7ocUxF5kAd0Dq0LiVbQmq68mbYkWyF
npUfm5r9ZB5sjGzfftiwZsyHor143/gs+ShsbbwiXAbIAmzMWpb6PSXbYu1h
8V1BCfk4ziTm2dVdITugPrEqYjSW7Ajj7aGLqTKyE2QJFjtqXMnOSLuRXpTK
IQvx1TerVrnJY3wCukKVfdgs2QUGwvbJ6G6yKyyejC0s1pDdcFDAL+u5SXaH
fiEr452afBL1rN+ipEiyBwzPzfkJAsgidJoWXWizIZ9CbNLrwZE9ZE/0Rl1W
z305zNgLV6tuSXTTZKDRe2n9VRdjLcDhaJQmDdS9cVr/i5d5h7o3Wrfk+hep
qftAHLvaYaik7gM2OytTIabuiwpVi3eXA3VfuA6U5xiZUfeDzlir4xlQ90PI
9wLfbx+tmO6Pndxsze4Jxlp/WD/uG57uoy6GbCq5vKqRuhjVI9bJ7sXUA1DN
in/poaEegDVV3LgwkroE2qmlqHkJdQlmDkxk37anHojEFEvk76UeiHv6Eh1v
g8v0IFxaN/ZMmWesDULsnHVcWz91KSbLO9byn1OXwsu8P09WRz0YrPlnFuwy
6sE4L6o/a5hDXQa3prTlwnTqMixW24f3qKmHQB9lOC2Ppx6CoYEMJ5GCeigi
hYPhzaAeiiaHMANTV+pyjEkrOf3OjCFHzIsWSaUH3cvRcD03YZTPuFOOCnYx
b9mO/ofBYCXhPs+Tiz8Jmha+
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0QtYzPkeBvC/y0a55VJyKVOnaCu1iqXd0ltUhtJomq6TmeZWDdZtU1o0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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0ntQVGUcxvGTcUtImsALuICoEDBc2wVEbg+wiMAusuwusEAgchmBAREM
GZnRDYeLSOFsCNMoaiTqYkBKGWFcpIaxxkKQgkAwwjUgKQgQCpJoen9/1Jk5
c+Yz3/f5551jeeBQRMo6juOy1t5/vvTE1tfaXdB5Df9qxtdN8Khy7BdrZg6q
F486ynvJeii9/p6g8Rb5FVQUHexUnCcbo1tdcVxaSN6Cu9bl8tlUMg9nQn08
0kTkbbjQ4L5Z24W8HRLP/A65MXknhnVibYuXrZitsaGrab/6MdkGpYm/aq5+
Q7aDSjOw7NxCtkfcRknf2CWyI7xNJvRXS8jOOCC8cfLzTLILxmZ38LOiya+D
4we16fuR+ajuMFOE2pAFqBdufjvIgOwKgXDYYcPMTmY36PLE1XUPyO6w966R
yFvIuxCcojKfrCF74Obh2pTqYvJuOPS138rOInsiY0TpXxJJ9oJubtkH/b5k
bzwYng4ZtyP7wORKwFuDRmRfLFY4DTj+voMZMH3D43jrELMSMDb6JK27jbof
xkXGY4nXqPvhYa6Wiegd6v5wKklJDcmh7g/jEu/w0WjqARD0yePig6gHoGzT
uS+GHKkLwcuw6T+2hboQvhefGp1c3c56IP4wXOc2PcmsDMTgJa7uzR+o74Fe
bqa5ZRv1PXDhYrOr3qceBM3ZnIKWQupByFPx3xUmU9+L/pc/nAoQU9+LOwtV
vTF86sGI8E2U9JpRD8aMl+G1wyuWrIfA4ll2nus4szIEerz53Lgu6qGYjxFt
bb1MPRRJi22eTRXURWiW9ScnFFIXwcYsgRd8iLoYOqYK+aKIuhhZ2gN9PaAe
hrqP7U/4bKIeBs716PwCR30fUpNSpCs/bWN9Hy5/+pl44h4zF47r4+tPFauZ
EY4RnUHL5+V0PhwD5VeXawqYO8PBuaUN8jJpL8GjldY5JzHtJbCSOE186U57
CTwr59JLN9JegoRamW2SPu0j1v7/ac3dry3Yfs3qxnqr88zKCAjzBJXOFcyd
EQjwSgvUxDNzUjTcT9a42tNeCp2M/JUBI9pLEV+51ddg2pztpegK+Upt0sHM
ySBY+k747AwzZLh9LuHHJ+nMShmej4c9lUbRXoahTLG0WkJ7OYrqe9q7LGgv
h4O3o6zjiRnby7G+S30nfYS5Uw7P3qbeg6vMXCSSfz6964QW7SPx1wu5v8V9
T/tI6OqOzp7V0D4S3cbiPI8p2kdBebOqpLqfGVHImF9Sz9fSPgqGM2UVzSra
R0H7tKrKv4f20XjoZvDSSCvto3GliG8+2U37aLT71+g0d9D+f51TgH/Rdr/F
DdorUP74I9P827RXoO3IqOjVb2mvgJNJ/bHsOdrH/LcjBjONC0U592kfg/Y/
Cxq5UdrHwOleb4Md3S8Xi/C66SOqFdrHYveUlk3Vkhn+BlTmx74=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0A0w1Hkcx/F/Zk7mUvbkhIS1ojZpQ6RyPog85GnX7lqPS3kodSW3bpTr
VkKnLg816XQ6UbqKdOWuSyYqIdfD5JSYbi/duYqs0nBR5x6m33du7nZmZ+c1
n33/vzvLT9gkTtThOC7/7/c/n/SKOlkpPKxrh7d67pHt7vv6yLAtM4fghqnu
B38k62FkVNb2/vdkHixiar3Gy8lG2FhZ7TCQQzZBbdfx38bXk81x4uNrt3vD
yFaI63a8cXQF2Ro7hx59Ps4n2yDS1TMyR49sC58Z6YNOz+cyz4P2J+2T1G6y
EKq+mmGbi2R75BWKwn8+RnZAvqDSdGIPWYTY8uxXNenkxRCcDEsuVpAdYf9K
0Ml3Jzuhy9zg3jU7sjOmPJi+oWI6eQns4q0+wrgNswsurVt/37Cf7Apx853L
6nbyUnSbnfm14DTZDXW1XkqvUvIyvMsbSOdlkpcjPoU/diuevAJO4/cviQLI
7igam/910GLyByjwDo0XG5M9YNx60HorRwayBn95UfRY8NZqYFuFbJ5OBzPn
CZcaE0loHe2eONfSKC0po90L7y0unjNzG+1eiD1gPlK/hnZvlLrHCEWBtHtD
M1L2mYOI9pVYunzNOqkJ7SvxatRt4tYU2n1g0KO3W9NvzXYfGH9n2bf2LjPn
C02VsrqtkXZfXCnNrPIrp30VJndUa5JzaV+FK8Fm2s5E2v0gcjkWXe5Jux+6
3/HYa2JLuz+uBKQVWhrQ7g+jKnGGziif7QEwNNjy54SGWR0AxzNn5n3bQnsg
IvJ0M07V0B4I4VB5wdS9tK+G1sDsdU8W7avxYPbMegsV7UFI3Aips4z2IJQf
vxbo7kJ7MLJNS58eMaE9GN/kuSwwG7diewgE8XfTNj9gVocgye+TJQsbaQ/F
iUmF9k4VM0LxRtXXP383fT8UwrTspgUJzM2h6Bg6UHIimPow9LXv8u9dRH0Y
elrDLzboUx+GtIaxoLXDlqwPQ3tQu8q1n5kTQ3bK9dwfZ5khxlZnSYp6D7Na
jBRhpSAA1IvRq7J0LrOgXoLiL4oyjM5bsF4C1Zenp5fsYlZLME2PS7oQztws
gWRMvMjDjZkLh2DnoZ6tUdSH49PM4qtFLtSH41B3jkYgpD4c2tzSMrU19VI0
ZaVIJ4fnsF4K32O9iaODzGopqnOdLJ62MjdLsW2c76dIZ+ZkaDo+d5bSmXoZ
yh8a8nbyqJdBoe90+4YB9TL42KS+l1Vvzno5tBgZGjjLDDlWYdcL7kNmtRz+
0fVd+ZHMzXLwarTmjvbUR8A+pOplsj71ETiMNoWsZzbrI3Bf/vB622Pm5giM
HK5esESHegWGX9YdFb1kOxTwiEqWtF2lXoHcPZLrP1ymXgHR4FKrJ78zc5Eo
qTPxTOHT/Ujsb/WolXP0+yMxe0uiJq+T+kh0XFrW0NJCfRTERo3z2+rofhQ2
+67MzE+i+1Ewfex7JyyN+ihUbeDF6xZTH42pXXaqtVuoj8aE+lbFMjn10Zjj
dVCp8qH+f+Zi0Lh/UUGOM/UxME311yl6Zsb6GHS762ZI3jA3x2Cg8ILv8jZm
LhY60bKeJ+eZEYuvbuvP2NdJfSzu6W1fE2JO92PR0TRZfNOS7sehqWFf4X4e
3Y/Dwk3V22860O+PgzwhoD3Oifo4THNL0jxzpV753//LSgmDsQa/56n0PCWc
ZiXY1mQwK5WIGdjwaNiQnq9E6Hkh39WbuUIJ496TOwKz6d6//V+SIi1w
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd03lQ02caB/AfTMGLpVwVRJAAoggpCohFDvPlEjnkJoSE4C8HWOwiaMEV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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdzwlQlIcZxvEPBAyCRhQWUI4FMcrZiojlCDyAAmI4FhaF5drlMGmMQYlx
ZRRdjagJVECMdsK1YAUNUYsQRC2wgonEIwo6lJRWKRQBDXJlYmJR2g7vOx3Y
GYb5zX+f7/3WJjk9Mk1bEIQL//3733/+xH1Z4VCqtwLTGvX1f/Gz6flnb5EF
hO3f8nj4PvsNmHUZoa2evRDX25vTfyphG2Ol/7vpRw6xzVB57syPhr9nW+C6
z5DzhjC2GOLyesl77mxbnNS/HvbCkm2HFXg5tWcO+y1oNE9LkwaXk1fC1K4q
MLeD7YCQ4tFBk2tsJ+Tir8vdy9kumBxSZlQdZv8Wu0W3P93/IXsVrBr6H1yI
ZrsCPQl1qd7s1agd6YjJFrPd0OFRlFCqx16D83aO6fmjdmR3JOgZtQd3stei
w9vtpU4z+3e4VihxKDvD9sBGp6bHIflsT0w1fG+7Rsn2wvkVOdFfydjeKBX/
zfiVD/ttzBt45lzgwPaBp93K22Miti8eXl5a86kuG4i1rGm8OLhs2iogs/BF
0/r7ZMEP65yuHnp4lbsfvr7XXvBdGXd/rJ1YNnw8m7s/OvO0u+d9yD0AJhHq
PaUR3AOQd6r7yikf7uuQocrcf86R+zqIJ+ML6hZwXw/3nJLibc9tqa/H5zKR
vl87WQiEXmD5wLavuQciILGvoqiIexAe/dBlP57LPQjj9XAQKbkHY6Cicq9t
LPdguJkkWmQEcN+AvOKMYYUb9w3oiPkkvdaUewjOjVXV/aTNPQRa5e/XKMZs
qG/E8sQl5Y29ZNVG3Grbuv75d9zfgdndevuQS9zfgdPIvjsmn3MPhU9d/1mz
LO6hcB601hMncw9D/vGGW0nB3MPgmtP7dJ8T93C80A/62FrMPRwNN4yc/zGH
ewR2bbvm1/0v8bQRAW+DsntW98mqCDSHmQ9UXSRrIrDX83lFTglZkCDqeZ7W
8qO8l+DY4tBjVzJ5L8HA4e03JQreS1BR3rouW8r7SOSZ3+76xZn3kTht+7qs
34j3kZB4VAeZ91nTPhL+u8Z7H54kC1F47fK05mIYGVF44lJ/0smKrIpC/Wj+
b5bctaJ9FNxOL0uuKSYLUszfXZm9Q0aGFGXdq0VGQ5a0l0J9Ys6+oVayRoqa
4HTXL6rJQjQEtyzDPiUZ0ejICfvMfgXvo3EuJeyEXIv30eg6cMygqtuC9ptg
s1VduOUQGZtQ90N98REpWbUJTuGnJ941JGs24U5PXbfvAt5vxhHtcOW1m0tp
vxnXLZpKH1wlqzZjb4KOYetnZM1mSI+23NnpTRZicG+od6Reh/cxyLrrFbhL
xPsYJC1sHxBGltA+Bl6GU0/3qslCLA5kDittlpIRi8qWxm/fbzOnfSwSt5Qf
0FORNbHYObqqcZEfWZBhn6XpmfF+M9rL4DqVat6sJqtkuOn353m9LWSNDCVZ
FlvOFJKFODh0nl/0xh95H4cbxspM8bgp7eMg8hRnGGaRNXFo2XjWoT2eLMTD
6sajXzpCyYjHsV37D3o/EtE+Hpdvm+pOysmaeIxdjoxa5kMWEtBsXWRWok9G
Avp1T/58+ZQJ7RNw6eJhK7O/G9M+AZOndWwG7pOFRGgc/Ye/yiAjEXOtdKQ3
OhbTPhF2Sq1C9xGyJhG12z+akO0mC0k49c9crUdji2ifhD/U6js2PSarknAh
aCRSacj7JJT/qc0kr5O6IJ/ZxfKZe8gR/8lqWdcgWS5HbFJLsCyG30+OVYFf
XAm5S10tR2+R+5ruQrJGjr6/vFI5riX3yCHfkfDvW4NGdF+BtJJK7T1qslgB
y+rJzvi1ZCjwsf2JwuOXFtJ9BTLtb/6aFk5WKTD/g0XPju4gqxWYEiRT8p1v
0n0FPvDPb1xQvoDuz9oLyaj2tn1vZSt9X5yMiddXYw/OpY5kfFTt5Xupgu/P
+r4qGUvN+gYLjvP95Jnvo5nlnmSc9Wv95lvz+XQ/BQHSSXfdQHo/cQqc33aR
Nj+hjhQY/WgsGhVRl6fM/H2qFBgublFuHyKrU2b+Xs2s5/WkoKjT4NfKNQZ0
PxVb2xqaHlwhi2cZqbPup2J+hqvXg4P0PFUqvpl4M0q2w5Dup0LmWBD8/W7a
a1IxWtv+KstEn+6n4nDBVs891nPpfhqsg0M9RF/q0v00SHJXOepk69D9NGiL
HV4aVE/6Tt9Pw4jHy9f+Lk+mrUqj59BH/X//B0AZ1sM=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdz3801Xccx/Hv1mIblSQpXS6ZrB9qRPrphSji+nnJdbuu6xpLZqKtLPlG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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0H041fcfx/EvUpFRMpJ7lcRmUj/U0bwQkfv7g4NznHPowm9y08+iX51R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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1yQlI0wEYxuEpmZEGRYLmualTGyLeM0t9nXPObU5Tg4UiHm3LA5dZ6GB4
VEwsFUsjNSfNMnQoiGnBMslMWgTaoZAdlhV2KGamghlY0f/74OXj4cfJ1aQq
rVksFv7u36fLMHXyOrb74r+WY066rC0eXfJhzEKH4ZX++EvyDuQqxibqRsi7
ka4y6se7yA6wNg3wVy+QnZA6vND4uZTsijcj682RmWQ2phonJmVxZE98ma/h
pPHI3mhruR3t5UD2gbfHUJR6k8vYD3ln26Nn5sg8fH28ojNayP7INqSJDX3k
ACh78/KHL5ED0W9mhyrKyUHI1FjM5lxyMIyZ08sCKTkEioaNofAwcijS9/S2
+LuQw7DfeERiteXNOBx7RVN+Hz6S+Vgfk3bve0iOQNX1nCrHHvIBvJ+L97Wp
IUeiOKuysq2QfBDud0Qrp9LIh8A7wc0pjiBHYRdftZrEJkfjbqlVlsqGHIOd
7ld8exa9GAN2Tv1nQmYYVwEW9bYV2Rj1WDheVZVoTdRjcUM3P+t8kboAgncu
9S1a6gLUleU/9VBSj0PT+e8pChn1OFQXNQxOh1IXIrAkrzXfmboQowkWJ7MN
9XhoDJNlDxY9mR6P05fZzY/mGLNE4GqUXZxR6iKcy9BmuV6jngC7H9Wm3xXU
E9Ac0Bn0SU1dDH5d/WtOKnUxfgkXHMrCqCcic9D9yYAb9URwXcW2a7bUJchI
OXwLGxymS8D3ue9v/40xS4qoVnnl20nqUjRFZNxc6qMug6Farn/WS12GaZ3+
eXA79SQU2rdL7jVQT8LWMV1Bt5a6HOUFwoUODXU5XhR5VGSXUE9Gdu1syLia
ejJq2W6bP3M4+AO56v81
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1QtUjPkfBvDXNSskhIRGF0RbGyql1pOIisx0Md3UNNM006RcanWw6l27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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0QlQznkcx/H/0oFCuiilPNmiiw5RiU+npOvprqfjeZ4WSylyZCT9czQT
Eeu+c6thU5GS4yFsNneOYiWDta4tDZuw7O70/c6Omnmmec379/n//s88Q5Xp
YVN6CIKw69/Pf//5T1ayx3qnhhW61DYhNLCv4/Q3lmQBepZlZcdusXth0xr3
6z7H2DrwHZ77aMx2tj6M+u2Mal7KHoS9F3xc+s9gm6BjVvEn60C2Oa7PTndN
c2FL8Nji4YISE/YwVJinV7xWZ1tihYtOyf1X35OHI2ZE/pbkW2xrlKXVPtao
YdvihKTc2mg32x52dU9N3uexR2F08CzbGalsB7ildp6tDWM7IuqzfGOkG9sJ
dgeC419L2M5o3Pxcd4kWezSK37YV+bUPI7tg7tP5az7dZo+BToFnvwE17LEo
a5iZfHQ/2xVzqm+Ps1rBdoOV5M3d1nS2O140OnRaRbPH4e5pxwW/ubE9kKpu
KEZI2OOxLGT+5ZV92ROgN9C8j1q7BRnYNslhwC9NZBHwnn08I+0Sd09U5mdI
w8u5e0I9oHl61g7uXlgULrE1ELl7od+QMasc5Ny9Yba84bJDAHdv2G/Td861
5+4D7YRhCU3G3H3wXqY1sVGTuy+aMxYlvX4loe6Lure6PiNukAU/mN3r7CMt
5+4Hx/s3so9v5j4RntolQ9QXcZ+I+k3G4/2nc/eHqcYPDdIg7v7wlhVnXxnJ
fRKOPei8MMqQ+ySUKpdlWvTgHoCq1cE3x78cSj0Ai8+ndBT+ShYmY9DVyhEB
5dwnI/y5hv2QLdwD0aq4vdJ3OfdA+NnpSX+cyj0I6wo6DC55cA+C6ZOcIy22
3IOhun9hXp4R92AUDNV9vLgX9xAc3uda9PwPc+oheFN8dtvoB2QhFKWH5xrO
OEVGKJx7Tv9ktpXPh+JewcFPO7LIqlBYFj0bOl/Beym++IyvOO3FeymWvhfL
dw3jvRSate9m6PTgvRRpoSlN13eb0T4MNjlf4wdPJSMMbe6C2hljshiGKXkH
UjJeDKF9GL42Oo/cVkkWwmHVvLfJsIiMcBy4my55sp4shsO+3aJ/Ygzvw7Hk
WuHJCZ68j4DbS7XhGz+Y0j4Czb21HO2OkcUIpJz9oO0tklUR8DbZEJXrSxYi
EavtdP1Kf95HIiWzNLu42YT2kfDIDnwYkk9WRaK+cJ5RjpwsROFm1Z13jR8G
0z4KB3vMupy9iyxGIbPdMzDcnayKgprNIYdej4xpHw21rVWJ6+6REQ33m2fn
+Ewli9EYGeVs0f7OiPbReK/58sC0MrIQg9pA/aTIPWTEILt4wxiZB1mMgV1u
U6LWu0G0j8Ep11ZkrCULsbgje+z64stA2sdi7MWcrJ0nyWIsZu5TaualkVWx
uHhub6NKSRbi8ODr4BrZXN7HoX5E2lGTz4a0j8P5gsIBeyW8j8PWkM5H8q/U
BRn+TDh3QnGJDBkW5nw8l1LCexmq62Mro2PJKhmuescYPftgQPt4mPkHuRqW
kBEPn+0tutX5ZDEe1rKxF8+EkFXx+Nm0QWL9XJ/2CbAp9LvmVU9GN4sJkBY4
2KgtJ6sSsDU49+OTPrxPhLJOctJJ1KN9ImKTzvvHxZDFRGhEflfRVqtL+0Ts
d3OqO7iDLCTBxtTQaJqCjCTMKSvND104gPZJqDFev6O6VYf2SdDWO58560V/
2stR2bZmpPHVfl02l+OvvtW5n0dr0/PkWLOsZ9WjhD5dlsvRafvTooOpven5
cqx9MifLq0Ozy0VytFXc/DvbgLpKDouAjXfjDtG+RY44m7X+1xZo0f2Kb22u
QEpd1ZmGajIUMPtytX5sG9+vgNOqNx2eKr5fgbqLHplzT/ai+xXfvp9K0e3+
bucFJf3+6nS/8tsOJfLWprhlmdH3kyvR6vrxi5e9Bt3f7XyRErYVahouq+m8
qtvzW5T0/p0Tuu5PhlbPIwtfrnvbZfNuRvK35+XdLHY7X5RM7/d7l1X/+x+s
jJtF
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1HlYzfkeB/CfCCkyRVNUTomihFISTW9b2qhO+yl1Wk7LOSeuxhLq+sm+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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1yw0s1HEcx/FLuqSHk7DSA8e5TuSpPMRdPsdxHu4cWaZoSrmEnQ1TkWUl
yUOprS2KCdFZa+Wph9WcktYsyjyskW6RGBmlXElP6//9bd/99tr7++XGJu+K
02OxWAF/599PL6qucks5ezP+a9r7jaGyw3WSz5iF2Wat/G032QALx6Urwx+S
jaAwd14ovk42wbtImycd58hr8bg5uHE0hbwBOxJfNU1Hki1RlfNosktEtsLe
tvWCozwyDzairNRf+mQ+Dre/aOufsmEswOL0fQXj3eQt0E7IDefuke3BM5kv
8SwnO+COou6AWx7ZCXF93J/8JLIz7g4e6bUIJ7vAQTuypsaTvA3zNTEmH3jk
7bAfz4lnc8iucE7i2R6a4zF2g1I5ojc+SHaH+nnDtY8asgcMMqL8PavIO7B1
VGs8doHsCdeI4rOmqWQvZP2O46oiyEJciXTU6YvJImScmVGdsCPvRNGSTZ1J
q8neKMt66sDWWTMGCtXDL4U9jLOBYfvlltEt1MVw53BqjtVSF0MgMuIrL1D3
QQtHmalKpu4DN11DvCiGui8WbQxSV0io++Ik536xypq6BE7fUri5HOoSDLXN
e9XNWTHdD/UtdwtLBxhn++Gy/R2d7VPq/jjlYiRsrqbuj+Z1YyGjedSlsDg1
9Mw4jboUWotlfSax1AOw50uialpGPQBObjeiy8TUA7H/c33uQwH1QORLKyYM
jagH4fRAconpDy7Tg2AmL0vXDjNmBSN6ljOk6aQejO789vc5D6jLkDYvKzVT
U5fhZqux8HwRdTkkjXYHrTKpy1GX8PU0O556CNjme3bPyaiHQHzLuqDJm7oC
5eZTXnagrkBCbH+/QkQ9FJy4i44bPBgjFL3qq12tQtoPRdIl6fceX8aaUEi/
v+Z/8qP7MOitcF1eK6H7MDgctb3dS84OQ/TSytL1tK8JwyrrSzPVPlz8AfoU
HYE=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0wlQVFcWBuCHDpsQFXTYRGgWI7hgANGAEH42RZqwN3vDo+lm0USikIig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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1zQ1Q03Ucx/EdHkENJIQQEIFNGThNQxTH4uEznmEDxp5gm1hnaYqdID5w
BuZkMisxSA80JB4D0/IRRSm4JgQeR+JDPqASp1IcSDoePXahZdfv+7/73/9e
9/m/78tbm6VYZ8PhcHJevf996dGfqBVWvuaP/zUacXDHrRK3ZwJmDoxifvLw
b2R7yIuWu5xoJr8JS+K9uzerya4I/Synvs9IdkeRiyEyJZPshYbQ47YXU8i+
2GZJHpItJ/MRFWLYusyDvBBTNqc7Rm3IAkxuq4xIGPZjDoCd9/aCkatkIUrW
fGnsayIvQQTP9evxcvJS5A1dXsQ1kN/Bw5wYrwcfkAOROdl8dn8MeTn04r1H
fReTg3BqQb+PrTN5BWLXO1onJhYyr0RyzeSp233kYARI3Fb2/kJehVKRoDa1
nizC7Rqn58c+J4dgTtrJ8q7tZDF6NAkDCzLI7yJrY162MJwcCun9tHtN/uQw
TAmXWDu55HDUFVTnmywLmCPQPTyjGLlJBmQO6/3CLjAbAPFYblnjYdolmGw4
kPNdLu0SrDgzLajT0R4J/uzgfc5xtEciUFajDgikPQoz12ZvrfCgPQqWl+NH
wuxoj8ZkyzmO1cJnezQaH989lHCdmRMDnlel1niW9hiUCzeZqw7SHosX7T99
UbqT9lh8O+5r80cG7XEYWFy2uCmG9jgcdt6laPGnPR7Vh8b22DvSHo/wtVfH
GiZ4bE+A463+zPw7zIYESOzkY/WXaE9El0TN01XQnoiHPe2rTfm0S2G6sOWB
8SPapWgJ3GypT6Fdhozzc9TWENplMAXvlnzjSXsSpri1/H+mfdmehNHpgtZd
N5g5yVCcyQpyaaY9GVLOnGvc07SnwOr+w16U056Cp4Ot2Xl5tMsh1sZ3KN9j
hhyq+W8d6Y6i/+XIu2o+2x7AbJZjxH1VqY8n9angXrFV8W2pT8XNy9nDb1h8
WJ+Kwiud08mtzOZUiIOePkmqZuYoUOa9qXRWDjMU6I92H+FIqVcgyFS5dYcD
9Qp4BUz/OXfIm/VK9F1s0z25zwwl3NpOZF87xmxQoiNh6V3jAWazEqrUqsai
DOpVeNRoMfdoqFchv/P6QJCKehV27/yqvSSYehWW/XrjpHBwPuvV+NFuTWFZ
PzPUsHlZ83PlbmaDGn3vZ0/9nslsVsPPqu9tAfUazHoxKN0hoF4D+w8fl9bP
pV4DpZKrqu31Yr0GjwdEPP45Zk4aOiaclLotzEhD9QvRflEhsyEN/bKqc8Wg
Pg1F1nVH/36b+nR4HlMentpAfTq2SZJ8TNupT0fFScOjnhjq05FlLDC0uVCv
xcffx18UeFKvhcNGrxqnedRr0XR+85EwD+q1cDJ2zRjcqNchrnhe6QV76nXI
cu/6tPZ16nW4cen2ZO/0PNbrcPwv7Sfh48wcPUqKrye5TjFDj+eOzXtmVlKv
h9m2e9HpCLqvR12H67M6Ed1fjZe5GzpFcrq/GtI743Uer/p/AbMm3ks=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxdy39M1HUcx/EvsisHejT8EZfHj4O7g5GeYSEgXLw4kJ8H3I8vQzmhwTQs
tsCKobbsm5ld0Cq9muIpv4KIyx9jCTcmHedE8McxlCWlJIEcd+fUNLLJakm1
Pu8/6rN99tljz89LVlFt2LaI47jiv+8/Lx2TrS226Ylo/KsHqRXV0pAv7yuZ
OaxYxjUeHCcvxl6HrPGnfvJT6OvdXv5MB3k54iRrpn9vIIfg7kJUaGwtWQr5
8sCKtSZyBFJC2suCM8iRUElH4izPkuUYNrU1XQwmK9Hieq8ya17BHIO+iKB4
0y1yLIq/C5t1DpNXQ5tg3RRjI6twvH1ip+dj8nOofNhp99WS4/C60jdQv4W8
Dpb1ARnqZPLz4KK1Q9VR5BfwclViUnggOR5uv6ljg3Ny5vWY9Kg3z46TEyBK
ML97/VtyIvzlZwuvtJOTMCo7/vmCmbwBt3mPLbeGnAzlB74mgSenwCu5tV+k
IasRLFKNtUSTX8TpX+teE4nJqQj0Xh5x/RbFDBitB2a6bzILQP87jqm3B6in
odLxaHJPK/U0dPl2jwa8T12D70cWUj6toq5B30lvaIeBejpsh8WlH62jno4b
km9unJdSz4DVGzfT6089Aysl9tCwe5Gsb0RXvjHRfpVZ2IhrQ+ctP/RSz8QW
X1DbwRbqmci27P9qpoF6FvSXX1p6ahf1LAz96W6cKaOejb2v1sUMp1PPhsu+
0/+cinoOujsGnc1S6jnI1DQnL34sYz0XBWVP/jI5wSzkojIobeBHJ/U8PB4q
WaLqoJ6HqDMBxQ311LXwTFhW1b9JXYvSNvWOeZ56Plydin3TSdTzMXbpjZu7
FNQLcMfv+tyiIOoFqGhWntLORbBeiP7y+3zvOLNQiPhN1tiLg9R1OHD6kIf7
mhk6GH/+xE9hpv86tLwyu62nhtmpA7dDkA3n016PUfeJQfMG2uuRWlvv6pfR
Xg+dw20qj6S9Ht75C6tTxLQ3wHV4QFvzIJztDbC2ljwsGWMWDGgSdW7d7mB2
GhAmrAmf7mbmjLg9VVzX/QXtjViZpLlztZP2RuR0nbQpjtLeiNKn7Ydaj9Ce
h/zaAp9upj3/3/8Cj+DWP/akVtOeB8Red81btC9CnljSU/Uh7Yv+ty+CWlO+
77OecPwF/ndotg==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1AtQVPcZBfArRvBBEEWWhxCQl2AUETUK8jggb1CWlQUWEPZFU8UEwiAo
GrmiYmyVaAWa0qqAOimIWBRMhWpWWqtIRCJVJ6RGqkgAlYdBKQaw7fB9nZE7
s7Pzm3PP/9w7O7ML1GmyFD1BEKr++/nfN18JleWLjusvxIQGfJ/s7KjxeuZE
FvBbM6OvzdvY03Gn+dmUmfVsY0R+bFnpfYI9D3WfnpRN2c02x5Hmu80jGrYV
PIdW7/xLGNsW331T5fGOG9sOxYM7HFLM2Q7o+7H2k+3jjmQnrHxxymdZJ9sZ
crslja3fsBchalnJoZ0X2Itx06zgy7ZitiucE6YGBuWy3XAhRuX9oYa9DDVd
2aWNIWx37LNvWXjYlb0cD+SzmrZYslcg3WPBdDc99krcOvXw+fIeB/IHcDiT
cyu/mb0Ku4aedhrWslfjnvEOddBhtgcq67OC12azPRHw3m/+nZrMXgM3bVy3
gz/bC68PGUWvcGN7ozAh5ly/BdsH8S++/8BxzJ7si+z9rpEXu9hAvEfv5kN3
ySIw2tJd6FPPuR+Gbj68U36ccz8ceUd/1dK9nPvj/q03XodTOfdH0yYxdGo0
52thNXZZUuHD+VrcsI6V3XDiPACn9vUPz5zFeQDSjt3ObnxmR3kg+o5dmB7a
ThYDMW7SdPBsPedB0PtFxbYDxzkPguVBVZJhAefB+GOli2zHVs6DkenQdS4y
ifMQuNn0X48O4DwEI+e6I7SLOQ/Fu0+zdF/P5DwUI/YmXpe7FlAeBu/frc99
cJsshsH+T0v699RxHo6RLwrnG5/kPBwmsobypM85j0DEpdGlNVmcR6AsrK3z
fCzn65BoUF4yP5DzdfjEPqeg0p3z9Rgy3VTmaM/5epT7BrocHbWlPBL7Imu3
Of9IFiNhalkwcKWFcykqdjeYbT1LhhSRLR2yv/+e75ci6kPja0V5ZJ0U+XrP
ZZlq7kfhD4+kn/fKuB+F+Jennr4P7kch/1f2+9615n4UkuV+eQ8E7stQdPdS
e+01G+rLIEkruedSSBZl2GNdLLeLIutkCImwLi9aShY24Oczl38aH3mP+huw
8IeT30lKyeIk6zagJ9Nz7782kYVo6IYrfrZw4340+p6EX3QYtKZ+NH6d95HJ
ritkXTQs5ks/W3GALMjxy2ihNXwrGXIsqE70OerJfTm6m2zSO4etqC9Hytqw
lbYnyEIMRosHvfemkxGDXqnjnVYnshgDRavF7NO986kfg6tWV4631ZOFWCS5
HTUtO01GLLZ9H9XxWSZZjMXsV/UhA6ncj0XMfZ2+9Tzux6Fni2R1Wpcl9eOw
xvBN785SshiHwQfhF4u3k3VxcKk68qg+gywokG/ga2u0kPsKyL3atQ7tFtRX
oDdvj5NJNVmnwIuTCp2NO1mIR9t1q6ntBmTEoyTYPcs8lvvxCG1IM/tpCvfj
cVsbEqGpMKd+AvBwV8KcIDISsPfNP2X6M8hiAp5qz+e9qDKjfgL63TzXnR8i
C4lwnNES5/qEjEQcKAqeZtNKFhMhHapt+nMA9xNx9a+n9e4puL8RBVm5eV4/
SKi/EV81m00bVZLFjdi86mMjUU7WbURdYo4ydgtZSMKjsn/IjS25n4THu+c6
p2tMqZ+ENZszvlDWzqN+EnTv+z+vyiALyej76G8vl78yoX4yjol3c2ZXk8Vk
FDmOKYQTZF0yOje7eI7tJwtKuDgYdA4Hk22VaL5YV5GRzucp0VOc4XfWl6xU
YsO9AwfvWPP5SkjkdQ01qXMnXKpEgLhtbNn+ObSnRINl4bFL/cYT7lBibreu
8YyMckH19v22Kvq/I0OFJXOcB0u+pb5SBUXJ2TLTxWRRhe0u10dSIsmlKhia
NGan98ymfRWkWxY1v7TgfRXmPJsnGZAY0b4al6979jk/NqR9NWzGbzWvHphJ
+2oMXPh27FPTGbSvxo1r3tmZ9dNpX42a6rRC1wRyqRr9Hq/H/V31aV+NnNzX
V1MryR1qfNlwX3LTahrta5B/JNVzh40B7WsQsSr3q8euU2lfg9h49+oMuze+
E/saLD/0fNhPNzJhcZJLNdCzXfR61pnRCesm9Tsm5YKWnvfVhG21b58HLf2+
evT+2refT5zkUu3bezotvSddHZMspNB+F+1PMiZZmfL//n8AsYbVWg==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1HtUzAkfx/EpiTFlW6oVpVG6ju3UUlHo040o3abRvWamGRxly22tiOkJ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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1yn0s1AEcx/GLcGNJOlwSHXe0ywrn+ek+OE/n6Wj9gfVHnuJ0GNNYWtp5
GDFh/knUJSOloY7NTJpK07jklI1VrrGS2mWySFat3/e7fffda+8vLy0/KdOA
xWJJ/u6/S5Pac1vYbuyC/9KLPayvTbC/OjNm4WlJQ/XmDJmNokX9Ad4Q2QJT
Sm1YbRuZA8/skIYWJZmLD/qtRzW5ZDusHHJpUsvIRxFVkNVZ6kN2xJuF7tlW
BzIf/KzAySITsjO8H7+MWfwmYHwMOmVPWd4rshCC6dI+o0GyK24lPdlovEE+
gcnRVmGxkuyGu6GDc0fkZHfkFOoSuDKyB3LM2HkSb7II+X1ulzrsyZ74OZ+t
9jMke0H8+d36+zU+Y28US9r7r7wl+8DIxrfCZZTsi8sBvsPWd8h+cJ/aEQiq
yf5oGC6y48rJARAtaV7sTyQHYmVuReEqJgdhcFe0WiIgB6MS/VVqM7IYmGte
/bHpxBjYaLLlJM8zLgc4HKuw3jHqIXj4uq9Z20U9BNnR12duNlIPhadVUcnQ
Beqh4CZqSwpSqYdBl/slJwXUw6A6U6FaEFCXYCfdQjhjTl2Cw1KNTe22I9PD
MSBdnfRaYlweDkvjg2v249QjoLE0LHjQTT0Cbb3GiuAG6pGwVZ5vkZRRj4Ri
b5ZYmkY9CtM6fb5BNPUoZKdLh+s9qUdjeV2YvOJAPRpVXan27qbUpZCvi/g1
eh7TpVhut6n//pExKwaWGc+C26apx6A7tG6XP049FnJNx8nT/dRj4db2a3ak
lXocFHvumWRWUY+D8rcq5Woh9XgEmLI0lWepxyPfci1FJaWegE/H95WfC6Ke
AH99R+0pEXUZtu731Hm5MoYMap7/iJZL/zKYP7/YmcFmPCbD9oDaacKEhz/o
Eg/v
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1XtYTfkeBvClFEqILjY5tus0SaMS0lSvbpSY3X3vrrt2u9vebqWijFku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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1yV1IUwEYxvGDk7HSYImCRqlbay6zyGnOj7k9m27TrBBpUtQwh6nJRNwo
hnVh0UUa2EVlFCVSEbY6iBSzgct0F6sWUem6qDGSGrZgy4LCs7ao6LwvPLz8
+EusfS1H0xiGKf27f5/ukOtm8ZiwCP+1ov1cczvwOibnzeCHYOLYaJAswj67
u6PaSxZjxJ4tjI+TszF/5555bJici56pk6tDdvJG+JZymg+3kguRjL9tbK8l
S/FkWb6cJiPL8HK905m+hiyH78Opmbb4Ft4KrCvs3WRcJBejSXFrf9c0uQTJ
VCTXep28A2UHuhrY0+SdGLBd4EKd5FKcSO9euLKXrMRxm9ppVpLLsGde9W0u
h1wO91BmOJWQ8d6F8cxfHkmYXAGPwLPU6SerMBvYnuTukiuRUaC5pB4hV0Hc
GhEVOMjVCJ9/5I8eJNfA21xybUVHVsO9O2b6vpVci23d7i+vssgasPkdiSJu
M28tXlj8/aowGQh8WrsYneU9COj78u4LJqnrsFAeuhy8Sl2H0IOMNs1Z6nrM
XBwWP7ZR10P9MdkuN1OvQ3TUrmO11Otg7b+xwaGgXo/feTLuSBb1esydOdfz
NCXluwES1lIZjPEeNMCSWH0ef0/dCKWwiuHeUDfC2fLVVfGMugkDTawr4qNu
wjvDz4eN09QbIHL05ku8UvwBfY7JDA==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1y38s1HEcx/GrNaP8aGYpkR/nVzfkqDuOeOFcOsUd2TqKxjTGOYU2wqjl
x6rzo7pWVm6q6wdHpqbJCBfRalMsLXX6i/ltlkSo1vf92d777LHnXvaJiqjk
zSwWS/z3/v304p7Uce4auOC/5gPdcvomOmecGbPw+7mPq3SYbIiLlp9sT78k
b4eXjTHPSE22gDzmqUBXSt4JYd/oyeoMsjU46spOjYxsh8vLHmkJAWQHCBsb
S1OdyI646iKY9TEjO2NAn6C2WnJi7IqpwLMJ1l/IHLSaXzCs6yG7YZ/3gyUf
LdkDSqNmtraG7Anr+ZUyXRGZi/48lc4oheyFA4ViQXs02RuZy6quST/yfvBk
Jh472eQDaLQ03ZJsROYhK1NdkD7ryJiPvmub6u8OkH2wbdLls6CZ7IvzbEVk
w22yAC84Coznk/0gW9DsCj1F9oeuou2RXkw+iLeLGrNoLjkA7rc82Q0W5ECY
t7TWCjfYjAG985rJjznGRcA5dStPM0I9CAbGu9k5PdSDUOw4jtrH1IMxMSWs
SbxOPRg3bOfcv+dTD8GcVa8vX0E9BCHxWtlsJHUh3ii/pdlyqQsRpD/xNW8r
9VDIFheO2y06MD0UMYvZ/NhhxiwRAvPrQ/o7qIvQtGFctP6E+iEMvq5ULauo
H4JoPJfvn0s9DM0lSVKXeOphsN17RSkXUT8MXmxvUgqX+mEoeA/X7llSF0M7
qRo988ue6WJ8WD1W3jLEmBWO7Jj7k9x26uGQmLo+/qKlfgRhFfbF3XXUj6A4
9ad8/RL1o6gaS4q+k0H9KPI+Nva/j6MegVqneptQMfUIvKudlm/xpB6JsvnB
obg91CPRbj5SuHXdjukSrKYHZCn1jCFBh8I81qmHcZEE16t3GBi2MX4lwUx3
WqqZhvZSVIXdFJbeoL0UXeLoTpNq2kthNe1Rk1NOeynEK/15nBLaR0HHL3gm
KqN9FJRjTfImpR3+APwXK6A=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0H001Ikex/EpitZzCXkoIi258pCV7r35kPRAwjSMwcyYoehB5eYW2+7+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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0XlUVPcdBfCnImEJsgiDgMrIatFjBdQIaLggAoIgO8MwA8OwBrQRpS5E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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1HtQVGUcxvFDXhAVxQRBIeO+tlxkwcUVWngQQW4Ly8Ky3BYMJVjlYipe
wMsGJkgCCpppSoQOCmgQKmmKLsLiBIKUJBkoXoa0BETMlGwkG9/fP56ZM2c+
87zfef87FgnpssR3OI5Tv37//9ITU1XOL53IwxsNe15qG9pjOmDLzCFAvFrF
7yJPAu+g8OKKBrIBdJ9X/b6pnGyIlK/5vLF8sgl+KaoQrEknm4HTE4j3R5PN
8UGaTnikN9kSosIx0xw7sjUK2rKjbAzJtkhZl30lcdSGeR4KTD7Zouoj81GX
JE/oaybbY2VF78vOY2RH/Fhp2no4n+wEbfv47aIUsgCNhgeczeRkZ+wwqNIT
iskucNTh8jxsyQvg3pW93k2fLESW6tubX41aM7siMzPPSNVHXoignRkbnK+Q
RTg4y3dVSi15Efbp8LjHxWQ3eCeWXTfKILvDKmN+p76c/CEyF/canVpEFuPm
2vNz/S3IHgjJPbxSqU/2RHeTukfy1IoZGCxR+XTeYFYDm83iPRMu0+6FpAdC
N59q2r1Q4rK+43Ah7Yvx2NBixGYF7Yvh0GXv/kpCuzcSawPVZnzaveF3fd3G
9qm0L8G2gZGiYyOWbF8Co66dp/NuMXM+mB7YKnikpd0HozFb5WdqaffFjma9
Nv4h2n3Rv29N1tls2pdiXvG54gtJtC9FS9DC1IEA2v2wf8YW2QUe7X6YXb6j
RahLuz8GU682fTlowXZ/rDFu+WjqdWYuAH891HmZ8QPtATheeXFp/xHaA2F1
frLi83zaA/E42NemdTvtQfjpwgPFs7W0B+HVC6e6xuW0S9CwqeFAr4R2CfTW
Xt3Z4kR7MJ7Zl6mPGNMeDK15a9mtKbSH4F1N9RHeU3O2h2BP1tj+1XeZOSlU
IyYnN2uZIUV1jsBuZj2dl6LUo2bChD3MGikSalcGjcujPhSj5eJzBRuoD4XU
yeR+j4L6UOj+a+/+zIP6UOzWv9UxZE69DIrYvj+7JlIvQ3LTXZ3O0fdZL0PX
N0Uznp5h1shQU+I0/7c0Zi4MaVmxWbclzAjDpXmRf9ydTX0YaqAszOyby/ow
DE3be9zvFDMXjuHEg4auVcwIh+PmQ7evfcysDkdmUm99jzn14RjqD6y3fvIe
6+WQ1/OaF/3MDDkMpcom43vMajkUe4O1+d3MGjnqlhsfCsylPgK8qclPTiqp
j4DelLpdq7yoj4BrZr/ttMnUR6DyhaLT7pwZ6xXw853ZevooMxS4/BkKutOY
1QqcOCDaPihm1ijwa+GMG3fMqI+ES/SN5l0DpqyPxHBe8r1GLbM6EtNyt1UY
FDNrIvH3rOxxyTnMXBROh3AJ1nupj4JDesXWdkfqo7DNYWzAfxL1Ua//z7Ns
qyZTHw3p93yLhd7UR6NjZpnB6P05rI/GKS/d6cW7mTXRKC0TRi0TMHMxMJnz
HS/nzmzWx6D6kVdS8ALq37ImBpYbHh7tdqY+FtlV/QYlMmbEwlQblj4+gPpY
eKXauKnk1MeiVeeaGy+UeiUEHdZn9V/Q/Uq4/pN6qaGGWa3EfatGl9KLzJq3
di4OG1OLRBlh1MdB7OYvsFxGfRw+LfyiJ+kE9XEYE6ZuyW2iPh4OuZLKyjbq
41FjN1e0ZJj6eDxfLmrf/Yj6eOwycrJe7TgH/wGr0g0F
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1HlQk3ceBvBXEI9ySD3AKmgARbdYuqIQCggPhxUQuQ9JOJKQsB3Q0vUA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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0AlQkwcaxvFwCLLEYgUjWhQIiErRAqWISskDxgsFTUKEAJKDsDCeeHEI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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1AlQlIcZxvFPPMItCgGUwwUUFBUtBBXB8ACCAnItx3Iuy8JaUwrIpQHU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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1yw9M1GUcx/GfQXUNgSIqieP4KxEzwJMu5U74cMfJHX/uP8dIlMbAMMzL
0E0g6AT/NcEwRQ6om3LVNTrgxjIgxB3TpciM4UTMZrfizjUgDWpdkEa2nu+z
PXv22vv5RJeadOWPcRy37dH976Wztbsr0frES/hfv2WIIbwvuxfPzMFkcyuP
3SDzsFok/+nvEfLTWNHtSgo7Sw7Fu6ky/fnD5DXYPnMix2Ei8/H43risqkJy
FETjy7EeMTkGqoemT0YjyHHYt/7BfoEfOR6eh0cMYbNrmRNw5p29/UWT5ERE
SoID+74mr0Ng8vmM6DPkJOzM4604DpNT0H/qrZLd5eT10Kkk79tyyUIYenYO
dm0gb8By6Zfq0FByKmJDFpdsD+KYX8Ut5YvyshmyCNbLF6wVV8ivYfxg2267
k7wRmbzBpbhW8iYMB63xL6klpyG8kK92vUEWQ9Sc87ksiyxB3bmyyKFXyJvh
0dxtHXuOnI7GD4tuBy/FMmdALQ6t0P1MBoLbVdJbV5jNwHCEQLSnl3om7D73
dvcp6plAf5VdWkNdivmWxmO+MupSPPuHpaRZRV2G1quK5kQhdRmsw40KXxD1
LNQdL+7Qz8awnoX2+uM9i98yc3J0mjd2Bn5FXY5e3oESrpP6Fuzpkzd9bKa+
BZrXr1m+20E9G349FUX/5FHPxjpLbY4xjboCKXJu/y9R1BWwKAIk5X7Ulcjz
tZRMzESzrsTVZ/z/4k8yczmQLDSnfz9APQen556vbu2kngu+VT2XcIB6LuJr
DF2GSup56Aqb9Kwoqeeh4eDg5kMi6vlYzmhZ+CaWej7kq73yrQHUVXhyrLp+
cS6KdRV+mLt8kXeTmVOj3BJeKrtIXY3RYsdRt5O6Bn/+ODcvOskMDUavvT1+
9xD912CqXhiZvI3ZpUHTqpHwGA3ttagMajCFiGivRV1xunbqBdprEeIdNooD
aa9FurWve+R+JNvrUF3l5gsmmKGDLconvuRkNuvgqRH+XlvN7NKhL9wxcD2X
9nrc3heZ2iGgvR4JFn9h+7yA7fWoOuubcnYzu/RYGPIm/foRM2eAQjF7gdfE
DAMCeNyOIQPtDfisbNd1SyztDTi3KdoRvor2BbiT8vLarHsRbF8AcW/atGmQ
2VyA5IHM4QYns+uRK1XeGw5mzgjppze/OHGU9ka02aezJR20N+LOmDd/+gPa
G2F7qs355nu0L8REkuaS0h6BfwGW7ng/
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw9zQ9M1GUcx/EL9BQKPHdMGCl4IHAe/TmREBXiAxzHycHB/UVHKYIUbBIN
dUEF3YGkFIEIeXKcKGwe4uWUPwK6hCttIKlAySIWhEiguaaBS4jgqvV8+23P
fnvt/Xz2CNJyVBkOHA5n7z/n3z99KecbRHXcAPynJxGpN6oKT/7qz8zBjbyK
I38MkldCdspmf9hJ5qGqLOOBQx3ZDfLmhapjRWQPrHjxq77lWeS1uLOqwhSt
JK9HyrbBljWhZB+08LU+1z3JG9A4p2oPs/sx+0PieiK36ReyEC9vvH17xS2y
CA11v20520p+CeKeQ0PGWvIr8ApZkt80kMVomppwn3ubvAlfGMfXCRPIQdh9
/Pg3FzeTN6Ms9WhToAc5GC1plvZGDvk1GO/tCt77cANzCH73tixI+8lbsDa9
yhDaTg7FAaWzy6CZvBXp3SdeCC8mb8OkJIkj20/ejhqdX6VjIjkMS2JfoTCE
HI7n5Pvs+wTk13H4UrWj63JyBK5aeotV077MgDBL7+gxwKwHxrp51v5W6pH4
3Jc3OlJJPRK8x12jlkPUo1BgmCwv3EM9CpbvTjrYJdSjccE4/F55IPVobDRN
Jz9eTV2CeW657tG8D+sS3K3LvKOYYObEwMSVFEhvUY9Bx/0MuFyhLoWiw9P+
oJ66FMbZ7JnOY9Rjwa+s7NLmU4/FpNuU2CeNugyiPtuqTBl1GdxcfDslwdR3
gKuO//qeO/UduDxVmX/zTwHrcSj50L7GfJ9ZH4cnfp5e2V3U5Tg8e918ppm6
HLVjy0rP1VCPR6m1JPPyu9TjIVCOyvakUE9A1LOx8XciqCfgLYPoUpCAugKp
B3YGqXnUFYiZmRoMfbqe9USktwxv0o4z6xMh6P0+26mDehLK6ht/zqtiRhKi
/S5qXHLofhKGmtuuJuxitiVB2/HGo6FI2isR2Ox+sDCA9ko8LzpYxvWivRKL
ceH+E3zaK/HX3Y6wb5fRXoX60Tnt+/3ebK+ClGf+2NzLrFfho6ERYWENs00F
6+TMRJGemaNG9bmcaf5+2quxHc7xtVraq9Ezkr74WRjt1XD6QZMf6097DRas
12aX5r3YXoNqpzb5mWFmvQbiqZJPF3uYbRqYtvbldn/JzNHipyOWK16naa/F
j10BdlMR7bUoaJC2VpTSXovVebnPxGm018FgNBQLUmmvw4CIe76Nul6Hp64D
upVv0l6H3guBLvMK2idDI/hkgh9L+2R84Gw1V7xK+2TUZxnW1VK3JeOUxfva
7iza7/z//b8BviCSGg==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0WlMFHccxvFFQVkMAhEFhMJyCFtsCYIcAsLDDQsi7HIssOwuiKJW2ChQ
iFQ5yxXiAS2NURFUSkRqW0u5lUUhosWWU6lGsRwSqIiowXhUatP/70U7yWTy
yTPf+b8Y0wSFcOcyDodT+uH+50lXbP1Z66oVVvhXzzxUDk6anvzTkpkDVfmu
pHuDZHW8ObfOPLqNrI1Nt6PeW54l6+L3Q11z20vI+uhvXXBMPUA2Qr1tjLgk
mszD49HmSnuQzTB9WaBebUW2wC/mihIjHbIlXGxaCjJeb2DmwzOry7donGyN
84vxlrxe8ifo7RQaezSQbRDT4f3g2nGyLcZT5LVJ6eRN6EDKoIOUbIczabw7
d73I9ljhFpVQxCdvxlSy/l1TTbIDdiqUi53zFsyOWN6ZNlEwQnbCp4uTLpw2
sjNUAgZnik+Tt2Dk8VRmcAHZBUsLM90TKWRX6GrKE6ojyW5wdKzJ8PQgb4X7
54JbCRvI7khM7f91SIvsATufo3mlz82ZgbJzcsHUXeYcYE705geTLto9UXg1
PLiljnZPDE9u3dNZTrsXXIaupHRn0e6FR8teXrLfQbs3+rSO5JoF0O6NA2N1
X/Y50e6Dza411gvGtPug7JpN4fL3Zmz3RVZHfmrtBHOOL95xNST+t2j3g17L
q53uzbT7Qb9pTaNqNe3+SC0xVjlVTLs/FlyGeQ0K2gPguNut3T2U9gAU5nn5
NDvSHoit+eIqngntgehT2F2QcWgXQPLbrlXnZ03ZLoCySqNp5hYzJwgXNVcG
5dXTHoQBs6L53mO0B+NkipZ6fg7twXDce1M7M4H2bWjO+PHSRBDt23AnqNao
z572ELzi+qeb8GgPwcNHidZGXNq3w/qdxuHv5nhs346115abSG8zc0JhXpcr
c21gRijKaurGMivo/VAspfRr1uUyK0PRtthUbruX+jCUy/M6E/2pD8P60mF1
Uxvqw1AZ0hOdq0d9GG7cdOHWzpmwXojhmqM6L35mhhAmG/VzZzOYc4SI7Ojv
lwQyK4WQNi99bbWKehGeuPEfvhg2Zr0I+7yOXVldw5wjgjjI701JKrNSBAHf
kNsjYOaEQ/f+uM4JferDEXWZnyC+/BHrw9EqmmxcX8CsDEeSt+RMlwMzJwKr
jFcXctSYEQHFWlX9O1eMWB8B08+qK3YVMCsjoLNvRespPjMnEm+LsscadJkR
iY16A31qi4asj0SX0dWqoTZmZSQMpv0GwvYzc6KgMl/xbknGjCjEfxXeFGBO
fRSKn+5pGRpaz/oo1I5nv9TIZuaIYdgjUqgKmCHG4ckLgessmHPEWMbNdy7h
Uy9GhNu9RIt7BqyPBnf/Nu2pLmZEY8kh+VDRdeacaDw5ObGjtZFZGY3ZvHzL
NZeoj4F0Wp7GraA+BteDdWURZ6mPwboHHm1pldTHIHC1d4vwOPWx/+tjMVo5
6vFxD/WxKDN1vf66g/pY6GXNO+emUy9B5+T3nX84UC/B89M2fi2a1Evw0FB1
TGNRn/Uf3rdVMbmoRX0cph/3aL80oz4Og72jdhf51Mfh2U8Dfx1aS+fHQaex
3eC4NfVSBLYr9F6oUC/Ft+KZ3U4e1Evh4zTvEGNDvRTlc7v5h12pl+Hpyu6K
M37Uy1DlOVAaIqBehkmf4uyn8dTLkHuk8n5SA/VyfNN9uza8nZknh/e8wCov
n74n/+//kstRraYU3jhI35fj5ohfcpcTc7UcmclHndNFdJ4ce0d81U7rMD/6
0J/YYlkkofPj//s/ePF4Wz/bX/SFAf4GYVc4Bg==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0ns01HkfB/CfWlK6CFvEMoR63J5dsuSy3lNqJTRuuZsxN1OhG3bRatJl
9VTqpM2WtqYWtVp0W6Tb2FVKWyHV82w3XTxFS4rKpWWf5/T5/jHmnDlzXuf9
fX/f8zvnZyleHiIbxXHc5f99///LPjGlh+z268zAB3X7JGVNyi7usiVzeN/w
3M73FrMubiW+PvbJWWZ9dDckzPzPAWYjdC0qaMjbyGwM259kWQ1JzGZwdXfP
/SGUmYfqT2XjBlyZrcCTj+ppNGW2xnDknLqj2sy22JWSkdXcbkOeidp36Qd1
m5ntoL/xxUTPamYH8N6c6+nZz+yEh/aOy18pmT9Fla+jqUEi82eIaBxT8j6A
2RlufiZZE5yZXeBoX5FUbsw8Cxsep/yupcXsCp/7bRme7dbkz7HMXm3Wf43Z
De13K5MaTjO7w6pYHXf9IPNsZLy/eKoyl9kDB447Fe5YwuwJtSBQcVrA7IUS
K+/S9W7M3ph8zlfqacz8Bfas579O1WH2QZV41qodXdPJQK/f8i2nm8hKYFfe
rGOelSznQ6K2bAwqZDkf96ICOj0yWT4Hq/z9Yp4LWT4Hczs2BV7ks3wukrKC
pJH2LJ+LN65/tRw1ZLkvjnW+lBqOYrkvnNM3Ce0fWVE+DzxZRrJPPVk5D8lF
tt8FFbN8PkLu6UjDtrF8PtS/qe3rU1n+JcpyvfMMl7D8SwQ2+uc/FbDcD228
kD8HvFjuh9V5bt+0mLN8Afh2/3oZMpblC5DauKelpN2Scn+4cCunhzSRlf4Y
zJRvMKlk+UKEPtNxMt/D8oXou/64+lIOywPQKra8sl/B8gBYyTICpvBZHoid
9zun/2nP8kBY9L6a4m3A8iD8pfPdXJshHuVBcLE5OON4N5lbBC+9AzfMG1m+
CGviLos3VLFcgEDXgtrOEjIEsHf3KNLdxM4L8MzobGPKCrJagKkxLW82h7N+
MP79yvPFZnfWD0aRfNhFYsj6wbjqblF4nGP9YCx7HKST3WFB/RCYTT3pM/Y6
GSHILuD3mZwiK0PgkNsUePJrsjoEwWVlvQX+rB+KCzMj2x+ZsH4oyoRHHiy9
YU79UAwnx6Ud+YWsDkXFoWCfC3vJXBjuDi4X/iOBjDAU3ln/YLod64fhjJFp
yRf3PqF+GITLJn9msJPMhaNtX6XRkDMZ4XhSqb++azxZGQ7R+fqPVH1m1A9H
9Cj/Q+vOkLnFiD8ean9aRcZitLyYVG9SQFYuxoTnru+0V7P+YmztlxUOOrJ+
BBpn+eXO12L9CNg4Fa84+9yU+hHozlU8rr1IVkcgfWvaAb/vyVwkvH+76lW/
hIxIXKjJ375Ln/UjETDGRfvq/WnUH2EuCkL9pmfcSzKi8NpErZ12nKyMgkRQ
Vv22lPWjIBinte2hlPWjNY1odDxp7LMwZ/1oeNZwZd5DJtSPRtXJjR4JlWQu
Bkvf5/xSt46MGCyY1tJ0yZesjIHpZo+Ke9asHwNx9bHZv941pn4svg+wDtHd
RkYs8nltzwV8sjIWZqrkZ2HnplI/FmkDMyquNJC5OLyQnsh5/TMZcdDN3m7a
ICQr47B7e8qK0o2sH4ftN/W3/O7P+vEIui6oO6xg/XgU33t081bfFOrHw1K1
zoh/jayOx1K3lInKcDInxPkaA93uXWQIcWnrr1+lX2B9Ie7Wn/rjzmrWH2FO
BGWaT6+HLZknwufTxv74SvUx3SdCm/but1UFZJEIgytVawMVZKUIDyLzvt36
zuiDVSJ8m1n3dd8+sloEv4475yduIbeKkLcirTQmlMwlwM9/6x8nosi8EUYC
cuoj4gYCyKIEGAvPNufNJysTIPinyirVmO0nwKE7r7xquyHtJ6Arue6Ny1ty
64icE2OM+Udhdc1knhjxufPbvevIEOMH5a3MSeVkkRjzvJ+uuTFgQPti5Mu6
82MPk1VinI+1qTXXI6vF6Csak/2UT24VwyeiNzbIdDLtS6A3uiyzI5/Mk2jm
kODKbevewfFkkQSOk2e+2tukT/sSrD7q6XPiEFklgSDJ7uobE7Jagqi9ZQc/
diC3SmDJT9ycNkTmpJo5T4oK05+rmhdOon0peoZqonLGUC6SYpgLHhalUq6U
4vaEXEV/0ATal2LHhtHVD+PG0b4UFkPXrrp3k1ulcNnW+Y6vHkv7Ms2cJ8O1
ad0du/TJkGmeF8lQeFuvv8RVj/ZlmnsqGS5f9P4qtUaX9mXod9i55nAS9Vtl
mO6/+3b0ETrPyTXv48lxsWdSaPTK8bQ/wiI5IqKdy1dZseeXj3h+OYqu/Jiu
lzqR9uVY8FN5qc0+Ot8qR9oZgZd7H+VcouZ5XqLm/0MiMtcO1C4r1aH9RBw+
c2dKg5k27SciwG1t1ROn0bQ/Ilcn4pv9N89OeUR56whzCs3zPIXmfVDQ+6lF
+wp6/mGfD/sjrFLQ+8jRvgIvZw8MzXH674e8VUG7HPc3uBNcVA==
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd03tYTfkaB/CVWyiXqChNbeUaoiiK9C0kdC/dd3vVbnfb7SS5m2mVx22O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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0glQVFcaBeAHGFFBNBFakK2DoiCIqFFkGw4Q2WVptmbtjW5xKAXBuBCB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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1y39MzHEcx/FTXZeKwllS4urUqUQpdSiv69eFrr5d6wfnR0ttUrmRathU
1CiNxh/0y4/QTyGs/Lgr6opqNOmHsES//6D8yLHGZL7vz/bZZ489Py9BtFIe
q8PhcAJn7r+XjqKyxP6ivh3+a3LjCmMfWd6kLWsOuIrlCqaHbIAOG26r9hHZ
FFNuJ14tvkzm4/aVurJLWeRF4PKT4tYmki3RJ7huJg4lL8PsvIRTQx5ka/x+
1SbVCMhC3LWqMWnjkW0xX9TmUf55OWsRth8o9NzWR7ZHj9dbiVhNdsRYr2th
RAnZCQefuRt2nCKvxvTrTx9aksjOcG9orwjYSnbBw+REgak3eQ1WnX9/J1pE
dkU4T3shfA7ZDecmVdOlX4Ws12Iw0qw4rI/sjmHewOdxNdkDUXXFNfeuk8Xw
SzEJv5VLXoelGkGTKJm8Ho9PTvD0FeQNqJ3WtPp6kT2xS6sajLEheyFzqrNW
aUTeCB3GafzlpA1rIOppZIxlF+t0QK/6eaheA3UJTg5PZJ+upC6BT+bLB9wz
1L3RZCTc2Z9C3RsuQnG//Q7qPhD5i3tHpNR90BPLySxypO6LIO/X1xbwqfui
N7uIydVas90PVytynlm9YZ3uh/0VB5asbKHuj+jckRKDG9T9IYxvfPL9LHUp
UvdadImPUJdCt904NSGGegCY1qpdO0OpB+D5L719MRLqm/DDTNyc4kB9E4p0
o5LmWVDfjHNl3aqfxtQ3o7OxY+nRCQHbtyD3j7rOoZd1+haMmIcXzNNQD4RR
FDdDeId6ILrC2rUviqnLkBGnTfyTRV2GxvKxNMNY6kFQH1Lnv5NRD4LegMLt
mJh6MJQ18bxPrtSDkc/nl+aJqDP4sifzcORC1mDAi78ZNDyL/jP4WF9inDS+
7L8fM/jpavcttZs1JwQ1aSaLRzWsEQLlen+G18Q6PQT6UpmoupH2IcgJjdjW
rKK9HBLz+7yqetrL0T3KKE7X0l6O3c5DcwvUtJej6rizw4KZ/hfkHjMi
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxV0HtQVGUcxvEjui4OFKBGgEiwCBEgqHlB0OXhDosit2XZXZZVSBKJSyKg
iLCyVlYIguaq5QZUSoSkwiiyqSyCU0IwgKJOoancJi8QlpIiVNP7+8Mzc+bM
Z573O+/MsUtIj9xowHHcrn/f/770yKsrnbUz38T/GvXWPdmbL3rgyMwhrJG/
+lAP2RBXUy1OWOjIphCb1RgLy8lzUVDcn+7zIdkCmcpk3ZIUsjVyrmxUWESS
bZFcr883W0EWoP3w1c391uQFcL2jdR+ZTnZE8MnZUW3DDsxO6L0ulFr2kJ3B
4031XzlHdoWJJIBfUEl2g49hS5uiiLwI75g1fDf9ffJiZKSX/PCGjLwEr55V
VY+D/Da2XRFt2OlEXors2RnbhSbkZWjnDyac/2MB83IIfOfcmbhJXoEXK40F
hy+TPVCYHda3tIa8Egs9zJIea8ieEDsUtfYUkL3w/f2WvGcJ5FXIc3oRUBhE
Xo2YBoWiyo0sxI2D4rECc7I3XnvoV2Ly3J4ZGOsNOnqhj1kFfFlb6FHaTLsP
TAO5T/Z8Q7sPKoITG37eS7svtGWTudu30O6LM11fXVokpd0P5td9X/lgFe1+
uDhRdnGhgHZ/PMyyMddOo90fheWhgbW/CdgegBEV77yrnlkVgKeeM3ecOEZ7
IHbcMTxgWER7IJKLtWuvZdEehNc/bxswl9EehAEEaluFtAej4a007RZH2oPx
u5tz0nIe7SE4Ulj1nuK+HdtDMJp2Wf1tOzMnQlbRE6NNp2gXIfF0aoDREdpD
YdLu7DGhpj0Uyzwdu7o3074GFcM2/k2xtK/Bzt01nZOgfS0c5BcWn7OkfS1u
PPJLXD+N9jDUusoTuUe2bA+DRtxfHdHJzK1D7das3i4d7etwoTRnsLCa9nDc
LJMOSfYzIxwlz6zmBufQ+XDoNV+UaaTMTeHIKM5rG4ijPgJ7rH5pNBJSH4FL
kxF2hs7UR2DrUIVklSn1EbCbHLl7pvsN1keCH9qedrSFGZFIC0+52VnBrIpE
tMJaqslkboqE8nTBYzcR9VFQd6zvNPKmPgo/Bk7NaLSnPgr1Nk+jS2/ZsD4K
SflJg8f7mLloDJzd79etYUY0hJru5Ck5syoa18Z91e6gPhr6bAvrQifqxRgd
OdYsGpvPejGubVUvUbcwq8TwLtXZKKuZm8TYUJq13D6NmYvBkPF5Pc+G+hjM
cJ+jNu6yZn0MBvfa/pXbzNwUA5mBqHKXjpmTYNav9SWV+5ghQVCDa8aJj6iX
wGferhX8UOolaJ3ImH1kYh7rYzG6Z9NdfSszYjE2nlby00lmVSxkLqXBHduY
m2JhPizjbAXUS9Exp9z073tWrJfCMiXEYN8DZpUUM1yqFhveZm6SwqKhdbxZ
x8zJUBnwvD1nN/UyeHVdzPRPol4Gl47hWWFh1Mugr6tsme5MvRyWQc+tFnhS
L0eoV17I3ATq5Tg2n1fcE0O9HP2ftaiH3amPA7/v01N1jyxZHweDWWqPj52o
j0ODzqAzk099HNyEAbeq3qVegdsC/3uN6+h+BXxSHTyTxdQrcFx8vX5ZKvUK
bH52b+NkFPXxGDqVt+3PXOrjkWKdvvSQF/XxqMvnte50oT7+5f/DKV82lMgu
rivPzaJeiam79o1lB6hXwl50sFdWRf16rOn7eqZ/jRX+AWgwFaQ=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd03lQ02ceBvCISEWgXhgVUSKIqEiqIrCAlCdcxosSwpEEgQQIRxnE5VAb
lvqDKoNWsRSs1noEXLUFQUU8OMZGFAEV1FVRUTk8GIvUC08Wcd3h+/4Bmclk
PvO8z/v8ZpJMj0j0V+vxeLzLn9///2SvkKLCOXsNbDCgF+5NU6vSi7pmknkI
2r7JYONV5pGo0AXlPTvNPAaXbY286gqYTVEu3+6p3cQ8CQVmJ5KWJTKbQ+Cz
zuQ7GbMAmfH3al+LmC0R380XCayZZ0B6f+v5W8bMM6HOX3/JoceaPAuGpu8+
et1hnoMpjb+4vDvLPBfdt9pr8DuzEM/EXxeIc5nn4WFK5Zlba5nnY1Xox/YF
IcwLUOkeeDvHm9keKYkp8/bNZl6I5DevR5aNZnbA5IaWUlnPDLIjNiyxm821
MTuhIb3rU24D8z9wR7hdT1PE7IzGc/b96zYzu+DpZlH/4yRmV+yt8iq3kTEv
grVznfjMImY33K1OvN82i/lrJMikmQ5GzO5YUxitKH5uRQb+aH1+qucumQPe
7vz106gqlouwMLVP5FvIchEu344c3ZbFcg/krZ+PsjiWe2DOlKcrXKUs98SD
+KdxCrDcE6t0H5fqrFnuhY681KzyUSz3QqP+sJ7V3ZaUe6NO57vc7j9kzhtm
PW+OfqhguQ9szxbhu/0s90GNU4gXP4vlixFw6c653GSWL4ZHlnhXXAjLxeji
d47igeViXKy7e8lpLsuXoFpibRJmxPIlKGndsj/h9XTKl0IqtbTIvkvmlqJu
V8bt+nMsX4YON77z6kMsXwaha0F3fg7Ll8Or3DbSMo3ly9GV9d+0plCWr4Bn
UGehWMzyFbBP6fwj1oblvjikMpZXj2W5LzR9Z03yewWUfwNB+4cLRX+RuW9g
dyXuyo2LLPfDMt64K0ZHyPBDg1oiKt/BzvuB88/wkXBknR9WzXvusjOZ9SX4
16628A4560vQ/MTg3g++rC/B98Ivsn4Vsr4EWZutNppMZX1/zPjSrUH+1oL6
/oh/lfB4Yx2Z88dF49wT8SVknT/edIi7ZT+SeVIk+ax78uBb1pfC3qamuc2S
9aV48FNGZf+badSXIiM9q7nxKpkXgN2x+7Jti8kIgF2o2fWftWQuAD/J3Fe6
R7F+AI5emKgztmL9QEyfZTxe//1U6geiMemVXuIBMhcI3sJ044drybpAbJ6x
Ido4icwLQsGOLZP+XM36QTid+zb0oTPrB+GrKbvqkwxYPwimLS816y6bUz8Y
5U0dZ6+mkxEMC8liuzZHMheMqhcpO6yGk3XBcFBMWvPk0RTqy/Dq/aptDUfJ
kMFzSav5syVkTgb+EwVPYEnWyeDVmtY//qYZ9eVQ15zy23eSDDnW5BzXalLJ
nBzSMNMft4vJOjlsm54Y+vqyvgLHvx9Rm27L+goc/TAux/LvydRXoKW/8enj
JrLus9Up06L0WT8E2N3VUlpBOULAv+9emfIL64fgh8M14wPDWD8Ew0yze/o/
TqL+SpypnhYwvJuMlThQVrs/+zqZG2LdSsxpLhk3cifrh+JYaWK+MIT1Q1Ei
bulMGsb6oUjttTnScHEi9UMR12wtNMol88KgSbFKLBaREYaaLdvG7rckc2Go
MJcn1Fuzfhj2Gu84aXqDT/3wwUY4ctasz1zUSubCUfW4zLztIFkXDsP+fENX
R9ZXgkt1f+0ykyxQQro7f4pm/gS6TwnJlvm2+htNB6xUIrMuOLR3OZlTove9
Z+HauWStEuOMJlZ3Vo+nPSXk4TVihYzcrkRYts9fbufJPBX2cDc1o0vJAhWO
vTLbp4klQ4Vlx18ulTiRlSoU/Lt+wrbmcbSvwnk/3W9cJVmrgu1U/uQYFVmn
wgEX+/pDe8jtKjz4zdHhbh6ZF4Eb6reGsyrG0n4EZvtamXonkBGBb1PenxwW
TOeVEch8FLH10WHKuQio9xzUS9OStRFIPnZkk5+GrIvA1OK+5pVO5PYITBfF
bErtH0P7kThotbRlYQ1ZEInU2fl5P5eREQm7sbNe7rpGVkYiudjVvayQzEXi
6T2bDV9lkrWR8Azocxzh8yXtR2Jstyn/BZ/c/vk+N2HAn50mtB81+LwgCr6H
c7zVJyhHFH4Xnau9MJmsjIJJ0gLX65lkLgrNJtmxH3zJ2ijoCeb0GhUb034U
4utPn7leYUT7Q8xTo7ZntFTxTzovUMN+69/vRDpD2lfjxfFrH9MnkJVqXDt9
8/Xt99Tn1Gg0e9GVP2YU7atRX+u2NqVyJO2r8dakIqPPge5vV0NhmytuWsf2
owf3BUOMaOQ+TE7zePcF7UfDQrzCmV80gvajkZUb75JmQbk2esh+NOYe1zdw
zKG8fUifF4NDVbf4F83Jghho1veejS8yoP2YwfcpY4bsD+lrY5C+93o1v2M4
7cfQ/1ef9mPADzxRdSxej/ZjB1sQC6PhJZquvGG0H4tgxYLSJMtP7gP7sfT9
9g2Yi8Vyp/WnHgppTxs7eE83JG8fch8vjn7PPNqPw3Pn3n4PYedAjiFWxtFz
83j/A03qZcA=
         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0glQVdcdBvALQVBARYgIgiwKiIigqIAL8oEENxB47+Fj58JjeYBjEAwK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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd0AlUzWkfB/C/RLQIKbToFhGlKFEiX2kTqW63bvfe1N0r21DEYPhPJa+3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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJxd1H001PkeB/BfSmwixKxQhvKYbLEUkjchz+v5YQx+jEFpsWJrSU26PdxK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         "]]}, {
        RGBColor[1, 0.5, 0], 
        Opacity[0.2], 
        LineBox[CompressedData["
1:eJw1yXlI0wEYxvE5Y2qkmI1SZ6vZdHktj3lkqY/z2jyXgZq1jGrhRDCmKJnJ
JBTxaH8UilqBQx3KMKZhIlgGkWLmlQOJWITHygNUrLQyKvq9Lzy8fPgKrhZl
qtgsFkv6d/8+3cUeve9jjgj/tRHz6fWA04dVb8YsbKUtSm7Nku2Rb68Wjg2R
nTGSPR+g0pO5yNluyGHXkl3B5tUvjKjJHijQ7bUNp5OPo/FhRasmmOyJy18s
c2Z3shAFuYb2cDbZG/yiXjHnsxfjk1AHfZ0XTZJ9UTxb8Sv0KdkfNdpc7rEW
shiVofqSPC05EA5RS7LnKnIQesMEOSo5ORgr28bE8QByCEolLYc+upAlWP5W
ZZrdETIOhWQl5s6uhRyGkKzpU7pRcjiUtXbsJgM5Ap2WJmNjPfk0Rvyk60YN
ORLP3n8vib9EPoMJl6rQmVjyWZyPLK/miMhRqD5qzhZzydFYDaxI6N45wTgG
/NEQnZ2VDBwYco5YmmOsBcxcvjLyBfVYcNR9qTwT9VgUXulqe9dKXYrg9jDz
hXLqUvAyS23F16nHYWMhb+Kagnocdie9nMXh1ONR+dtgsvCpx0PU3RJQY0s9
AckPFMLba55MT4BhvTSPPcuYlYhHXV4H+wepJ2KqblTj00E9CT3eW1rUUU/C
E+Owu+wmdRn2ue6XK5XUZTi35RG9KKUuhz5/zAof6nL437vhMcSjnoy1+ZrN
GQfqydD2DvaYbamnoG9PNLq8KWB6CrqdNt74WRizUjHtxjX8HKeeit23RS8F
w9TT0NrkWPajn3oaCoubreUm6unIGuQd2e6gng4ba5kNr5l6BmwPDyg/1lLP
wCu3zlzHBuoKOPJ5OwF3GUOBqVWZTnNfgD+7eAaq
         "]]}}, {}}, {{{}, {}, {
        RGBColor[0, 0, 1], 
        Thickness[Large], 
        LineBox[CompressedData["
1:eJxd2Hk4lekbB/DTVIYWaUcax5qk0K6kb6lQkX1Xx76e42xOUqOjkfYYbUbb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         "]]}}, {}}}, AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesLabel -> {
      FormBox[
       StyleBox["\"t\"", Bold, StripOnInput -> False], TraditionalForm], 
      FormBox[
       StyleBox[
       "\"\\!\\(\\*SubscriptBox[\\(N\\), \\(t\\)]\\)\"", Bold, StripOnInput -> 
        False], TraditionalForm]}, AxesOrigin -> {0, 0.}, AxesStyle -> 
    Thickness[Large], CoordinatesToolOptions :> {"DisplayFunction" -> ({
        Part[#, 1], 
        Exp[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Part[#, 1], 
        Exp[
         Part[#, 2]]}& )}, FrameTicks -> {{{{0., 
         FormBox["1", TraditionalForm]}, {2.302585092994046, 
         FormBox["10", TraditionalForm]}, {4.605170185988092, 
         FormBox["100", TraditionalForm]}, {6.907755278982137, 
         FormBox["1000", TraditionalForm]}, {9.210340371976184, 
         FormBox[
          
          TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
           SuperscriptBox], TraditionalForm]}, {11.512925464970229`, 
         FormBox[
          
          TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
           SuperscriptBox], TraditionalForm]}, {0.6931471805599453, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.0986122886681098`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.6094379124341003`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.9459101490553132`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.995732273553991, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {7.600902459542082, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.006367567650246, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.294049640102028, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.517193191416238, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.699514748210191, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.85366542803745, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.987196820661973, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.104979856318357, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.903487552536127, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.308952660644293`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.596634733096073`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.819778284410283`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.002099841204238`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.156250521031495`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.289781913656018`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.407564949312402`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{0., 
         FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
         FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
         FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
         FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
         FormBox["\"\"", TraditionalForm]}, {11.512925464970229`, 
         FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.0986122886681098`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.6094379124341003`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.9459101490553132`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.995732273553991, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {7.600902459542082, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.006367567650246, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.294049640102028, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.517193191416238, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.699514748210191, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.85366542803745, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.987196820661973, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.104979856318357, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.903487552536127, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.308952660644293`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.596634733096073`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.819778284410283`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.002099841204238`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.156250521031495`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.289781913656018`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.407564949312402`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}, {Automatic, Automatic}}, 
    GridLines -> {None, None}, LabelStyle -> Directive[Background -> None], 
    Method -> {}, PlotRange -> {{0, 1000}, {0., 11.512925464970229`}}, 
    PlotRangeClipping -> True, 
    PlotRangePadding -> {{None, None}, {None, None}}, 
    Ticks -> {Automatic, {{0., 
        FormBox["1", TraditionalForm]}, {2.302585092994046, 
        FormBox["10", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
          SuperscriptBox], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
          SuperscriptBox], TraditionalForm]}, {0.6931471805599453, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}],TagBox[
    GridBox[{{
       TemplateBox[{"\"All replicates\""}, "PointLegend", 
        DisplayFunction -> (StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[1, 0.5, 0], 
                    Opacity[0.2]], {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[1, 0.5, 0], 
                    Opacity[0.2]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
          False]& ), Editable -> True, 
        InterpretationFunction :> (RowBox[{"PointLegend", "[", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}]}], "}"}], 
             ",", 
             RowBox[{"{", #, "}"}], ",", 
             RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]}, {
       TemplateBox[{"\"Mean of the replicates\""}, "PointLegend", 
        DisplayFunction -> (StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0, 0, 1], 
                    Thickness[Large]], {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0, 0, 1], 
                    Thickness[Large]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
          False]& ), Editable -> True, 
        InterpretationFunction :> (RowBox[{"PointLegend", "[", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], "}"}], 
             ",", 
             RowBox[{"{", #, "}"}], ",", 
             RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]}},
      AutoDelete -> False, GridBoxAlignment -> {"Columns" -> {{Left}}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.702030141207961*^9, 3.702030175836627*^9, 3.7020302378821487`*^9, 
   3.702030404975274*^9, 3.7020306630798283`*^9, 3.702030767795496*^9, {
   3.702030806322263*^9, 3.702030849085206*^9}, {3.702030920292411*^9, 
   3.7020309411688843`*^9}, 3.702031248885127*^9, 3.702031312736662*^9, 
   3.70272927107448*^9, 3.70273035679858*^9, 3.7282167747683897`*^9},
 ExpressionUUID -> "b9f9446b-d5c9-4912-85eb-cd1adb5caf23"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {{}, {}, {
       RGBColor[0, 0, 1], 
       Thickness[Large], 
       LineBox[CompressedData["
1:eJxt1kms61YZB/Aj2ESssniLLFAxCKGAEDKUIQylh7FhdssU4AGm7Xsvr+2j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        "]]}}, {}}, AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesLabel -> {
      FormBox[
       StyleBox["\"t\"", Bold, StripOnInput -> False], TraditionalForm], 
      FormBox[
       StyleBox[
       "\"\\!\\(\\*SubscriptBox[\\(P\\), \\(ext\\)]\\)(t)\"", Bold, 
        StripOnInput -> False], TraditionalForm]}, AxesOrigin -> {0, 0}, 
    AxesStyle -> Thickness[Large], LabelStyle -> 
    Directive[Background -> None], Method -> {}, 
    PlotRange -> {{0, 1000}, {0, 1}}, PlotRangeClipping -> True, 
    PlotRangePadding -> {Automatic, Automatic}],
   TemplateBox[{"\"Over all replicates\""}, "PointLegend", 
    DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0, 0, 1], 
                    Thickness[Large]], {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0, 0, 1], 
                    Thickness[Large]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                 ImageSize -> {10, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"PointLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"Directive", "[", 
             RowBox[{
               RowBox[{"RGBColor", "[", 
                 RowBox[{"0", ",", "0", ",", "1"}], "]"}], ",", 
               RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], "}"}], ",", 
         
         RowBox[{"{", #, "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
         RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.702030141207961*^9, 3.702030175836627*^9, 3.7020302378821487`*^9, 
   3.702030404975274*^9, 3.7020306630798283`*^9, 3.702030767795496*^9, {
   3.702030806322263*^9, 3.702030849085206*^9}, {3.702030920292411*^9, 
   3.7020309411688843`*^9}, 3.702031248885127*^9, 3.702031312736662*^9, 
   3.70272927107448*^9, 3.70273035679858*^9, 3.72821677477839*^9},
 ExpressionUUID -> "b9f9446b-d5c9-4912-85eb-cd1adb5caf23"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example for population with standing genetic variance\
\>", "Subsection",
 CellChangeTimes->{{3.7020278724611797`*^9, 3.70202791065306*^9}, {
  3.702728279140745*^9, 3.702728304660205*^9}},
 ExpressionUUID -> "285463bf-09f2-4908-ae56-38b410115d95"],

Cell["\<\
Param\[EGrave]tres et initialisation de la population\
\>", "Item",
 CellChangeTimes->{{3.702030543335829*^9, 3.70203056723954*^9}},
 ExpressionUUID -> "e16c65ad-bdc9-4a16-bc34-9f9f600ce930"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tmax", "=", "1000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"No", "=", 
   SuperscriptBox["10", "5"]}], ";", 
  RowBox[{"na", "=", 
   SuperscriptBox["10", "6"]}], ";", 
  RowBox[{"nrep", "=", "1000"}], ";", 
  RowBox[{"npopMSB", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rmax", "=", "0.5"}], ";", 
  RowBox[{"rd", "=", "0.1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";", 
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"2", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "5"}]]}]}], " ", ";", 
  RowBox[{"\[Lambda]", "=", " ", 
   RowBox[{"2", " ", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"allelesFGM", "=", 
    RowBox[{"RandomVariate", "[", 
     RowBox[{
      RowBox[{"MultinormalDistribution", "[", 
       RowBox[{
        RowBox[{"0", 
         RowBox[{"UnitVector", "[", 
          RowBox[{"n", ",", "1"}], "]"}]}], ",", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"IdentityMatrix", "[", "n", "]"}]}]}], "]"}], ",", "na"}], 
     "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Mutations", " ", "effects", " ", "on", " ", "phenotypes"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"xini", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"0", 
     RowBox[{"UnitVector", "[", 
      RowBox[{"n", ",", "1"}], "]"}]}], ",", 
    RowBox[{"{", "na", "}"}]}], "]"}], 
  RowBox[{"(*", 
   RowBox[{"Initial", " ", "population"}], "*)"}]}]}], "Input",
 CellChangeTimes->{
  3.7020282178346167`*^9, {3.702028301162031*^9, 3.702028311145953*^9}, {
   3.702028351497774*^9, 3.702028391465397*^9}, {3.70202851192909*^9, 
   3.7020285698320217`*^9}, {3.702028700055134*^9, 3.70202870253507*^9}, {
   3.702028823494272*^9, 3.7020288784544163`*^9}, 3.702029117011627*^9, {
   3.702029172739476*^9, 3.702029173395179*^9}, {3.7020309643725033`*^9, 
   3.7020309944199963`*^9}, {3.702728071109846*^9, 3.7027281083729777`*^9}, {
   3.7027281390617332`*^9, 3.7027281558616943`*^9}, {3.702728409350193*^9, 
   3.7027284182467017`*^9}, {3.702728471653756*^9, 3.702728472133784*^9}, {
   3.7027285213665996`*^9, 3.7027285229346895`*^9}, {3.702728553477436*^9, 
   3.7027285606298456`*^9}, {3.702728860150977*^9, 3.7027288665983458`*^9}, {
   3.70272890373447*^9, 3.7027289725024033`*^9}, {3.7027293592075214`*^9, 
   3.7027293596875486`*^9}, 3.703308525693863*^9},
 ExpressionUUID -> "97e2cfff-73a8-412f-be2a-eb1c0fabcfc2"],

Cell["\<\
Simulations of the population at mutation selection balance\
\>", "Item",
 CellChangeTimes->{{3.702030587687306*^9, 3.7020305894320927`*^9}, {
  3.7027283831086917`*^9, 3.7027283989315968`*^9}, {3.7027288078279843`*^9, 
  3.702728810564141*^9}},
 ExpressionUUID -> "fa894fc8-4133-444a-adf9-10eaab9c2c79"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xini", "=", 
   RowBox[{"FGMNCst", "[", 
    RowBox[{"xini", ",", "U", ",", "rmax", ",", "allelesFGM", ",", 
     RowBox[{"Round", "[", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"n", "/", "2"}], "*", "\[Lambda]"}], ")"}]}], "]"}], ",", 
     "npopMSB"}], "]"}]}], ";", 
  RowBox[{"EmitSound", "[", 
   RowBox[{"Play", "[", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"1000", 
       RowBox[{"t", "^", "2"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.702028020381042*^9, {3.70202805732902*^9, 3.7020280913876543`*^9}, {
   3.702028177258871*^9, 3.7020282003470497`*^9}, 3.702028246266089*^9, 
   3.702028475593751*^9, 3.702028892853054*^9, {3.702029051252069*^9, 
   3.702029052342152*^9}, {3.702029437393388*^9, 3.702029458193593*^9}, {
   3.7020295407366323`*^9, 3.7020295915380993`*^9}, {3.7020296530565577`*^9, 
   3.70202965398308*^9}, {3.702030439048958*^9, 3.702030442920479*^9}, {
   3.7027283614614534`*^9, 3.7027283671767807`*^9}, 3.702728562724965*^9, {
   3.7027286247735143`*^9, 3.7027286393053455`*^9}, {3.702728840933878*^9, 
   3.702728916934225*^9}, 3.702729503478773*^9},
 ExpressionUUID -> "9bfd8cc1-13b5-4ac6-8fbb-a2d9040b5c7b"],

Cell["Simulations of rescues", "Item",
 CellChangeTimes->{{3.702030587687306*^9, 3.7020305894320927`*^9}, {
  3.70272905269599*^9, 3.7027290544530907`*^9}},
 ExpressionUUID -> "fa894fc8-4133-444a-adf9-10eaab9c2c79"],

Cell[BoxData[
 RowBox[{
  RowBox[{"out", "=", 
   RowBox[{"FGM", "[", 
    RowBox[{
     RowBox[{"xini", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", "U", ",", "rmax", ",", 
     "allelesFGM", ",", "tmax", ",", "nrep", ",", "True"}], "]"}]}], ";", 
  RowBox[{"EmitSound", "[", 
   RowBox[{"Play", "[", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"1000", 
       RowBox[{"t", "^", "2"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.702028020381042*^9, {3.70202805732902*^9, 3.7020280913876543`*^9}, {
   3.702028177258871*^9, 3.7020282003470497`*^9}, 3.702028246266089*^9, 
   3.702028475593751*^9, 3.702028892853054*^9, {3.702029051252069*^9, 
   3.702029052342152*^9}, {3.702029437393388*^9, 3.702029458193593*^9}, {
   3.7020295407366323`*^9, 3.7020295915380993`*^9}, {3.7020296530565577`*^9, 
   3.70202965398308*^9}, {3.702030439048958*^9, 3.702030442920479*^9}, {
   3.7027290888220563`*^9, 3.7027290914472065`*^9}, 3.7027295051748705`*^9},
 ExpressionUUID -> "9bfd8cc1-13b5-4ac6-8fbb-a2d9040b5c7b"],

Cell["Scaling for graphics", "Item",
 CellChangeTimes->{{3.702030475176388*^9, 3.702030517192234*^9}, {
  3.702030953700338*^9, 3.70203095610056*^9}, {3.7027293821018305`*^9, 
  3.702729418308902*^9}},
 ExpressionUUID -> "ef3a70ae-0b6d-48d4-a307-05e8d790753e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"mms", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Log", "[", "#", "]"}], "&"}], "/@", 
    RowBox[{"out", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmss", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           RowBox[{"Length", "[", "#", "]"}], "-", "1"}]}], "]"}], ",", "#"}],
        "}"}], "]"}], "&"}], "/@", "mms"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mtp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           RowBox[{"Length", "[", "#", "]"}], "-", "1"}]}], "]"}], ",", "#"}],
        "}"}], "]"}], "&"}], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Mean", "[", "#", "]"}], "&"}], "/@", 
     RowBox[{"Flatten", "[", 
      RowBox[{"mms", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "2", "}"}], ",", 
         RowBox[{"{", "1", "}"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vms", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Log", "[", "#", "]"}], "&"}], "/@", 
    RowBox[{"out", "[", 
     RowBox[{"[", "4", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vmss", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           RowBox[{"Length", "[", "#", "]"}], "-", "1"}]}], "]"}], ",", "#"}],
        "}"}], "]"}], "&"}], "/@", "vms"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vtp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           RowBox[{"Length", "[", "#", "]"}], "-", "1"}]}], "]"}], ",", "#"}],
        "}"}], "]"}], "&"}], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Mean", "[", "#", "]"}], "&"}], "/@", 
     RowBox[{"Flatten", "[", 
      RowBox[{"vms", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "2", "}"}], ",", 
         RowBox[{"{", "1", "}"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Nss", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           RowBox[{"Length", "[", "#", "]"}], "-", "1"}]}], "]"}], ",", "#"}],
        "}"}], "]"}], "&"}], "/@", 
    RowBox[{"out", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ntp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           RowBox[{"Length", "[", "#", "]"}], "-", "1"}]}], "]"}], ",", "#"}],
        "}"}], "]"}], "&"}], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Mean", "[", "#", "]"}], "&"}], "/@", 
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"out", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "2", "}"}], ",", 
         RowBox[{"{", "1", "}"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pdf", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"tmax", "+", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PP", "=", 
   RowBox[{
    RowBox[{"Extract", "[", 
     RowBox[{
      RowBox[{"out", "[", 
       RowBox[{"[", "3", "]"}], "]"}], ",", 
      RowBox[{"Position", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"out", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", 
        RowBox[{"x_", "/;", 
         RowBox[{"x", "==", "1"}]}]}], "]"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cdf", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"tmax", "+", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"pdf", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", "1"}], "]"}], "]"}], "=", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "/", "nrep"}]}], ")"}], "&"}], "/@", 
   RowBox[{"(", 
    RowBox[{"Tally", "[", 
     RowBox[{"Sort", "[", "PP", "]"}], "]"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"cdf", "[", 
      RowBox[{"[", "i", "]"}], "]"}], "=", 
     RowBox[{"Total", "[", 
      RowBox[{"pdf", "[", 
       RowBox[{"[", 
        RowBox[{"1", ";;", "i"}], "]"}], "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"tmax", "+", "1"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pdf", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Range", "[", 
       RowBox[{"0", ",", "tmax"}], "]"}], ",", "pdf"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cdf", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Range", "[", 
       RowBox[{"0", ",", "tmax"}], "]"}], ",", "cdf"}], "}"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7020304629533997`*^9, 3.702030467593549*^9}},
 ExpressionUUID -> "872d18e2-ef8b-429b-b275-865a2d7c37b2"],

Cell["Graphics", "Item",
 CellChangeTimes->{{3.702030531927964*^9, 3.702030533335875*^9}, 
   3.703308521637856*^9},
 ExpressionUUID -> "4dadad81-047a-412e-9440-3fb2380c9051"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ListPlot", "[", 
     RowBox[{"mmss", ",", "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "tmax"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "1.1"}], "rd"}], ",", "rmax"}], "}"}]}], "}"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"Joined", "\[Rule]", " ", "True"}], ",", "\[IndentingNewLine]", 
      
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"{", 
         RowBox[{"Orange", ",", 
          RowBox[{"Opacity", "[", "0.2", "]"}]}], "}"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<t\>\"", ",", "Bold"}], "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{
          "\"\<\!\(\*SubscriptBox[OverscriptBox[\(r\), \(_\)], \(t\)]\)\>\"", 
           ",", "Bold"}], "]"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"AxesStyle", "\[Rule]", "Thick"}], ",", "\[IndentingNewLine]", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Background", "\[Rule]", "None"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Background", "\[Rule]", "None"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", " ", 
       RowBox[{"{", "\"\<All replicates\>\"", "}"}]}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"mtp", ",", "\[IndentingNewLine]", 
      RowBox[{"Joined", "\[Rule]", " ", "True"}], ",", "\[IndentingNewLine]", 
      
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", "Thick"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", " ", 
       RowBox[{"{", "\"\<Mean of the replicates\>\"", "}"}]}]}], "]"}]}], 
   "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ListLogPlot", "[", 
     RowBox[{"Nss", ",", "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "tmax"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "No"}], "}"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Joined", "\[Rule]", " ", "True"}], ",", "\[IndentingNewLine]", 
      
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"{", 
         RowBox[{"Orange", ",", 
          RowBox[{"Opacity", "[", "0.2", "]"}]}], "}"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<t\>\"", ",", "Bold"}], "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<\!\(\*SubscriptBox[\(N\), \(t\)]\)\>\"", ",", "Bold"}],
           "]"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"AxesStyle", "\[Rule]", "Thick"}], ",", "\[IndentingNewLine]", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Background", "\[Rule]", "None"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Background", "\[Rule]", "None"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", " ", 
       RowBox[{"{", "\"\<All replicates\>\"", "}"}]}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ListLogPlot", "[", 
     RowBox[{"Ntp", ",", "\[IndentingNewLine]", 
      RowBox[{"Joined", "\[Rule]", " ", "True"}], ",", "\[IndentingNewLine]", 
      
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", "Thick"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", " ", 
       RowBox[{"{", "\"\<Mean of the replicates\>\"", "}"}]}]}], "]"}]}], 
   "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"cdf", ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "tmax"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"Joined", "\[Rule]", " ", "True"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Blue", ",", "Thick"}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Style", "[", 
       RowBox[{"\"\<t\>\"", ",", "Bold"}], "]"}], ",", 
      RowBox[{"Style", "[", 
       RowBox[{
       "\"\<\!\(\*SubscriptBox[\(P\), \(ext\)]\)(t)\>\"", ",", "Bold"}], 
       "]"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesStyle", "\[Rule]", "Thick"}], ",", "\[IndentingNewLine]", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Background", "\[Rule]", "None"}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Background", "\[Rule]", "None"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotLegends", "\[Rule]", " ", 
    RowBox[{"{", "\"\<Over all replicates\>\"", "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.702029212966033*^9, 3.702029217092496*^9}, {
  3.702029915118822*^9, 3.70203013910067*^9}, {3.7020301701239443`*^9, 
  3.7020301707954473`*^9}, {3.702030232572843*^9, 3.702030402825589*^9}, {
  3.702030697064245*^9, 3.702030937973783*^9}, {3.702031296418846*^9, 
  3.7020313083383303`*^9}},
 ExpressionUUID -> "8f35501b-e279-4aa4-9651-7aeeaa4b16b6"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {{}, {}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQk01XkfBvC/hpS1t5R6SRoZUvO2MNnCI1uDyLVv1924l96UUJzRnNuU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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlnlUzXkfx3/kVIekmng01VQMyhKGpkV4kxaZqG57qtvdm2EqRQuaW9Ep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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0Hs01HkfB/AfSlKP7s+pdJnsLmFjo1QSbyRSbuM6rjPGMKqTikcX2aaW
Uh1FtbRoU2zul1JEYQpdJ5dCaLUu9WhLZbObbvTsHp/v80dzzpw5r/P+vr/v
328WBIbxJcocx93++/vPL/tMfpixZZX6zepRDVhkzy31F0xi5jA91yh/2wxm
NVRZKu5v/jfzZEScCTFK1WCejnOH+sc2jmWeCdud3B9tfTfIc9BefUK98DIz
D60rz52bkcishdfm68fr5zN/jSGnqU7FPzFrY1x/0g7efuaFSOqrL9q+mFkP
w2Xz3jd+qiN/i0vV1/9T9JTZAFYRtgdjapi/w67qVi77KvNiGEYFd2pOYjaC
SHXGqfJttWRj5L9SUl7nxbwEQUqKPN4y5qU4laJRKf69hmwCaz2nk+/TmJfh
pxNaBSkB18nLMcdMV/qvETl5BdIf+nD7ZzOb4sXhvsRB7UryStTvbhO/T6oi
m6E9qOa0Xzk7vwrzcnylKhrM5nheUVTYYcjOW6BBT7fGQIXdB5wZXBKpIi8b
tQwQfM8pzHMvU26Jt72mUrMzpZRbIodnf7D9UBblVnhwZNj4dvFhi9HcCiGB
Hjqdmr+MmrNGXYZi/o75qZRbw/BeaEGOVjHlq+GZ1JxqEniJ8tUouOIVYJpR
QrkN3rZaLl/6opzyL8ytwbCZ3MduQhnla77Ibb/of2HO7ovcDhE337ybvYHl
a8EfiOr5NYHla1GzNPK34UKW26Phm2S9YwdYbo+0qFpJimYF5evwW7fC6O18
lq+D5dntVqprWL4e4W/maSt6Wb4edRLDbeXsPOeA89qtOVNH2Ps5QFasnqNw
JHOOcBrgTbTXYH1HqGUoVfK02f1OyJ/i+9Q6luVO2F2vem5lOLvfGSmfG3Il
fnQezhhYpRiK28T2nFF93M/4ZgNZ7oySinkF10+yvgsOZxpmDMVfpr4LDD5s
9izTJMtc0PtogtXpatZ3AUauaP8/5/gYidrYvVdA94EPQVTJ/ZhL7Hn5mB1/
8y/DFWQ5H/tWy+XRaazvirwHV9Y7h7K+K/pet2RGH2Z9VxhqLyyb9ID1XXGp
5VnjLDP2/7hh43ndYa929v5uKF6WmqBnWUl9N9yXP9V8t/gq9d3wzOFHnVw1
MueOS1V/DtWU03m4I1JT7Bn9mXKZO2qt2wouCKqo747cEeUofhOZ88AY+7mm
t8eR4YEj+aX+FQfIMg9cnVKl1HSU9T2g++P2bWETq6nvifDB5ecbTcjwRNIT
K0frRXLqeyJ5T8wxu+xr1PdEqYdEtyeOzHnhROLJIzWq16nvhdroy7qbp5Jl
Xrhox5MampPlXojIdji6cS+ZE6DxK502wzGsL8BL/cLEq5NZX4DsMiP/Y1as
L0DHx5oU9yes742RH76JF3+sob435ljY7IucVUt9b9zWsv6v/R2y3Bs9Awfq
BRV11PeBn2XC8edON6jvg3kD6yZMjyfLfOAbv2manvdN6vtAmbtrUfHVLer7
wkVSX9qTSYYvXjd17G6YRpb5wujhrNYXEWS5L+JWXDy70471/bBIe2bnpgrW
90NL3GOXsadZ3w86AxVnC1TvUN8Pp665Tf9US+b8caujZFljJRn+WOo25aL+
QrLMHxeWt3yMdGR9f8Tr2Rwq3cr6AfAvHY7LSmf9ALSFXy4d28L6AeDfnrV/
5XzWD0BXYfSO5JesL0SXgcPQCsHdUfOECI75QfvndjKE2JBVkbTJQDFqoRCC
+/wGa597dL8Qui/sDuh3U54uxInKV9/1DpLlQmjssL4z1obcJcSejD9e7XQg
cyLoDW7gm2vRfTwR0hrH6/tFkiFC2CGxTkI/WShCjsq9bz+1sH0R1qnaKu/y
qKd9ERZk5nHGV8hyEfZOlc7cmt1A+yLYfWoue7SqkfYDYcnvS7M9RuYFYl+A
a2hsLRmBGKrLHyja00T7gXBXT5A2N5Nlgdhbv61izbj7tB+Ik7ndiqVnKZcH
wpFn03/0e3LX33vjYhWua+g8J4Zp3uR6jbtknhhFlS7mBk/JECMj9saN82oP
aF+MP+v2dA/YkmViRO1adFhHnZwuhvH2g21m08hyMcLSpRcjfqf7usTQd251
D9OjnAvC18ltPZtB5gXhmmalTuQMMoJwXLZAfdJ5th8EvrjnmlsS2w+CfmH0
9v5kth+Eg7GOvuV32H4QsgreOt5VkLuCMN743Qfp1mbal2B11vHkPk8yT4Jb
dUVPZ+SSIUFtAsLTeslCCZQWJJ6KfUKWSfBGL6t/3JYW2pegf5pBir0/WS7B
yexdKg8DyF0ShC0cttV1JnPBqOobTp5QR+YFI8XcJ1VtcSvtB6M8YZLv/Diy
MBgNMV7GmYNkWTC8Nwmv8K49pP1gTHwz5pb3yzbaD8bcDeN9m5TbaT8Yx1w6
XTNtyFwILoRfEOVtJvNCsFjk/sHkHBkhyPz5+pYlb8nCEKzv/WCaqttB+yHo
XlaSqgglp4cgb06ektozsjwEzappJloBj2g/BHvHKL/usCBzUlxYGNNRHPor
7UvxOanETLWWDCnupo239PuLLJTiyYHcgKSsTtqX4pfSLUfXnianS9GZaKDg
bpDlUpw6O7FHa5DcJUWTik1yretj2g9F+COTD7eeP7b4H1mZ9RU=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQMC1xcX2HId3w/hfbBPCnxm/pIXxmdwELy3fdZv
GRifw8H3WdNTI1EYX8DhK2+JHh8/jC/i8Ob+oh3VcPMkHLaH9dy5+fgYlC/j
YNshXlH6FMZXcBA1vPJq+1EYX8lh02EXDc/dML6Kg6jRJcuoQhhfzYHJ9ZHB
PlUYX8Oh8+mWHzsiYXwth5f5ZtKf5GF8HYdKebesRhYYX8/hVqvD/NeLj0L5
Bg7+3jdmr+KF8Q0dNnVw7z/hBOMbOXwze3BclhXGN3bwW/Ws5bA0jG/i8Pb8
0nWbrx2B8k0dEuKS266/gvHNHNzC361+mwPjmzu4+qSdfx0K41s4iMiyuLXO
hvEtHaZO2b6t3gjGt3Ioqj7+8MfHw1C+tUPIWqv/bwNg8jYOvNk5DqVsML6t
Q6qktG3TDRjfzkEzQt9igS7M//YOjbc/PPRIgvEdHP4uFAuecA7qnwYHhx0S
kz4pR8PkHR2eLgiIdNGB8hscHfKCSwyZg2HyTg4TvkXdL26CyTs5FHtsu/tg
M8x+Z4d5i3RCbYqg/AZnh6K/c77ZL4OFn4vDNMcPHa+3wfS7OJTmtcdNuwpL
P64OM7dzPznx7QRU3hWuHgCv4+Ka
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90AtUzHkfBvDRRlRvZpMim4163Q5eQhc19ZQuus90nS5T00xzQZLq2K28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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10gk0lXkfB/BbqWTKW2polEgYFaVs8Vq+ymTLvu/3XvdaMlNGO2+6qTGW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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0HlYzPseB/BRlnGrUzdLXN2a0CIhimQ5vetEKaWmaU9NM82SrWw5R2gc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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10GtIk1Ecx/EnRbwQYw3LWGU1L1itddHlps79NjenrosszJEjUrNCKTcx
aGCyV0EiFPkiwoRKwflCzWs5nWvqViak64UT87IgmhJSqClEdMPzP3A4fPie
8zycc7Ck0lAWwnGc7N/8v9Lg+5vNiqg3ri19V17pHlXt5JM5SMdjntXuIEdA
m5oYuSuUzMfyiia/eN3LHI3zbU1pq0Hybhh/v2syBch78TPSoLVOkA9gVOSM
KewkizBzf9ZdW0eOx/hbae5UATkR8x3L8+5MchLGxC7dJkc+jJ6KY9c+tXqY
xTizud00oCdLkF/0RL4uJx9HIFjiNd4gn0DqnLB0Jot8Eq01Xdu+dI4xJ8Mp
COVJvKPMKThbnixOsJClWJeqAkmnyadw82LVUPL0CHMqRHa9LOBzM8uwYVk1
PfVTl+P1ntj+hD7qaeBJ1tTG5+R0BF1H7dlKcgZmFxN8pophZgUcK/G9k9fJ
mbBaGoR3hEPMSlQKwuKKrE5m4NCGv3VB6dqyDfDEmT9PNtN5FSRDGXNtLWy/
TYWwfb5HHcWDrKuRGOk5F+hltqmh+Ni4lO52sJ6FB2bLh5WyV6xngTPqvk6F
D7CuQdR7viMoY/ttGljv9Qzm3H7JuhYxNb6HpdH9rGsh2K+TC0XUs/HLcPlW
bF8369l4HFK10CimrkN8nbJZUk//1yFiYanCUN3Deg4uaHiZ/PAu1nPgrZ5I
mW57wXouluu/jYDXznou6v8s1paHsO9xeegoONLgLOlkPQ/mS/bCH110Pz3W
qkI9jqv0fnoMe+62TCvGXH8BQR8ZGA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQMC1xcX2HId3w/hfbD3m7j/TDwPjM/gICRX8u0T
G4zP4dDUZBlzhB3GF3BYs0i4pfnFMShfxIH3mN6uJedhfAmHW6+K3Ninwfgy
Dlz+721DWmF8BYfH62tfn6uA8ZUc3NL3ThaOh/FVHOb4b/DhzIbx1RxSFTjc
/lrD+BoOTwSXbu/1hPG1HLJfy9htcYbxdRz+KS8xl/WH8fUcHi/IXiZUCuMb
OFT0TmQuXAnjGzoYaZz7p/gAxjdyeBT+N3bCUxjf2CFMSC/o4zwY38TBbpe8
c5oUjG/qUNw95++mhUehfDOHC+vfL772BMY3d0iLikrsmwDjWzhUaHp1e9jC
+JYOx33PLXXPPwLlWzmEz/VY/HIPjG/t8E7uzsXeOBjfxsGi5vO2z/NgfFsH
nS/r2adehJln5/A5PsLghvyx/X72CVHfHtg5fLrkmyQQcXI/AC2NomE=
           "]], 
          LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQ7X4g1LHC1cHh0yXfJIGIk/sZQKDBwSHvRMozxa7j
ED6Do4O2jut6K8cTUHlHh6dTvMQKbI5A5Z0c7m3/pf5x/QGovJOD7dRZ082e
74XKOzs88psrG+y7Dyrv7HDi+2fPtbJQ9QwuDqEHHU59YITJuzis+VzSL+O+
Hyrv6tDxMqowcMNhqLyrQ2naDW5PRSifwc3h+/WLKpeuHYTKuzlwr4/mbEqE
8hncHQSQ+Q3uDmuOf27liYLJezg8szq/xs3kEFTew+HenRO9msUw8z0dJmxZ
vOhxF0ze0+HQzfy9HpEw93vB+QCXMnRr
           "]]}, FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwB2IQDQMC1xcX2HId3w/hfbB38npnWsgN4zM4RM+eZZzI
CONzOATMC3j+8P8xKF/AYY9HU8f3TzC+iENwS36o8BMYX8Lh60XRfVpnYHwZ
h8iln92+b4HxFRy0ufomCE2H8ZUcCq7nS/e1wPgqDvMWvO257A/jqzls7lyY
cskSxtdw+D7FcV1NDIyv5XDx/b7EeCMYX8ch/NGccCZuGF/P4e5J36+5R45C
+QYOBzYFZpiXwviGDvreEf/t62F8I4cHuvyNt6phfGMH329lHN+CYHwTB18J
ton/gmF8UweDaXImKX4wvpmD91mRFwXxR6B8cwePTOe8SmsY38Lh6KUVnS25
ML6lg0Pe4yDbaTC+lYPv0lcl+7fD+NYOl942PVIvhvFtHPbqPONNugbj2zo8
DVbgmpED49s55DnvO8b1HMa3d7i6W1ByohWM7+BQ89nDgnHLYQi/wcFBtbbq
Ybb/Iai8o4PvL1/71cuh6hscHW47fGpl9IH5z8kh/e5K7ekPoOHb4OQg0RG6
/Cw7LL04O+QpPWI+uRam39nB4lfgvRVCMPtdHH7I3Ny1RxGqvgGNz+CKJo/G
Z3BDk0fjM7ijyaPxGTzQ5D0cTPKO3syUh6UXT4f7S6S6Ej9A/dvg6WC6Otwn
Kg2m3wtNPxqfwRvOBwBCYB3t
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90Qk01XkfBvDbiGTtKC28oaSaSCFZop6SS2Tf17u69yqTZArTpP9bKTT1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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10AtMk1cYxvFvmGGl3IIwISmGVlY7ooCCCFXWh0uBotDSC3G6zMkEhelw
LJBhLFQuY+BQVEBARqGlCTrQwEYEkQjoRBpG3FxWcW5MwU3EjRkIRFxkW/qe
Jk3zy/97vtMcYVq2Ot2B47g9/33//2Ufd5v5SKTT8HW7/pbZxIUeja7MHNLf
3d88y2fm4ctzyog+F2Z3yH5ts025M3uisHh5vf8KZm8slV1erFrFLAB/UZO1
hcfsB+F4TIbSgVmEhgKnfuXsLbI/3PNL9Q5jzGLUjXKzH15gliCuVzKxO4M5
AGLpV+P3Q5k3wBSkdwwSMgeiuzr+pXXhW3IwnO9N5a4fYd6EpbVZbrn7mDdj
0LFovmwTcwg8C8XGsVTmULTo+4MD9t4kb8GBkFUd/+Qxh+HuscJ3urYxb0VI
ZMlY+EHmcGTVifZP85kjsLFSpBXob5Cl4Db+wb9nYd6Gmvb5ROPiIHk7jvZI
qyPuDJAjUZXwxmithfW3YfR2ylsuHiLLIFb81uNRwjpgkujOrvXss9sADB2R
B3W6XqUehaCwtMnp9CvUo/BspDnyVhg9z0WjM6/udkco69GoslZWdEt6qMdg
pW5csf1r1mPglznyySGfbuqx2O1Wqw8ZvUQ9FlW2J2duHO+kLofKmvPA8AHZ
IIc0erL41cdd1OOgXPq9oKaebIiDx0cXG0Vvsn08+L5i6XkJe388DE/3zvRO
WKgn4GhDUmnTwWbqCbi6a5p305t1BV6/8lqwV7aJugI/ugpzA02t1BMR2/ps
cXOvmXoihL76JueHrO+AW45Uan3QQn0Hkr8JeGukgs7jdqLg+/Yf9Avs/J3Q
3rYZjwsbqCdh2RY/VXGgmnoSasb7fvZyPE09Gde9zBLBRBX1ZGy1zJUEq85Q
V2Jlg3pm3uVz6kqsK1INzsyVUFdh8L1A2+SJcruhwurSyn27nNh5KvQFP97Q
/MtJuwdUiD7JPedf+4z2KWi6u/BkzUv6P0iBfNjSny2vp30KfLLbw6uNp2if
AnfhFy5Fe+g8To043xdr2pbLaK9G9NlLaboCet6gxvPlPyONj+j9A2rMKwZM
1/S1tNfAPJ0jTvvuHO01OC2uH2p/Rfdn0OCyQ4fKz0T3MaDBocNlZstjdr9a
lF9seV9Q0Uh7LRSfegnuP6X3GbToEgnmzD3naa/FX/JZno+M3a8Oqf7HhsIF
FbTXwXpKFFJ8+ATtdViYi3rx03CCzL7XId9vRea6tny7uVRkNibNZRZU241U
pGTcaff1LbfbkIqHbo94zq21sn8BBgPHIg==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdkgtUzHkfxidkZdENm0SjFdUmtwwJPd1URumi+21mmqmIDdHFm/yT7KlF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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQMC1xcX2HId3w/hfbCP+vKq6BkHjM/gcHPnr4Av
fDA+h0P+5GiGMDYYX8BB48McgUW/jkH5Ig6qzaoczl9hfAmH3R9DFuZeg/Fl
HJ7JBldeOAPjKzhYB8y+q7oAxldyaD7H+kyjCcZXcXiWa7dvTxKMr+ZQWGq2
s0IHxtdwSBQUsPlkCuNrOajoztvFyAvj6zhslPkaz//rKJSv57DGtTXpxx4Y
38BhQv3VmZyLYHxDh9PaKT9ubYfxjRxKo5P0LzXB+MYOd9xf+Fn5wfgmDkt+
bJu++tgRKN/U4Z1sAn9yE4xv5lB8K+ajw0QY39xBInwvz9d4GN/CgfVVHP/X
GBjf0sF3qtDl5BuHoXwrh5ZLF1M6fWF8awf9mM9ci/ccgvJtHDb4qnLOW3MQ
yrd1KF075cEfPZh5dg7z83OnVcbB3GvvEK4iaLuZDcZ3cMg+edOtfCLU/AYH
h+g9aUc/RcDkHR3epf5j9JOD8hscHTx/17xOfbYdKu/k8M1mwacw421QeSeH
xd8OCOw+vBkq7+zwav4E5oigTVB5ZwcrIWbBySUweReHsLp4i4CjG6HyLg5S
llmdtVNh8q4ORQJsK2Q9YfpdHTofWDq+t9wAlXdzUFLynmrxBiaPxmdwR5N3
d2DY1FtyUHA1VN4DLg8AqVfxrA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n8s1HEcx/FvOfJrJp26THVxmTmHqNwlvLgjP8JRraJUtrB1JQn9EN9R
Wz+XilqaSoaSpR8rQiiOP1CUUKlJC5mZmWa5smp93rb6bt9999hzn+/n8/18
P0tjEiJ2zeY4zv/3/edJl3l34T5P4+a6vxrz7rmRmZtmQubgofWU7p6xIaok
dl8yZmyOsYUteakCshBZI+YG90zJIpzqf6IZ/tDEbI3wWtto6UuyGPayHtcL
pWQbVOvSzCT7yBI8yLdautWdbIfQGOc370Vke3zNGxpQdWuZHTDoeKdzxzWy
I+Z65xVeVJCdkCE7E9sR18jsgo7u+DfjUw3My/Fzj/azfSnZFYpEq8JvsWQ3
vNBrbXDjySsw4KCMunGVvBIRfUYBWjl5FUavb3p7IvI5szvKjcWH2raR5Ugd
cbSMTyYrME/OJxuEkFcjPk6g6Z1+xuwBp7GTtfFl5DXYu1m300tM9kRluYNy
wzmyFzxVKX2z4sje+KirOro1mgy013BrjAzZfDzQl+mz/9Z56j6YEBTXFI3V
s+6DRQKpMJarY90X9cNluZ0FT1n3xciGJsHN9FrWlVDw242r25h5JSp9W8cL
PtF4FXpzbmbbZLP5eBUuqayPZWSx+Tg/6DVvHC+2ovf7Qa4ZnJAtofH+6D/u
cy9Jn7o/1FJRtE6f1r8W4kgDF42Y1r8Wq4QHDwslFawHYDTJsKS75DHrARhK
t7hyxu8h64Hgu16MTNhUsh6Il6cv2wZMUg+C7H2D7HZZFetBeJfwKurId1p/
MNo/5yzkYmh/g6G9f2DLlIT+7zosbtmZeraRnRd+HX4kz7ubuIx6CJyLeh9Z
cNRDMPlMLsxaT+crFIkVbc6lZuw886F4u+CHtUUa9TAMZkyLRK9pf8Nw6oLU
xWYudfW/hhqmhyzrcmU033+9Xo05qepYjRl9XziiTeanDCmq2fhw5Hdl3wlR
1tT9AqtAXHI=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zglYjfkeB/CTTJK9lHHLOCUNnmi31dE32rXve2erc+wkGaJ5Zd+SJVtx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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9lAs0lGkch4d0W86SSrJRpLZkke3eWL9cQu4zY8ZtSIpQbBd7SmGadlNs
CCmXpckW0Wita0oNhRZJEZsutmyJipIuuyfttsf/3TlnzpznPO8z7/+bb95P
f0MEb5Myh8OJ/vT+75O9NLryvrX4rPHyGL20vDLk0d3zP3NQLxcY545jPAkB
NxduLfvQQKyB5pQqzc+HGE/DjqbOJzP7GGsj95b3xuY7jGdBnhPiMdjEeA7U
gmunfMxmbICZKRpm9pGMDaHZU/LO3JvxfPSrFYX3aTNegIh/XOb0v68nNkLo
QLHq0euMjVG0vydpaRxjE2gVywsDJzE2w/Rr43X3yK4SL8avZg3TNoUxNsdA
bkh5rBLjr6GeI7vV33aFeAmKuodGkroYLwUvU/C0ZSHjZTCZ0TKvwrGOeDm6
5w06FpgyXoH6xeKIXhHjlYgyq6g3fFVLvAoZeqa19pcYr0ZpmpPKo01sPRfi
jTGF7W8ZW8DI9nW1LYft/w2O82OH35gytkSU9rLM6FNsPSB+MHqx8yaxBDCK
kw7ca2R+Dax0BGqp8Qrya6AkVJEqzybmWCHtpyTu8swa8lYYMDmt9cvUKvLW
ONSheS+5q5K8NT4oyz39uOXkbTBav9epWVBC3gZzakMtuOlnydti8i7DntA5
Z8jbwnaKUsz0pXnk16J8ULSn1bqA/Fp43Nhz5MazKPJ20Bvom1pd/L3lmLdD
GY9nl6CXMsYce4TE1yl3t0rJ2+PkW1mgVUw6eQf8Pqw8UWp5nLwDDCM6kptu
pJFfh7rWUsn7fFovWYe568UJFlaJ5B2hzZl/u9E5nrwjTCp596MMosk7YdvZ
q2nZo+o0vxOCuUccAvYepPmdEaElm5h/NI68Mw4bD7fHlqSTd0GoSs32lroc
8i7g8gu/DC49Sd4Vz0Lntq6XnybvisDev2ZKefR7cdxw9+VrJX0hMdwQtkGr
8juTQlrvhnnBOua7zhEr3BD4RfWDBgHr3XHhj8aJnddPUe+OZMkQV26TT707
Rg9fNNkvJVa4Q2dn2/oH/Seo5yEnrzc6+QXdT/DQOSjcuzuSWMKD2YiRblsF
XY+Ch+CRwhVyHl0vhw8bcdXqDi/6PvCheixf532llHo+2mvDXCy0Y6jnY2WM
0/3DNfupF8DW65zVDhkxBFhQufrhU7dA6gUYV59SIuiWUC+Av/6qDtEbdn88
UBYywzUqN4H6T1y/JWBLUDL1Hvjt0MfJgYmJ1HtAEXq+Qb0xhXohnJfkX+vS
TKVeCP+Rey7ZbZnUCyE6wA9xck6jXgiL5brGa5clUS+CSlFmVvQBtr8IsfxL
TbulkdSLUHQ52DHoB3PqRdgR9FFX5Ywn9Z7YpvZcOTI8nnpPVOU16f0dQfNI
PFFd9HBrx06aR+EJl0O1qeO/YvN7wWNzxvEp5ceo98KdoaCsVTJ/6r2Q0nPX
/2bivrH/u8IL70ZU5b2e7Px542Bfe0F4OZ0neCPbaJ+oo+RnOi/e2GxtJ9ue
RazwRkZA8WDBokLqfRBaNdoiX1FKvQ/m56cmcPTLqffBwkuPVdv6iBU+uPC2
ewIOEnN8MWzzyuzEogrqfZERFufl84RY4ovy5n8UZX+ep94XI7P4bwyEVdSL
Pz3vXcvgWUm9GBstt+g+4rL9xTDwCZ9tml5GvRgRUbeFE3rZ/n7wF+zmaaiT
hx9uOVvs6splvR+eOiw60/ywmno/zJY1Zj3/sYZ6f7x4/bht89zLlv8Cmtp/
Ww==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zgtUjAkfx/HJNZellW4qZtGs3EpJF5d+RaUr3afbNM000/QeVFvZUjFs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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtI01EcxvF/Wq1UTFiBoYSVRcha6nRepu7RuVtqMgslrF4opSll4Nog
0tbFBIkac5GUSrIyUnQamGmapeYgE1OqNaXSFKRAmBaNWWZF59eLHTgcPnzP
bWteSdZRL47jJH/m35VGgN1yKtHH1vdPTmmZryXuHI/MIU04NxnoTV6HTvHT
FTufHACNq2pOvpq8EUsPxKqyNeRAVC6O8SqcQ8zBcL9wFAdNkUMQdVud0jtO
3oZER5fO1EgOxf7zHYcuV5B3ojUorPebkbwL3iUh2dY8chhkyhbZQghZgPsT
3hOFArIQdUsFM7b558zhGFA+ni6dJUdgYDI38lU7ORLFt0Q9rmtkERbeH7++
6TA5Cs2z+yq11kHmaNxcVln5SWQx0iNyq/PKyTGos2br1c3kWDjt5Tp+AjkO
FZlrBWM8cjw2SG5keE2TJaitHxuv+TXAnACzZo+hKoucCJ/XDssWEzkJ3atG
nsRX9jNLcdDv673QH8+Ygc6iEdHJHNYNwLFHn+6umGh/MrqG68+6vdh+QzJs
BX6NJ47Q+RTwgtuMmpo+1lNgydbH+DuZORl8dYNNudqHrMtw+p3EpX3bznoq
HMuZ4es/NrGeCuuo+U2tto11Ob7wyzq6qhtYlyNaU1rVI7zDugIt/d1XCsXs
PoMC/hcv5bR/bmVdCUx9GC3aTu8rMW/Ux+oXmTkVchwHvpt30HkVuhWKn/lD
vayrMSxt2G3PZ/8xqOHmu90z0k7W9+LqmZcXNpeaWfcwl+bRPcyle3QPcxn/
/Rs9iDHK
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzWtI01EYx/E/hVqKbi9ElojdxOkaZbq5pnP+vG1zE8SVkRKkhmIpzVwK
bV3EiCTDLiNRMja7YlSzyxZJc86ypNEFSUUKNHSaRRFlTQq70XneeOBw+PA9
5zmrywz68iUcx8n/7n8nLf7oxZq04Cfu//qcfjR0XGwNJHPIjJqOSQ4gL8OR
zaJ1lfOPmfmYrXSbXs2Qw2GaS79ZNEIWoP7DwQWzlxwFb49FcMpBXoWd3Jnj
xnbyGoQfkqa0lZBj0Hl1+4pqKTkW/gJfdOv8AHMcptTQVznIIujDPAPeDrIY
7XND/tbL5PVYmde/LbeEnAD7WVt7/twj5o2o8qwdTMwnJ+Jwnb3ZriAnwdo1
2W279pBZAnHkgjLfTJZC1vdcKdGRkzHUfP7FRwlZhrYT74ubOvqZN4EXv6vw
whuyHMKx2K2NZnIKdIP8oqlScioSrCrzhlCap8CsN2KCr6CeBp2nsGlmtI9Z
CZ9t+Kev2MOcjiStxTVRRgb2GhyKSA273wDscY3VdGX1sp6B4BiX9YqQegac
49fj5D/crGdC4Pq2fIbH5jVk4oCQp6wdoflZ6Nl9I7fEQj0L+yZ/hZii6X02
hKHft+Qco/nZuJdcro/tpf9zwDNHeH9fcrGeA59kh8j45QHrKjQ2V98PcTpZ
V8H0zFMr2s/MqdFyzqCwGB2sqyGOL7A9/XSLdQ3e1tmH/fV3WNfAr+hzh6Xe
Zj0XFdWy6YoA5oZF5rSLuhaG1y+7ghLvsq7DO3FpWshXO+uLzOXhdFBgy8ml
3e4/Vhse6A==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0A1ME3ccxvGToaNMLW4uIiuCTIyyrlqKFKXIU4QKWOgVitkEZYqLWIbQ
DTLm681laLKtWZi4udlgERUKaDGDwCaF4tRFfAkgQrbQDANhoYkBphtFcS/p
758lXnK5fPK95y53y3cVZbzrw3Hc1n/P/67sCBg4Wxznf6PDq4n48O4gG7+A
mYP/jmXLFUuY/cDLhlZ9GcAcgKVlceL7c5gXw33qr0b9n9fJgVCV9JrkPcwS
2L/qedA+yByKwCH9GXMLcxhEl/lY3UHmFXhPHu4o2Ma8ElfmuSbUO5lXQbPv
NVd3HnMERqPceZ5iZik8omMFb4Yyy+Czv2Xy00jmtVh2RDnh+/M1shxPc8TV
vX8wR2KiPvvEpJ1ZgS+Ofr67IIc5CrvagiQOLfM66HXq8eTxn8jRqC56K2r0
ErMSQsn+sWYRcwxyfz3Xmei+Sl6PQy5n1aUc5g24/bR81ijqIseiP9+nJWeN
k6yCvKLps701HeQ4rBAP9zZ/3UneiDtHyzr2FTLHw/ibZsZUyZ4HtImEJ8Ee
h9cCsFhaaP94hD1PjV9KF4aI+XbqaiS13guzFrOegIVyqUXkYj0BL5/MfliX
/SP1TXg2P8LauuF76puQsl0lHb1to54IWdbs3D5rDfVE1OhSb7xhs1BPgqvU
dmw89gT1JBxYX7rNV54d7+0a5CnHppQWk9eCBsbz0gvDjVXUN8MaFTT96kqy
sBkPZ6eOu/nvqCdDNvJ6Ya9whnoyssIeFTaHkrkU7P3E0mfWVlNPQYRB8lhV
aaWeiqny393rJGepp0JZm9+gvkfmtiBk9O95FRrWt0ChWerwyM5R1+LA42lZ
WPd56lps3SN/tuBuHfU09A8nfDCdy3oaUmYefNify96fjjrfWufbR2qop6NK
sWbj4Sy218FpKakrT6f3CTrYT9Z7tH2N1Hk0BY8tujnS4DV4DMYMXfE7ThZ4
vH84RiK5Su7kcd885VdhsdFej1ZbZHJ8wwXa6yE3z/dd3VBLez2qDqW90P7K
RdrrMXwq1lh9+jLtMxCy2/StQkn34zkLGSgOf2TsctD3dD5nLhM/tH3TvkNF
RiZmRvxNoU/YPhNF+e9UlkezfSbMitqyrhm2N0A2EMKPB9bT3gBnz/abg8Fk
wQCx4aOXmvbYaW/A3Fsv7hyYpP/BZcHTdDBazbH9//4H02mg/g==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0nlIlEEYBvBdkdRVdFsNI43UQjwiNa81j3081ntVjGDFJNMslcwzA8n6
EkpbbaMLFHRzyyOwtAJTs1Ytj0QR0yIqzRBrUwtF/ynPCucl8oPh48czM+8M
81onZcam6PB4PP8/4++fPuG7u1m+gr6ODc1LcnOK7YaNyTxkSkwT5fpkfSSr
8pTHl3qZhbjeubXV4QvZDDZTgxLRJHk75MqpgvFusiWWG2pLrDRkK7TP1aep
z5JtYPZmxml3AnkPZrcYXhwQkW1h6Nz/IG++h9kOppfKzWTfyQ5YuzmduN5A
3guFfWiKMpy8D56WP46KLcjOqBh2LOho72Z2QbCq5EaqC3k/Jjzc6uS/XjK7
wnDYY6WEI7uh+WT++eLxF8zusFV/jYs1InsgwDRjTibtYvaE6qCr4bX0TmYx
fOq/fVBpnjN7YYEbKk9dfMZ8AIr30SZpdu3M3ph0ndGrErcx+yDFfdH+3mgr
sy8+L6hvGZfSfD/41Wcoc+KfMkugvVPU43eB6gFFg4r0XplmwxyQz9d2rx9h
5vmj8Ge1d5iazef8IS6cMGqZo/MFoMpHf3VggpkLwNJpj0rdEKofiP7FtYSa
bGYuEJK1/OWYbKofhNVJkxlpIq0PwkiTlZZ/mPaXIrRy/ljaOVovhcGYU0qh
A903GLl1oycgaGF5MFRt2uLXIspDUDutanKLozwEbkL71eTCJywPxU6Dj4Ir
V5m5UPRNhs821lAeBn7jngp7PuVh0Cuo0ak4RHk4bmtOXXZR0P7hGH74akTo
SPUjUKYui7eWNLM8Amd0V3Y86qL3i4T56NC2T7Z0v0hULzYqSs2pP2RYTWh4
LIhh/cbJoBj0emshov6N+t/cJvOiN+X/fD8ralfqWDQWRmRJQnl/x28BN04N

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0AtIU2EUwPE7JV9ZU7NSlPK5xI3lo5W2pmfqdDqnMqLAyECKnrRaakTB
bsYMZ0ZC+QotFSwDnyxnmq/NqblE0jSrVSqhZZYiTcFKM/pO4YXL5cf/8B2+
65kqlx2zoCgqYvX988XH4VXFOYFdT/tfzYWrsmZ7devQFHTNfC/n26NtYCf3
xYAtE+0AXFZ6puNSN7EzMF1cS4tm0S4g4o3re+fQ7lDZkT0cOYj2gHlmwI4N
/Wgv2O9mJU//gPYB8UJmmJsBzYKSwey0wAG0H5ia1BNL/7o/+JprhYfz0Bzo
m+l/xL6M5kKhuaOuToIOgK9BdxUCjYE4EJiHeJSsFB0EZ9aPGUUF6ODV81TL
d6zQu+BTu85kPdVFzINCZm5/8gJ6N1Q58Q40q9B7QFjcaDefqScOgbeurJt5
XHQoyLRXqnyP6Ij3wsp4xk9TdScxH6ozKjc+lmLfB/dVeqH1CnYBbP1cc5uf
hT0MXBftyr8p8fxwmEjSA2caO4C7WjdksUhMA5Q5jaY+0+K8EHoapcYab2Ja
CNKRfNpf2UF6BJzQvBbGG9tJj4CcqxdaBaeJqUgYTekcU25uIz0SLKvemG84
PyU9CgwMaVpgWQvpUaA2Viim84kpETimrYjPbsEuguKTfokjZuzRcDEnwbI+
uZX0aPDpzpe09mKPAVN67ZdBiuyjY4C9nfYcSsb9YnhObVJw5ptJF8O4pUx9
Xd5Aeiwo8tjXjioaSY8F77ZLfH6ulvQ4WFhmNWhvaUiPg6WylFKP42SekoD9
UH3oPVsyT0vgFOdh5NQw9ngo9ws+3/QO98dD32iL4VcIuQ8lhR99B70mX+L9
pKDhyeOEBdgT1ppOAIaJoWS/J/+bSlxrOhEmbRiaj6FPSE+CbUVhD0oEZD/8
92951VV9
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zXtMzWEcx/Gj6aKStli1RXdKRKF0PZ9u53Q7p9NtK5VWuZZJjssyctpa
HJWN0DLSXTgqnO5KV0WOWavwB9aVwrr9QTdhfZ9+27PfXns/3+9jHJsYdFCJ
w+F4/Tv//+zTfl90wkW988WyJrmjb+IMqrWYOUgtmHK6tGI1RGyaPiVew6yN
vt39eo7KzOshLFMdk/55SdbDjDSkPX6E2QCqezQ+v+llNoKWxaR2bhWzCeTl
0n1ni5jN0GverRJ5lHkzhHofcxZimC3QdDF6qdOceSvSdWplg4oO8jZk71Ju
6E5gtsan/uvzD9yYd4I7cLNptKKdbIPDGhPB5YeYbSHN72+eHmsj78KBuezg
znbm3bD00FcLa2DeA/uYnPAMIbMdepQjR1+pMtvjpHuNxH6glbwXSfG83B/v
WsgO+N3f1rpQyOyIhcSO9IlYZieU8yPT8njMzmgfGinusm4muyBPWrVKPNtE
dsXicdPOPgUzF7/CJ2XF041kYHTDh4rJmYZlSwCeudhq6DSZ44bCuMDSKJ96
6m7wmA3ZeGyglro7Qr27dKq6WXfHWuVrtS6K59Q9IHg1oJGtXkfdAw43xo8k
J7F5T1z1t5w9o8S6J7bY6u7PENZQ94KKwfYllzSyxAuGVnccr8xXU+chK9Jx
OK2eLOFhMMvSM66nijofESXJ1WZW9J6EjyyucajYgs17w31E3BSU/Iy6N1TX
abX5yuXUfZCxw/Cbxfun1H2AcfG5VFPWfZFZKkj48rWcui/4F76b6L99TN0P
JZzid69/llH3g01Ytqdm9SPq/oiJcqqvDJVR94c8auxeXwzt4wgw7OunayOo
pC5Ay+Ii1yfxCXUh1tnM5bYM0j6JEOaXHxqFFtB9TgBcneNXT6Ww+QDU6fPt
ZI33qYsgulukH61J70OEWzXn527L2T4RUhT81oTMkmU3i5D30VYxJ8un+cAV
/wXH7GX1
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw903tYzPkeB/AfodtSQjrW1oiS3Ti6s6neVLqoppru15lmppmQUE4tG7Ob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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1yW1IU3EYxuFTeGpm6CQxNa12chHiYpXlNNdu3VEiUiEwB4EbgtKXOkYz
ekNHXwpKoxr0IZRwxIJKqLmh5XGZa4K0wsaac4OKrFYHpaIX0KQX/D8P3Dxc
/DTN0oGW5RzH6f7t/6dTR11txlXj/iV9MQ2vjbpiajKHFXLe/lIVWYUu+cys
YzHIrIa7b7DePkPOwlX+Z7E2Sc5BxHfq/vQbcj4sXUHRlyBvRPl8QaPwgCzg
gi4spdwlF2JgUXOv7Sx5M9Ls+ZzHRt6CqdA+bchMLkLAf9sg8+RiRIs6e6XQ
U+atMHbkHm8KkvUweSbDgZvkbVC+5shpHeTtqD+qSEkreQeuOfv6G/8EmEuw
UHJFaF5NfSfSy25lmpLUd+HTodGF2tPkUqyMv/om5ZEN0CmJy3ZljLkM2pez
3iPdT5jLMf3ONtJ+g7wbTrdcw6vIFehOvD6pmR9lNiJjvf69TUXeg+zWDEPW
Z7IJz050Zk72k4GR9hdjgY+Pl+wAhuIzrnAqM1eJ8xUfROt36pXYlN4Qa5ij
XoU5y7HI4Z5h1quwV3+wZ413iHUzznlrf4xf97FuxkX+969LBYOsi9jgn6hb
x3tYF9HqjC9zPKdejSblTqrb+pD1akgTQq/l7SPWa+AUI7Fcwev/C2h+5+I=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw113tUzHkfB/DJriSXp3VZ7IaRVJtEUrSkd7lWdGVqpttcmkucJLmHhhbR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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tIk1Ecx/FHG2g1co5JMqI0lm01ltVWzqX76bw0kaJ1EaU3RqHZxQZe
ljV6qjcrpwQOguYkGw50a0EsitLUuWVu5CKS4YtGGESJlb0oyYoudP4EPnB4
+PD9H8452UcaTceSOY5T/1l///SJ4u4zBSvGh/9pXu++nRD1ppE5pLyuXXU2
nZyK/uD9Cd9ysgjhbHM4V0yW4J1mJnT6xxPmTCSkA/tPTZLXYK1C0REfJWfB
IG2xTrrI65H+tPPKFj9ZBu+LE6ZINzkHz4wVCzX5ZDmmN/QuZArImxCd6lS2
q8hKpL4/mVWtJqtwfXDfxMBcmDkXtk9yqSJK3oqcL28C3/3kbWiL1LsFTvJ2
VGx2aEIOshoRY/f8kIeswYX+YMjcQ96BoDKZr0qn83ei4ahsz52xEHMeDn22
x3Rvx5i10IfbP+7VUs9HjUd4oFVD1iFpytVlySPvgu6g2O06TvsL0NNmalzs
CzIXQhKzGjdmkPV45VwcscdGmYGvqyu7nCuZecBaK4w/qHvMehE0Sam8sHmI
9SJcbrqr9QaYuWKorNHASxmb54sB2y9Lk4+6AVdvzVw7XDXIugHjKX6gnpkr
geU8uEsNtL8Esx+mhevmRlgvhbw1rdGXTPcrxbdl9yQ/bXT/Mjx3CDLOVbN5
vgz2RxdDtsJh1sshjnhavB0PWS/HjVmzqVlJ79uNmzV1CUUfm+eXmDMu6f/9
G+tEBeM=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzHlI02Ecx/GfSmRaaNgxOqipzTCTLF3e+5j3dLq5LLCSsosQWSkquQ7J
MiNbU1c5RSV0kavZ4THBI4+paVRgp6B0kbVO84D8IzvY9/GPHnh4ePH+fh9+
iiJhvzXHcdF/77+XHccX1YeD7PruWTQmCphQZMOJmUNL50u9YLbbwvFUqtrV
mtkRtWe2mdO/95IXYVx5W3XiMzMPbuE87+wx5hXgR8i/Fcz21fAdL+w638Ds
jF7nOfkLGpldUcDX3jNqmQVYs2iAF7qTeS2yeFMnTguZ3eGmud+UOtND9oC3
IlGobGD2BMcLWFZbx7wBTmZOMSNm9sJCY1uzgyfzRgz4n09xLzORN2FjdcfT
XgWzN6IEzYGTAmYfXKj/vP71fGYh5hn0u9uudpM3I7377jqrR11kX3TZbU3W
9TP7gb87s8QYy+b9MTfD9XqaB3MAVtVcDLK9yOYDsU+dajqQxBwEib37ZqGG
ORg7ROVN/WnMInh33K0pc2UGrG6/7/mi7rQ4F3j+wUZ90NRBPQQ5xZuqAjLJ
uSFIcqk4yjOzvgVBa5J0/ldY34JRhyMpUQL6jwuFsUoeos1hPRRKOy8Pf3E7
9TA4K3zSzg22UA+DcG/fDVNDK/VwFMx7NWGoMlIPR9VkUV5GXCP1CJiX6vKe
bW+iHoHBQx+DK3IaqEdiuHVa+15+h3okvibXO4zwyVwUNDK5uD3PQD0Kv/Q7
eMdcblKPxqCu1FqlvUY9GsE/SlWJJWRODKnbsNfQT7YvxsDxxUNW0zXUY2AO
Lsqf+5j1GPgaTmYmKtl+LL6csj854lRJPRYJxdnjKpOWugTvIn3efjybRV2C
nm63OOWnvSJLj8Ow3603rXX5FufGYUn7yB6PB2XU4/G71NHaIVlLPR46jVlt
06mhLsWUasB37CF1SGEoVi0fzSqneSmq4wtH+1svW9whxS6hfmhl8yXal6Hv
kqQy8wn9BxnGlDLnHlEJ7ctQI5lKWTFRRPv/mUuY9R/H3Gym
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zgs0FPgeB/CpJY+Lnqpb0oSQGyGhkC9S3u83ZQxjppaK3VIpzXYtqVtt
auXSYyqsTaWISmJENAk3QkoZkdVjxbbVRbW79/T73zlnzpzP+f6+/+8s4G/y
E0zkcDiyv77/+2WfKZ1nN9upNlR/0bC90TQfIVeDmQO7sJmL9qszK8Oxeqhh
lyLzFKgZTy2w/L9n4NHVql22L+vJs/G31N7hZXXMWhDq/F3pcCszF/EGp0qH
K5h14L/kU0Z/IbMeavzy0xNlzPpIGKlcsXAfsyHszqQFT97CbITbyTvPK/KY
F8Muw3vTQj1mE8hkd+NeqTKb4m2+WZYLl9kM4kU3fRq0mM2RO5y0iHvjNnkp
hvSj2jasZLaAboesoECdeRk0+kwjjB/WkS0hKlbxLn3DbIXDPMXX284xW2P/
Rb9ml3/Vkpdj2m3tBLX3t8groNiZ3PbJnNkGU/NkuipDUrItJlzs39wRxmyH
T6az5IGOzCsREFQxED9WRbaHybDS3qLJNWTAQFgif2RK74uBQt0z3XqlLHfA
hy6bwY1vqyl3QNx5873BGhWUO8I++vhdq5HrlDtitEak8KaHzHHCjqKrewov
l1HuhPKgl/K2/nLKV+He1oq0nzNYvgrckRupQwMllDujLq/5QsXyUsqdMZpq
kFGXcZny1bAYUdet3k8Wr8b0KY9TXOsvUr4GJZVODfLdFyhfg6qufebaLXmU
u8B2cKu4h/8T5S4Qq+45Z62VSbkrMov2a2rGZVHuCtl3ibXPzh2j3A1NOcO7
H19NpdwNPZLszVqnfCh3R3eTm/27axmUu8Plzaz0Yv2DlHtgYr3XCn5SOuUe
GP88eXB29mH7L7kn5Fa3ulfj5BeLPXGqN1tLISKFci8sf5Jg/W8DlnvBpLab
M+RJ5njjj1aTPuf2c5R7w2eooVxPoYxyH0y9NSOBM37ti+EDz5dm3M6GG3Tv
gzz+Kb+qmMovlvpg5Hfr57YXqqjvi+riDu0XydXU94Wp9QVlvSIp9X0xXT6m
o+1VQ31fjL7xtJH30T3HDxtVmvRr8lnfD6NKQRe7K+le7IfMjiN+JZn0ntQP
Jl9Zqc1Ko5zjj+3b2+/EXSDDH7bTj5Qta7pFfX+kLm8Z+/yMLPVHTXbrt53O
tdQPwKjv3Hk7xJQjAPHKvgL5GtYPQECO3dj8ePb/AzCovNg+ewrlnECEHgu3
XFDI+oGo7TCyfneS9QMxTSV0iaiV7QdCc1zWMRjD9oOgNPl5/Ptk1g+CTdez
tpwXlIuDUPROcmPfEFkaBLeDiSlXP7J+MATxkgVZr1g/GCku+524P7H9YNw7
tHeh+y7WD8bj/s36/I2sH4KXiVUu36eSEQKdgdDDVR511A/B3Sj1OcE/s34I
MprmzhbXsX4odDJ+PN19j+4RipD7VjMvtrN+KE5WybuqOlg/FK8fXHFLjqOc
E4bJWfO7x/VuUz8MB9Mfai19TRaHIfZu6nkj53rqh+Ha0a+Tnh8ic8JhXBvw
9N2SBuqHY8U3pXuWLr5D/XCU93ASZDZkaTgKBH1Wvw2wfgTMZJktV6aSEQGZ
842tNhNl1I9A44SvuqeOs/5fec9vGarlZM5alLjcqtS0pHusRWR08qT/TmD9
tUg8uUi7afVd6q/FhI47kx5LG6m/DsZvrS285zZRfx3m2ctq7Ayaqb8Op1fd
dPswRJaug1CUMXHhFjInEktuqlka5t2nfiQGcgetZmxqpX4k/IZeRGzsJ0sj
kdqYPPNcbhv1eTBrUVy65gOZy8MWZf7p9FoyeLj+4OYPq5LIPB48vGvi/DUe
0Ps8/CK47hCXSpbwUJatljWWQZbyMKI1V3omlyznof2kk8pzw3baj0LB+tTY
pnlkbhTSjaq3Jf1K94jCeqfC7wM6ybwoxLQG5cz8xPaj8Plz11mlS9SXREHX
3Eq9vZEsjYI8bs5A+dcdtB+FTIs0o4/qnbTPR5poUYjgLJnLxwT+KcfZB8jg
I16luC3/BJnHxyrJLmnnpIe0z8dxT8t/htiSJXyc+M7h+MxXZCkf6z0jFxco
ddE+H9HFOrq5BmRONFrSeo03TCNzoxH3TKl0zIOMaPA8yn546krmRWPPupZ/
NLuRxdGwM8+2VjlAlkRDxr09qy+HLI3GW3fF15rubD8as/oX5kVGsf0YqPAu
KWRnsv0YHEt7W9t8iO3HwKv+R2XDRLYfg57EplfDJWw/Bkkb/XynX2b7Mcgx
/SMrn1kag6UburzOrHlE+zHY1hCUp7qMzBFA6b3FjA3byFwBKsYPbN90ggwB
FAO1ko9+JPME6Eopy7UIeEz7AjxK6IPJdrJEgF+GB2PaxWSpAJ7xDfMMu8ly
AbZ1lBi4OXbTfiwc2+9dNlhA5sbi4BmN3S/dyYhFWf24oYGYzItF+LX/PInd
TRbHolGzVnppB1kSixzj69fGXcnSWOgXNRfP+Z0sj0Vm7+D9jCdsX4h94uzj
Dxc8oX0hYNb8zqGY7QtxXXu4WEGXcp4Qmxr7j15VI4uFyJPY7CyqIEuEKFw9
Q2uPnCwVYnawWkPbC7JciCLDh+FPvn1K+yKYhXg5fG4ic0WYNGqWcNigh/ZF
mH62wWqnspz2RTDtuLLSUoEsFsF3vqqayTdkiQjTRo7ml1aSpSIsPuKU/4rT
S/si/KqheSDFlMxZD0XRVoy79tr/CRqd+pM=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQMC1xcX2HId3w/hfbBPf8mbzcoN4zM42HKpSxsK
wPgcDgwnrzX854TxBRzawjYeq2GE8UUcFs8/wFzy/hiUL+EQXbvdZM1tGF/G
wWrb5HTDizC+goP0p/VbfA/A+EoOIo8mNO7cDuOrOLxvz5y5eiaMr+Yw633i
oa+JML6Gw4HCecU2ejC+lkNdbWcC78ujUL6OA/8iAZMzO2B8PYeKbeembiyD
8Q0clioEtG0Ih/ENHXyP3am6oA/jGzmcLdiibVoB4xs7VJV3XHgxFcY3cdgX
5PvcKQrGN3Xg8tiS5X/nCJRv5pBi9FQunAMmb+4wl+veJJtQGN/C4eTXB6c2
lML4lg7ftP64ecLVWzl86jJ8pxwCM8/aQfaWv2QsH4xv41B5fNqKtiQY39ah
bOXG2BI2GN/O4V+mZsKV5YehfHsHVafb58LdYfIODh7fZXacqoTKNzg4ZCda
2Z5xhal3dHh24ZfHqUSYvKMDa/Lu2LJZB6HyTg66m/VM8vfth8o7OfRVMra9
LToAlXd2cHz4PvOvDkze2cGEJch9bvweqLyLw1WeNRPkru+Eyrs43Jy51DK9
GCbv6vB2itKE9AiofQ2uDml8YZuq/22Dyrs5XN/HdODm0X1QeTeHw3OPvItI
gLnP3aHA9Orit53Q9NmA4AMAnmr0VA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdkgs41Wccx8+jqagpJSsRtS4ywlCcZr6uIbkct9NxLuboHpWiKzvk0rTc
Q3JJtsoyrXQyxRxCl9G6TGUauri06KKldJltj9+7Pfk/z3n+z+f5vJ/3/Z/3
fWcGbeCtUOJwOLv/+f37Zs/EW0UbrVUvVA/TU5uC2eX1mqMZc7BLLr0+4W0D
8Vh0dun3a//HE6FTWejJfcZYA0KtVmlgG+OpSDBSyVl9nrE2LEJ2BIljGeuh
LTR1b5mU8Sxs1VaIe1cxno2hO/6CWQaM50LSEKbmYc5YH66npdo9zfXEBkiJ
iLStLGFsCHmn/RSTg4wXYH33w12asYxNMO16+nfZSYxNoX8/fN3pCMafIuFt
SE4xh7EZiksF+yaPqSM2x3gVG5O2+PPEFlCu3Xk0UMx4ITROtF+cJK4lXoTz
IS2LyqU1xJbQipzu94EuYys85r78o7iZMReDH191zZnP+sXoe2X16ORz5j9D
cUmu0GCJgtga9578NT5gbCXx5zBvCa4c3FdFbANu3zylQeOfiIEuy98fbb1H
42XAnCc8syvTz5K3hbqfesHd1nLytojN324oV6kgbwcDddEl25ty8nYIKjp7
9avHzNtD9a7a5btxrLdH/su8h6aRp8k74JxGtkeULrHMASn8xDCzvWXkHWE9
9cCoAi7zjkg0V6p3jDlF3gm31rkYPvyNWOaE8Xo6qeq3T5JfgiCt3BfO62k+
2RJE9RRqmr/7gbwzFro4zfDeUkreGSt1Wr2e2BBzXPDAeOZU+2YaL3OB2ex7
OyTz2fquyJqxzMf15+PkXeHWkJ+6fXMJ+aUwTh6okngdI78UOU1hoR/uP0Le
DY0dzwbkYwrIu+H+tC/ULTMzyC9Des3JATfDLPLLoLI4buelFfvIu0NDmnHh
l/hU8u5Irsn5E0lp5D3gb/Gm1yUln7wHNEW8mnFGh8h74lV7a8nxuqJhxgiW
ecIk94qd4wsar/CE+8Wuo3Jjmo/jhTlNZV0TJmdS74XmrRXRpVFJ1HvBwr9y
V7FaIvVe2LFmteCMKIV6HoRrXZOytOn7wYNuY5v+K13W85D2TWdL6cJ06nlQ
Gn3h67yzbH1vhHaM+2hlJn0fvHEqdFNd5/4D1Hvjyuub4Y8zaP8U3uj50rpo
c0A29T6YJJJy1+6k/YIPZLmiKQe4hdT7oKnvzKBDBu23wgcaJjdMN8TGUO+L
/klJlUM6CdT74seEtAlRrnHU+4J/VSW8N0JKvS+Efe0nhozW2Az3fmipG6gt
f3BwmOEHVYsHxVJDYpkfCjy2dc3qiBhmhR+8tvUKn2dnUu+PGD1LVb6pjHp/
5IUZiQ7fjKf1/aGmGnGxIpv2S+GPCI3qLHE/+/98jGlwDK51JwYf66rz1YMn
RlPPx6/xt/cothAr+Eh4s+mgdPRu6pe/zxjBshGsGMEcAa6lp8jrS6KoF2DF
U4dV/CEZ9QJomi0wTgjZQ70Ao7ruWC04tZf6AKS1rDpW70T7jQAcalRrT2wO
oz4Ao/hN7fZ2wdQHQH67xzkeG6kXItfcyombtZ16IUxM1vdyK3jUCxHpzntj
r0z3UyHEiZJPEqqWs/srQvdmH8k1Z1oPIjQsd+yvEtN9kolg+67qSHdqKp2f
CHljbwmSlPfT+YlRKpje3fDsMJ2fGB1x0ZeT5xbQ+YuRY+VUrbDPoV4M2dD3
0TdssqmXYGlp6zRVrT3US5Afd65ReV4h9RIEJm+7H/Utza+QQI8bnlb2upT6
wPdZbwTjf/4b32Se0g==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxF0GtI01EYx/E/grkUh5WU4BStP5oX1NRylrqfl83LtBcL6YUlamVTX2RS
JlhrkBVesqCpUaA5zcyyVjqxlpoNl8KU0shQhuQKDaWNfLMuiwrPUwcOhw9f
zjnwBBadUBxz4ThO/Gf/PWl5zXaUJ7q/GlmXXTK/+klp2EDmsLJsdUg5sgDu
2TM1SS5kLwTULuncVkzM3ih8p5wLWyD7wB4hVhWMkkWYvmeqyW0nByDnmm3u
QCN5O564hqsOl5B5LG9ZFIb9cxD0Z1ydvIy8ExHVLj+kmeRQmCeC8oYSyeFY
i26abQgkR+BmyEdBTCQ5CrzEo7IhnrwL8/t9F4rXxpijsclSUF8VRo7B4mKv
JtKfHAuP9mJ/3mZk3o1gqUJ3dYy8Bz76z5ZYV3IcDI0moWb1JbMYonJx1rSZ
HI8177Px+R/Ie+HrXf7GyY8y78MjR2GXcuIFcwIU+Q+eey4NMydi5Lyy4nsp
9SQsz/oeeepHluC1XCiX1ZGBjPvjpZLmkXWrAZvey1H/7RnryWgpq/nZf4NZ
nQyPNmuem2qQ9RR0FGtmTnMDrKdgUt5SYfylYz0V0u4Qn43p3aynwqbbdkGl
vct6GuJS7freug7W03Ccv1X9trqJdSkmTmUbii61si6Ftq9zZciuZV0GHS8Y
DLbQ+zKYi67Xqt3vsJ6Og9MXPUU9zayn41CoXwl20P0MROUMHDWo6P8MnNNc
mZqsop6JrZtPmt9bqWeirOd21aSoj/UsXK6cSsjl+1nPwmPj+NfWh2wenBxt
MU7tl+Eu1v/7N4f2Hcw=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgs41Pkex/GpY4uSpEKkhpO2UqRISnzcySXG/dI05l6K2FNbUmcSu6Gj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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdyWtI03EUxvF/OjDMauqykpLZxdKsbOY2l3PPnM5LWhS4bsIwCCqTyl5Y
+SIRzfCSkTGdWtllizBLyRQvtZa6NdFAS8WizLCUwkuQbsWKCs+vFx14OHz4
+h88vvuQC8dxYX/297PjD946IXe3muY0rdjXp+gwezBz+LFju/ARj3k+Mr36
fXbaLWQ+SvIn7PoJZgEKfjln5v3zMmT27E3p+cK8Am1XxpX575iF8NaclC+x
MK+CyLe8Or2BeQ2kk7zC5+eYA9Bf53pp8VHm9VirN3Q7xMxBaHIkhsvHOsnB
KO8auN2Sw7wJl+vDLd+0zCGo15xxs4qZt+DnrMvS9/YOsgjqcWlVyyhzKGpm
aj0y9zBvRZVpyr1hrJ0choj7y/sOvGIWozu9xPj1CLMEstD9ktRgZima0za8
zR00k8ORt9owIGtllmFySF600sm8DUmHpweyRMwRmNUuPJv8+ilZjq521VSa
gzkSstaiiizvJ2QFil1fer7xe0wGLvDTJanH2uacDQiU3jdtzmbqSpiNUQ97
c1uoK6Ha/MmjzNJIPQq6xCB7yKIm6lG4ODzzQL+OzKlQNmy7yuXcoa7Cs9GR
FyN+BurRqPVX6hokN6hH43x3qfZ03XXqMZB4VQk/3K2kHoPheF2CIPAadTVK
knoj7+lLqatRkCwo55vzqMeiIvu7Z0xANfVYZLQpfDN4ZC4ORQKfBW6aWupx
KE6st35OMVKPx1DPqcDCwRrq/5lLwEaLrfPjrkbTbxnSEZo=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90G1I01EUx/H/lNK0yNSgSNBMSyJNZ261Of2pm3NKDUylnDWYBD2BZhFF
DTdw5rLSN6nVCjP1RWLgmmbOnOZze5GFpQyKgiLSCNEKdREVndOFy+XD9x64
3M2GktwjPoIgSP/svyevoKl7pYqAUdc/zaX2jX5Sv17BFqDc37Ay3I/tj4q+
n+Hnvo2Qg1B4KrS++b9DIVF3a5ffsTdgqkmVXeRhh6HuUJnB2saOwPRR8Rex
lR2JkTx70FgJOwrxE8HT0mj2VsSuqbxWFsKOwUTWbPXz2WHydoTIWuYbPewd
MC4/GtPb2HHolZukl0XseKiskiVb/xA5AaKGdYrvx9hizDjHfe/r2YkIKzbf
diaxd2G+dHlb59tBchICC70nzDfYEgS2Dl233nlKlqJVo9HNtQyQd8Po1u09
29hP3oPDkphVzTK2DAFmh8Kn20WWY3BwKN220EdOxurIK7nWce4KFHrqEu0V
T8gpyBtbyk2OZqfCN0yXpx3vIQOKibrg+ePUTUCGvEpINfVST0ObI2XfJe1j
6mkoqtZFiHO6qadD/KDG2/6DbEqHNt/7C4td1DPgJ79QfdXroJ6BxZIB2TOL
nboSHQv1XZYl7kpUvXxjqLlJFlQw9xRH698/pK5Cqyju7kk790wE9mx0eJp5
PhPDp53SLQl0X1Djxa2vBz9WdlBXw2/SrK/N5/kslFuS9UUtPJ8Ff/ek44OB
369BaJRr/eeZTuoa1F60xOoK+P+ycSD+vHHtTrIpGwV4Zdwkov8ScnDGXd5k
G2h3/QbDKxXH
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0X1I00Ecx/EfQmHaH4tMC4ycDcmoLedMm3P7uAe3sLIGDsYQqvWACi5Z
f9SItWqDWq3MP4KgUBIqGSQV7sGms81lfzV7gDIK0RUJKnOSYWVa0X2LPDiO
F2+44+74By36w2kcx0l+zd8rDd7rjmMVGYPhP5pWSMxz1yb/mkN8xWnr6PwT
5nRcaZysDiyQedDLhJx9jpyFurhTbJoir0W98OPyZW/Jueh3X3B6B8l5GEpm
BJKd5Hwc3e+o/ewiCyDRT/DONJILYGhf9c6zmrwJKlE8LngRY96MjV7b7EgJ
eQsu7elec66ILER1380+cfsA8zbsPvn+XuE6chFKvy0qnRejzGIo6432mvkI
czHuDjXXyNvIEniNbX5zJrkE2R0zbklrP/N25Gb1pFx7yaUIL7wZHs8kl0He
ZFLM5IaZd6DcF5Zne0PMUjQ4E5cNol7mcpj8rllLL1mG+HOp1554xFyBhzmd
kRP7gsxyrJ+9Y/sq8zErED1vrdXe8jMDRr7Z82yR2QHki4Ih6X3avxJbU09v
NH/pYb0SQbXqbMsBZk6JI2M5yutT3awrURwaF9zuovNV4J966UsJmB0qJMcM
2R8+UVcjFivY5Vmg89U4lLdhZYYuwLoGw1a5rTD6gHUNmiaC4YYfdJ8qpL8a
TXO6H7NeBd3xFotKQ/+nxfcR8XRZHXtvhxYRU+vA1QS9t+5/O5aY27mk//NP
/skQ6g==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zHlIE2AYx/FlmKlJS7ZSa6FiLXSZ5jGPLX9zbt7rUKpRRoiW9I9hlihe
mZbHIIpALUhMp6JZy8yjrLktyyRZZF4QDSQxFcVCRUS78HlfeHn58H2fxy05
/USqFYfDCfl3/7/scEfrLkvt3us3tBBW6i5pyNvOzEHSo4TFBzuYt8JuUrhl
cu0dmQuer66fP8fMQ91umzLZELMTfM1rJpmJeQ+mdTNOXfXMrji3r8LtVDWz
O7SZDfbPxpg9kO4xkXj0OfN+qL933ipqZz6AHmNwUPUdZk/cH25y7HdnFoH/
Sjq74sPsjeaBP83LC31kH9gKP7c4WZh98bFjb5lBw3wYCas66+nat2Q/eH9K
u/Rj3UT2h4PKcCMhlvUAiMyF4sA05kAMpH6wzhph/8Vwyf5VO2tkDoKFb/59
r4Y5GGPtEo3PNuYQrLcKcjdrjeRQCI5H2VRO9ZIlOFY88lriYCBLcTW1Pr/m
IetH4FYhO2uee0MOw4z47rWlgh4yoB9v4WXPvNxwIVCtKs8tUnRSl+Fn5pJW
ouymLgNfkVOZlM/mw7HMVwkGF7uoh0NiVIynLNE+jhwHXeMDFN0d1OVIxHxQ
qd0L6hHwzBBwxvlsPgIlXtYnnb/Qf44C86MuU2KLjroC9cl+Bf4DT6krcT0r
J8208Ji6Ev0136w28RqoR8KwGtqkiW+kHglL2/lBk/0T6lGQlwwdkpez/VE4
cyV4wjldSz0aakcvIVdYRD0aUtXX9hVRVdhGj8Hpm+KBKbWGegxExbdrtX0X
aT4WjiP6RmVGHvVYZO1K2XmB20Y9DgbP8IwqdSv1ONi2uAxbTffq/wK72yJI

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdy2tI02EUx/F/pssbpmggFDZlaRdbXjLN237bvExdZr7IMCwy1JRAoy3D
Uv4QlBeKtBeF1AudOMvKiZWbjLTIHKh5aeVCcUlk0Q3NtKyJFXsOXR44HD58
z+OfW5yZ58BxXOyv+b3peY5pSuJc+7rtmpEUqL3amlzIHE6V2VaLBGRnLIXF
dSysIHvim0GSM/35MbMPDHUJ00dmyL4wmcvzRc/I61Bfsn681kQWwvo+3Vbb
Qg5AaUaHm5+aLMKn437ujjnkQCTdmkjbICNvhEap9rbYepk3I3pEfE72hRwM
71dTe7+OkMVw6h5SVarJIdAIiio0lkfMocja5rEyc4gchhqFTVJYSA6Hp1Z0
8O1W8nY4lcgHKlzIEWjPz/M6ZnrIvAMvnZ+WjunIkVj7vfIk0slREA6Lzk8G
kXfi4+TVuqo3D5ijYVkeNWRNkWPQ9OJiUXsfORby4ew56zw5Dq3lhqPBZ8jx
qOKNN6qjyRJEdGSf7s7uYQaiNqn6T7y+bzcPvAPfNOvBzEkhXCXw1XZ1sS5F
W1tz6I/rRtZl2M3Hh2dJmXkZYg2zDv6LBtblULmnFit1nazLMT+tl/cvMXMJ
KOd9nnjp9awnoMW6pWa8jJlLxGXzQush2T3WE+EWeTtIPHCH9SSIAgc7Y6/c
ZT0JA5aJvudr2D2XjF6r9GbxB/qfjKn4kEWVXse6AtfGOG2vqZl1BUr3BRgP
OLayngLh2ZjawJwLrKegWudQl6toYD0V+wvMIzGGS6ynovHwHn/X0XzW09CY
+5f5tP+6Ej2Dc4Jlc73E3pUwiTMajN5au7ld/5r/4594ZTAr
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQk41fkex/F/m4wGURIiUiltZGkbfJwikez7ds7BcaQ6Uo1MqtNwU7kp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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10ndQ1HcexvGfWAFbDoKIQlbllFOaCiIBwwPSlCJNetld2hoLzXZgWUBK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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz3lI02Ecx/FfeZRujnmUDkvTJKxkTpfWtLmPa3OHslEjMjM6loqkpGGR
grkwKucfKakoWqRZOAIhKsOlU8rNI+yQxMKww0zBEEkogtKMnm9/+MDDw4v3
c/CEHT+1L2s1x3Gy5fl3pSEcu1Ug9+7v+ad5RYH/95EmIZmDUTFRHcgjr0X8
+2ppjRdZiEpPk3mVGzkA24+k6/v+OwjBWz0nfdeQN8BsE++dmncxb4K7VnDA
b4EcDuGLgYWMN+QIFObdP1HRRN4CUZ63Pf8iORKGpUeBEWnkbaiaCBdJ1pOj
0D+s5Td7ksX4qqszvnM4mSXoyiwukT8jx6A82X8qaJQci/3nfVNnK8lSJJy8
MNSRS96Bl5zSWBFOjsPiDbfujXJyPDoDTnfI1OSdsLemD/ioyLuwziAUZPzo
Y5YhU3y9tL2WnACfS7njl23kRATEC6Q9M0+Zd8NRdubgvSWyHKoSr83BgeQk
TPEqTWfdyApoZ2MPR44+YQYW1XO8RhHrFkAQmuitTKKejEmNwjDzq5f1ZFS1
RXD5HxysKxHSMjj4zcZsUUJTZE0qqqW+B/4hDb9dn6kvu053rSGLugo1H9+e
G/HoZl0FflV0+cN5O+tq3B4ObS8+9Jh1NeTRN2Mk08xcCkKbW+ujvKin4EGq
xzFrayfrGkjb7rS4xtl9Fg2ynfWSozl0XgtzqVNviutiXYvqMmWO9RN1HayF
z0fGnOw+iw69V/h3X/mx/ZwetsZ08dVsel+/oqdC+cUx53Cn/60wl4af1tfT
WUOOnj9hhxSg
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90V1Ik1EYB/DXYaRrpaXEaks3E9NYaqXLr7m/c/MjgrKLwIoS25KIoVBE
XqxekSTtS7QPycwwJS8mdmFS6ZzbtM3R1i5ymSaRUIHSaoSRhljheTxwOPz4
H55zznPk5ZWHDQKO49L+zf8rjch3j6tUQqd1RT/UrmmxbDGczEHwa8obWM3D
cPZTKQKreSSsX/mH3MIr5miUK7suYY4shuKM70SbhyzFEeVxS4yfLIPr50R8
Rjc5DoPKNVH3OsjxyL7t7RmvIycgt6z+mP4AORER9qPyxo3knQgpyZ+tfTHK
rMDzhFu1mzrJyagW6k9e6CKnQhuYbOlNIe9G6PbcgZ5Q8h4MjW27/2xyhHkv
FkzNfaI2chp84e8tlXJyOgytEZubQshKfDY0lKs58j6Ir3yR1kSRM9CgqnH/
MTqYM9FeLQhmSe3MWci+vCQMPrAxZ2M+ONM+coOcA1e0cSppephZhYuz5g8O
CeW5qFD0izy+IWY1jB+9ttO6QWZgzh2SkuMcWDEPxLb87t7gtLA8D+5ryxXd
S2w/n4eb87Y3fTFsP6fBt5KDmhLlS5ZrkLgMTayT6ufD4Zq57uln9fh8eBZF
d83NVpZrkTpxSFUqY+a1eJvilcxupfN1aP6+f8vMLnZ/XoemzE7T6zp6TwGU
681hkjt0vwKMy8uqzvupfiGmT8kD53awfvCF6B2VpyfXU3+LoH80tnadk5kv
QqPfPNxhov4VIy7pibAvjf0PX4zg1adlxa12619B7ghk
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10QtUjHkfB/Cn1K5K1rtSLq9M7rJIkULTtwvd6TalqaaZaW4qJ7Ulkkxs
hVBbvVZRol1aoiIsXYyUJIRclzIbtZbw5rKdVy5ve/z+c86cOZ/z/X+f7/M8
YyGN9ZfrchzXMvj955d9RtwtXe1g2Hzui/7rOPZlYfKY4cwcklbXxVsaMA/F
qzSnvQKOeQTifT+nPvx0kWwCSfMfhW+6mEdD03JHr+wu87/RcW397TePmHnw
rNg5yqyTeSKEmkmzc98xT0Z4b1T+qFbmqajKeH2or4J5OnJT9oxzLWa2xOOW
beNjFzN/h8ScCLeNdsyzcVlkrv/xUhPZCnN91OWZQua5sJPaDXFPYrZG+chL
HibRzDa4Yz67uCqLeR7Ssrp9NoYwz8e6mhemtW8bybZQ8lfmppxiXoC498J3
skxmOxR81+xepGC2x7QbVsqtc5gXor3x7fDHlcyLIEirHfO//cyLISq0ztyQ
yOwAk7/03tnsayDzUb9K6WVyhdkRc49P0zZZXSADfYvrvFtAVgO2H3NOlB9j
553gWWYi7ojTUO6EMolW92PnOcqd8awqp+3KQB3lzui/5t5zfAGd51ywxv3J
yzeNNZS7QOxhbZMXeJZyV2gTipzTJ7LcFclLsv+Y0Pob5UsQd60+v28CWb0E
LjkHS2UedJ5bivxZJ9Uzh9ZSvhTXrLS7Rm8ic27oK5BZ5j0/TbkbjnoJ8uNi
TlDujqoJurlz9Sspd8fRr2vHC3eXUe6BDa6O7/VOVlHuAWObuSkb3x6k3BM3
vFr6hsWzvideWzxVx75g+17oSxpiqv3M3o8X9m4f+mvR+gLKvXF13qob9mbV
jl9ybyRNnJ9XXHj4izkf5PX79V/tPEW5D/zTjwz5yrSW8mX4pqzENNbkLOXL
YHik0TFgF5lbjka9ojM9hnRevRzJ1g6lhT//QrkvOkRPMjfZZnwxfLG92cc2
7eg+Ou8Lk4rt9+09NF+s8cV/rDPlFklkzg9T+3d89F5wjvp+sDHilWxLJKv9
8FQV+sFwLFnjB/W2EptRU8icP3KXPSzMmEXXgz9+rq/W2B1jfX8s4s/v7NVl
fX8kzFKf/6aD9QNQ9OlX3UfO9dQPwLi19gGGKrI6AK0Ss4S1nvT8mgAYx/59
VGRKORcIyaKYEevHs/sPREKX5Y6VJ2qoH4joTKfuk6511A9EXKfReVcj1hdg
o+XpzbEbKIcAgc4N3pOPs30BbrlvTzkdTtYIMDRZdH0/e19cEBo/uPNr09j9
B6FtP/pftrB+EFJ14xKbS9nzB+GBqNZYv571g/FD/sDo5B7WD0ZvjflTWRLr
B4N/iV9Rnc/+v2Ds/HxlcsEW9v+tQG7B5qb6e+z9r8DKW9Vjhrqcp/4KLHvq
03N1F1mzAgkzHrtF+JK5EHz4/bCTjoiMEExv+uzMC2+gfggCsldvWhFP1gzm
0dlLq+ZdoL4QZrX381KiyBAiokKQ6nmIrBYi3YLXb4dG6gvh23w3oL2b9UOx
51TCU7cDTdQPRd893kJORlaH4oH+D/emZVykfijMvR2mZEU2Uz8Mw3mr4vSV
ZIQh/abBuik/ktVhkN7ZPaA7+RL1w3Ap5vuy0RYt1A9HvM638oNGlCMclvnl
mnExZHU4NquabtXl0nlNOOJeSWqai1lfhOBnZUYzY8gQIXnN0rHr7rC+CM8T
76zp0rK+CB03rfW2HLhM/QgszPn7dYislfoRsOxa8nGk7hXqRwBmUX1/GpI1
EYgx7Fed0pA5Ma7zds00O0LmifHjhLaZ+g5X6XpibDV02W2XR7l40A3iT1EZ
7PpiZAoE+mfc6HyJGPq+C4bV7SNrxOgVtY+OnE7WimHFP5De9IntS2B8uq1+
SxzlPAkkukZf+9eyfQn8CgQNDWHXaF8CfvwF/gcpWS3BfYPKLb1XyCUSpKse
2got2mhfgr1rK0T1xynXDvZdrerfGVDOSeG6fIRRei+ZJ8X+OVXHgtLJkMKh
dXhISCVZLIWXiDv8rRdZLYXng8zNN1eSSwb9evUjicF12pfi077IcfO/Imul
OK/ofeY0g+1Homez+/gedr+8SFhMenXm+VS2H4kunaxzm0rZfiQGwiKSRvHp
eupIPOFlfS9wJZcMXs9lQFUSxvYjodNdUXo2le1HoqI0L2+nH5mTIVpgfqY7
jsyTYfnk7cHGeWTIMMSoSViYQRbL4GfqK9/YyvZleNLmktrdyfZl+Mnxqzm9
p9m+DO9fiHXym9m+DJGpVdbKf92gfTnSKnc8al9P5snh0naoo/8MGXJMzT68
xL6cLJajvLBIvzyarJaj78D0rb+dIJfIcTJv5G3dGrJGjpR288TFZjdpX44d
RYsi7EaQOQW67KPt31ayfQXuy24s3JPO9hWQ944p3LqO7Svwy03H/sMytq9A
zUNptsnvbF+Bx6PMd5pms30FXlTzHVvmkLUKFP/V1LvOgj2/Em0enVmGJmxf
CffbUfwZu9m+Ei2JEVsVF9m+Eo/fbruwcD7dv1oJ6Z9B1cJJ5BIlfioWBSpd
yBol/PSOWM/cwJ5fif0PPGsOMnMqGE/Itnjj3E77KnQ+nK3DLyVDBZeLFypO
2d2ifRU+I8fryWKyWgVhnsFAdjq5RIV5l89GnUsia1Q4lK4ZtmAtWavCRsV0
48YYMrcStnVZ2tDyW47/ByG97Dg=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzXlI03EYx/FfK0mMyrLDDjtMU7RVms6muX3MY25T8+jwj+gwFRbihZal
1IqMmnSXZyVkWCkpHlNz2axmknQtEdMpBhWIMgud1cJ1sefbH33h4eHFG57v
6oS02CQex3FBf+bvZs++tyI90K5Ta9UXcZ3Bs8bOhpmDgRc/IpvObIvw1jH1
vp/PyPZ4Il5R4/CdeQGq3UVFljFmR+yXNFoyxpmXI9mcwbtuZF6F7KLF5fWD
zM6Y09p8Pu8qswtWumL33gTmtRBK9ZM745ndoe0bGF3LZ/ZAWWnd8zNDHeR1
eBFg0qb1Mq/HWTH/Um0980bEvJ5SdLoyeyF0JLnlcjSzNwbv6N8teqQjb4Kb
28DdqRxmH7TMON+myHxK9sXbLDM/MIFZgBjl7aVHS5n9oJ7QCbp1T8ib8UOZ
ebJ1L7MQOW90Lm3nHpP9Max4mP3yWDs5AO+bS8pS07XkLaiIiyt4KWEOhLAh
zDDxmVkE6amSHEeNhizG8UnJhR7vB2Rg4YtXw7xNTVYrga6e2pvTzpC5IMRW
aXI/Pm6kHoSO1BGzML2G+lYkivim3EN11Lei23N1rn9KA/VgGCvdbk9tUFMP
hsN8zZXKPnY/BLNCfVQFva3UQ+CkiLIkLaH/uFB4vpk5u1BeTT0UyxJ9++c9
JXNhOCG3KbUV3KceBvmBLL/BV7XUJTDfKA537lJRl0Ct6pdIvQqph0MnWGwa
B1kZjv4AY0b5rovUpfBwFLkUtF+mLkV9sVBTJLpCXYYhsUGxxu4adRn0xhCb
PV751OU4KMsz7uhRia1dDp9fG/zP9pRYzUXgg8lSrUy6Rz0CeqHT4U8ljdQj
EVwl6yjyaKAeiSOnU45/zVdTj8K30UTp3O4m6lFw2O76fL2kmfo2OB3kVLG3
Wqj/Zy76n38DEaVH+g==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0Hs01HkfB/DpjnLpJmza8SQRKkKLLW9yJ7klw2AuBrk8KSWlU9PJo+uW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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQlUzXkfBvD/MdmKacElSyox2aOFSnoobZK2277cut3bTat1SOVapgUT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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90As01HkfBvBRcqs23dPtnYgVXaSL4rUeRUpIgzHjUjNjBt1IF5TdjCJE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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zWtI02EUx/H/9iKtZcySDLK8pGltmTbbas75++9iZEFNKAzSQpmgpVME
iSU4LDIKJjKyBuYboShMMhqmztbUTXRQYzEjci6w+Q+GFYldXnXB5zxwOHz4
cngyaywVZjHHcfn/5v+mJ3030Fyyacazrm+lsSHJSd9GMgd79Fj/kwRyIlRd
ir4DIrIU2dH3VusXP3MKgrfczsIF8g6YNI3C5Qg5DYJyg//8G3IGpqvXAg9H
yFkw+1cC6RZyNiRPU1O2VJL3omhhsK1dTs6DLeGH+9pHH/N+DF3Rnm3tJctR
3Ct89VSS8/Fn66OBD2JyASS5LWb9zWnmQoQPzvaoB8mHEDGdlgXDZAVEHZv5
+yZyESzKxudXR6eYD6NquyM010lWYnk5yeetnmRWQemwGXO2kY8gNN56I2k3
+Siq1HvSJlq8zGqolpYaFHfJxYjbLokufCJrsCp9tiprJpegLdnwwBF6xaxF
jubE78e7qJei4nqy2HuKOlBXq9qpnfes2wYEwmuuMzwzx6P87efAbNNL1nl0
p4d/RSVjrOtwrsk19X1lhHUdRHxHfWrDOOt6uGqGIzo73euREZPXd8XcrBtQ
EBN+YnGCdQOOx+tedwsu1o1wOvvu5O0bZd0Ic38nJudfsF4Gr/1isD1O/5dB
fM8quz085vkLkmHpTQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxFzntIE1AUx/E5SJwSmVSsWjgfVFRKm21atvbTbU6nWIpFkA/K+sOofP2R
D7ARiEyIJF/gg7TpotLZpNScpLW2oH8SDTItTBQEQbfSbNCyB51DFy6XD99z
4IZdKMy8JBQIBMo/9+/LJ/i9uUgV+Hr0nzzqpmipzL6ZLcDquU6XOIAdgOys
Xcm1Qexg9GVFnTH4XORtUPW+m61ZY4ux2N3uWJ1mS7CM+eumN2wpNkJ9baX9
7HCo6lx3LpezI2F8OhFkymfvRXa5vfrLafZ+mHM2nijk7AOoyPWPWPvhJB9C
/WydNuwROxrzC3dtOSr2YZSdtxVGe1+RZWh2dok+lLDl+Lle6WqRsmMQYh9b
X6lykI9AUDLuGJeyFXB/1HgkErYSczJ3+lnzS3Ispot1Ink5Ow6Zw363e6Ne
kI/CNuIUx3weJR+D0lrdGr79OTke7rWOnYYZ9nHsMF+5KNxiJ6ugyNh01bt7
mHwC6fKt880FPK9G35LyprVphAx0TliyaiZp3wiUvhU6Qq7xfALmGmszDrrJ
xgSs5Op7HubzfiIUznsdTY95PxG+VL/qgRv8Hw2K9akLxkCaN2pQU2X5tG7l
rkXLt55f+xqeUddiJtLkl6chC3QYCVUv11YMUdfBvHR/TOvjnoQC31SceoF7
EgpFDR5Daz91PSz+GUJMDVDXw3ErMfbB117qycjr2lM5VG+jngxT2mBaUUkP
9RT4ylSTJ+M7qafg1FzE90V5G3UDNIPt3R5vI/X//g2KcBoU
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlAlUk1cahuM6BbeIa2Va4oKAAtXqNFS2V1EEESRhCTsBsrIodgBFQVNw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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1yw0sFHAYx/GraSIk1dRW4ajOTXIhL4f7ndydzttVtlrpZTkvterUWloz
M9qJjMqUxeacXuQOYe2Kw3npXapNMr3pQqP3yNKbap7/sz179tl3j8tu1caE
mRwOR/Jv/1829k8rUoKtb7dO67NIn5268JoNMwfbj0d0ieYyz0atoNJdZcts
D178946QqVvkBXg2Lp30/MS8CDWJRX2135iX4P5w4ZGhh8zOKGsZ0yzVMXNh
mPH6iGc2sxtkRV55/duYV8CNZ/6RzGfmwRjGUceN3iTzsUXmZOlRz+yBEfHk
4JtZzJ4w1Z/LnpjqJHuhM0d0o2UHswAGrvRQFpd5DXoFyQrViQ6yN5Rzd5Tp
25h94DyUk+8tZvbF2cTULxYl7eS1EFeWBoV7M/vhwdZNj/N3tZH98dG3xz3w
OHMAvtp9G5A/YA7ERFpzjyqFWYj3hw+UvnBhDkL6seJ3ShsTORglqaf6G+1a
ySEQClSlZ7RNZBEife17NVnMQFdLS2jPgGHaGYD7z9il0nmN1MWwrnjc6qpk
XQxjnu+yWJfr1EMxJnUVTgXWUQ+Fa9RmN5f91dTXQd94OveRYxX1dfAbKHCw
arpCPQxXlzc3jdtcpB6G9CeFVbsGyBwJhpVmB/+Xl6hL0PwdFhpjJXUpajqN
v3N5l6lLYbtYVzA4yroMDuZFbxR7tdRluNvHn+NeUE49HN1jw42PtGrq4VAE
1cik1Rzq62G4k6I2+yVSX4/he8UJZkdP6nJYbrbg/XLMpy5HYGbOV2V5GvUI
COsy1YMlGuoRcPLZxzUNnRJN90jIVspmJQWcn3ZGJCI+pFft8S+iHgXnbv6k
6m0J9ShEKxrid0vKqEfD66h+5KR3BfVo9Ce1K7fcukA9BmdfHZzfz79IPQar
VZKinQ1a6gpw/1S2xRXTPxQY+vn5edo76hkK6NU6ka6cukkBddkqg5yvp/8N
qHezupSZXif6C37KWdk=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zws01IkeB/Cpq1ZJet70YshikbtCRPJFeYvxpmFexkytorWq6xZT24Me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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0FlIVHEUBvCbIbgVg6ZO5DqFmrmvjTb6uY3jmmUNmWgpVtpCjZVpaAym
ZpC2WIKGRU1G4TK4ZWMy5qSjoCWCWiqVYvbSZG7Ug8RU9D89dOFy+fFxzrnn
OGae3nvEgOO40N/vny89vLeKMyKTgZ6/WgydrjkUKdtA5lDUbeI6Z0Y2ws0M
for/v5yHC9pSsRVH3oQQi3qvIp2WmY/aHxKpaoJsA/7myQOGCrID2lcMVr5W
kQUYNHMyMzxF3oaDrbz5995kJ3gOT2cfMye7oHa0oWnYgeyK3G6ltWaon9kN
bUZ5bzKFZA9It3KPmyb7mL1gMaIrnn1H9kZ+i3TQ7i7ZB2X+iivlj8i+CJia
uORcRPZD88xok3sL2R/npvj5PmnkAHA3ktQZGg1zIE6Yq6oaQd4J/YvphR23
epmF6BwrvG33kRwEaV4ZahtfMgdDXD3ab79K3oWg/a7Kkg6yCH5dFTn31pND
MKbMPrtcSv1CkZV8UXOcRwaM3exh2sksB+y3J17rT33F8jCMhM09MzZmlofB
+3KatC6J9guHwCavZ96U3V8ejkC9pchZTveOgLds7fvrSsojoJvVH607T/WR
qGjOsnX+RP0jsVai3TKmov+PQlHBlO+AroflUZDkF8oW1zFzYozvE6RnQ81y
Mayeu/xs6+5ieTQe1G2sTnqqYnk0/Kw/KAsKqF4Ct4erh7910/4SzNzv++yR
TPNjsCSITo2Io/kx6FhyzBG5U30sWnPLMwotqT4WvHq14k4w3TcOKcW9Funz
rJ88DpqMoZPaLOofD/3VJ8OBnlQfj047lbCggvIE1Czkfqlcpv0SENiwJ1Vt
S/MTcb13vDFNSHnif/lutBsUwk2m7vkFqk4+/g==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlAtUzGkYhyfZ5LK0UmJtjZjQZUQqNNWvG1GopqaaMs1Mslt22amtVblM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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11HlUzPsfx/EvchWKIkIYWS5+ZbtZEvVCNEK7NjM1e1Mu5edelJZvR7+K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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90Xs4lIkeB/BJ25bbpkKS3UWlKLKV6IIvjeR+y/02M2bMoGS3trJKk62j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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzX8s1HEcx/HvNSmKU5lVs4aaOSsLd4S4F/fT3aES12T9IRZbnFJqRcyP
+bHlR630R7eSkd00xKlQ4pKp3FZL6pD+aDGbH2UlG101n3d/9Nm+++yx5+f9
fbsn6Q6lrOE4Tvzn+3vTcRqpywy1H+hZ1by4djlmyLyBzCHtqCY905a8HlpR
2KD+x3NmJ3yQjhxonCI7A8Oes/xR8lYkWhM/tT0ju0JgtxJXcJPsBtmER5Hm
GtkDZofuwgs68i6UuBzzbE8ge0IdZmy+ZUf2guGy+V3vWD+zN1Q7zsa6VJF3
40Zz2efSIrIPNOMb9XfPkffCkj1ZkZ5B9kWCcs7b24/sh2yPcvvbKWR/lFyt
WbfLiyyEUCyoE+0hi7DYPF/qZzUxB0Bu8Kz8pSUHgj9TePH7YB/zPtQozpt6
+OQgSES+vYtdvczBsOzMCRDGUg+Bk5rn1L1EfT/cD46/WO4gh8LwMeP9g0vk
MHxrTpIMxZPFWHK8nmvNIwOOV8r0cwVPV50PLPFm7g+VMXPhyGyNz8oN7GE9
HDxuk9WQ9Jj1CJSMOXduH37CegRsXOvr0x3Ze04C43RcMK+Avc+XwKSaVOec
pnkpBrIS8+uDqEshWuhLra1g/+NkmFtO55Rvab8M2uRcq/ZIN+ty5IkP+6d9
7WRdjtfV21p9XjFzCghClO5fGrtYVyB5rPpkXRXNK1E8MuOWaqX9Sjz8Ob3Q
YKQeCaF2qliip/lISJscLFZJB+sqKO4YWizORtZVmD1eWck3tbCuhk7uVfVy
tpV1NWxiZAHutm2sayBvsprvObazroH/5oYugY7t46Iw8ai8dssJ2h+F0fgz
yn5b6tFYWXtq9E009f/MxfzzbzhCQ74=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxF0QsslWEcx/E3ZjhJ6CxaJrcQddxyd+p3Duccl+SUxKSYWGupzJkpYzub
tVYzibIuYi7NnYR0IXJrRYssFq1ELZcop4kkXdb/We/27t1n3+d9nmfPYxZz
cm+cGsdx0j/v3y979IaKE4S8x63/9GUnf3SGf0STmYP7yCl7TzVmLbgd1aic
5Zj14ODc7v5suZvMhzhpbqB4gtkIzfqh+aIeZmOMiwMFxrnMpgjJ/myylMJs
DucwHevwRGZLdMqsXgiCmK2QU1t7PuZdF9kGC28jLIcamW3x3ahpY+Yh5q1I
Vng3dTgxC8APu1Rp/q2T7AB7LX8N7WxmRwhujmzo12R2Qjcv+OiriA6yM4YN
DA/UVbWTt4NfeVhUOvWI7IKxfllf63rWXfHGRZr3Opx1NyhSE9bm97WR3VGw
pjx36h2zB8yilldlSpk9Ya9Tti2y9yHZC/t+Xg8Z+9BC9kbNe3W30CpmISYt
6mNLqpvJO3DWQ3zG8+t98k7UZ0Sf8LrRRAbu+SZFmbQ0/LMSeB76w3heWU9d
hPILfmu2TNRRF8FaEBuXwGukLkaEQlW9X8y6GGGZwhieLZnzgUF3WtrwSil1
H8QaDBd2pldT90XqYOq0Nq+Sui8Oxsee69Etpy6BrEAlMnSooi7BMcMB28jE
GupSqKYdBYUptdSl0P5iOnZ88TZ1GT5OvlQlv2fzyzCeNWYvsS6j7odyieeT
leO0ntIP6aq5cDNXWo/zh5C7etrFmMYr/eGdpFfCGV2jHoCz+gu/CicvUw/A
c8XmsszlYuqBsHGUjy50VlAPRNGZxd78etoPtwtDVk42wXvZ/nahqGhZmpBH
98EF4ZapZsgnBd2HMggz8bK3DRfZ+e9GxaD6nVadO9R3Y9Zu3m4xifVglIRU
FxVI2P0GI1+Yq1UzxeaX46lrVo7/DI2HHOmiTeui1chKOTIa8ixW69L4NjmC
uh6oDyzdpf/3oCr+itpED3X892+3wmA3
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90H8s1HEcx/ELtfwamxsK012FSi35WRwvnN9u5mTKmrZTVtSEInJ12JqI
rbbcVeuPfkyLXVc45/LjwmFaIjcrkbJZtTZb5w+X46aaz7vv9tl3jz0/v/bh
SQrFp604HE7E3/HvT5/zh8cXBHYjug39irrW27ca70jmoEDvMnXSgbwVR7vq
TPyVYWZnrFcHljwykrlIFx+bTpohu8M6wKdtj4HsicZKO5PhCXkHJA9Np2pK
yHxsOqE/25ZD3oWK3KyaNDeyDzxiBSlcyxCzHyQqOSfhB3kvei0G48AE2R9X
9rt8tRSRD0CqsuQ+55MPouGS2iFvUs8cgJYRYdlgPfkQgm5VT6flkwMxb+3V
Pjo7yBwEbYUNN9uTejC6My6vcV3JIeiZM3oXZ9H8UAhalpbzAslhmHxr5ime
DTAfxm6l6pW4lXwEVmXf71Y1ksMxfvvizHJHP3MEcgI2Z/Z66JgFkLzLjzSZ
u5kjcbX9pt12GTkKwXG1TqIKMvCpMfOLRtS1YRnw5rjHWlA5MycaS7azAlV/
J+vRUHQsh65KqcfgQWmBs3xRy3oM7N0mPo7877EYC8/PHFNrWI+Fi8GsKczr
YF2I3DzbInMl7S/EFrONSuquZj0OQsXLsfpsZlkcrkx6pzd10vp4yLWL/nN+
dP94NOjbXxRr2X6cBGR7tYYtDLeznoDaIblS6Uo9EUrdzp++9B6yRDwNXFE2
ve9hPQmaoHmJ0Zd6En6f2zdeNUrvlwy+2l7qJO5jPRnbSksiw+3p/ik4YxEN
fg55zXoK0qubebFpdH4qVlPO595byIja6Kmoay7jKb7VsC7CjfJ5J7HjdbZe
hPWpsfsNwju6P7JZNbQ=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91Hk0lfseBvBXneKW0HQaCDnqFEqS6aY8KFOGbZ7Z7G0M15DQcNtHkSan
26TSsEV1DIlLE8muRKJEpDRtpZtOioN1T6Y63dX3d/da79rrs57vs5/91zs/
+B8uIeM4jqv/9vzvm32U2nNjV02qq/6uPrMug1cGGbLMHNRFGpzFFGY5/DtQ
50qxPLMSPsp1J10brSXPQDN+3On9jnk2bg7xlv3zPbMKdvyUoe7wnFkdhQVb
NiXdY9aAMN1atnInsyaGvVy1eVHMCxF5+HFnvCXzIpzQ85xiL8+shbyPKq75
9XfIOtivmWaUKmBeCvWzpgW6wzXkZVDjLbj4ZTezHhrSAjwPZTEvx67fq+5q
C5n1wZO+aoiruk1egRMn703TV2Y2QEmF2Ck77xbZENN644QhKcxGCLIMdRGO
3iQbQxLWaD68gNkEDmdmjHffKyH/HT65r3elrmNeiVShQ/SrRcym8O1rfqL/
8QZ5FZbMqV6ic+g6eTU+pe5yMNlcQTZD+WyDjf58ZsA2xjpdkHLtu0WApMhO
ziaZzJnD2/ZK0g+XWW6O7rdTJ28ZuUy5BY4t7tz00b2ccgto1IXH104todwS
q1YfONsaQBZZ4p3pc+XNnYWUr0Hxl4ZnfaksX4OOR06VWROLKV+LBoWJTV3G
dC9ai44BNxvDjlzKrdCUENdRfYgsssLZgc5ALuI85dbYqTD0UPtrFuXWqLju
lm3lnUi5DQRW/esNKtIpt0FaZfeFXZdZbot0np20aG4q5bY41y5qKq73odwO
Jz+d7imxPmH2PbdD8pjy55Xl576bWwcdrQ8FmR+KKF8Hge3h6NndZM4eZ+1P
qfj9WkK5PY61q/Us1Cqj3AHiiA822YlkkQMOuGnun89dotwRtpuMVPsFZJEj
NPJq9wY9YH0naPl7rBgsYX0n9M83FWnYsT4Pe1RNO/U3kMFD2bUq27Say3TP
w6VM55sXEq58t4SHq3mt71+MI3POmDlrz0hoFN3DGbr3YyVTF1+lvjMihuQG
f55VSX1nJHO/fFnpdJ36LpC+2ShZOUY5XOC8X5pVvOEG9V3gsk27pbmCLHGB
MLNGo9C/mvquUG0+F39SQUJ9V0j7j9y66kkWuaKUU2q1WnCL+q44FaK414OZ
c0PKVJ7V7L1kuCH6hbGTrug29d3QNjqt5+NBssQNbx/zU+O071DfHV/7Egyy
2mqo744iI5enn1+yvjsetqi099WxvjsmJHbrxsWzvgc0Lo+91q2tpb4HVuwY
N2H4X/XU98BVk7OejR5kybf7nbHybevvUt8TojG3LqPllMMTUVHzgv3PNVDf
E8mXzNLyUhqp7wnVkkUG+fco57yQM3GkUmYd5fDCzL2yS4oP3qe+F7KaY44q
HydLvFDu0RxfaP2A+t5IHLFw/zKdDG9clBm6GJNPFnmj4NeaHrUYssQb0/Qu
DDpYN1HfBxPvpEuNjcjwQcmTnMAndWSRDypUVqdoKjykvg9k7saOLHAkc764
2RjSO7GMDF+YfTCsV+wii3xhoag9Lzi+mfq+SO/ysy8FmfPD2+rBrKRbZPgh
f3u1+xn9Fur7oWX/nHf3V5ElfhDHzO0LnfGI+v5QPK2VcFCzlfr+GCqolUlW
JYv8cdykvayUT5b4o6C49XXK7DbqB+BTs32122MyAnDKsd98m9dj6gcgv7Vy
wuJosiQAOjNM/jO0lswFQlG11PxzGhmBiNyvJPd/iwIxVJM3fqYr6wdC3i/8
Td8R1uejTGxzS6+XrM7HpKGIY9t+bqff48MlRXRUT4/M5yPKZJlt+RmyiI/7
PKU/t14hi/l4tPmpYX4CWcLH0s4fCwe7yVI+zCLQN7+fzAXhh90X8pYmPKH9
IIg3OvZOWktGEAaulMj13SHzg2Ch0Jc9rPaU9oMwNfP8Qq1MysVBMHiTs/52
KVkShM3RmvevNpKlQRj+W3Ccj4j6XDDaJmtF1d0nqwdjTEZ7/KwjZARjss2B
h/f8Omg/GEVhlYXnbcmiYMRKG9d4ddK9OBjj9exiI+vIkmCkGDQ2RlaRpcGo
uZvbsKeA7QsQm7HRZ8iH7Qsgu++P1AeX2L4Ao7meU3Rl2P43X7NvFMxm+wIs
TG5pa0okiwV47W4pyPlElgjAb4qZ90LrGe0L8NJJ0hZnTOaEiPYfSCnSIasL
sa3jp3pbazKE2F1jeiA7kswXokoz9XFPAlkkBJcY33PRjywW4shb32PGcWTJ
t/vS39VO+bN9IXrf7hvQt2L7ITg8M6mh3Jfth6DX53zGVvb/EILp76M+a5qy
/RDEjgYqnndj+yE4MCdi2odMth+CN261AzdOs/0QvMidtNXmGdsPwV1Zectk
pee0H4r3ucelUmWyeiiWvVq0bIs6GaEoWp4/VyWazA8Fz8K/IyiDLApFbeE7
1d/2kcWhsC1q31q4nSwJxZ9NR7tKs8nSUFQNmAyK2T0X9u39pzRu+n/ZfhjG
ylds/9rG9sOQ0H2p+wT3gvbDsEFthUWTAVkUBue2Vwln5MniMPxhYViuMIss
CcMe/YZzi5zI0jDscLY7qptE5sIh+2hEj19AVg9H9cEMwzdPyQiHXM5vFsqd
bD8cFrw1jaNzX9J+OJQttzqOqZDF4SjLaVA57EuWhONRnlXRvniyNBzbVCLV
nieTuQj8Ys7xW+pfmv0F3N/8bw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1EYB/CX0M0Z0sgoYYtNGVMqrdm6mJv+3ZxubqkYqZTFsBsWuGUf
kn1x1ZStTIWQsPBCug0iK5tlZXOmKy0CwShbV1EoozCpD7pk3eh9iHbg5fDj
z3Oe87yc+HJT0YElDMNk/P7+7LT4E51mZfSI76/mMn1fig37Y8gMBF419JHk
KIzMlsvHfzxkzcfl61P3bk2SV4BRG4++DJDjUDeiPVjYRxZiUt0zU9NKFqNf
2NZQU0tOgD2tUtN8mCxBgzp2oaKQLMV6X/3n6GRyEh5VcXdVLDxgvQbXmkIR
rhnyOui7z95tqSengFunCNmF5A1YKnn7+slTP2sZXpxoTsyvJKdCM28zGVeR
N+Imhxt44x1mLYd5cS1P1kvehLgOnlfSRN6MDtk3+fND5C1orLAHlXNDrLeC
Ny5YfYpDeRra3buv+MYo34aWYb89KKI8HQamjH/RSbkCBmH3bHQPWYlQrc7H
tZEz4C4ypu4rIWdCf8R1w7SDDPw8r6r2j7HnWwG7yPgxe5r6ZSFixqS7bWHn
t2bB8WyoP8p1n81V+HTJYxEWUL0K79pi3CsDVK8GZ9DJK0inejWKTyu+m9vo
f2bDNRCwvRqg+mz0OS4E/VN0Pw38O5PmJyIp1+CquKHUkUv9c/DBWTJvOcPa
moOEdun0nrhBNs+F2OCt0qawtubinKTLI+qkei2SYZ4tO0nna2FqFEjjpdRf
h+rHsXuP0fuz6hDbW3pn+VeaLw+exGX5wUWaLw/vR1uPc0fpfen/tzXMjCEs
DzOzPSwPM5Mflv/zL23uQcM=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03k41fkeB/DTIksZtNwy1ZBBSjTUkKLzzpJDlkO2LJ3jOIfjVmKMmJbr
SLI10aJurnSGGykpW2U/iY60WCdEZSpaJ7RcNE3m3sfn98/1PB7P63n/3r/3
9/z8zhLBTnfRVBaLdeu/v//7y/yod+WGW6nI6yY1zK75U2+iQo0xCxedYyc8
NBgrweJBfq/TVMbqKI2sndL+4SZ5LqrmlL26+4bxAiw0jOxIGWG8CBZKaWOb
Bhlr40hhpXZzBWMdTHd2/TrxIGNdvHNP6Dztw1gfsg22RQp2jA0grq1buUKd
8XKcmW2Ve6WlkbwCHV5pM/5ZwdgYKc7Zbbxwxt8hfuPEkITL2ATDqtPzO90Y
m2JGu+Eoz5HxKsQlSS/t0WK8GvKyzkBxfgP5e8ybq9EnTGRsBs30uHdn0xib
4/ybtHU2EYzXQLFdpe7B3RtkCxTGNtytD2a8FnP2av3jj9v15HW4M/hU9dfl
jC3hUPvy7Vp7xlZYUdwSUPi7jLweWZcvLFh0to7MRoa9l9zyUSUZ8FI/HDZa
e3XSEuDrgIe6fKVrlG/AuvfVet5ysmQDYtqSFRqXV1FuDYcjkVcPXWdya7Rq
5XB6/l5GuQ2S2t/Fsp/nUm6DLF+JdEveIcptkdB4Ity5L4NyW6BZpVLZ4Djl
dmiMC0Pb4FHK7cC3V9jlOTWJ8o1YYB6xw8x6P+UbkSs4FerI/Zlye9jvCzQa
PJ5MuT0+Dix0PKySQjkHOi+jo9fuPEA5B6NVls2xJXz2ZO4AlSW3Zq1N8Z60
xAEX2N5sBxcx9R3x6+MsGx+zH6nviANHequ5BumUb8J10TabPa/pfpJN4CoM
KX6vlkr3d0JiSZZB2ZQEyp1QlaxTKB2UUO6M/SdvjyjqZlDujPVJ34b9SyeL
chc42JmMV5efpNwFYXM+JPh0n6LcFQWZvLUHjmdS7opsP6Fqr+Zpyrlou6A4
HLZGOmlw4c/ZUa/nRveXcJHf2lGQVXZs0jIuYlctDC1dmkN9Nww9emynEU/X
ww2/qD7oNC09Q3035D3XPqKy9N/Ud8M1sSTbOuES9d0xZf9PY7u2lVHfHTzz
8ajRWWSJO+5HqCnVxJVT3x258mq71acvU38zWsIiDQeGCqm/GSaLF2eWhlEu
2YzphvbpXkXM/mb0fanMWVpTQH0PVBrFpGtGUA4P1NnZWc+Mu0B9D8QZtyYo
Pr5IfQ+ofZetpW9wnvqe0GuoVXqsyux7ooPTnaCTVEx9T4TrN4lH0ouo74nr
Z3LnJE5l+l7gFIyWC/7G9P/PEi9kudr+8OoG0/dCTnS2Sq4mnY/ljeGqlaHv
q89R3xvFURO9pm/JEm+cfvPetruJrpd5Q6rwNirNuYT6Pmgasf8y8KKU+j4Q
rjnXscyGOb8Plp3vzjmYxXx+H3j1xBs/LSWztqDEv7B1SUU+9bfAtntRZr4W
WbIFtw5aqxtm0nlkW/C8+Muz4pVM3xdl7LvPNCzOUt8XvyRz1Vdm0P9H4guV
g0+Uw5zIMl94b9quZ1TBPD8/ZF8M7117gnl+fgh3SR+KWMk8Pz+U8doUtW+Q
ZX6IaDTkav7AvD/+yJ9x6449m54v/DFrWt5ZR2Wm7w/PjcKx9v8wfX/8Nuub
r+YmM+9PANITjiv/PkzPFwGwmKbUEvOaeX8CUB5n9lhrN51XFoDPcdHjpvPp
fqytuNilV6L7mTn/Vnw6f8K2RUTnkWzFwxFnz3ADOq9sK0I3tMc7WDPPj4dL
3akRTj3MPg9O5a8G7PdSLuHhzNUl24PZ9H2T8XBbQT8j4gHz+fnI91T0D79I
74M2HybTuqZvDGbeBz5emkk/HDOi7yOfD6NUofGUm5RL+MjJUNdbWEq5lI/s
pFWca3mUy/jY9+lR3MAzcj8fCrcDCo4fpetZgbj6Wk3X1IW+39qB2OVY0zlc
Q0Ygok4pbUjZReYHomF4kONhfIX2A1EWONvwxz6yNBAmJ796sm1+Be0HIknt
27zzkZW0H4gd+usrni2rpn0B7vctzbikVkv7AoiUlZ1+fkqGALifKW1urKF9
AVTDOfW+c+toX4B9Gg/nlRyQ0b4AhvF/yAX9ZJkAis8a9Aqjr9O+AB53Enic
hHraD8KDnWM6Jotv0H4QiuTOxqUaZASBI+8JuhnaQPtBWNBxupHPa6T9IKRX
tUbv1LhJ+0FI+3P7eOoJsiwIvhGj130HyP1BuDdxyjLJRE77QnBT5y1yOUPW
FuLqknPHEuVNtC+EZe+ewGO8W7QvRP8Kfn322WbaF2J3/J1P+V2US4UINd/z
RCGVcpkQrv0ZBlFR5H4hjhZYfjJOIbNEYC/XKbw38zbti9D+Jnh8mgMZIpjr
6mceGiHzRWC9kMTKHe/Svgifm9ZP94whS0XYG/qpT+J3j/ZFSPD0mnrZuIX2
RXinpVG825TMCsbMdT/VF/XR9drB0Cw9t12u2kr7wegqlF8WiMj8YAzxrPPF
H8iSYDTJxhUHJsjSYITeNDC4tqqN9oPhVLTz45rZ5P5gpCVPyTMcpetZIUg8
yBs5x6VcOwSa880OSfeQEQJXnZhNYelkfghW7zcaV+shS0Lwm9KjsaELZGkI
DI9F+5a8ZPZDcJIzjZ1o3k77IRjVHXuv7UFmiXF4v1VXUDNZW4zMyKwbTYod
tC/GVxYfWf7jlPPFSPTi77piTLlEjMoar5hSNlkqxkOdnvLio2SZGJ7fXF78
IprcL4aulZVZwlMyKxQzt37RKlnayf4L5grguw==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90AlUDPoeB/ARUXTVxaWbXEXaXwtajNKXSiUardO0ztIyKRWSyDKWstSL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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10AlYzekeB/A/ZqyXJDeGMpGUsjNJoW9p06ZF22k759Q55VaIYSpMR83U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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10GtIU3EYx/GjEw1Dp2F2t5yRU+ewLTNL8zedc25uLiuTgoF5eZOXJAu1
F0mN3pjlSs29Scuiq9PVKlvLectqWNhtUkEoWI6kMtEijW74fw4cDh++PP/L
Cd1bmlXgyXGc/N/7/0tPwHDr/kTfR455TSY5ZXcNUYvIHBr9DfknAsgLoPrl
9T46kByA9iBB+HV/chCKvWorW34MMC9FQfPl1rBx8kpUKdb+EfaQ1+DgSfDq
HpEF+PLhqlvSQl6Lonreu1015HXgt5nql2wnC+GXY7tweCU5EnmXzWXj3x8y
i/BWao49NkEWYzbS253lIscgeujhjgYreT1OtRl7fY+QJRg9urDzcQxZiiS1
PufpCvIGbFTcmArPI8fiU8Hr1vhz/cwbYTMHu6R6chyKp9NL45XkTZAmtanl
2eR4+PwxzSTYyZshKRuZbgohb8GV8hOeO419zAnwGsvVul72MidCORlxYLCW
vBXbO97ot/X2MCdB0ah9Y0E3M1C5fJIbjmOuBlymZaaaQOoyRHwUq/Xe1GWY
7Rh85hDTeskIaW5PnRijnowSm1Xk5tN8CngNvJCcigesp6DxekJM6Wc763LU
hTkkU1U0Lwd/Tm+1zzhYT8W+pl9X3/dRT8Vvi2F3wB5aX4GQomyfspEu1hVw
Hre4BZ40n4b9z5v3+IXSfBqaMuTj9iHqSpzfVDh4o5a6EgkjUavOdtP66RgI
P5ztUUnnT0euStcV68v241Qwy41Rc7dofxWswsiK6mi6nxqW87fzDy2meTXc
Mzte/ey4z3oGLgn4Hq5A6hm4JlA53aM21jUoHzgaVhh8l3UNxsy2fb8LmTkt
Tq/+XFcyd4d1Lbj+m0bNKDOXiSHhxbTiiNusZ+KF6Y5o+ImVdR0Mzm9vTzk6
5w0dztz6KvYLpvPoAKV1okTJ/le3Ds/bRRrZPbvjL4kRW/o=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzwlIk3EYx/HXdGV2TefVQeYUHVKaaWke7TdbNm3OFVkas9RS1KAkKbU8
thhoh6WYkWDpMgnJwkglE215ZKUZ5JUGQpZXUEmK4REd7PkT+YeXPx++7/Py
PvYxJ/fFLuI4Tvbn+Xuzw+8rS/I3a3tq0IR48FhRt9aUmUOneaj8rjGzKZyP
bM27yjHz4Wc8li75+pxsic6a0VyHEWZb/Exs6I94wbwOJ5I/efvUMm/A+mfj
xyc1zEL0iLhlukhmR6T1cEsTweyECxpxvFrALEKEXqtcY8zsgr62mUUl11rJ
G/FaEDO5cjWzK2r4Ybd4t1vIm5GgbwntCmZ2x7RZkGIwnHkLvBKkdZcEzB54
pzvdqk9vJnviG29eMPeribwVBU3utvfTmbdhttba81sEsxe69/PuH6p6RvZG
/9EAbUcU83ZEHryuXOGrJ/vgzUQOP2Mxsy9OpS7vqv3+lOwHlUQ/IWxi9ofN
vHDJxbON5B3IuXdZLotuIItRPaTkvbJ4Qga22UiH7LLrDFYDfpWOvYcb6qlL
4D9sH+0iZ12CLJVj1WXLx9QDkJ+pqGntf0A9AGEat8d9pyuo74R21q1jwO42
9Z1QRLX0igZKqUvxcalGPG/NuhSug6O23ck66rswHra4I8OpiPouZOemTCnz
iqkHolT1PkJuRu+rA1Hx4WZNu4Z9fzeGTG3Pfg1Po74b5RaBSaqSZOoyOAvn
mrsccsSGLkO0t0fWyI1DBnNByBgrflt3oIDmgyBaJz1nfuUSzQfjmtWUzYxD
CfVgDG/KnHfzI3N7YGJeGJNVkkd9D0YD1lp1PyykLse0pn71l55c6nKIByS6
H0LalwuBtcu0kfODq9RD4HQmttqk8wZ1BfIa2+Pt7pRRV+DzbDVfKcinHore
6FWPZLO3aL8F5pRQpUiEqUnlBmOB1QusVyLu/EylTppJ83v/NxZYvRd1cSkv
tUY3Df+j/+ff2T1gkw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zglYjYkex/EjNMkMMSkkc6QkTAuKlPqlTdr3TXX2akKFJHNHpwWhsmS5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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10Xs4FPgeBvBhyaWyklQiE10USRIp8hJhynXInZkxw1RI2XJWsqObaivV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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzX8sFGAcx/GLCqlY+bmZReiyXJfLz/Pjc3d+H4cWG6dpRjcTCWFynIpq
Smr+aJLsxFTCWnKoidzJbWplF7UkzFgYWWG7dNU8T394tmfPXns/3+exSzpz
LEWPwWDw/u5/J12mI/WZvjsGeja05N8xm8Jh7aJmID27Uyn93w3h59i5vq5T
EZvCeCz99u4f1GYYFzUEKkaorbAtg5dcoqK2wUmrCc11NfU+VA4PLpc9p7bH
J6OCzPwH1A4osjVxZSVSO0GrzItzdqBmwozX3S1XKYmdMTS+yr7fQH0IlnPW
eoWnqFmoc5/XeptTs5FxLaib29xPfATmdZK2Rjm1K+62DEV3+FBz0Mpp17K7
XhEfRVtrb+PqYWo36IXbIy+V2h0WUoHQOoraA3tKXzDFij5iT0zHqnT37Ki9
YPI+cq8goZfYG15Zl4Pq+dRcSNRmfFHrS2IfiJ1mnH9epPaFZ/xbuXgLtR/0
nVuqnhb0EPvDqF7ocnCFGnBNW/id60buy4BhSfF6NDWDB4OARHWBAflfxkMR
a1nJm6fzfFSctrc0taadj+nlK4bqJtoFsKgsd5l69Ix0AWzZ1t9syrtID8DH
5LG01JY20gNQUzoRVqhWkB6IteqvCzc6yX1ZIB76FU5+uNpJehDO91+yCPak
80FY8fKpeKJ5THowtscvrb6RNJEeDPEgM793Sk56CDiL7Av6fcWkh+BWtWPS
mlTkv9FDN/XQTT0M89p3RotXY0kPQ+wvK2b0aDZ5X4idPS4hU8Y5pAsRl5N8
oHgxhsyHQ9Y/pxngyjYsC8cXA81WXW4S6RFoKppuV3icJT0C0mVuTJmyhHQR
dNnftXnHK0gXQXNOdaLq803SI7F/sPn1aDmxLBIJ0ju1M1m1pEdh1GS2ZmCy
1v8PXXtGAQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQlUzYkeB/C/KULlqYkW4UpZUrQnSd/2tGhftdx761Y6STyvmpDL9BhN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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9yntIk2EUx/F3WrhS3HBRI0SsvG1aW9ams5Y/3bxsYZRLyb8mpcUWallp
Gl0oSrIwVAhLEUtKtMJI58zlLugqi5oiaUSZSIiTjFKwQpGKzuOBw+HD92w4
WJSZ78NxnPLv/rtshKPNx9SrXzj+63uid0F2breAmUNC5ttNZYHMfNiUeotz
uQthS/khmFrua9BgnbN7p5+TxYguFo1NOZmDsafmccDsI+ZQFPTmZpQ0MW/E
vSibZOIkcxjcrzzD5fuYI7C4OfoQF8cchZmrsnxXp5sshSS8xXyxmDkGVV8a
xaEG5i3g6sTqWB2zHFniqlLXYD95K1wioVmuZI7F2Ybfjc0ZzNswlv2toDyc
eTuGrvN+ti53BWSfTbW3J/rISgh9TLPrkpjjEMkLuFU7xxwPO6/SG9bCrILz
mrn6Vw9zAs57xqUHVjLvgFxrbzo8w7wTwZXSYI3HRVZDNFh2ya5g3oUoC18m
qHOSE9Hrm/VaecVBBs48UdXzKskXAIXTP2RV5DPqSag4LTNK/G3Uk1DnyHtn
bLdQT8b4/vWpgfwe6smoPRJfmhdK/5wGOeruU+0rWNfg5X2xRFdE5rRY+jjT
KQrppq6Fn/OEb27OU+opqNjbVzNytJd6Cu5Mri2YvEz/XCpi7hoUH3RW6qlY
Gph/P+3HehpsX4PS+0s6qKch3J2mErjbqKcjKLtt0brQSj0doxHDXUZ+NXUd
pgoNI2+WblDXwdAlL+TPV1HXY+iTVGvqaKSux8MHAz7HE286/gDa0AlZ
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03k01XkfB/ArLcqSIk8pkZREUinE8Eb2fXcj7uJeV6FlWiiaX5lps1aa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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zwk0lXkfB/Bnuo0MU5MWJypzUZpRL5K9xTdClsq+x73Xde+lMqJlRjG3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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11XlUjfseBvAtLk5E3BxJUl2SDJWSRDwd0kBp2M3T3rvae8uOMsV1HNtp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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90Ak81Akfx/FBNhsqkWoTU1GtbCepVXxXzohx38wMM472kZ4SW7ua1aV4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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9kQtMW2UYhmsNN6OloolIYELHNrxvgw6FUV6gjA5a6DUsZBdmYFC6S2UB
igzXkQNOwkR0clUYMtyo2MFoittY1jEubuKkzFDBGqaZSyBjGMQJWezU8P2e
5OTkyZP3e//vP2FvHVLn8nk8Xua/739f9ghdHca4J0avrNLv8W3Gt7N0/zMP
suaSF9V+jH2x33m36vpfI8RClHk1ttl5zD+LlooynwOzzAcie8Alld1mHIxj
scpwywDjUCQtG2am+hmLEJXJOxPezjgcEePFIvURxuuR1e2rfuYQ4whstLjC
+p5m/BIKDs60HpgaJn4FQ1CYwssZvwb9y8Pel04y3oiRJccnnJLxJhTkRi6Z
fBlvhttTVtIQM0QcicLJDY4NfMZRkETu9vOTXyMW40xJbfBvPYPEWyD3Sb23
Rch8NIYvVUU9X8H8G8jzf1AwPniV+E00fK8553iS+RhgoWlfRBbjWPCV/use
r2G8FWvEvWd3jbB8HIp8Z/YGGB3EEjh2PFbtLh0gjkfdg3Lb+v6LxECzad6/
tNi+ymagpn5m4FtZD/kELGir10XfPks+AcNO43VPMPOJeLQg+IILbSefiFNN
xbxA7iPySbiaWWtyJjeRT0LqV41/B46+F7/qpeiOXCldzPhslc1SdOU9Cvkh
6EPyyXAnaoo888TmZDTHRrt/DCwivw0xNzZ77u5tpfnboBLOGTvbO6k/Bdmi
+71XVurIp2AsZG1Kn4GjvAwqQd/5ffoO8jKYxHMS5x+fUn47wk4PK/RFbL/t
uMOJOyVj9eRTsef4cxdyJmlfcyoeJtravGsKaX4a7E2VtcsSOfk05PDfzT1+
+AR5OaalC2M/6dtpPzn67tdZvD5vIa/Azodc8AdDH5NXYNl4irusN5BPx1Gj
+X1DKEfz01Humb6zEnmEzpeBvBvjNpdPC/kMzE3M77aMZJNXgpvtMu0oovuF
EjqRM8ggo36zEse+ucUTbKJ+hxKT+tNrZrI6qF8FISe40N9A/w8qvFNwsctm
ofs1qzA2u/OoLJ/2c6gweFNxzV1pobwa6q89AYLXeymvxq9in3rRU+cpr8bW
clnVwehzlFdDuGfJZU3robwG+SGjN92XuymvwQv9+4N2NVopr4HXkPfiz1Yb
5TUQLU6p1lbQPJ4WK9a4hMMG1q9FQOvEvUorzTdr0WI/OVGYQ+zQ4rtpe3Gm
nuV1qOa7u39JYv062KQT+X+6vqS8DpL0V2+F6nri/wEfuq15
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90Ak4lfkeB/BzE9OkhoumsZRllCZKm4bQ+VZICNmOveMszqnpYroyMsUb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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zQk41fkeBvD/pCY1lWRKxtJp0aYa5aKJxps9oWNfcjjnOJtmokVyJ+UY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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQMC1xcX2HId3w/hfbCf7bFImg/OZ3DYenX371+c
MD6Hw/rzMivk/x6D8gUcfnr2M139BuOLOJjb/WM0fg7jSzg0hDDP038H48s4
LHcV+cF5C8ZXcPjJyTNx2nEYX8khXTbwJ99mGF/FwXh55Vn+JhhfzaE163K+
fimMr+HQ+8Jr2eQMGF/LYUp9JLv4r6NQvo7D2iRe+/QXML6eg92Mlx+iu2F8
A4eNCaoZX9xhfEOHrfdu5W8yg/GNHAzj44tmc8P4xg6LWo2ZGt8fgfJNHG6/
KEl+awLjmzqs4/484+efw1C+mYPPQfdnEodhfHMHvqlT/WaLwfgWDmt5ONV7
jx2E8i0dtl8/sWLj5QNQvpWD19KC+3df7ofyrR0U634fK965D8q3cSg9yOjm
9BvGt3W4URl49JwhTL2dg7TL2jj1izB5e4fX/3/kbOeC8R0c7FILZs0K2gPh
Nzg4yMue3fFs1y6ovKND9s1zhu4MMHlHhw8PSoOSVHdD5Z0cIhJva/FvgvIb
nBym7/G8NrUAqp7B2UEtbvmFR9eg5jU4O/h9udB17cROqLyLA0v279sbpbZD
5V0czjO6ck6S2AGVd3W4uOxZ5MM/UP80uDrMnr3x0sYgmPvdHJTXCW0p2rd9
PwCmtOgr
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz30s1HEcwPEfO+tIiMZtIRkm83Chk4c7n8Od43CyNcVOdjJLhqQlrXVq
bjHTFmauB9ahLuHEYjquzsPNrbZOIss5smq10dWYLQ89rM/XH32377577f35
4/s5KClKy7WkKIr75/59yXGYURSzbXSafzJHl601zZ63I6ZA2rAePLpjOjiZ
5nX0X+NoB2DZG2xNK8T7wHZj/3CHiZgBU9WC8cFZYlfYZJg71Tv2AH38BRvJ
BLEnuAhY9+RKYi/4VFVWo60j9gHJy9suLRnEvjCl0ft6HyD2A+2Acf3N0hja
H3IrT9kvNBAHwllZYG2CkJgJ1WwG5xaL+DA4zo2V308iDoYR+t7JygDiEGix
aa0/40gcCvy3WxP12aPoI0CplEGpIcQs4M+/9y3KH0GHgbXBySh2ID4KYoty
1fEOLTocQmd7K2Qs4ggQM3r2vPrwAh0J7svXdT0/iKNAFG7yupJFzAbtz9Kh
LcVzNAcal+Pr9B7E0dBincfVFZB5AFfNcG+XP3YpAN3gts5+p8HOBffSnMYG
NelcuMOgSZoj1Nhj4PvlubShh0PYY2BzjEcrjiQ9Fq6lR7UFX32GPRbyApo8
CkRoKg4G+0puzlj2Y48DuXPlqnntKXYebAs/r6hk3dh5kLO4y9KC6sHOh4v9
ymkr3mPsfJj33NyoeNKFPR7kya2jmdtt2OPhdNX0oSAnJXYBnMiK6PRmtGMX
QK7BbcuHhvNUApyU1Ei/vVZgTwB/O44r0+oR9kS4If749Vx4B/ZEWMjPFtJE
5H9CkJYxZZK7aKkQ3BQDvCUm6Umw+9KxyUJ1H/YkMIZ9yQSeCnsycHrDYv0W
OrEnwzglau9efYA9BYQhUc0Goxx7CtS2lRQ669GUCMwuGSXpi2T//0yl7sz/
Bj7gSLA=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9y2lI0wEYx/G1DiwthyhOa2Ia60+15d1Mlz/vI98kmQzU5cwIypS8Sshm
iVHqKDNFEDIcCd6WaGHTMo9JU4TAYSeYUS9ShhRirazoeXzg4eHDl2e3Li8l
RywSiYL/7r/LI7G25Ku3TQz/ly3ig82Sct2ZLcJK54NkNxe2A24oauQ3t7Il
yB9YTV1btyv2XnF62WAfJ0uRltvQP/iFvQszmsyMo4Nsb0hGp3TJzWwfaO+m
6YxF7D1I3WGN60hjy/HK8MTXZT9bQEips2usG3sfTi01ePlvYB+AxTSmlPeN
kZXYlLMcXJXO9sNc6Vfv6t+jZH9Yqs3l57vYAehNqij5pWEHwqE/JmjN+oIc
hIs+4jr3c+xgrIZ/r7TPjZBDsKWm2J7lyv0QCmsdu6fLuKtgjZyYdfNhh0JX
b9JO3WMfhjH7TNabZHYYZIFLbeKrz8nhEFTC/cKhZ2Q1MmWLxypq2EdQkmf2
qL82TI7A29Y7Mxt/PCUD0rNCl+YkWQ9szheJhXLukbg0eXqmzdFEPRIWz+1T
pSOPqUch8IRXu7SHrI+CYUF5QSHupx6NclnRT0P8I+rRaPkkZGdk9FKPgef8
reOLRT3UY/B6smnWvaCTeiy8AuYrM43d1GPxUTi4HNrO/3EodrJVzN/m/zio
HbUiSW4H9XhMr6hw2aOVejws42WfF7QPqSdAIRS8a27so54Avc2e3jk0QD0R
db5V5m+1ZH0i/Ha+X2sM45607j/mSwej
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxFzQlYzfkex/GDLHU8RJahkBRxk6WihD7Spn3Rvpx9Uch2UQ1zqqHskpGi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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90A1MjHEcB/CrpaJDdaVjoVQ3YlHi0NV9r6473bm6l4ja7DLF8nZMy3nJ
MVdepiw18x6xSrild6LzkiixUVhGed+8zcsc0Y7s/j/P9uzZZ9//9/n99g9c
skab4czhcFSD778vPZ6PygzRw9paHPosHvFNWBDqReZAVyFw8uKS3XFpkkTQ
/+Mmsyf4F47aPgyQfRBirvs+5guZj8zcsT7pL8j+WNS/Srj0JjkAF7P5Byrr
yBNgzz5j1JwgB0NmiagJLCcLgIoU72m15Il4HOQWNPX/+VCkPYrJEpnIU7DV
0NUmlpPD8Kf3jnGzG3kapJHCn9qLrczhWByUIFgynRyBAK76vvz1DebpeBFW
qQsfSY5E+kChwkN8nXkGms0TXVYfvsY8E8q2BxlYThai5D2v+kcVeRa+curv
tC8mz8aRSwND8rLJc2ArLkvbpiJHIcW3tz7HnSxC07pafUMFzY/G/i0tpXYX
2i8GUtdbXOdddF6M4HdiS9FPMtAucmt8vZ31TUDXyhz/WD71Jdh71v/srCfM
JgnqNnkPtZ2g+4nFip1R/FYhu09TLJ5OHfH58DHaJw4Nv5tG5xno/3EY/yrt
eaeZ5kuR9fFe5EFXyqXQv7WaXRZRPx796eGn++j+TPHwyJPCxr3Kchm8mnse
PhvXwnIZBvrHbniVcZnlcmQp1+1f4GlluRy+T7sn7yhh5syFWJ+iXr6P8kE7
xxiP2ylPwMKFmRvja9k8UwIM250arTyar0CP0p6nkFOuwHrd/fmlb9g+HCXc
PbkPdtyj/ZQ4+WZZUe8p+v88PFH3dfptpfnz8Fw/IX+4zxWWqyAMkx0SNDez
XIW41C6Xg72NLE9EVVWH5GVAA8sToTg3fsyWxCaWJ+GYzbJ5FI/yJETdLZ6d
5lTDcjVyI/yMIR+qHYYaRZ/WRBtl5ey8GsPLb3d3Fh1w2KoGzy5NVqv2sL4G
Qfneoi+8QtbX4HyfTJ/fbhA7+hr0WLo/uluSHbZqkNQqqh/WYXaYo8WoHElB
t7nMYWix9tduXVdnDesP5q4BGmFHE+trsakn1yO1+gLr6/77L7hrfgk=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90WtIE1AYBuCxZEY3V5ltzcW8ICG61iqbS927zc2h6MiQhG6wXLYyZ7KI
YMZgFEWyUMhGZCWFWsagwqK1sXYpG4lgUwb9a/qrYmWETMJ1wfPtwOHw8PIe
PvgKTNZmM5fD4cj/3f8vHX78QVf1monAin6opJMKUU0OmYPgxt7lCT55NX6r
U8vNmZyP8FWhv3sVORcyXyLXmk0WoOj0THv68zvmfDRtaEh3+sgS6Hc2bKu/
TS5E/2R0Rt5CLoZnafxEXiW5BFfmBaMRIXkHLJID07rYW+ZSWEI20XsPuQxi
bt5whZMshW1L0R+hlixD+uB6gbmUvAvWnIXGhIQsx+aTlx+vexph3g3xUX/5
eIS8ByF3sOeJi7wXa7NEyhELuQKGR3NfO++R96HPWTDbNEdWYERxaCl9J8xc
iTHe8WQ/yEpcPOUS+drJ++G1578wfCdXQSB2Jx9eI1dD+bJKfD6LXAOTb3Bq
URRiVkHm9Li2cykH3AtnvM/iwRU7gK3GboPRz8xRQzkw3dE6xPoONTZ1zX77
dPMNyzVQBXv89XFmhwaJY8XG2Fkvy7UQao58MfW+ZrkWh3W8wbtT1K/F0AXD
aPAS/V+LsufmctswzaeDfb7F3gG2b4cOYwPS5K/MfvR41Xb/XCib5tcjFbhV
GIpSvw6p2HWLNM3sqIPHt5guuUF9Q8bhD2ZeX5sBPz82mvit0cBfbYH+Fw==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzGtI02EUx/F/C7xMI190WbWsdKYNG262ZV5/m6lrXSnKvGGzNqIMl5ZS
zLQClbQyRB0WFVSIILVoWcumoc1ZkZesOV+0EYoWMTEqkijL8DlveuDw8OHL
OWvyCnbreBzHyWfn308vaPiWIYHv6JzTVBIvwzT4zofMIVv92KrzJ/tBdsI+
dXweOQiVry+H933rYV4EX6vTZBsjC5BXPZA+0U0WQrurNF15h7waWTtdYTUG
cgjO9v/hm5PIIsTwc5q+CMhr8cvivTHjsTNHIPXMOUFVH1mMOsXYXmsLORLe
Af6Ifh9ZAuM1db0mkhyFF+Kups/3njNLkemeXC/RkGVwdfxu+mruZo5GztD9
aoWWvAEffxobjxWT5ZjMnl4u5ZEVmJ8+sy10exfzRqhK6nPDb5Jj4BStOlV3
iLwJ7qFLIkcRORbXi3xsERXkOLQu9mvwlpDjMe0eDPAayQn4YIrWHPQ8Y05E
8UApeveTk/B+Xe3hWgMZCDTeHQ5c0jHncuC2a1mb6YqNdSWEwa7EltF21pX4
tPC0yPcIM6dChkcfZf7+hHUVFPbzvS9l1JMxbSvTHLDSfjJCK41l9rd0fzMK
R7bWmOIfsT7rHmdPwYSF9RTskGf6vBI+YD0FK5RhWc39zFwq7Ln5joaVtJ+K
UX+tMJ/ucWmokgb8aC1sYz0NFZKTF7HUyroace6Q8QXlzOVqXB1v9oiLH7K+
BYP6N0crLjxl/T9zGqQFW3Sxe9o7/wInSA7x
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzWtI02EUx/F/ti4MDbVFRmpeVoqZy9lqm+l+mzqbN2L1wvRFFgURll2o
KINNDFOQsovL/lZCQpm3lml5I82tVHBtXUyRisGg0gJTsVeNVficQh84HD58
4Tyh+wv0B704jlP+mb+bnu9I7bEEYX/PnH6oevgray+tIHMoVOtvPV5EXo6Y
TevOS6dfMvvi0LB/0FMnWYQgzVLf5n8OAK/UyxLs5EBU/jK1bbSSQ1DWn/3l
czs5DAEZsUGtBrIYi52KRrGWvAHi4lHHZCA5EgV9mT4WzwvmKHgGBRpXEzka
ZSXymd6L5Bicqw4e/yknb8ay/LOmMRE5Fs3hB2KaOq3MUhQNlbtmn5HjYIgW
2q8uIW+BavhORI7bwizDvoG4nbu/k7eiV/uuUZpF3gZX0fjDWUcfsxxT2oGZ
1UqyAuv9rZOdYWQlBNcuq0/y5Hh0WU0Ce+5z5u3IrI30efCJnAAIjt5zviEn
QvJ2yH06lKxC/plML3V4LzMQElzS4bere85GIMr7et3HFmZOjdLB0Q7e08m6
Gjo+Yk9pKzOnwd2VBSdst6lrEP7kxpEZSzvrSag6vlfked3GehLqZa7pSlML
68mQlGcnGpIesZ4M23uJzFlhZj0F+pw878PCetZTwCsmVkVO3GddC9u3koZT
VXWsa/Eh1Nw6daGR9VRk+X2dMheye8ZU6OPHioVu9h+3Y76NC8zp4Kyocfi8
oq5D98jNrjU11NPm25iGXHleRHV6A+vp821cYC5jQf/v3wo9JD4=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQk01Xkfx/ErleKZiakpTckttKhU1lD5WNpQ9n2713VdaqJBJ6pprpKE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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10w1M1HUcx/ELLYnmgIZ4JjmehiBKoCByPPjh+YQT7oEHGRoddSBIHoFO
CQZHE0GDE8QzSfDUA4GIJ50EXnZ/Hi0G57KModgwQCkKjKFlQVbj+7vtdnvt
/f9sv/vv/7dLVkoVJjweL+m/7/+/7GMxosv0N7tlWNaTncYRmdONV5l5cPVc
EZzPYzaFTt1a4PPXANkC0aVFj0bHmK1g90bFh3kcMx/D/CUr+0pmGyw8cH03
Jp/ZFlFS5f7VCmZ7KNKNgVmWzI5wEvlKAtYxO0Fa1NbzQVs/2RkFk8qnSh3z
JhyvTTo8mc28Gc0Vd1cc9mZ2g+WCYeOPNszuOD3fruA/6yN7wO0b1bF2DfNW
fOZrmvDUg3kbQu32Xr4300v2hKg+/Yv1HcxeKPTOdhlv6SFvx0ioobeppZvs
jQa5MXPPY468A4a4rkPGQmYfiHT1efFCZgFK9hlnjQJmX3SnuJcmTd8k+6Hn
hUvO7TE92R/GDWrrtJoucgA2WmuH5cc6yTsRcejoqN94Bxmo21Ns1fUzWQWg
P6W68+Q16oG4Gp/x8mxBO/VANFcp1OG9bdSDEPA47/fRj5qpByH/dp/m3tlW
6sFIK32unPmOrlcFo8j2YrnjPrYPwZWVts5r1jZSDwH/eod5dlo99VD8Zh6s
SX3zCvVQFKVt1Q4l66iHQaC52v73n5eohyHBgctKab5APRxZTYkrZ8+xHg4n
/dhgzqoq6kLoiuoefPV5BXUhUsI1DjLzSuq78M/+n3xONdZQ3wW/8QXjXDOZ
FwFr/zLTVnfWI/D9jcnuhkvnqEdivdMd1XzieeqRkEuV3YvBdB6eCLb8sZPv
jNF5VSKoc2O/zk5n+91ocy67nhT1CfXd8AsMWpp4/wz1KBT36z0X1xRTj8J8
T/KOL18poR4Nk4ADz85YnKYejV/cB3P65z6mLsb4/XZBiah82RDjdYP2bm4k
7VViCG52qjxunVo2J4ZweptV+bCa9hI4znwaFhZB9w8SHPR2mzDdcpb2EujW
hbxWMn+R9hJ42cuFx80u016Kgc7nZm/n1tJeisq1vyqjW8kqKYQ2QzW1YfQ8
cFI8nMo2H/y2jvYyyFNWHYlObaC9DPypQstUG3o+VDJMuz7ZPGXU0l6GxT/0
Pto8dv9jsNC0vTp0ju1jIPaa1SsK2D4G2oePWoNeouu5GBTbLqkntrB9LPrc
sszqyuh6xEKekeGSO8DOH4tGD9lerpo6F4uWcmXC0RJ2/jhIDhwMeusa28fh
jr7pvSPTbB+HE5n3HTIyyVwcNBbc0A+J7P2Ix4ve1Rfqq+j9QDwmuKq5+gL6
P6p4CDaITSr8Wgz/AmCm66M=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzl1I01EYx/F/5mQZrSUjXWygM6apVGpOt7n8TTfnrDRFsq2yKIvKfCMT
aiUjqMAIQ6QkagobjmDhLFcra6aZlpRoEVsXZpFmLxeFGilIVnSeLjpwOHz4
Hp5zovZWFu4P4jhO+Xv/OWkJ/fYqTehA9199y5hy8uwOAZmDacQ+sGQpmY/G
pOhX5n8Woux5SXVcEFmELZLc2KrX/cwRkOq/xrWNkCWI4m1fdfUWORJy25fd
RQfJMjTVyif4W8mrcV7AzzTEk+UIO9Yj9YSSY1GQMVUTNvaYOQ5rigdNzgA5
ARWxgmZVC3ktZhfkPmMreT0Svfl+zkxOREn9+LDhXR9zEj6Hi04qHORkhNen
NHhLyRtQK80/ZPz+iDkFg55p2b4GsgJFy162OuTkVHjNvhdhBeQ0aGZP2S7a
epmVMFkF87xo6iqciwl2581RV8M7/GOaF0NOh22PQaJo7mHWYPJDKHZsI29E
sKv0o87mY86A++iQ7439ATNwpbnxbJeZ2QqsaH8vHnxK97Vou5G6SFx4n3Ut
VqonXCEhd1nPRHmk9AlPe4f1TMSPtw8/TOtgPQuVhqHrpwM3Wc/CuiPqhfnO
TtZ1uFSWpxVHUNchCvqgeT8zp0d/oWvU4mHzrHqkW+Qqv9TDejay6k7kzOTT
+9k4oP4pEu3ysm5AQXVT/+FiZqsBPuHMrPM4u8/l4JNy7FpCAs3PQd1tt66l
g/5vxJm3l2vGs+l/RshqLvSqKuj9XEzuTG7z8ZituRC1P7OMBmj+JuSVVy6e
u9fF+n/mNmO5sk/Mn+no/gUtEhWa
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVzWtI02EUx/E5xtIlsVJswrpokjNT0tLmZflzF92b9aLIQJBicwMjTJrr
RTb6y0ICI4LJjIWVG6yiqfmi5mW1trwsgmRFKYKltSCDlhLLLpoVPSfowMPh
w/eBk6E/ccDI5/F4hb/fn00jnnQ3KUTjgb9aqGic+nLrqYDMw+k83cwyj5wI
h6SsuXN1jFmMEfNqKCVKToXLbrggCJEl8HWED70YJEuxWhJ21vjJW2G1zC7f
vUPOREvMJhRdJGeBb7Y/07eQt6P/XLyntIEsw8f5S8f3y8k78ONdacSgI++E
UWXCTQ05H9PB1svt0VHmXbh3MDurd4pcgLSQQsoNkwuxYI+/ft5P3o2XY7XD
PznyHqjbPsysHCYXgV9f7ho0kYuRLJh8a/l3fy+MCZ50IUeWY6VK0N7sIZfA
ZuocOOYjl2ICfnlXN7kMiaMdQamXXA6LTjtdV0f3FHjSLZOtc40w78NV8UIk
3UuugNX3YGnO8YgZWKvbsmZuIzMHpAgys91p1CvhDG4+G4mHWK9Eo2dImGMI
sq5Evj91sUZEXYmi2JlwQgUzT4WMnr763vcPWVdBn9uy6E4eYF0NW/FS4LvS
x7oa64eux74evc26BrP2DTnW+17WNahN+tZ6ROxivQrjidtyhdFrrFdBMl9m
KHB0sV4Nq7np/JXP7D9XjYlNSQ2nPt1gXfu/OS0ev8p7c7LNGfgFo7n/lA==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90As41PkeBvDpIqUbXeloG7JllYol5givWyRkXMdtjLmYUVEqW2k3Q1uL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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90AlUzWkfB/D7WiN672gkUW4lpAjVRI36tomKVu3d7lY3NdbIaxn9SRM1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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zXtIk1EYx/GXWSLZSkRYUOTMYWKp2zK3aZs/d7MhFMQkcKKrnH9IdIVA
amQRtRaUGl0mNtqKxSgKt4TGmG/OciBKdLFRxuyCJKNgIHPdFhWd58Dh8OF7
znNK9h7cZRNwHCf7u/+dtAritw6pV8T4/0o1ZIsmdL5cMofWgQ+ljpXkPOz8
5DOt5sgFCH2Jv8DiBHMRlnZfUX17Q16D99GvwqlR8joMTSuzHg9ZjNm5ubTp
GHkDTvSsumo8Q5bAFM4mR9rJZRBcD+4Z0ZDLUdiaMkgXnzJX4MK+pYeTcfJm
zPS/q7vrJlfhnPqIrNxJlsLZsnA7bSXLcMDY/tMy9YRZjsOSsvBpEXkLrM9i
ndFL48w1sHCe4VAeeSu+C4Q3Rd1R5loIubMtXcExZgUiM/aMb4ishMvlqJRd
I6vglb6tzvCPmetg2xQbbltOrgc/qA3V9pG3Ye0Nb2Iwh96r0dH2enJ/B1kD
SdIUKLxD9xtgqficCM7yzMCYvktrL2HuBeQnFUnZeuqNSPi7lfaJUdYb0bOx
c/5jFXUtlpXyjxb8bH6vFu7zgXspG/2ng7DYb3VXU9fh8o/jzc1S6nqMu/LS
ovs0X4/fzpqL8gDNNyDiNWvMYuoGDDxX5qtehlk3orKf04ePUjfCnJn/lVAz
c02YfqVRnHJEWG9CTnEqP1fMzG3HjvoH2T4Jz/8BRsz6GQ==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90AtYzPkex/E5HW1JyKlULmsicktUupD6kEp0vzfdZqa5kVxzKLc/dVgd
KpUTXTRTbEWuXVFMlEIXVggrFTqlTdg221pZ5+n7P/M888zzet6/z/N9njEU
bvQWq3A4nDvfvv/7ZT9aT/I2LdOouzGi9/Zr1cYpPqmz5mBnnpVR2f+7OlJX
XHAq/HqbrIXgUb1aYz+x1sGR4jC9riHW+tDI3ZtwtY/1FIwVJLam3WPNxcln
wQuSr7Kejkjjs1HNJayNYFCRvr0qlfUsTE4ocDwWwXo2tDwO6YXYsJ6LydzQ
7h411vPxfGuTSbcW6wVo2eOxpWki64WYGnVNlVnGehFGJ4UKrR1Ym6F6OFXF
sLyWbI4oyw0Dr+xZW+CXQ+k73sWxXoyKrugvp9eytkR9uiI0ZeAW2QphRrG2
gpibZGtMi34/+m881jaYGGwQVcBUk5fAXKGYva5USV6KN1kOq8Qi1rZI2xEV
frn3BnkZYvtfFfygeZ1shyUlLatMbleS7SGe4xvS2VpOBlIzzsgD5KUjZoCe
DSttX0Reor4cRbuxWfFzEfXlSHyZ+JNtjIL6CpgN/nLC8E0O9RUYl/y9YULQ
QeoOWLS7+mlKbzJ1B8T8+aLhwP1j1FciaN+xkzdKMqivRGZbcqaOdgJ1R1if
KPKa1JZE3RF6t/lLxAoyxwnNf0waSrOVU3eC+9aqwVGzTlB3RhFn1JWPkcep
O0PVcqoiyyiF+irsd8v8GNO9n/oqmD02iCseiqPuAnXtUy3PpfH2I90FDolH
49V4x0bMWQ27P30HOoxSqa/G0oKmma7qCuprYNqd2d0ryqa+Bpn1yfcaK3Ko
u6KvaFtsjGs+dVfU37036/TFXOpu2JjRv/XIpaPU3ZBv5L1xeF0MdXeYqYYt
fr4nhbo7Kj+GStX2ZlD3QJr3PfXSLjl1DxTPU8nt/3KGuid29n6fLZtwbsTw
RN7ltAnLjl+k955wvNTpsCDm0oiVnrhcyGR2xJbR3gvNd/WlF7eW094Lk99v
+bvOg2u094K7ZOz6he5VtPdCVvmad3ymmvbeSG8c+JDmSYY3TgfOHxDr3aS9
N2Tpqsf7u27R3huzD4za+eIhmeODS617MedBDe19sI+3uW/K/lra+yBLhxPW
bExW+uCzhZX3Qelt2vvC53rycPnv1OELZl+YMZNLnfH99v+PT7hwkKz0RZzZ
by66BuzeD33xrfGVmnW094Oi4avO0x/rae+HsMU2t3adv0N7P+it6Onv+YPM
8cf7gWQNm7H3aO+P9i///rD8CZnxR4qmtlx/gKz0h35KPPPucQPtA1BiebPV
5zgZAUhOLjhgqdJI+wBUn8uZUfKVujIAm9+v3qjNo84JROLMKzb/WddE+0Ac
7u7M5vyDzASCb2CXsOMaWRmICrPfkpYeJnOCkBevpnrSrpn2QdD/lG1s00Fm
gtBikuRgIrxP+yCUzWm+axpJ5vDgXxAcH5NNBg+nsEDb6RWZ4WG6+X2Hc9oP
aM+DTvSZkGhzMicYCZsb5/V9R0YwNFNe7jxvQ2aCcWLcmtIBD3YfDEleqoUr
j92HwC09jRd+ld2HoKa5J3y++k+0D4HLu5uMdQ1ZGYJ/nQ43vJtO5oTiiWlh
h+nyh7QPReS0LZ5eEjITCi2nIVP/X8nKUNQPd8w4odFC+zDskihd2taSEYbV
hhFjfIvJTBhys76sW1FFVoYhZXesxlutR7QPx7z86qp3k8kIx/2PacZvxpCZ
cMifSQyjNpGV4ajft65QFsPu+Vhg1BDTZfh4xFw+nDlVcaGRZPDh1qLpJOkl
8/n4Gl56cdNpMsOHiPNKZJxPlvORt9G6rEntCd3jo+/CtfIcG3I7H2czsux4
YWSOAP4NQ6K90WSuAONNP0yttSBDgF3bFh2yX0zmC2DiV+zUdpTMCDBhV83j
/ImtdF+A2mLXeC9vslKA4JhHQp9B9r4AFd8P6gqG2ftClKmPtZJZ03uuENvF
yUdyWEOI3z/+uM1ClcwXIk0lc0A1mMwIMVzvMvWVhL0vhKIu71rdlKd0X4iC
x4Wm7XbkdiFckt5OOcMlcyJgsX3nUtFn9n4EXC6mHPFaQh3fXOlfdt2RzI9A
Lnd61O47ZCYCldOmr9/RTJZHYPKWJF3n/ez9CFgeqOzqZnt7BD5nJ4fsN39G
90WwF+xY/OI8mSvCdw7uGg9fkiFCyEy1qDrFc7ovwoOQCuf8djIjwnT9XdHc
ZrJcBGNpb+eGK2SlCIfnPYvbs/Jnui/CQkefkIY1ZI4YAV7/nOQuIHPFGMhb
2l8URIYY48N7rjJzX9B9MSZciNXUMCQzYtw/ZVCzW48sF6O2tMhvdC/tlWJE
DjW66l5h74vRHBD3kL+NvS9BnECepXGMvS/B27YfMmYWs/clSAr+tDevicyX
4EL/+de5r8mMBGMO2SbOn8Lel6CixNfH81eyUoLl/Z0fntq20X0Jjq4+PnXc
KjJHipz1jgvdqshcKc7iyaxJui/pvhSDecke08aQ+VLUztYt6G2h94wUPgcf
Nc4ZJMul8JPNrX/tTu+VUrzmbQscqCC3S7FrWkundhWZI8PJSKc6lTYyV4bZ
azXTIg3a6b4MUU8VE6PUyHwZaiqdTXQtyYwM5+6YX/mvNVkuQ2GV1aQOJ7JS
hopmU62+TeR2GYy0Ge1YHzJnLSKtbs/Y8K3/BfX+7Ic=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10HtIk1EcxvE3bXmtHJkamOkyM2+t1HnJ5aObzjklC0oq10WaJjizWn9o
tN5CmxiY0zBaUZEFS0depiOtplkqLJKozEG2MisNsVyloAlWeM6Bl8OH7+/A
eU9A7rFdCgeGYRL+ff93ujyG6ouFrv1di5pKbBek317lRs1gTWd5c4ELtTO0
C9F3n3/vI/bAlxVtRq9xak/UnFAeFoxS+8AuttuTP1D7otBlXBdmpvYHr996
0XiHmocx5U5usJY6EDxXXZvhJHUQ9Fxz2ud46mBs8JkKmfChDoHVQzYabusl
DsOMrteps4g6AlwNp7FsHzUfnnZJ3t5fz4i3oKeCG+itoN6KHfsPRL4poY6E
JbZwvtTylDgKB4Pm87UvqaNhOOo499qbWoAo3+mWETl1DExG7bnYEOpYXLJt
4jQM9xDHwckYn6kJoI4HP39ocm049TboB/mv6sVPiBOgEsToTcXdxELcLLgs
s9Q8Jt6OUKc890mTmTgRqp+G7IGZR8RA6JKmj19rHi6aBeJU746cruokPQlu
N5YNWzs6SE+CLMvfPUdhIj0ZVzY3TYjYB6QnQznd18GxkHlGBAwwXmbQLkKd
X9X9W1Z6XgylYdZTXW0kXQyr7Le8Ir+V9BRovZOKxhvIPJuCuU9qB1bdTnoq
ihfWa+SV9HwqJrKDR6pVLaRLMBA7ps7ZTeZZCaojmLqy2UbS0/A+r1wnVzWT
ngbNtfNTP0qIGSkcX2w8dMaZ3IeVolY66HdPTN8vHXsUpQHCC+S92XS4LDde
r8ul/y9D1FnR21O15D6sDMLKpQvS1XrSM3BcwudyLMRsBmx/upWFcQ2kZ+Kb
M892lUN7JtY1rczKcGzt+gvO5Csc
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0X8s1HEcx/EvmlDLpZbqqOg0YspJEcfLHQ7H5ceWfi6zio1QfpTyx6XW
7ra2frEZidwRdxUtOV35kahL0S8/VlndaPohZaTaqvVj3p+19d2+++6x5+fn
vk5JGXG7zDmOC//z/v2yhzegzhTZ3G2d1nhQ/L4JXc5MZg4V74yNk5bMVjCe
KZ8wTd0h89C3/GFC/wjzfKyKb3fWGpgXIkcr8TrXwOyA7l7bbTFnmZdhy2iU
2ZICZmfcz0+bUb+DWYC6OLVBEMi8Ak7739SvFzC7QuVlV+X7o5O8EiOZ+tmH
25k94Oq4+L2FktkTfMsSH00V82oEKIM129KZvXDE5pRzghuzEHxhikvukw6y
N+xqFyQ8CGBeg07/BJMSzD6IdM32yDLeJq/F6zOz+KpQ5nWwfddYWBTeTvYF
332qf8adW2Q/ZHsXFFk0Ma9H2Umrvo0OzP7Y/kmaXPq1hRyAxjZtviTtJlmE
4UWVLi19jeRAdMjLP6u6DeQgOEoT7QsVzECd8mPy+F6yAuC6mvJGNE3Ug3Hi
e2iNbaKeejBkZsWp28VkToxh4ZbDfs4N1MW43BUfMDZI5iRI3f/C3az0CnUJ
FHlZL4MM9dRDUH3oVfSlazrqIRCpu4WqEQ31UFT32xz81V5NPRSPEdtkP1ZF
PQxifbq2vIvGK8JwO9BNOFVH4zkpsq/mG5dqaqlLcWLX9YmBEtbD8cHieE9c
Gq2nCEfIL5/n5tasR+D940lBgew89QjIW4sianwvUI+EZ+JzUa+KrR8JxXBu
+tEUdj8ZDA1rm8dH2flkOHZMZJOVVUQ9CjrJ1qRV+lPUozBP9yXzmamYejSa
VRlvNfoK6tEwPzCYd01N5uTw/zkndeg0O58cwsHdT+ufVVLfgG97frrnHFVT
34BNO5c9mr+ZzY/BDacKK3t1+bQRA2vjveTei6U0/r/eFoO5GwcWVPXQflws
Jt4ikGei+yEWD/OHBrkW9r9i0ckbFV8pq6H5//wbxzFxFg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzw0s1HEcx/Fb7VbaaqfcIjo9YORhla5T6D4ujsPFeYrkejA9YIvFVGvc
OeV55VZCUztyKULSw5W4hNp6WqOHydq1topImZ6Lav2+rflv//332vv/+37/
/4Vbd4UlTOFwOLLf958nXbwn1SneM261/9V7sdv2e/LsaWQOGoV30cElT4f/
dUHn65lkHp5bCz1jZpEtkHi0Z3jbRDezJSr2rW/TfibbQDngHm7fT16Aspe2
o6l95EUY/zlem3yEbIdep9JI5+1kB3TlDe7OCiM7YmC2eptMQV6CpB+b1MVi
sgt6V6tDeFZkN2QPVwRJSruYl8IsPbUkr4y8DNK95lb8aPJyaDZmC+ceJbtD
3mB8d7CXvAI6u2RNQSFZCNt6fezQzk7mldhvXlOuW0AWId2pmtuTcpPZA3WX
5SdS7cmr8Dgm7Zkojrwao1LPi67aDmZPRBfZ9HnLyF6onNCbngrI3vgo+VZS
dJW8Bk5T+uNfXDQyi5EhOqUwtdxgBk5m6gNen2ZWAd89ho+/vE77fTD/TuN8
/RvqPkjp7x1ozaf5Eqy6/zCpbjN7XyVBRvliri6C9q2FoVzw4JOplfW1KIp4
x61RtrHuC4+qB/zxDddY90VxV2aOy5lLrPthKj/cdbb1Fdb9wN07oit7dYF1
KfLtxBMWDswqKZ7kdh+y9Kxl3R9riuz5URzq/hhrcm4zWjSyHgBdT4lAk8be
VwVA0/6+oS+Ougy8KPuNVjn1rMuQ+WOuoXjXWdYDIUxsqXl4rI71QHTMyUrM
jqcehKw9X6vi4ul8EAa1QxHRRpofjHlDFiJTdRPrwZPmy8Ep9FJGtjKr5Bh7
W52brGX7OOtgOBJ7PsRA89chz0qkUdefYz0ElVsG67+M0vwQPDrA708S0PxQ
WOZ/it2RwOYhFAekDXmOZvQ/oRgp+G+/MXTS9ykw2pRhijnM9kOBN8OPlF0e
zey8Ah+aDfNud7Sw85PMCfvnXx2jfSs=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0GtIU3EcxvGjQol70SK7CEamFjbGKt3MtjmfOefZ1ElKMqFAsIIuWr5Y
ZebayZEhhG9y9KreZAqBEcpQc7DachauCeFlLRlDulhBm9GFsFhF/1/BOXA4
fPg+h8P5b28+U38sleO4kt/3nydd0oXbbaUZU96/SpQ18gnJAEfmIPAXHcl/
TsetzhR5y88AsxQ7BsKdyiQ5E4bJByuaj+Qt6G+9+sw6T86GJO27pvEpOQeV
iWTrlTvkXBTPjDl1XeR8rF1jPG+pI+/EcrS6d05LLoB/NuvE0DqyDDf6PYI9
Nsksh+7m3dCwi6yAtZ6X1LSR9yDVGXgzryXvRXMwWJclJxfCGbueqRQeMxeh
b4Nh1dVOVsLy/sO5OE9W4bnC89I0Qi6Ga0ndYe8j78Oie3z69Rc/cwnCTT3X
ehTU9+OJ028KffUxqxGMZOik92ivwaVNKbULKrIWn5LmhtUu2pdiNDrxuSr5
iFmHU75Qy9bj1MuwPKtzHCmg9wGD6oIt2832AnD0mzZn8Czt9dDlhqYshWwv
6BHs7l0/6KXzKcfKIZugP83OXyjH6P28kOcddQOsP6KBiRj7P8GAjkhYE+6m
XoGRjWlLm/PZ94QK1Dak71p84WHdiLzwq5OHXQ9ZN6LpgOVtUXyc9Upsm7HP
WS6zvSAyx8PY7piO28ZY50XdJHpfZM6Mg8Nm9e4hL+sic1XwCTJZJOhmXWSu
WtT/+xcGCCPS
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zQs0lAkfx/EplWLbtV6rTraadFFSLkvKbX65NoXc78Ngxky0mwrvVnQG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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzQ1MzHEcx/G/KDlTh/IUI8tTLHq60vXwqauux+uKiAm7noSpyWMtO2Eq
2nUqS55qZjhslUuRHujJQ6QHIk9pMYatjWJKw/p+Z/Pffvvvtffv+/taqhLC
YgwEQfD7c/7++RN3nkt0EzXVjKjPw2EorEVmxhZQ8Vm3Y2gi2xjvHp9ofzjc
SBYjPDW8dbEhdzPcn/T6Wdcg92l4sPvylzet7JnIU8W13atiz4GVbf4vw9Ps
uVjwYVy/eBfbCvVdOS49SvZ8hMdOzVnpzl4IeYGxnXQV2xorygZl5j8ayEtQ
tO9lnvQi2wam+ePU6Vr2MojCTZoXDNSTbeF1Rnt1uI1tB4Mjij07NWx72M2L
zLTZy3bA9O1Rdz3b2Y7IepuUmdTLlmBVZGfbWDHbCZIpEbrUjjqyM0KPHe0p
rmEvR/e3F+b6ArYLovZs2ZpSxPNSPGm0KN/2hu0K77isJZ982G5QLc39UC5l
u+OB8qlRWh2/54Ed3yVG+o93yMCc9foQr023R6wG1FVOs7WXaqh7wvGV/EBu
YBV1Txi1rJA1T7tF3QvdLfEVY9Q3qXsh3kNWfWjoOnUZXKyycyTHK6jLMKOi
91pLF3dvxK8enbK77wZ1b9ioE05szSQLPjCyXWl2ZKCSug888i17m0W0T/CF
Q7b+oXEQ7/fFy9HLmsstaJ8gx+KS6PNLdbRPLYfpbRPJmgze74fnohK4xlyj
7gdrfLRt7yil7o/OOwelj99fpe6Psek/06py6b4QgFJVclzOJD31ACQqouWa
fu6BEEUuOmpaWUY9EM8ly6MeVZZQD4Im8WZ2cgS/H4QJ5tpLTcHF1IMx2V04
PN7sCvVg6C5bOXXbc1dA05+h0LXzvAIGmkMS34aL1ENQurljeP7aQuohkOzS
z6q+dZK6Emd9nON9ddShhCrGFXpNEd1Xot48Nv/nhVMjrlUiYMPXkHWFdF8I
xf7qzRbijVqaD4Xj3HTjUdfzaP4/1/7zb+AbZyM=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zQtUjekeBvCvcR2HRJwjNKJE4SiSpqJHVKKS7un27Vt7SxSJNIM9Ybqg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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90AtUzHkfBvAp61Kbdtqk3bPta0ghhJWsZHuoqZTofq+ZprnpokgUu8wK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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10Ak0VfseB/BTdCuaSSrqUCRFA4UKX1HJkHmezjnOQAOubhLl7m6RSPQq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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XlM03cYx/GfqMgQFJk68UKIMeoqFkHFDfRTCrSUQg8aFHRTW2Cj8UAj
ccIf/FTUKGK8Y4xHvBCjooA4DKQgWDQSj3hQTJUV3FDxiKQp4gF1xufxD5uQ
5pV3Pk+aL0HGlfoMD0EQdP//ffnmj5/tRHaU9/Xar3o7z/y0fnimF1uAR6vB
XjCQ7QVzb39d5bfuh2yvBYlF7kbycFQ8MBeedbFH4cJ/yJrfwR6LaR2rA5c2
sSegLcCi9jnADsZfr0v6etLZE5EqL7viDGNPQkGqPVMZyp4Mx5J+UpfTSp6K
zo0jhz5rZUuwoHPXy67l7BDcGqCejnK2FPcj6rPGy9mhaF13a49xMHsGQiqq
OmuC2GEovlkS5Gtgh2ON8d5VpYY9E8r1Yw6Ft10jz8KnN68k3dvZs5HuTEyZ
dqyBHAFJ6dTs9gD2HOSNy3+okbB/gWlNU7jzwlXyrzhvteLEkHpyJPLK/jTH
f6wjR8G2OdOecpE9F/tObtv3Yznv58GmOLf0j3TeAwZT6LmVudRFIN8RcSY/
jfcyvJGafMSoWuoybJsQtqHGj3s0DgaukHb70z0xGnNdO/vKBvF9Od4mudpL
SyzU5Rg9q+jI4S28j0FDRqFf9ye+HwObq+qFRyq/ZywikwfeLbhB7yfGYsCZ
ZYHWhfyecUhZnHDS2597HFqGKTocsmrqCixrDkjbtJUsKqCdqOrfPLSGuhIW
ca15ZM4V6kpsXPvE5OuuoB6P0t07+tnDy6nH43Zbrql6O3cV5veFyfe+565C
i7QrbrHAPQFjAjXFp3u5J6D91N7YD7JL1NUYoc3KUf1eSV0Nj+Zihd1OFhLx
/nawwpjDPRHWA9afNnhfpp6Ewgzlzyt66J6YBFmT7V2pg+9r0ON53rTIwXsN
om7+dgk+3LXIc9YFaVaRoYXbXW3pekK/X9Qi5XjIjNQh5DotXk+27N/Vy3sd
HnmWHznaR/ehgzDn8czG6Cra66D2/Pef9RJ63zodxGc19w5N+Zv2ejTHdKkq
G6hDD5/nerf/ft7r8eGHGxm5abzX42nj4ecBkdSFZIj+CUXBOfT/RTJ8a1ui
jY383slYdOdar8pQRvvvLBi++TMFOagH
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0m1Ik1EUB/AnUaxGZDichqLN8qU0dWa+pO2vzr2oUQQlkiYzKlZiYvqh
InnMoMg0tQSjzJgVNnNGZKZmU7Pp0gwL6QWzjVIMcjYZK8EPFd5D6IXL5cef
c8/hcjfknth72InjuPi/+99Jy+19Y0HC6gHDon5KvQrkhbWuZA6VgsD6fify
SgytWD9caTMyu0F00y/0xiRZiD1ff/j7fCB7ose2pUVtJHuj9Ohrc1EX2Q8h
glxFt5YshsiUv5BeQ96IuAMtXFgROQC+NvdM635yELrGtI0dKeTNmBTrdS0S
cgi8/DuzfILJW/FlarhqneMlczg0kQ1J44/JEdAiMCL8GFmCJ9bPgt3B5Ej8
mrz9sTSMvA3WirpMp7F+5iiUfNNGLzwnb8fxhghzlYgcDd/Zap/pwRfMMdi3
RnLriLmPORamqDMPH10jxyFb3no18BB5BzxsFpOumByP878nTM4jvcwJeCWa
UXe8Je9ElospR/CJLMXMwUs57bYeZqDsdIXGYeleNA8MPS13l+Q9Y3kiRj1D
5+8MdLI8EVV62wVVH+VJaJU1rbVnG1iehBhL2MBsIc2XjHexc016KzOfjDfG
ALt7Lc0jw7w5SuVioFwGQ1e5zOMKvU8KHBOuGbo5Zj4FGr7turCNcjm+q/Mv
d9ynejmmjb1K4Snqr0DeeMaEuoz14xVobg0R9LpQvRLOJd4nN5VQvRJ2v7PS
ZgvNp8Jo3fR8qobqVTh3V1q+Skz3py41v8xcGkaCqtuLvdh/4dNQc/HBvSnx
IMvTl5pfZm7Xsvy//wCM1Dma
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zws0lekeBvCPZqY7MYWRapdUKmlU7vLkEsk9d2Lf2BuhG2UmbJQx0sVi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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10A001PkeBvApZbfSprg30bWoJDeilYjyeAmFYhjvL/M+o1K0SbXSJKFa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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ns41PkeB/Bfd0dpdVGobYdUUnKpJGvyZkNyZ9wZY24mp0QXSZumYm11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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90Q1I00EcxvG/m6BJOoMt1izTcuvFCHMtTffybM65Sa1mZkTMpkvXGqEW
FL0og5DEiogMghTRsBZGkdZcKtmL6SgDE9OkWCaEzXAYFZVFb3i/Do7jw5c7
uLvE4rK8Eh7HcYq/899KI3b0crkqqr9nTjMae6C4WB5N5vA+vYjXO48ciSqF
dbyFR47Fa8dY2HWOLMTnGode+qmPWYy0ULyTC5EXIyavhnc2SE6ApzVREhgk
L8OzU99LG1vJSZjW9JmlF8kyhNfVi1ut5JWokH3t7wJ5NTapAwfN4eQ18Dj5
vlvPHzOvhc0cv9PTRE5Bwc8Fhm4DeR0mlZq+SEcvcyrUb+sHN68gy5Fbqq+e
zCSvx9jH4YLhZLICX/JlE922R8wbECcZV5+sIqchuD1j5uUJcjrccd7o3zcf
Mm/EyAvhO2049Qx8iDJfCo0+YM7EuSEn/4mYrMQRe/Qq/ZseZhVqC3MkhbPd
zGocPVDWrGjuYNbA6Nz1Q7T3NjNwJkK61cb3ztkNiBrn+60Dd1jXYoqv/dYg
b2Ndix2e/UHXBDOnwx5xpmDLYeo6WCoFujYLO4/LglI4pLJe8LGeBZ9UldSx
tIt1PRIqwq6eF3WyrsfpZHX11O57rGejqSRlemE7u587G8ZF5Rm8X/ReBlxZ
cjdGqWb/7TZgeersoWvH6T1yINMdK4uoZP/jzkFR1sCIx+Vn3QhvvqC2q46d
5zbCbml/Gie4z7oJ227sk3e+om6CyeN39bbQ/tz//gMDbQA3
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90nlIk3Ecx/HpH6bLPEBL2cijZRI60mbqzo/O+8KrxIURmlMCdUmnWEwx
o0DMTAwrYUmIB0pgamneOhfTMJsl+UdWhpmINsUs0Ip+3x54eHjx/h3Pw/Pz
yCxIzrbkcDjyP/ffJ10Obxs0Mq6+/59WFaXPpHbptmQOXmbyZtfsydYoqeDO
qqzIDriscNNtb44xO2FGnedis0R2gXj6tSnXQOajyz1J9LGO7A77a98+ScrI
nkj1E9d755AFWPVIiLZLI3tBIElJcQ4le6Po68bFlX3kw1DbzHv6bI0y+2Bv
2bBYdI8sxJw644rsKvkIeE7lB1R1ZD8UWipUNT/J/njSJm7S7af1j0LKD5AH
66mLkP45lZd7hhwAqxO64xrhCPMxcIWi+qD1YeZANO5eDDj5nHoQ5K/sje0+
5GBYNOSX6CdovBj6SZPm0SmyBHfGQ6p7a4eYpahvrm6cHSfLsBBouGtRN8gs
xztH577mXdQVyJJ7S9vWqAPbddadN7nMWiDcOHk24/oA6yH4MlB1rruFWRuC
9ZTvKaIbND8Uia4rrRYXaH4ojLez07qk1JXwWuNlni+irkTwHvNUFJ/WD0OF
sTSnNaqP9TAsay51Tm9RD4fqQWnW03jaPxyJXtlvDk6w8ZwIVKwXL1X697Me
gcC8jsc6Nc2PxC3dqPD9FPVIpM3dLy4U9LAehZmkh5utsl7Wo1DlNpKfPMjM
iYbyx7yyx/UF69HoGm6XLG/Q/jEoMJiyao30/jHo4TsZyrvZeE4s1AsTiy1m
2j8WYyKB8tcU/c84xByK2JH50vfFwbxZbms6TechHjuVA9JcR3a+tPFoKnYY
afs/PwGRHWUK31pmbQI+mBdEtjVD/b8Be3Q8YA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91nk01XkfB/AfLWMqMsiTpuXSYgmJVKTxVvYlS8jS5d7rLrRMaS/MXKnG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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0W1IU2EYBuCzwkrBMBMVtUgTsylrzeZSs92b0zlnur4kSEvFmVmhaKWY
0hEK+3BUUv2rMEGywI5lYZbNNJUQEmYpkWK10jRwKsp0Rlb0Pv3YgcPh4n6e
m5f3BGYX7DEu4zhO+ef9+6XHY7CuMNatx/xPU8qpjoqlVncyhxF/aOI8yKvQ
V15ZXLqG7IF09b7L913IXjhqSHu7Zb6b2ReWsnujXtPkAKSpm/UvR8gb4Ka9
c+CamRyEifbEJvNDcjA66nPWHf7vEPS0zJ6w15BDseg96/PYSBYjA2mmEh05
HC1rj9w9U0GW4Hj3xQ8rDWQp8k+9aJxcTd4KVTjejFi6mGU4XfpZ5mIiR2D4
pmfUbRV5GyLCxhQzfmQ5gr9v8ueOvWaOxHBDlmfGUCezAgFjE+6KcPJ2WJq+
WndLyVF4ry2T5QqvmKNxZWDcXKokx2B2oUjUl9nOvANy4YI8pYscC4dxSDjZ
SPM78emga+H5sx3MSizX276kh5KBoCHlox/P2DwP7J1P7ex+YGa5CrU5bXLN
U2Zehaq8/flGPfWrUfwktn/6Kuvj1RgM+hUp4eg8cUC5KcmWx8zHofb6okP8
jnINAnJn5qpTnrNcg/G8pcI+b8rjoZgUxTh6qT8eGw2ZQpeMzp8AkzBdV+PD
7ptPgMxu+Wn1pfvUYkDCS13FtK/Ft826jBVe9H8ScSvrUtXHQDbPJ0LnaBCK
rLSvA98rypbWU7+TuSSnPAlt0kOiOYH29ThnuLF+QUS5HqlhfEmwN+XJsPa3
FvTEU54MW2ZJoC2S+nfBzx49GlVJuZO5FKfcyVwqNJLm6pC6TvNvBFRCwg==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90AlYzXseBvA/ZYiskWQ7KY3rpoUURb1F2lTa9zp750jLyLVkOwwtc0eJ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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zQk41PseBvD/jXBTJ67CqVOJFqmQpJC8ZOugrGMfM2PGoJVUKmqOOt1o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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tMjXEcx/FHpItaVkaRQ9EhlxI6SqVP11Pn5OgcdCH32DRUStlEz7rI
pbEJFZpbaGSGJqU6lS6TGgeTy5HbrGSp7WxZFw3z/f7Bsz179tr799y+zx6H
zfGarUaCIIT93v8ceRvffjnBx7xZ+1d9vjnRk65KLdgCUjoEqx4ztiniK1e6
aoebyOPR7LtmZkMfewKM95/csPsD2xbTI4di3jxh26Mq1d1Q0cSeDq+8HakX
7rId8TZNL3HOYs/E0DcTx2IFW4r2ke9mXUvYs7HK2rA13449B9/NPr0Z09pI
nodpNW7BGVfZLrBam2fxMoK9AF1TrOe3tTSQ3aBbbHVZ/Zm9EM5Jhu71SvYi
DLxPtvrx7iF5MUZHXozK17Ld4V31yPWQjC1DyfMZrcfs2UswMCd7Z/Z7tgde
tydX10nYnvDubC61/FRPXoqSHg+jmBG2F/IPbvp66hjbG3GdNt0ZKrYPiqQz
1nmW15KXocD0Vdr22GqyL5Sno7XDB9hA6shxo96LtF4Einal5VYpuPth+5YT
5ncbaqj7IfNkeuNhpyrq/pCdM/WcfIHWi/7I2jdq4mCZlnoAKvcm9jXs5B6A
KNURB0PSA+qBiLV0HiiqoOuJgfCp1spLnfj+QSjreFwzrZ97EK5ZN+XZtlVS
D4aAIF97OV8/GD/lt55BQ88ryKF58bAkNoyfX46BjlWJ/VKeTwhacp6qK+Jp
fmIIoo7o7Vzc+HuEol4XOuVmC/dQjPpQGjQ3guetwJczfYZJwfQ+ogLSe4nF
/nEV1JXIua5sFeXl1JW4MdTy5I6EexhkhXGD+s771MOwJ/Kx96t9ZGE5wj10
+typt6kvR0yCo2V2YRl1FTIP3Ur00Z6nroJTwbbsshGysAIm1gavdKM71Fcg
1yY5JVDJ3y/8X+M/i/+5NhybsyRFnWN5fmqYxKTnRvfW0flqnFb0+qWY0fxE
NUZfdzk86wbNq1YNR9XZtnEBPD8NTC9d+Riup/XQwN/4tnvxRvo/RQ3qCnU6
m9XUazU4oT7TeDSzXvsLwAKE1Q==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1kQk0Ffgex2+mEPWeHpXp8TIptJIkJXwjZM2e3d3vVRolMTWv3FSaNi16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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntMU2ccxvEKbkHZpRmEYbcpJaKOGIZQubM+VMul5dIrqDjSTRtDYOMy
RAIEKlGsgIIoXY1TkEu2IeoQhtOCdCCjOJZCIsPUQTZlNgG2uAjBAZpt6e/9
A5o0zSffPu9pTw7/kyyF1onD4aT99/7/k724403ZkesHex16Knzgd3rGw5mZ
A+OU2/6b//xIdsFap2+PH/mLmYuKjKoPhu3M7uCdyLfXPmb2xLFu3gDXyvwu
fr7k9pOnidkLx+KWSuUVzN7wen6vWStn3oy4U/Ojy1LmLfhic3Wf6wbmbbC/
Zol+sTBA9sWIf9R23iTzdgxN68XLzcx+6Os40D45w+yPgTJbS5WFeQdMU0UX
Ur5iDoBYOuxly2UOhNocyHFLZRZg8pl/TK03806YFjODu3yYgzD9y7Rwyuku
ORhrrLea7g/1k0MgEOWllR5kDkXBHnFXkKWPHIazdX9KJlKYwzFROtGhSv2B
HIGLkjvZF6rN5EjUV+QWikKZP8TVO/nhNfuYhQgp01UeutpLBmZnKsvPz/Y4
rANcH+Vf8eWROVFonc9Q/y01UY9CZni+pKv1NnURrhvz3g+NIOtEeLwxaMGy
7Tvqu7BlzD0gYLGT+i7kCIy5+mcd1HdDI5/kdLu2U9+Nxhv37msK2F6MuSex
zfHeX1MXY9b4qvZw8RXq0UgXGFRxT1qoR0O7r2hBk0XncWLgLOaqnLn11GNg
9VAuTs3XUY/FjUbXbNXHTdRjEbzRXpYkL6ceh71vHbyVyNNRj8MmqXF0eeao
0NElCDObdryxs8ZhnQSSR0tNHnOnqEtXdSnGz8oeRBpOU4/H0ZK+NZc3VFKP
R97+5tHX3zlJPQGzQl3DTT3rCRh9L73Klsp6IgJdLCZ3DZ2nS0RSS38IP7GC
ehL+8HzaOKY5Rz0JR4Y2+S5VGqjLcG6urCQii/aQwffMQ7+S82X0fRmsb4YN
1v9a5bBZhgHnYf7z6+z3y7G2qa3BOq6nvRxLlyJaP7cV016OzFSn+U8nymkv
h6k746XheDXtFVjfWMvzuV3suL9Q4KO2V9Q9GXT/dQpctBcm2L7X0X6VOcqV
hhLjg4KtI9fS6fpKhGvHbA/7c2ivxJ6ZhhMjdw/QXoX2dYpSfsdh2qug2Vro
8mVnHl1ftfI8swratJMvuDlCej7UK41V1qkR6dfVpjfQ/zGrsa5O/tKlp4b2
ySuNZPx2SCO6Vt9A+1U2J4Mve7vos0p6Xjkp8Pnd64wt6xvap6B9b8HlYUNn
77/jKNeB
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90mtIk1EYB/BNGwwjtkSmjkFaYWm57DKnK91fN91eaElKNSolzQluS0Po
4iJctDRvFYlCKFmEpMbApmWrwWibq1WkrKioVl+i9kFQsmgbSBd6nx04HH78
3/c55zmczLrmSkMCh8OR/Z3/VhrCt7eOFyU9cf/XojLhaj2vL5nMwSl/blaK
iMyHOXYlnxGThfjWGhI955JTMKJG4bWon3UauiSMdOAHWYJIRFbMBMgZyK/6
eOKwm7wWBocgNWOKvB4Z4WqvfoichbNbTLqUCvJGKIa9d3sl5Bw03Rup4n2d
Yb0ZitY0Vc8LshSdjlS/1kXOg31WbjLmkrfi02X7+Ew2eRsio49imVM+1tvR
UbtpKNBH3oF16vDp8zayDAenLRFUkPPhPFduTk8my2EUf9kviXpZF4DD63Cq
58mF4Gr9pfIJsgJNscndcxHyTlyw3G7+0Ej1dkFgVi6GxOQiJPL3Lqpq6Pti
zK7yJL6SkpW40WAxHL1EBnQrltqG5tl+rYAx/XX/+EnqvwSMzTPt7KC8BIHu
wbZfBZSXwiZov7gcorwUv29WHul1edhche6nozUNA+x+VhXeNeZN6h9Qrsah
nNrrG6KP2VwNkSvYVh0/fxl6DqiP7eNS/TII2gfGWnJo/3Jk13/uXwqy9azl
SJr7Gd4Tr6/BMyMWFt7T/xrwTW86NWG6Ly3sKye61txh369Vi5eDD4eL4u+b
Qct9n2M83h8Doc9wZrXM707XF3vGlhl8D+rqhPqA+w8m4Q3H
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxFzgtUzGkfB/C/S0mJvG9WyTKbV6xLaHOpVn27KJrumu4100wzTbm+nWpd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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XlIk3Ecx/EpHUvLVtqBBGlbXquslk5rbp85b5vNtLCD1XKWZaJWVq6D
dSCYSFBJUZmYolKWIyvR5VVqheKFtPpjWaaSpDgiF3ZIxX7fIh94eHjxfn6/
5/s8j/uetM1J9hwOJ+z3+edKB89UnB7k8LzBJous1GB+PcwlcxA/XFFywp7M
xazjAWrn0VZmHhacFloXD5JdINFe1S1sIi+GUGoUHSgkL4FD15VBay7ZDbdb
htp6jpGXgcvX7i9MIQuQr0i/OS4ke+BrpGaueKKF2Qu+bYodnY7UfdCT2uQa
7kRegeGMUmVBPt2/Cl/iX+hyjpBXo2rG1ny73eQ10BpW8lISyWuxvW8goUJA
FmHO4Qfa56+amddh2fWxWW6rqPshfmm1Nd1E3R8bhWMRItMzZjG2JH70WuRJ
DkDtjzhva9dT5kDEXZP3T99AXg9B8ssM5UQT8wYc4j85o6ogSzDJ1WWUxJGD
YNl29eHbNrIUwlqf/tYysgx5bhfAd6PnA6Gmw7KTWcx6YOcbadG9v+vl8J8z
M7njDLNejs9lSTfU+2i+YLT2auzEUmZ9MOa5iAdmy2l/BTSnFmiiYqkroOuq
MYf8nT8E57ee+7n3fT3rIajnF3iYA+tYD8VL3a40rqKB9VD4c466jwpo/zC0
m+7PlPTT/GGwxBotTr70/cMx1C6XZp1i1odDLFj9nneQ/lcEXL53Gs7aM+sj
IBy5NfZZRu8XCefM1Jqk5Y2sR+JEwk1Z8Xw2LycK7s3lOamVT1iPwripr2oa
/zHr0Uh3Lrh7MfgR69GoNDpVmEQPWd/4v/VTzFFO6UroGnPzjO8MrMeg4+e3
O2uqq1iPwYduc/Z4bznrm3C3yjHT4XaizNY3QZ3tYdFcuGwzR4U6P7HE1fuS
zVChuEEr651kXa9Clrd6xPfTFZsbVZCKu+viPYvY+tj/jX/+BbMJXTc=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10wk01XkfBvB7hESW6VUvL29po7KEcDMpj72yxLVzcXdLNYwIE82NpEVJ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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zglYjPseB/A3JFKWThxLy0i2Iopspb5FSinTvo5mpmYmyomyizN0CHES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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91ntUjPkfB/BHu4pSYpXskomSDSVUlPQudKP7/T41NWVRI9V2k8eyhbOy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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQMC1xcX2HId3w/hfbBfM3eG4UEhGJ/BYW0a4+xP
vDA+hwOzX4LsbT4YX8Bh0osfAamMML6IQ8AUi2Ny/45B+RIOa8+8nen2A8aX
cZj21eTb5PcwvoKD/rdA7dWHYHwlh7Ov2OOql8D4Kg7zSwVzwqphfDWHeDEj
n1InGF/DQbeps7P8/VEoX8tB7e8lpogLML6Og+iVg2c/FMH4eg6tP2rUOith
fAMHl1/7nUyMYXxDh9RuXq5wJxjfyCFfNnzq4xoY39ghwF5QS3j1ESjfxGGS
5LZ3EowweVMH7fkbnWZrwvhmDl7HZF55tsDUmzssWvfOfV0ujG/hILenKWzV
mcNQvqXD8hPsVZMPweStHCYfC8th7YbJWzvUHFlo0LrzEJRv4yC5O+3e0Vkw
vq2D3X3XBJ9PML6dg2zyr8sRcP32DhkbNFpY/GB8B4dd4keffIe5p8HBoXZN
A3f8DZi8o8Px/0Kn9glA/dPg6HAjQSWD4QVM3snB5HpiuFMvlN8A5E91nRjL
AJN3djCe4HtHJfQgVN7ZYYtVzEYZc5j7XBySqvb66x2G8htcHH7Kh1cZfoGq
Z3B1CFlo876bH+Y+VweHRWeanqyA6XdzOKmwsD5rBzT9Nbg5TF9c8vI/MD4a
Lm2ennHFzeHTJd8kgYiT+wER+e3W
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zglMk2ccx/E3mC0qsSkVTQnKhDGspCETUAa18OMQKIWe61g5ouJB3HSi
kxHJOuuQsQEq0niUFFvWrpvA5sQxkQBt8cBkmwJBilkCE3FzKfEglswj7kj/
z97kzZtPvs8vzxtZtkezPYjjOPW/739f9vC99grp4iFXQI/SvhN1hPgWMnPw
V7Tu7/77Gnkhyj4+Id8+z8yHVcSPdP7FHIq6MdOClXeYhZD6BI90s8wrsD+x
8ODUr8yrYB5csvOBjTkKiZc84uCPmKMRods6Un6AOQZnuEO3IlTMIpQMpu7u
4phj0d+5atneP66SxWiJWdBo72GOw3Ve6THZUnb+TRTx/A8bb7K+Flsffhtq
mmGOh2GRX6dXMCdg5jWV7PHcFXIiSiZTpO8fZl6Hmcn+ingx83oM3+QOTC5l
TkJE6/N1IuVl8lvoveDOvqEeJCejQDuusxk95BQ8CO/6qs3vJkswb0v1+n53
kTdgtC1hxahzgCxFysCf3zxV9JFTYQ/96YeoJT3kNIy3vii23fqRDOwKvzJ3
2002AitPBls/vH2Bejp2GHhC/prz1NPhzS1q3lRH5jLwurtJf2/fOeoZ6POs
7p7obqeeCZcgWmZO6qCeCUkwLzxz3kk9C9pnlQKhlmzMgpVXNavnHNQ3Yt9o
01QPx/YbMWxwbPP+3EY9G/2zsoIQ/mnq2Sgf2WFIFlqp56DRl+ZNf9xIPQe2
sJnI2HoL9Vy0J7xiq2sxU8+F4nTGy7OCz6nLsOudsyOiOBN1GWqfGMfeNdVS
z8MnecqgSXkD9TzsLHvVXHLnKHU57i8bkhoim6jLEe0JzXwaW089H8NBv1XH
X2umng+/0DIxraf/5QoQtrZ0bFxO9xkLIPw6piz5/mfUFVi+eM34tKCSugIJ
U3enJZYv0gJdiaheqynpkDlgoxI1xS/eEBe1UFehcLjqsE5iCxgqVHL28rj4
djqvwhOn5KCl4VzAbhWKPdfFYv/3tFfjU/vEvd5OMtRwuAo7HK3naa+G773d
Q5ZasluNgQ+abxxXkjkNPLO8RXX1ZGjQqW/e49p7kfYa5DQ8K82f66a9BluW
TztLqy/RXgt9V41hpJrdr8XmrCPH80a/pL0W5dq+U2G/HKO9FlE15pCqGgft
3/7f/wDE/5Fo
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAmIQDQMC1xcX2HId3w/hfbCPYPoi/Z0dxmdwuNd7ISxF
AMbncBDjFDy4iw3GF3CoWsIXJvn/GJQv4qCtZaRi8h7Gl3A49Mg8v/YyjC/j
MGn9qQlKR2B8BYf1Kcb9cstgfCWH+6qyx7XLYHwVB2vnr4vPxsD4ag6/Ht52
bPaA8TUc5COPJcgmwfhaDnePpy8siYPxdRzmf7t2YpI9jK/n4MWhFblQBcY3
cFDq95O1/noUyjd0WBp/0oZhE4xv5NDLqqMgfgjGN3aY1mHhbgTnmziI7Vhp
9bsVxjd1WHx49f8aOZj5Zg5vVrutfc4K45s7TPq+21DtNky9hUPoh85vfXdg
fEuHrz8U8zcfPQLlWzlEl5acDF0A41s7yKV5FokeOwzl2zh4b+j07FgO49s6
HPyykSFxGoxv52B47seUwkUwvr1DZ+UapiAWmHkODjuuHj1glAHlNzg4vNmc
os+nfQgq7+jwg8/u3uOXB6Hyjg5HcpiZUkWgfAYnh9urDz3OlIDpd3Lg8i2I
+DAV5l9nB+nqe313UqDppcHZgdtMdwafHiz9uDg8kN947eCcY/vzd3euPVrq
4vDpkm+SQMTJ/QA/6tPJ
           "]], 
          
          LineBox[{{41.34716737739882, -0.198}, {42., -0.1945148524872604}, {
           43., -0.1945148524872604}, {43.20683260078597, -0.198}}]}, 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91Xs41Ikex/GfVtvFkgppyrqEGGorIaV8XEORXMK4zRhjpiQ96lDbbSgV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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90WtIE1AUB/A5Z1pmzoghaKbTykrLmaUrl3+dr21qZia0wigKtA+VMkVz
w6kVvsBm6ISh5qMITaLNKEoxU6cr7GGCH5TIKQiauVBJzLCie7xwufz4c849
3Otz6XrKFS6HwxH/3f9OWvyxlhuSLYM9/2WL0HELK8vdyBw0qDQhfnyyE6rq
Oj0GeGQ+ZNUPBSMrZuYd8Hd4N+0zQ3ZH2xNHR00v2RMVwpV7TxvI3jBEv2yy
blgI17TPi6NZZD/kedRHOivIe2ARa7dN8cj+EObr9WbLAPN+COZUq7nPyAHI
3pdcEvSKfBDKnKL6rkpyED6mjo6pEski8PwTbMlD/czBWFv4ufilnXwYolCl
W7eYHIJAtXT7L1Mf8xEMT8bdT28lH0VVYurrAiM5FGXzzbsyG8hh4Do3PrgW
QxZjZ6nV/mvAG+ZjeGuY++YqIh9HSrApsONcL3M4Qq5mFafqyBKcaro81/ue
fAJphnGjTk2OwIfzoiX7DQMj/PyMJQfWXwuEG2vWvDZRHgl52kzPci3lkdgd
YFh3qaZ5ozAhLDHXv6A8Ci3fO2s/2VG9FH1JB8JKT3azXIrpdMjdec9ZHo0l
/sVpQbGJ5dFwHpoPLO9j5sTgULbnsGm2k+Ux2Kry6mh0ovpYtNecnrT6Uv9Y
zOSdTcoZpvvjcKvMwpn1ZfNq4yC4k2spuE3/F48giXdF9l32/9p4TKnWi6a6
KZehf3Pbcs0qs1aGmy6/1YlSyuWw7f2hb9VQfzmMj2UtGSp6HwUWHc90jWdS
vQIXFiYmlF1UnwC7wkeD6ubBnj8z9SRz
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10AtYzPkeBvApVtRZplyOxM4glFPkUknRm6abS/cy3adpppmKNtEWx9pJ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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAmIQDQMC1xcX2HId3w/hfbB//NZdM4MbxmdwuOBrfWg9
nM/hkOkVeW4mC4wv4HAsTvbzu+/HoHwRh7+rX+wL+grjSzg0fTGPmvQUxpdx
MNSOFN5wG8ZXcPBPbPB4eBrGV3KQ/bWTyWAZjK/iELXh5AODOhhfzeHxrzMP
4v1gfA2Hr9bPM1/qwfhaDtc53vDM04fxdRw+psqf2mYA4+s5lFdeLzURhfEN
HDqSzu/jPHYUyjd0uKP8y4FzCYxv5LBMZVuRbSyMb+xgcjmubtaRI1C+iUO2
2abP3dthfFOHjhu3zgQdPAzlmzk8u3ab13oijG/usCE1icNFDca3cFiVHiz6
7swhKN/S4W1U5LyllTC+lcOlqRdC1pvB+NYOx6OPPp1qcxDKt3Hg+yKaLT4V
xrd1EKti3XdhFoxv53CO7cXkvRow++wdip2e3ZgBd5+Dw1cbjvdNH6DmNzg4
BNc8aG1qgOl3dPDl4VwU9AUm7+jQqpC9eJYtzL9ODuptkQ1pIlB+g5PDOpWE
L72vYeHl7GB6MSc8sxmaXhqcHc4c1vhiEQ1LPy4OOSfvsaWKnNz/wmiP9Vkh
F4dPl3yTBCJO7gcAsi7aWA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0QlIk2Ecx/FlaU1DOyRMm9lhtizpWCuruZ/3PJZzSwyKQDtI81iusqJj
Gg47NMmjplamadm0RrVszDObZYNiRSRioEQWJWLOotLooP8j1AsvLx++7/95
eZ53XmK6fKcdh8OJ+X3/ebJr2qsqpcjxUctfDYnN2zx9+A7MHJgrJmXyucxT
kNB+b1g1lXkaGlNn1c8ff98VL8OLl/iOdzfYDzvpyt52kOcg//Bosp2F2QvZ
75/hZhXzfNiLHyQcv8K8EB/6TMaj1cyLIPpsHeMdZV6MyaltW7/OYV6CwoFs
T3mXmbwUB1ykpXG9zH6YWNwWnbKFeTmcbKOCGT7MK2BW5hluGB6SVyK5p0pi
CWJehUjXZRUjXswCVOTpivZa2smroT3J901XMAvB9YtZsbf7AXkNPMyFcV8/
tZHXQtjMSyxaw+yP+jBDTqkd8zqIcyVJtceY12NXkCk0Z7CFvAGV7habTtdK
FiElfkOgUsZ6ALia401p6cxiPPdMHfE70EwGMt7NTSgop64GamXrBVEfWA+E
fobVrPImqwMhlzao3kc2Ug/Ci30FHQ0eJupBeO0wetBiZD0YKzeNne8WGqkH
w69ffzfcepd6CAKaArxOd92jHgJplgBbNt+mHop5h8xPpYPXqIdiR39IrVp7
nXoYkntrfPwrq6mHwc0p8/Pl0avUwyG0iaxZ2hrq4RCtVTte2F5PXQLrRKUz
t1BHXYKb+VPKPrrdoB4BI1/S8ORnHfUIHOxNe8Tdc4t6JIIzVnOedtL76khw
htQpzwfoe5wonOszvNPG1VKPQmhN5+3MCaxH4/LJEU15+RXq0ajWFvQ89iih
LkVivLvmm+kidSmcd4ccu/+4jPpGqK694eV/Z/vfCAPXYa7vWbZ+DBrrpjft
m0nnoY7Bjy9xh3NTKqnLINuvd9Yk6f8aMpQtXyeYLWTryZDh0iF8VkL7bZXh
9KU046tFBpqPxanO9i+mxWTEYrukpaiui/6vOhbeIzkvcrPu0HwsjC8VzmfG
z1f+ryFHj1BzvaCT/e//3CqHptjFohyooHkFeOknhp2ytTSvgMqmtZ+FUzSv
gJ0ueYGk+Yj4F3S7kLM=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90XlIE1AcB/Blq+YiHWpQ2XLa8MrMra1mpn49Ni/UlArbWqUwIwM1MMVM
m4QGRZSKIBiCRjrYP+KRK8vpclvRqR2mFeWRFcaKkJGadtD7+eDx+PD98XuX
b05Bps6Fw+Eo/s5/Kw3ByPXCSL7d/F/fo0P5w7VhHmQO6h7zIg1uZB4ummpj
PwrIAnj32SJerCF7QW7zda9fQd6A9pAgP/EvG/NmtB+vDOgdJ4sgELp7moxk
PwR4VH27kUsWo/1+9dD7ILI/CgTZmivbyYHwHF1Ic0rIwShdajaa5q3MIdjo
OiS6/I4cikuW2pMDBnIYVG3pq4xNZAkeRtVzHRlkKWZEz9OzrYPMO5FWzb02
UUKWodPSMRtuv8csx7Pp04fPL5F34URS1fiEk7wb5poern8dWYG2KZ3myxsL
czhaK1p1WYYB5j2oOdI4eKbQzByB0jxn/6dD/cx74SpMr1DzKY/EuCSvPKO0
lzkKT/SOpZf2W8zRWBsY1vBz6jYzYBQXvnYoWL0e0OrOVbp332F5DJTCwcmj
QaxeH4PU+Zv5cx3ULxb83rKZSW9Wr4+FIffr1bp1fSyPQyt/Yh9/C/WPQ7P6
s9Z2sIfl8Rib7SrqDDaxPB7rlasXW5bPp8SwSzLvlYz6K+HFGQsdLaH7qRDs
U9YtHaLzqaA+K2xZzKf3SYDWdaFYfqGL5Qko98l4NCqj/onYFLPygOQtez99
Irp3uIkzR+j+SWgq7tN2JVCeBOtsg3T/1rssT4ZzushxSsT20ydDo5n7fewp
/WfKsuu3qbgf1Cn4MZyaI8h6YP4DMbwe/g==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQMC1xcX2HId3w/hfbC/w5Cbs4YXxmdwSNGtCGzn
hPE5HFqnGVcj+AIOHB/Nzxb+PAblizg0/uny4n4A40s4pLUe7kw6DePLODTs
PWlybzGMr+DwNu7Kb61+GF/JodSq2TM6EMZXccgKXM/i6QXjqzn84dvTMk8I
xtdwEFnEe8Ls1lEoX8vhUu7i2TPOwvg6DjzFd1cnboXx9RyEZBx/PSqB8Q0c
Jv6ULbevhfENHe6YNRrzvj4C5Rs5KOp2n4hzg/GNHY7ECd8ItYTxTRwyfNvr
rjDC+KYOGYpyKSeSD0P5Zg4ztpa5zeeH8c0dss7GK99rgPEtHM6l3Y1e7gbj
WzpE6KX/Yv11CMq3cvj0/VYdgw1M3tphW5KnRKMmjG/jcO/h/+R6G5h6Wwfp
26p57/MOQPl2DtPKu1ayWxyE8u0dvldeu5hxfz+U7+DAGDjl+nN9KL/BwaGq
xHDGz8p9UHlHh/Tc7Z+iUqHmNTg6sH5P1dk0HWaek4Pos1W2LZZQ+xucHOb1
8U9mNoG5z9mh6ZLiIueFUH6Ds0PGnon/Pl+B6Xdx+P/8meP3ZCi/wcXhh6a+
gV4tzH5Xh1/W+zsZbfZA5V0dbHYUn9b/uRcq7+Zwt6nmgsXznVB5N4eZn8zs
bYth/nN3uLZBOFrwBVR9g7vDUb7VavvfwcLHw2Htp4j46WLH90+9eMeZKcfD
4dMl3ySBiJP7AXQF/yU=
           "]], 
          
          LineBox[{{50.475258454393284`, -0.198}, {
           51., -0.19439856475870437`}, {51.524741545606716`, -0.198}}]}, 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwlYzOseB/A/SaWbyrFkiaiOVKfFWqG+LSQt0z4tU02zNW4iR3pMljNd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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJw10m1I01EUBvBhJK2aDbYPLoZr2SQ2e1Fn29LNx7dNxagMSqVkGaa1VUaF
TRktc4y5xOpD1GhfpmTLLw4KNamlWUvyJRRmFEFu0YyR6RKqtSij/7lwufx4
4N5zuEdce6aiLoHFYslX9r+TFne2q1G91u/7r8W8PpvNvZdDZsHw1Ds2kEhe
gzJDcMOD2AvGXKRaH3pufyHzYd+/uEMyT07GTPeqKes7shA1gaMLCX7yJgTa
xILHHvJmRI7d56W3k7dAJsy9MFVGToNH0KMKBZ4z3grJyFzbcCdZCserljfj
JnI6hPsa0lxy8nb8uRxObdWQd0Lh+ilih0cZZ+A1906DqIOciW38oR9eIzkL
61yXTi9xyHI4Q+GIIzLCOBsfItVO90byLtyaXK+6sTDMWIFlxeqM4xfJShx2
6vmDjWQV3h9KWeZ9J++G77p8bCpG9+Xg4O+qutlJci4CwZmhZhNZjSRfj/Lb
/DPGGhi1996q66nePJgH6sez2NQ/cN46Nyp6wtgC9DviBnaY8nw0L0ksvTbK
82Gt4lVoJigvQM5EVKp/xMyHpQCcGlEku4rmpRC61qZfJw8w71sKccWtTGr5
SP9ZhGq+OlYZYmwpQqa3u6lvmuovRlBRbtZ9ZWwphth4LavjCPWjxed2WbnJ
TPdrofgUt/NfUq6DWR8vjRqofh1O9YcFKSeo/pKV/7NLk5spL0HrVVNiBvXL
KkUn/+zgzXS/T3bX1us+V4ro9J5abuWY7y+Vfg9W
           "]], 
          
          LineBox[{{51.263227942072156`, -0.198}, {
           52., -0.19292654249173044`}, {53., -0.15632523934865877`}, {
           54., -0.15421866612183308`}, {55., -0.15106710357825054`}, {
           56., -0.135456576440351}, {57., -0.12396827872136221`}, {
           58., -0.135456576440351}, {59., -0.12781178109117278`}, {
           60., -0.11778873042015404`}, {61., -0.10545878049220005`}}]}, 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10gs0lHkfB/ChNqutqIhKkrzFCtVUSPIllEvJ/W5mjBkjpFdaNYum0iRb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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0QlIk2Ecx/EXjVimOU07dIiWZGnWzCxLbT916qZZ2ywNlXCSXVtWKhiU
usIKhMjMElGsNpZrmWdF98zUkRZmVnaIUA27UCssu6nY8yfaCy8vH77PyeuT
uV2RZcdxXPyf9++XHn6/bkeEg9lk1XvRi8vBwaUuZA6Ojj/f7HQl85Bs31/H
m0LmY2Cmc1ISR3bDWvcmVcFwJ/MMnNcOaUcekgWIeVdr+X6b7I1P4vJ6h0ry
LPhlN2TfzSH7IjvnTtaokjwHMRWzhjeBPBe9J/1Gx3hkf3Q+CK7pHe1gno+h
bzz1WBd5AT7EjZfc2E8WQqiSJJXIyEFINCVOeiMlL8LVdmNriKGdORhOxwI+
F6rJixH2rM/r671bzCFompu1b1hHXoKqw/yueUryUtSVH6rrrWljDgVfEh3w
vIS8DCaRU89rX/JypDnbS7X9N5nDUJFy8MTZbdTD8fJ+6mRvAa0fAXVE7kbl
TvIK3BnRn9zSSRZhUDEtX1FJBpZdnBg46MHuowF03+YNu+dRj0S3z4VTbWNs
P00kXm392axUU49CmeOZvCoDO58mCnv05h6PATpvNHTVpRsErq2sRyNwfUvh
1XFmTow+vkutfh2tL0ZAuLPf6afUY9DZmHPE4knzY1A8pfhCruUa67GQpadx
H8LY/9LEwtBWq+4Ip/8X9781cUjhGtujzXR+CXYVVT028uj+EgTOnvxE1mxi
XYqCA1dEIWsusi7FdM/8VFVkA+vxuOsUpv1xvYn1eGw++N3HdU896wnw9DWe
S5ygZz0BV34Zqj8GaVlf+b81NuYSbbqNuVVAQviX9GQD66tgbNnvYF6hY301
hEUZ53f7H2fdxpwMC3WXQi29R62GzGa8DAiammEyl1rdatM5OQYf2W0X780U
WefL8VZe1m0UHGLzbdwqR2iGu7DeS2UdzykgznQbqebJ2f7//BsERnkZ
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91HlUzXkfB/Bf1iZRM0XRg8KYaBnZCi3vpFtKue3ltty9G1LWGUtcVBRJ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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90gs41PkeBvCRPUuOLYmSVYbQZSWk3MKrohuZcR3GZYy5WUK1ujsNqaZ0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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgs41PkeBvBhqxNq2XS66aIicUJ0c0lei6LcBjPumRkzY0qFajvsFoN2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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91XtUzHkfB/CpXFJJz7qUW0bKuoRK9SjSW1cVqdTMVNQ0tyZEWexq0W/V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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQMC1xcX2HId3w/hfbDf4mg4L4gNxmdwyCsyOlrL
AeNzODAo7ZdghPMFHBas9D174+8xKF/EQT5+l3wonC/hcHHVFf7gTzC+jINU
z4Y9127A+AoOWYydqXY9ML6Sg7jX+aunY2F8FYdFa07HyZjB+GoOUWeFfvY5
wPgaDq3bVqWrmcD4Wg4fNfvPTH11FMrXcTirfyy1IwXG13Mo66gP4n9zBMo3
cDBx2M+/5AuMb+jArHXhRm8cTL2Rw1XeSj3zezB5Y4dT71oXZuXA+CYOHdrM
rU1mML6pQ37Rh+qPpw9D+WYOps8+Fd6aBOObO9gsKJ1tIwFTb+Gwm/eZ0bTX
MHlLB7Zlz3sPzz8E5Vs5PFr/1jUuDyZv7fDkXXNT8VyY+2wcovbZbD/WBuPb
Opy56By7IRKm3s6Ba9n6PztbYObZO5wIlbZJlz0I5Ts4hMjOWTBlJ1S+wcHh
95tXi6/zw+QdHVTUJ6hfXAGTd3TgYNngGyoEM9/J4c6rja+UTGDyTg7svf2a
uXdh9jk7yOa7O9jH7ofKOzusmXvGR+84zHwXh+dx8v63fkDDo8HF4Ueu4J7z
vieg8q4Of9571Mzih6a3BleHn/Nv57CzwfzrhspvQOMzuMP5ADxW7no=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0GtIE1AYxvG1EkWMKU1Xw0xFMrSLzkvN2x6nTjeNyA9FlobWKskwMtHM
cqnRCiMsL6mEk2xGNrYPJbqLt+YMMwIljcQsow8mmRcsxdEN31N04HD48ee8
B45PVm6qksvhcCJ+7z8nW66j989GO/d3rWpWEhg22TfvxMyBtspX3PjTRnbC
o4HMtc5/7YpuAZqvzzLzMd4tXuK+Z96IyH2jot4hZk/k3LJMqfXM3riiaSw7
UM7si00PvbnZ+cx+WBqcd5nZz7wVF0wtnuluzNvgL7yzJs3cRw5A9YRMFKpn
3g5z68SnJBnzTnxwkosKTVZyEA4WFSS+zWUOhs59MKv/3DOyCL1bzgvqXZlD
EH5q73A6r5ccCmVgqL3iRg85DNd4hZI8Z+Zw1G2utGo13eTdCNA12rUK5j3I
5onKpWe6yGJU5cylLVzsJEdAeOhNfvFpMzkSgvGZz0PLRnIUvkz7GDq/dpCj
8W3YzrdrTeQYBOqnJmNszBKsLPN7hh+weUDHYXcPU7Bl1Srg6kq0sXyO9ViM
OGQUpLaQVbEIsWnWP19h70nxsul4zSsLzVdJ4ehX6lciYj0OgjFDw4kf7dTj
MDHdZJ2794R6PF5cXjewGMZ6PPgZXjXfK8mcBCwa9fwNRawnYFdwdtuRMTZf
htdq7sdcNf2HSgaX5kzL1BLriSjxeOfGEbKeiEuOt9uFj59ST4LXmD+C8vTU
kzAi0dVbe1qpy1HhebLtbpqBuhw7GngLyrJm6goYheqb6sgm6gooU4pzqo8d
laz2ZDgoa6PSLWXUk1FqkNbZljV0P+V/q/75F/qaKi0=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zQlYzfkeBvCT5domKaKmMmfoStLoFso2vSWTFmnvtJ/9VM+QNUsyZzIk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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQMC1xcX2HId3w/hfbCXnlKhxSEA4zM4lK48sc2A
DcbncAgzVi4VY4bxBRyY7LpjDv48BuWLOCiuKlnc+hDGl3A4malptPYWjC/j
wGe7Nsh/P4yv4HDmwU3bx7NgfCWHEy7Fr3pbYXwVhz2L599hT4Dx1RzM0wMe
BnjD+BoO7IsnnnJTg/G1HJafEHVeKwXj6zjUdcTx7b16FMrXczB18lPYsgzG
N3AQ7in6a5QA4xs6BKWfe/3OA8Y3cvAReMI7VQzGN3bwaJUQav90BMo3cdh7
2unbtKMwvqlDj5Tkre1tML6ZQ9DqW5XTvsH45g6TS3bJ/JSBmWfhMCNnlhHn
FJi8pcN+jpQGOTeYvJVDZynn/DtLYHxrh9L00t9PTGB8G4cTky/bBt2A6bd1
iNt4dZvuVhjfziFUbvdp5c0w9fYOCSYLtKpvwPgODio3HZkeMEHDq8HBgWdj
lOyF37Dwc3R495dvx7KvMHlHh3/qZpPZfWDx7+RwPTbn7iEmKL/ByUH9Jb93
dhfMfGeHT4p+i78rHobKOztoO53lalt3ECrv4qBhs+TTrmkweReHPy8sfaIL
ju1v87mguWO7i8OnS75JAhEn9wMAXLLXWA==
           "]], 
          
          LineBox[{{43.83407175903467, -0.198}, {
           44., -0.19436084921659863`}, {45., -0.13814613136391388`}, {
           46., -0.13814613136391388`}, {47., -0.13814613136391388`}, {
           48., -0.13814613136391388`}, {49., -0.12479188208662184`}, {
           50., -0.13814613136391388`}, {51., -0.13814613136391388`}, {
           52., -0.13814613136391388`}, {53., -0.13814613136391388`}}]}, 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQDQMC1xcX2HId3w/hfbBv9+20VuGB8RkcfixSYi6H
8zkcVr/adKydFcYXcChgV78R+PsYlC/iEGS4yk7pNYwv4SD4Y8KHU6dhfBmH
JUE8zjkbYHwFh75eibaN82F8JYeqUL8jAd0wvorDhdO75NSKYHw1h8dSz377
GMD4Gg6rTj9YdckTxtdymHCu1HaJA4yv4zCl9cuOxzwwvp5D8ASxavXTR6F8
A4cju+ZE3dkI4xs65D2sTS92h/GNHE6ptZj//HEEyjd2+D7H/5/kcxjfxOFM
lEHr1noY39ThZp1hY8+Hw1C+mcPUsEuXMj7B+OYOB826xY4dhvEtHFaGPC37
PAnGt3TQUJqilNgH41s5zGV4qPbr8yEo39rhyIsrawosYHwbB1Fm8SjL6zC+
rUPHPsF3BXNh+u0cOtku+Oh0wtxn79BSrpI14yOM7+AQJ3W+QM0dGj4NDg7x
D1PUvVJh8o4OV34tYC8Wh/IbHB2m/EhZd+8JLHycHOZURC2Q+ALlNzg5LJrx
aethtZP7r0nnvX23xMnh0yXfJIGIk/sBWefL1w==
           "]], 
          
          LineBox[{{38.22448636194217, -0.198}, {39., -0.185184563150554}, {
           40., -0.18948073968073326`}, {41., -0.19327675259007038`}, {
           42., -0.17788806471673904`}, {43., -0.18256301877636655`}, {
           44., -0.1655849431107957}, {45., -0.17979637907447932`}, {
           46., -0.19786810912197073`}, {47., -0.16975833053280315`}, {
           48., -0.16975833053280315`}}]}, FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVzVtIEwAUxvFZIVYUEkoXQkx0dJmlWU5da99uSkMoCsXqIQij5ctCjShX
DNpm0UWWwQrKhaPl6kVz1oYwc1tzNE2yRTWILLsMZ2WwCMJtFZ1DdOBw+PF/
OGsO6nYfmicQCEp+75/Lk/3CflS6aGTor2ZlttTz6NUlbAHaBu/sFy1jZyH/
3u1VE5nsbNQtPe1tTAfJOfBtKj0+/I69AvrQpN0UYa+GzV1sT3rY+bj+Sdo0
3csuwNhohWfXDXYh/JcjUytPsIWwNT35EtzBXgtLfGi0OI+9HrW6BSpX4hFZ
hCPf3N6bT9kbYTFVCkds7BK8MRqnO8XsUsRbLZLY5wB5M06d2edURthlqF0X
dsqfsbegT3/RXNfB3oqzmgZN4CW7HHuS50yvm9liWB+bexry2BV4u7ilvu29
n1yJQJdIZlRyr0JXkT5VI+YuQU57OiUK+8jb4GxZeEUYY0vR3DrxcEPjMHk7
rDuvBV9995JlyDWOd2u1HjLg+5qcSejJBqA+Y+/JTA13Oczugk6pa5C6HJLY
/A/ODDd1BS58NDhC5+9TVyCuDfwYkPRTV8IzV152q72PuhIzs/3RMVEvdRV0
hXJraKqHugp+r1wx7uqmrsaBoqhDHb1LXY0HznBWWjdAvRrHci/9rJrk/9WY
68DywwkH9Zr/bfjnXyzCAY8=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlHs41Pkex+copaItuiCbGaHWplwSy8pbyiUNMsb9MjNmxsSKakttWSO3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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJw10XtIU2EYx/ExUmSlbMtAMkyXN9RsurxMp/ulu4qSFYoJJVmWorJhhRn+
McsoGpSHYUVlxqxAxgjTaZg4bGvLErRR2D8VaKkhpbNVrtbF6DwHXg4fvuc5
5305MdW6vTVcDoeTubb+3eniT/fo83hu+38ty1v9jpmeDWQO6hr8aW8E5BD0
qy9WDoSQ+fjuGn8qDLhYh4M53hLZuEqOAK+qjGn8TN4Cb6dbHzpKjoakw5ov
uEUWoTm5RclUkmPBPSQrGVGS4zG3kXP7Jo+cCLGOWep89oR1EmZiw5siLeQU
XP2YZVw5TE6FZf2NOq6OLMYe1esfpgRyGv6859X1TTtZp2O03hl95R5ZgpyF
O/el5eSdeFcaX9y26mCdgXnTyeCDQdQzccAnLBbPUs/CxFfrp1kPORt2877n
1xPIUmxq2D5W7X/MOgf725tLzUvkXIQFLUs858kyuEXqcu1mms/D4lFzpTeV
nI/xpohJ5gRZDp8vbrIin/YH9Okz6qVtbDcANV07RF966fldSNRWdQ2EUV8z
d07ze56+X4BTR2ziQgdrQwGEwS+GbGepF0LxaziJKaNeCIvFdPlBOnUFerXD
by99GGO7At139XEx3+xsV2LwVfLWFDNrgxIaqW9qSknzKoS1GwdLFkbYrsKx
iLTgC94htqsR6nwUULhoXo3y3Wdaoqx0fg0mfka9zKb/a9Cg41pua38/vV+L
wTKh6+E2Or8WXpEsbnEdzRfBVyvoPm10222BWsk5eRFWPCXV/Ipx+186rhVo

           "]], 
          
          LineBox[{{53.7027351014678, -0.198}, {54., -0.1919643770335667}, {
           55., -0.1882783486129131}, {55.40523965051212, -0.198}}]}, 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1y38s1HEcx/Fvv6QfcoRoWvqBY+fSHeLCvfw6jsNlNFaEaqtZfvxhmRW3
ca5VkvMrLWyc1vxmUuTH5ZzSZSGLhumv1vxohSG0fuw+n+/22XePPd+vY4kp
EVe3Mwzj9+/9/9OPNVGT6rX3TZ9eP4TSjL6sGiNqBsnMcOTWxiCxIV5pxuxN
l6hZGEu9rtItUJuhdo3lJJ6ktsQp75bx/OfU1igeUnBN26htUCPJO2eppD6O
teXc/KYs6pM4v5osmIuhtsOyY1PRmgE1G3YJ9VrvQS2xI+YRb5ZRTc3BR2bR
nyen5mK1tFe9paB2xk1dyi3jndSn4W2QrdRoBoh5KLWrKshVU/PxLZAvKe+k
dkHwrSShoIDaFfHKJ5tJDRpiN4SEz3Aa2NRnUGMf/bVyvZ/YHfyfumY3B9o9
YPE5puI2j1oAVamxWJdC789C4nT3yHDua2JPbIk2jZ37qb3g7HNiIHZMTeyN
0jRzzj0NtRAsdpXBgf3UgM+GYs+wuldvGSAQPbB1/t5Dug82u+Yiqze6SfeB
G2+beH2S3DO+sNg3fjhthXZfzFtl91StviTdD4rHVny+iljmh05+bO/Ulxek
+yNr4nJb3J8O0v1h47tj6tOVVtID4D7d3SKvbyE9AK7h6cbvRcSMCMW+EQoP
dQPpIhy1e2qVuVhPeiBuHPztaqgllgWibIQd1VjXRHoQavOEOYmjdB+Ewjzz
D4XTdC/Gqv21lbK3dC/GJiftV7sLuWeCUZ6dEJUup/tgxM26bBh50B6CGYeO
kl2FjaSHgDtr6j+6RLsE2dWHOhQXn5EugVHC/MNWExXpocjUNtuOSMtJD4Vu
Km3Yw/M+6WHYzb1j0O6VI9T3MFgNLViX5SeSHo4LlRVzlzQlpIdDKH/nlCwq
15uR4pE8rLo/r0hvSGHCqorWqkiXSWEz2d1Vp5T2/QUqgVHl
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zl1I01EYx/E1xNa6aJrILpouNefMzJVram7+pptuM8JWJKVNCQQrUFcO
kYL+KKOGZEUmmyMyvGhJZLGw0EzN3tBcg9Qwi2XRRbHZG7GBL1R0nv5w+PPh
y3mes/FwvbmGz+PxVH/O3z99otc9DWrhs+F/+lbg5y0Fff/Ng0cSqn0XRRZg
SmUfLV98yixChqwpeSlCjoNok/zVzwWyGAFr4n1zgLwBM+BkOj9ZipjloMV3
j5wEt182Y+okp8CfbOZ9tJNTMV6tjzqbTk5D0OWe2vrjCXM6Wva7rAtucgak
7T6D8CY5E7HPr/cNjpGzMHCnfdq2RFbg6vw+j6WTvA3zV4yf986St2MiplTL
P0PORo6lwaVMJCsx98EgPaR+zLwDB0fCjaM3xphVeFlhOr45/Ig5BytDJ9rS
BNRzcS2p3CBpop6H3irnp/UJ5J3w95dFdCujzPmobv76fVJCXQ2B07lbYqeu
gV+61jOgo14Ab0KcsaVvhBlomKtJndjDzAHxdXcvXLYPsa7FlxfLb1fHsnmc
FvlaoUMTT/cLkT2ucHS0Ui+ENbpT491F+4uQUl+bOSenXgT9r7EjXNsD1nVo
dLy3RsrYPk6HS/zp3u7TNF+PirpcS3+I3qeHQJ5jO9/xkPViiDwXm2J8zFwx
LJE854GT9P4ShH1eW5eK7eNKIFxzztXcRfcNSNWGAl0K2m9Ad2KwyD05zLoR
ilWVSk3rAOtGiONvmW+/ofkmnFqn3BKtHWTdhKzKY+JZkZf1UixWOWqjjnqH
fwOAzRMC
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H9M1HUcx/HviAz5oZwnDNRET2jCnMrBicVdvA7hBOSE+yVIbDa4nMpQ
wAjH1Ti8hADPvCvoBxUhoBOFiWf88sddoGgwWEEKnJRpbQXhhkBYnGI23p82
ve12e+x5r893+/zxXZ12QPmWE8dxyU+///2yj+dgTZbE9bp1XhMRjcOBVSXu
zBxe3qgZ2/+4i+yCXuXKmcH/7YmJQ+68m38wL8VwkEdkxT1mH/SJ1R5VPzCv
wNHyZuFvVuZV8LLHZv5iZBZAvOiiQlzK7I9jT5YLc1OYX4GkesGUQcq8FmFa
QWCy5Ro5CHZwu7Va5nWo+y4+a8PoVfJ6tMqSHKVa5o3o7w6fur+OORgvDMx2
3b7USRbC9yW3A+OPmEMwINxxsu0v5lC4VEUX7zrJLEL7ihut+1KYN+FuYcHh
4aPMYRibHJo4mM28GdNCefh5BfOrsNwSeK8s6SC/hqDYDEdiD3M4Ck3uYenW
b8li1OT9lBPgySxBAP977xNaG/l1+IdkZN/qZY5A5qnGveFLmIGRnHdE/eVk
PeAw38v4wok9TwqdNLiPL6Dz9VJc7vBzXXaH7SNRObJ2R+aIlXokDkfN3jR9
wvoW2C/pvtxpYX0L5iar+bmaK9SjMF1QUZKlbacehVTNG4Yir2+oR2ONURDw
nrGZejREsjK57ngTdRliDjb+Pvg36zLwZkKuS4xsvxWLi298nRdK1m/FIv64
t19LC/UY3PmHkwba2D4Gk5F1qXId28fCnM/3E33cRj0Wrvu9ffbUt1KPw+iq
hqTKonPU45D+52JzfvFp6ttw5sr5nW6iOurb8G7H3dHjY2epx6OnuvzXVN3n
1OMx2PuVdN/uD6jL4etodw4sU0fMdzkiHr+Z2uuUN29uO86Y5oo+02RQ3w6X
oYflM8651BMgaN7Ds8/k0PkJSLpv5XXXl9L5ic8aidD61jakDHxE/0/Esr6L
tZaumnnbnjOneNZQwKdk74IeUy3tFZhSPWhKP0S2PWdOCUulZfzcejKUKLh2
O6mzgu2V0EvPFp5aTfdnUz59P3jl9xiraa+Cx6P6EJ4be74KkjXvO7e0U9er
8Hbbi4a52Sraq2COywqTNnxKezUe2qePJPt/SHs14i4H9w9tLqO9Go6Epgcb
fqb7samxPC1f/GThEdprsERwYkBQnE17Da5Ote0ybGL3p0Fag7az+0cT7TXw
uGCW5YUarP8CmZnFWw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0Xk81Ikfx/FvOZL95chuadltpKSTsDkq3iRErpkw7hnmoDbUOjqU0YEc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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0HtYzPkeB/ApRYqNc9o2IhUbujhEW7n1ji4u0X26qGamaZqJaiUHXdSP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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAmIQDQMC1xcX2HId3w/hfbA/+LctS1oAxmdwWKSdc+Ed
K4zP4XA0zLhH4c8xKF/AYV7uBufizzC+iMMZo4VBuT9gfAmHMCFn10VweRmH
zfv3N9YywsxTcBBOqS37xwTjKzkw1FnIFB2DqVdxkPaRMvjeBOOrOWzymtv3
3Q3G13B4+GV3LZMWjK/lcH+z+nS+Z0ehfB0HhZ2LfSfNhvH1HNL2LN+/2BTG
N3DQnrIwgbEOxjd0SK4NkSosg/GNHOy9Mo/Ww9UbOzAbXK9e9eoIlG/i4HBr
wk+BLBjf1MEj28ZnDTdMvZlDnty/jG3/D0P55g5qys4P1q45BOVbOFiu3qWR
vBjGt3TwX6TUyuIJ41s5XCw8fVz32kEo39qBOWwSi64lTN7GoevJq2NTFsLk
bR00H+3eeHsqjG/nsC014gLDXRjf3oGNadF+3iswvoODB2dd0U8zKL/BwWHl
+ZpZp+MPQOUdHaz23Ytnid4HlXd0eGh5UKLm136ovJNDmpvajE1noOobnBwO
OH1sv+UN0+/s4H9t17n2k1D1Dc4O3vtdjszZBJN3cejlaw1Jq4eZ7+JwsuLY
r+fnYfKuDlOikhWY9WDuc3WY9fiG6SdDmLybQ5jl3AV1IdDwbnBzSFu/oj2y
ABY+7g5nJdYe862F6XdHVc/ggabfw0Hwxqn8/zdh8emJym/wdGDj0+f6Gg+T
90LlN6DxGbzR5NH4DD5o8gg+AOfVHmg=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90G1IE0Acx/FZRmqGUkYqynRJlAsrXbas6c+n6QaCzmy+EALTbODD6kWB
lc40xMp8kQblEyo9QOEcGzY3dVptgplZmbocW6mRGYVSZlrMCu/fwXF8+N7B
3QVnF8ly13E4nMi/899Kw3u8TSnyGDCtaT7me3mavciTzIGj78Ly0n+74Vrw
aOlNp4XZG5JknuPcD7IPxJGWMrmd7Atxz+p23XNyAAZzI2rFGnIQ8j/VSOuu
kHmY/t3UZleRQ8D1XBmbCCLvhKvtZbXrOzPzLpxdbKkXDpBDcarkfVTKFHkP
lCGaEvUEOQx8s15bWkfeh2VN5+63SvJ+VGY9bOZnksNhWPgosH59yhwBK5oK
v4VSFyDdKLuhMFI/ANNSS8SwhRyJ8MpLx7b4kA9i5ZbXQMrQE2YhRNoH66eL
yIcQsKzJmFWTozDqHj074kE+DK7sRY1tqJ/5CMLvbmqMb33MLEIet/1n3Svq
0agX+mc0l/Uxx+DOsHtLwUUysDdbMHS9r3fNKuBq2tb57tPMnFhUFHQ13PZl
+1WxcAnsMZ9fNbIeB+6OMbVeYmA9DnOlUj++2yPW45HjHBysatezHo/N2R2L
Xxo6WU/AnLn1dd42Op+A9JQPvKSjXawnoj6xsOLeTA/rifBy5J+01HazLkZq
r+KZPJDuJ0av/8i4tYPelwTbm1pFVg77D1USzsju9/uJTKwnw+ry2T8sVcd6
MpzHDcVVG7WsS3C5utwq/UVdgm7d5OTCKHUpmvJPFNs3UJcic8omn2nsN/0B
MvQf+A==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgk0lQkfBvA3+jRixBdfK0lSaRHypZT72BNZrp1wF9duIpNGkkubCokG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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIk1EYB/AXTdBZTdNgUmaaWtpY5bzk/b/Lq5vhULNcXwwGXVAxCUKy
yBezQSUMWRDhmOXUoH1Ka3PmmqtmJmUNIb8UZGFKUMxGwaLZBc/Thw4cDj/+
zzk8PCfVcKruWATHcXl/9t+TVty8ra1U9NSzpkB5lsS1ItpM5rBq7rVm/3M0
NtyYiKzfSI7DWI+11haeYk7Elsrz5boPZAlmfzgO/5omb8WLvvrxslnydpzo
aBJ/d5LTEBz4PNltIqdjpDPWsqAlZ+L2l/YUdwp5FzRBWYs6gpyNwuDb0Duv
j1kKxWjGtN9MluH0uiz+4iB5L5ztfT8l1eR9WHSsDs2tPGHOwUpxoMFyhiyH
VhLT+36MnIumq57WsnPkPHzNSva3LTxmzochad51Mp3yAui6FmNkYcr341l7
QNZ9k1yIIn2PPSOB6ovwDTwmaikvhuby3QLxyCPmEpgPnk1cf4RciqU3eqWt
jVyGmRqjPLfFy1yO5peHXNLGSWYg5NSpHlz3rFkAdreGMq/tYOYUCIle3XHz
7L6ggKsk0l3dTO8rEW2sen6JLCghdHx8fU9P/aowFKVOqNlEuQqB5cSumTrq
R42+2APNolFWL6hhck3Zj9+n+zwu2Acb/D7KeYj751q3mWg+FTDkm4aP+tj/
CxWwcqKkK/GUV6Krn++07GEWKiEbUCodUupfg9RkY1pjFJuHoEF8frBQZxtn
uRbd8uVP4Ywxlv9nrgruWzu9OUsPPb8BF2EKlQ==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91HtYzIkex/FfFG0kdJFLKtEKmxapaOqzMqU23e8z1dxLWVnNSm00qyzn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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1z38s1HEcx/ErhqhodOiUHxWSlPIzP+7l9x2HucmPf2pMKYSiJFZnpZat
NaepxNJ1W6K0KWz5cbhD94f0k+pi2lpyyo9Ufm6q+by/23ffPfZ8f977fG2T
s8SHV3M4HP6/9/+XHpPBe9l+hr2KFU3xXUaWY7R6ZA7mjb4Oi5Z7mA2gXPKu
CP9JNoF/wYuWdA3ZDG+Od3yTdpIt8GN8sl63g2yFOaO+Vv0qsg2a17q+s7pG
toOmesxssoi8DQkzpXenQsn26D0SKliIJjtCLs/mX/QgO0GnaVp2c7Gb2RkO
5bOm86uou0BbXlZZMEp9D17qJKra48iuaBdKqxx/q5j3ovCBKiDsM3kfUgZU
wyfUZDdYJHuemUghu6PuYfUvtULJ7IGk5ZKFmRyyJ+J3PEo1LOpi9oK1rM9M
gE5mb5Sd5zbz7nQw74dyVCmv7Sf7wCY23/bgJpr3ha5c4PNKS90Pa7YaWzpf
pu6PeOkhZVoidT6+H/OSJ2e1MwOne0ssL1UqViwBPiSNFxa30XwAeLdiXEdk
zJIAZNdnFAc00P5A5HXnfkzLZJYEIle8mPI8inoQtIN+B9Qx1INwbmO/l4ku
7Q9G5u7poTYd2h+M9Gdz1znm7D6cEMQMqHaKxey+khDkhb/3vzLUynoo3i4t
5+fHUg+FZUiJ+VEe9TBwDQQR5fFtrIdBqzaN059vYV2Ami3KlvX3m1kXQFY6
YVUz28C6ENtFFWdvy5+yLkTg6l1Lf5yfsB4OvQmbyjoJm5eEw2m2J8f4Bp2P
gPFJm8SERjofgcF1wuDNpY2si6C/yPUdS6Augvvr3P56S+qRqJV+ylBuYJZE
wk7xxY0nbGI9CppTFx7LucySKNi3a67KHOj/o2HdpalIrW9R/AV0jEYw
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQMC1xcX2HId3w/hfbA//bG9eTEnjM/gENig1xPO
DuNzOKzVP6rziRnGF3C4d/roGg0mGF/Ewf9FfJPz82NQvoTD9QiJA6V3YHwZ
h4tr9q/4uRnGV3Bge3umbms/jK/kIMp7OKRjOoyv4vBj7xXG3dkwvppDwt0Z
93ITYHwNh8+LI+V2msP4Wg6pN5M+MunD+DoOjfa+F+TYYHw9B6HDN+d9VYbx
DRzq9BXzJVcehfINHVSrSrbWPIDxjRw6o2REdxbA+MYOl9rscnaIwPgmDhM7
pp/5xAPjmzos+HU18b4YjG/mcIL15o/7XUegfHMHH97pr34fhvEtHNR1+2+F
qcH4lg4Ht8syyx04DOVbOYS/csqRi4bxrR1UJvd4HVsE49s4qNgFH60JgPFt
HZ6rvevX8YWZZ+eQr3c+f544jG/vsPVkw5PeTJh6B4efq7rcuGZC+Q0ODuYz
lncG9MLUOzp0ZLvnMZlB/dPg6LDNr71Z7DTMf04OYpdCJ/mlQsOzwckhssB2
wlEhmPnODoe3a0+R4D8ElXd2WDOx4tbu8INQeReHSMsrxx8thdnv4vDZ5EHY
bh9Y/Lg6dBk/23C58gRU3tXhYcWMPSvKYOnNzUGkUvDq1DaY/Wh8BneHVWvO
PXttDZN3d5gb57jjcwfMfx4OlZz2K8rlofwGND6Dp8O8RCu3AysP7QcA9ZIC
3g==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tMU2cYx/HCzMJElJBt6kYWJhWZAxUFtWPAj5ZbudgLrQu0cYJBWcC1
/4jGsLVs022EiZ1DghqVcikCqzrFQpXZWpBoJCqogAKjjIgByUSDDN1gW3ye
f9akaT75vs97mvOe8362TpnjKRAI1P9+//vlj29PlT5qfsflV3oSE/vI1K1c
yBYgcJ+9P2se2wt7dYt0Uy+vkn2RPXNAUz/NfhMbyj39H46yl2Ay425lhp3t
jzZ/fVywiR2ART7FP57ez14Gq2ZA7dSxhWh82PXOvS3sIOjMZVknPNjB6Lnk
99nv19rJKyG+bip/e5Adgq7D21JHWtmr0GSQ2Lw/Z6+BrjR0QruaHYawYVmD
804beS1+WBPz18x37HWoURXtX3nbRQ6H53RZ8bH3uEdAmjtoU3zJfT28IheG
ug5eIW9AsuGG23PISd6ICt3dGdtO7iKElGSmfHOf+0dInLzd5VPtIEdiyjHa
bcpnf4zXU/2OR8e3kqOwp63oYOmUnRyNp9k2zZzoIjkGfcvkZ24+YAPm+Pw+
u7TllY2Atea5e8TUTD0Wub3TF3YJm6jHovnx2GDy1TPUxfilcsfSZxUN1MWQ
yCx5NYWnqEvQNCRUh0jqqUvw7AuX3W+2inocpkcePc+Rko1x+HNAsr1lwEI9
Hi9DXJpyJe8fj0ajajRRwvsnIPLbo7lTxbTemABl7x8lazdzT0Sn1P1Jpu5n
6omYi/xAdN+njnoSbm6M0PtWV1NPgvech0U4SRZIUVgW6Crt4C7FxJxoQZ2a
909GknUyR/uE9jMmY7hDKxIu5v+fAvXy2pGC4BrqKfAr6XLv/rWWeioOJOyS
GV5wT4W2s+KSWcjXT0OxxutkSijfnzQEehQdGlvHfRNm6/bmvAjgvglDXxW0
ms+dpC7D7Ltnq6qsZuoy7NHXjj/W0vUEcrjDf6pv+ZDmIcc8r20Ldhp4Pzm+
dgdNWPppvUOO9vne1xpW03kIFOiQ9v1tukXnCwW2nFoR1v8an4cCvU+9pWP1
dP8dCvSM612atxppXonKN5xRE5vJUKL30+XutBVnaV6Je832oPW3LtC8Es4j
edcLtp6j+XRoTseIj52n9UhH5pLwB5Zhfl7TIY7dfejEUrIjHba8wtDOACvN
q9C9L78yqJGeZ6gQsT06PKud3wcVrngENNX+Ru+D438WqGH4PmP8fMHFy/8A
WJHDpw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91gk0lXkfB/BrqWghSyNT83YrUr1Ku9LgW6EGyb5f7uK61FA01BBdmpls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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tI01EYx/G/hlDOSETC0iJLllYza0vNdP6mm24OosYoJTSaziaBl5QE
0TUKX3XbpAtlMWJiVzMZNK3ZNLU1o1GhZoIXXC/Gv70wEbRGWtF5etGBw+HD
9xw4T7yuSqMP5Tgu7ff+c9KK/GSrzgp3u/5qLjvqnLVnKILMIbuoX6kSkFcj
SrVmhOfIkRgsKw9pWXjNHI0Wg+rZu1FyDDLOCI7XeMlxeF9prpS4yFswe4L7
+sRM3grDtOgWX0tOwLfgU62ikCxE88nYsKlMciKcmqQPm1PIO2D52CUNjA4x
70LgYnVcUz05GcGKGafCQk6BNfyn542SvAe1yTVdnbZB5r2IcHf3Wf0DzGLU
n15lfnyHLIG2qOqsd4m8D2X+rBJLGzkVh2wO/9X2V8xp+CLIk3mOkNPh8c2P
XL7fz7wf84aadm0BOQNXynWXhHLyAdhLFwc67vYxZyKxtTVgcbuYs5B0Pdjk
u0eWQukcHebLnMzZ6NcXxwTVL5kB0XM9H2Zn901ARcLOiQfNvazLMJ8KY93t
F6zLsP2zd3lhI73PQbp/8tQ2Mb3PAfSO9Wvj6b+5mJPwsmEXsykX0rHDvY2F
1OUwrAx9NzZQl0McHTsWLqauwKJPrynuZfOaFFBnjOmCyTR/HnbfjGicWUc9
D8OepU2PGmj+fFwwNYROHKOej6kf/MGVSepKdJ4XXdNMsnlNSoSU1I07NvSw
roJ0/Kj5Rmk36yosvLXPLguZuQJMP5QalzocrP9nTv3PvwBNiSNn
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91ntYzPkeB/CfLnSKs7lER1QUq9BVKJd5J91D9/tlpmYq0WWRKNqfRSJR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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10w1Q03Ucx/E5roCEbiIhecARpemABAScIPIBNxxDYM8rMA6BOkQaD2El
CSFoJNTAZ5KRxOLBNEDGk6g8C1xcHDcLyBSkJFO0Ix46Fc7Lju9vd//bve69
73/7///fvRaXIn+Py+FwYp4f/7+zF2/UkBrwUn/HsmYCx9u0qqQXmTn40S7X
pZzLbIH6/U4Pwhf7yDykH3g8v/cBsy2uCeysDv7BbA+1RyS3fpTZASZ4Na/p
Z3ZGlcWUyamF2QVefbZOZTrmN6DTBxVdTmVej5qaslWf+jBvgOKFj3MznJn5
cC3OPtr97DrZDfZ+vwrs25nfgtLPPOmXbmYPvHP6t5Bnp5g9YT7YaLn+MLMX
4o2F1vPDveTNSHuT7+CtYfaGZCZ734CE2Qc+Y623rRN7yL5Ibel+l+fJvAWj
erMCfjCzAOI9V9c8smbeCul9ffXwh91kP2gdPdtb3mf2x9nLouSCSeZtWPvY
1oOnZw6Ac9c3GWtV7HzbcfXQdpWbHeuB+PPu08IPtF1kYDYqcUIYS84BnuqS
DAUXWA+C7+eP8iwnWA9CflpTNP8h68FQ/P3P9bQi1oMhzhTNGl5hfQest30v
+iS1g/oOjL86nTe16Qp1Ie4Pzd7MXGylLsRYyV+b5yYaqIvgcsX1aHNSLXUR
FAEPX17IJ3NC4O+x2CffcJF6CCRaWfa0cz31nbh2qy6goe8S9Z0Ycci6OGio
oy5Gq/jurYUe+r4cMSoiM7K0v7MeilpP96HvQozUQ3EkYmTQxpF1CUpMX8Z0
uf9AXQKh4Gbpuf3V1MNg4T75b2BMFfUw9HDD8ryty6nvgr7uRIbHVCn1XbBt
aLKyFOuoh2N4yvGgY/8p6uFokl6YiVtxiHoE8nMTjGPqXOoR0MxnBVXXZ1OP
hHBlQezzQD0SmsXV5qP+H1GXojF9bl90YuGyIcUlk02Fm6GEPi9FnvGLJ+U8
/bI7pfC0iTretps6RwZu5aotd6LO0rwM5m3c4IGir2lehtjGdOPr0Wxehnqp
xfTSieM0L8ftjfF8w890vZCjKiE91XT6HM3LMTXJuxdV/S3Ny7G3tNh37jzd
T44C4V2hjQNL1KHAaoGrqc2M3W8FWhISlirjamhegTPKkt6KY+dpXomvyqLM
QpqpQ4mOEV12RRY93xwlksVb4+d5tG+dSvj41yaNG9l+qaCQnhQePkn7ARWS
P5tof3sl2xcVFrTws3pC7lRhz411BzYJyBw1bjhlVsahiebVWJGlM41uZPuu
hjLgjqhoiH5Ppxq9Nfd6U+LY/0ODYrPC3etkdD3QIGV+4ieDpq7jP36J4Zk=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQMC1xcX2HId3w/hfbBvCJgVYc0L4zM4LF1aupwF
Ls/h8Kc75tn+P8egfAGHVKWERP/rML6IQ+ziXuspj2F8CYcLC3RFNt+F8WUc
1DVdvrTsgvEVHF5URQSkL4XxlRx0Xt9kj62H8VUcYj9lKNkYw/hqDpF1Py0+
/D4K5Ws4XMn+fOrQDxhfy6FT9sq/iZ9hfB2H2TZna75cgfH1HLYULX2Y3gHj
GziY/Kxiyy6H8Q0djm8SWKHKAOMbOawp+7Sp/NoRKN/YIbJp2qz9aTC+iUMb
x/xT9rNhfFMH7wr3d07nYXwzh0nfJ4kH2MD45g4NT+9ym7jC+BYOR7+x3Zut
CrPP0uHf9t4nFz/B5K0cDpxbxH5JA8a3dvjBfdcp/+RhKN/G4d9MF8aAKJi8
rcPlfdeeRm6H8e0cVAJnr0pph5lv71Dax7ZSUAoWng4OGz+/9tQ8BpVvcHBg
fpPC7VgFU+/ooKOaZ/hyOdS+BkcH3jk9+yziYOY7ObwTn7OdLQvKb3By2DVl
Q2U+D0ze2aF+UarzV32YvLODYeSSbGcVmLyLA3PY3sKNq2DyLg4uv+Svxe+F
ybs6qHmp3LosCnOfq8Nynt9sH+Hx44bKb3BzCJT+mFenC/OfO5wPACzz718=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntMjWEcB/DXUTpKRaVVWEIpSxwlqVN9Ox0VXdQ5x22hRNlqVs2lzNgr
8YdpXWaFHKLLyJhELp3qIOUypHTRDLEiTct1LtWwnh/rebd37z77vt/nfd7f
+zrEJaviJYIgrPpz/r3SMbG9OMXXuLFuRAP+dUXV3/LHkwV0lmYbTzclSyGU
47HWgjwRgybRqSmWZCtYhtmEnJOSbVC9qexz7WAD81ScOnfStLeHPB1Jb+K+
CDXkGWj+aef79DR5Fsqq/MZo95GdoPRQdmZNJTvDb7IkN9+IPAc5Lk1H1t29
w+yKRx0W5mu2kd3Qscm2UOZAno+9k/LO63T1zDJEy0rHWieRF2B9W+bhxRFk
d0hq4z8YtN5m9sDVxmSnHabkhXCJvl8RpyB74nnPS8mw9hbzIuTZSH54Fd5k
9kJbdejMvi2UL4ax52qXGjuyN+xdTazsTcg+MF0wW1rnSJYjob33U7mG7As3
85ayrWlkP0gPtVYebCf7w+x9VElQIr0PkObqnJXQx/YrApbzkgy9+ykPwBOj
V54FR9m8xAA8THfryrCl+SkwIDfzsZWz+YsK7Pw5V3csgfJArDO7F5NRxtYT
A7HrglT79d/3V0LlPlhfkkzrKyH3zTQo2kfPX4IjKw2fuVZQfwkO3DD0Sm+k
/ysIfvVza7RnaP9BiMlWrFVXUj94tMVgKIZiB6d0XWF5yGiLnIWlXM5ZWMbl
nIVQLucshHE5ZyGcy8PRvV+eY+9/meURsJjibPLlBLMYgdSLjoWKKMqX47rR
x0RZcyXLlyPytHnLuEzKIzE8kPZL6c1yRKLY2nHzC/0ldn8kAhoKzLpfVY1Y
z1mIGm1wFjnro3DWKLf/XdM11lfh7fELE2Jzq1lfhdeq1NrVOh3rc9ZzFtSj
Dc4iZ70aKdt3N/tsrGF9DdfXYI+j8YZ5qdTXQGJup572ne1Pr8FQ/q7OB4nM
wgquz1n879+TccMN
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxFzglMk2ccx/E6MPFYtVwBC1GrDcqxWU9wUPqTFijQQq9lQncgiGZsUcxg
dSLulYES4zhWGlZkEZWiRtNQ1okLR2EcEqUx4lA2dbKxyURGCJnHlIxp+n+y
N2nefPJ9fm8fUfZeXe5rPB5P//L36s0ewe0z+dJFV1weTcvOh/09fHwpMw+d
w4cPNPsyL0DVoPEToxezAF52Ljditp/sj/Semoagh8xB8A1cwz0YYw6B5JEi
J7uHeSVsHe6Bj9uYV2HKbInotzKL8evFsNjgrcyhKHqb77/Fh3kt3ijkFnx/
rY8cjiSpvWNXGXMkVn/+tOdSJfOb+CX42pidzyyBWBgZzDvRS14PR6jZqyCh
h7wB4aHNjhgD80Zkzpb+U/rsB/ImjPkLw27ZmDdDJV31x8olzFug5H7LPqfp
JkfhgCPjxO6cLnI0Wv89KhgXMW9F78VjfsVRneS34AzL/0s400GOwfgi+f2F
rS5yLCYysipOidleipbTbldTWjs5Di3bdwjKBG1kGY7MWK+OxLWSgaHvxGKL
xekxB1S6H990Tzqob4PEHmuKXN9CfRsuu7pD0uuaqcejvDPveW39BerxkOn7
76VssFOXY1n1+H7fAtblkB/O1Fh5TdQViJfVn3+36hx1Bfh/fir9qKaRegJ0
84edp1/UU09A3b4nVfNm6TwvETd7S2Zjb9N9uETk1OYWm79m90/C6nWZDX5B
rCfhwU9OZe6hS9SVyA8Yj9YNkDklQr6dGvRXs/snI/j+SNbPH9ioJ+OOam6I
n3GKegqU16XCL1eYqafArywxvyXwGPVUPBl6x6oVFVBPxWeLhTHVphLqKtwo
D9U+lHxIXQVtXsmFy8pC6mpMDyw2RRijqasxkxqgKF9YKPP0NPxY3JRXOhrn
MZcG/mj7e1buK+rpiJ78wrRGfpB6OrbPPSqoLjRT18B7OjDvyqYaj6HBvc3l
Rw2Pa+m8Bgm6IR9bCvUuDaIkd7mAkSraa2GZUBmn9ppor4Xs9+EVWeEltNdi
6ZFbPrvu7KC9Fsv3bSyyJ9P3eToUxfdlVOy00l4H7z2uJNG8M7TXoVrd1lHx
ehPtdRjcvS6x3dlIez2KLXvOTmjoPPSY9DZWGNQnaa9Ht0p0dnQZ/V+XHnXv
+2n77n5DewPmKhsVDo4MA9zTIQ0xnI32//s/6qaS+Q==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90m9I00EYB/DNkqSGWDiVmLCy5pKl05lpc/O7vwq2yOUWVBArVmJGo3Cs
MepXRlKwFxUaFUmlIlGBNYSF5eZW+sJSFtgyKlpaWMtYKErNFxXe08FxfHju
Ofje3boDx8z2FB6PV/J3/ltpZEQ7HaqVw4ElJaoax6NaLp3Mw07OWdi+nJyG
nAZh0PF7iDkD5Vmfdrz/Rs7E7bqescUYOQeG8JfQh1GyCGqtwJrXSRYjLPS8
nvjv9ehOjWk+W8gbMDe9UNxvIEvw4lRu8ruILMXmmajgxo/nzAU4koworF/J
MghtHb5LU+RCuOMD07dOkOUIjfiahefIxbCH6ludk8+YS5A7ly9fFSUr0OSz
xewecikuPLT/vHqSvAXdSbGjKJVcBr9iXGl0h5m3QinavTB0J8Rcjmy+K35I
Qq7AqKnVNHKNvA14db++b2qQWYnEpuga2eMB5kqcCSY9V2RkFaxBpz8/+wmz
GstCeQqJ/ilzFUrrLrrNk/3MQMqDm/b9iuCSOeC87e2v1V0BVtdgtmiP57KJ
9XMaxL0TcjNH52nha2zqkqpYPk6LffNnB9stlFeH5BuvumyM5eF0aAnVCpyH
KZ8e97DxdNt1qush752vbEmj+zPgY4907yMxy88ZcLR3tu3gO+o34niiwKaO
UN2IRf+udH4z/Y9qdEReuios7H25anj5K+4at9N712CkT5LZoGP7uRpkudbq
ZlzDgT/sNP6S
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxF0HtIU2EYBvCTeUsUF2YWSdQMMzHxbqbTx7u76NQhuv4ouoiXgk0ZjSxR
EsQumoImYQjmjcwUNQ3ddCk5c4kliBrOWV5SCSvC/Eu74ffagcPhx8P7vN93
jl9SJKebcRwX+ff996WHN12vFNiM6Hb0PexddrtD7K45dLb6+GdYk61RnC3d
NO0h86DszJGMfNEzH0DsWm9a0nvyIbQ/3pD3a8nOSJPIh0bbycdwa0FQtK+a
zMfy/uR5qzryCYwZDRkDSrIrFt18GqJDyG6wz/LPe2saZnbH/P2V1HYN2QMf
bpT+mu0ie4JXFpq4riN7IaFU8/lOPNkbU54fLxyZJftAFJirqheSfVGAm+Lr
WWQ/5Nq3FbUaXjP7o3wuYLuEIwegOdO8qGzXgTjnLYnYUgwxn4FcWPBJc3GQ
OQh5lw2VUzryWUz05I8Ku8nBsBsc93soI4eg5AH/tE3zK2YBKsfmWl4WkEPR
UVywNaHpZw5DKN9kJx0mA4qlQK18krkQuH10VvyokfJwzHTtzQlw0rE8HJEV
eON0ivojELdiYVx1Yy6MgHdtpa3oCc1HQiNLctnka1keifSJaW15MuvjolDT
bRXa40h5FKTjXs5NYRqWR+OHQ13JenMfy6PBO/+0/8pAL8tjkGonb0s7SHkM
PFSC+WoL2h+LeV79iIuM8lisjInUxS7UHweVOv9u1XPaH4eV5lLZNyWdTwh3
3maKhyP9HyEs1SVGWyX1i1D7VaDedh1guQh9+rktM46ZE2OxqULdEcz2FYrh
kLkR1nOS5iVwVTzT//agfgmCVPyq7UCaj8em2jzuXgqdPx5DMUbLumFmLgHW
M9u+6kbqT4Dp6rLhmpHuJ4X0xUJe2ir1S/GzZlHb0EJ5IloPm8r0S507RiLW
JvvsHD2p77//AEkkWqk=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zgk4lYkex/E3NbrMKIw2RVIialqIUPxQslSO04nsx9loGmPcKZOUXpmU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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zHlIE2AYx/Ex/MOpqSMFIyvNKR1qTVNrufx5bzpBMzxQKEsxlVpmNRKE
EXbgUIvpwjzavNKkNIspmvOa2qEJIuYsqJVCakkoxQrLip73gZeXD9+Hx/2k
/GgWl8PhiP6+fz8bx9cN58Q2Y/3/9TUkbnR5qtWemQMeX+7dac1sDV/TxZuv
fo6SHcGVKxxczMxOaBMkuG28Z3aBZSXgy8I0sytk+TX8hAFmNyTfyTaP65h3
4nNmpaWklFmA68GK5vhsZi+savjWl6KYd8HHuDhY68e8Bx7ZYxl9phGyN/Qf
NVeHZ5h90SzwyhEvMe9H12rm3AkNsxCiUZO9Xszsh3sfLHV1RiPZH+uLqvK0
IuYD6DvNbVrazhyA+3NSwT4n5kBseicptno2TA7C3u9N19ILmQ9ixSzb9suf
+RDy3wwb3K2GyCJsUSj5jZcHyIfhsEM7NV3GHAyXFn1tQw6zGOuTZwZT1piP
YCJl65CqbZAcguTV7pHqon4yEJ04watSkZXA+Qety6XfDNRD4X9lIijUmawM
hckuT+W51kc9DGdTU+JUp3qph8Etw7tL/fYp9XDYvJBWeu+mfWU4HqvNhqQN
1iMw+bxI+DDnCfUI6Id43NkL7dQjsdFVOJ9X0kQ9EkHOnPGORzrqUciaSSoQ
+VZQj8KyzW+nwEYt9WjkZnQnehhpXxkNjbAjnqOvoS5BbMVmnmS2lroEnxSD
N+QNt6lL8SPfqEvTllOXQhtvW5FZdYt6DNpbwySeqSrqMVALvebvBrD7sTje
q0s5ZqemHou43HqVoaWMugyWBZ+XncXV1GVIdy3ose2p7/8DXjkpeA==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQMC1xcX2HId3w/hfbC/VqHqf4oDxmdwsNtV+28Z
nM/hIGx/LfkEJ4wv4KD2trW+ngnGF3Hw5ZNiK+eD8SUcDjjIX7aB82UcYkSY
Ffb/OwblKzhMiK37/ugTjK/kcH71shn2L2B8FYfXljebHq2H8dUc7jt237ac
CeNrOOh9OGj5px7G13LYXnf/x5cGGF/HweH+TiajMBhfz4Fpov/dyXC+gcOL
7WY5B4NgfEOHhy+efdkYCuMbOdTIf2h0sIPxjR0U+T9y7/aH8U0cXPn2hze7
wfimDjOXPqiPWHAUyjdzUD+d5fPyPoxv7mA2N3he6wkY38LhivKtCSrzj0D5
lg6HQ/W5TgTD+FYO1jYX9FWTD0P51g5Cq1a6iG6A8W0cviwyCF33+hCUb+tQ
rVx95sB0GN/OQWDnj7aHxjC+vYPo/HvbWb/C+A4O7xuMxS4vhLqnwcFhylfx
pRxw9zs68F1VvGXFAPVfg6MDb9flkjk+MHknhw2qU9+HroLpd3Lw/rxls8wJ
mPucHdZ7WGucCYXa1+DsoPLKfumuNzD7XRw4rXYq7MyDqm9wcQg9s0lu8neY
fleHznuHm7gOHoDKuzoUvH3wKWffbqi8Gyq/AcEHAPTO7aM=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQMC1xcX2HId3w/hfbBnu7Vw6SxuGJ/BQcsk49Br
QRifw2HhNhEZBmEYX8BhaesEpROSML6IQ+iW+z/N4OolHJZ9vH3O6/cxKF/G
QUJf4Kb4exhfwWFx9ocN9mdgfCWHjS41bzJmwfgqDqVOM2dtbobx1RyuWFxr
Sk6D8TUcDk1bkRoaCeNrOXArzG+7EALj6zjknX6Vsfr+UShfz2GJDEuBexGM
b+AQr/Tgp5gxjG/oIJwo2hxz/QiUb+QgyHH/iX0vjG/s8OrLnIg3mTC+iQN7
9/cyLWEY39Qhe+Lxn4Z1h6F8Mwfd5/tP/z9wCMo3d0j/ctLIawaMb+FQ7Mer
83HJQSjf0sHj5QGZNAGYvJUD99QlRldiYPLWDqVP9b69PXgAyrdxOLhWffLR
+zB5W4eC2ArP26thfDuHNZ+2n04sgvHtHcqmXTB7/QCm38GhScdH44QJlN/g
4CAhymB8wXE/VN7RYVF/sSp78R6ovKODwWb33j0Xd0PlnRyknyY3Lw2B6Xdy
EPR7xnddA2a+s8Nb1ludDDf3QeWdHfZ/Mn5ltBmm38Xhm1mp9tyjO6DyLg52
3Dd2+NvC3OuKym9A4zO4ocm7OTAwrektL4LZ7+6wZf/KlmZemPvcHbabaCUz
m8L0ezhoTGRi9dwH0+/hsIX9Acs2JVh8ejqs3WUSwux6dP+O+rKQ0FpPh0+X
fJMEIk7uBwCf/wQm
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zws41PkeBvDZNpG2Ym0KubVxkERWKOWNWJH7ZVzC3MyMHLpJnW0P/0Qq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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQMC1xcX2HId3w/hfbA/GPHLfiI3jM/gkMdRKHWW
H8bncPii+l47lwHGF3BYlbeskAPOF3HgcWF9Efz6GJQv4aB0ebLK0WcwvozD
RoFbmtfvwvgKDr5/b2ydeAbGV3K47BN5YPkbGF/FobWmgfXmURhfzWFrWlnz
uqUwvoaDVO2DdbcLYXwth4lqi4uOFsP4Og5cUp76JybD+HoOP0sZXs+vgvEN
HGJD1wo46sD4hg6HPlznW8MC4xs53CtZp9kw6yiUb+xwM3wRT4gsjG/iIKG6
9dH9d0egfFOHpyu2Pn8jBpM3c5ih0DxPsgrGN3fQbl/P+WQhTL2FwwXNYzfy
SmF8S4f1MYu9vlcehvKtHEQdGGNvz4LxrR3aBWu2/7GB8W0cbDyyN/b+Pwjl
2zocEXZP0gk5BOXbOSRtmqevsBUmb+/wQPXGNHFxGN/BwfnGPA7ruAMQfoOD
g/8Mq+qa3r1QeUeHj/YybiYKMHlHh/1bVuu/VYHpd3JgO3mh/UcQlN/g5JAZ
n+H74AVM3tlBq7C8Y+dmmLyzw7d9ufMfGO+Byrs4nF+t1mb3azdU3sVBuys3
7FL/Lqi8q4NmUNmHTMn9UHlXh5CMC5rTQw7sBwD6Htwn
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11ns8VHkfB/BTbT0ku10lrFt0kaKLIrcPElKNS+6DGWbGKOmqPLKPQRuW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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90nsslXEcx/HT+ce1mLFCFE4noYPIXT4cjuNuKqlVymXMJhplU3jWpnI7
tKzJbVIzWWZC5hLH3WHZajYxC0NKWrLjNotq/b4927Nnr72f32/P7/d7TKKS
wmL5PB7P+8/990mX9sTzZHf1oe5/WvVQlx559VKTzINKy3x09v+uCrvmk7JS
PlkbGcf2UiN3Bpl1kfTd17ZimnwI4yPWSrcB8mFoma06qraSj8LUI3apoYJs
CoOP799ZpJAFyJPH6+3EkIXQUe2z1ksmm2NdTTE770q2wE5BXnidBdkKj+TC
BgnIIiyv1G/4/BxgtsF9s9ocfgvZFkXiq2Vhx8mnoJXz7cRWTT+zHT7V3MmN
tyTb49bwUvvceB/zaURajX7mu5AdoLRPMhoc6GV2xNCTGePWg9SdEFEY1OXU
Td0ZH2TpTVnLZBeoBd3Nr96VM7vCts0o0Tmym9kNCZnNF/ri3zK740dURFaO
pJP5DOIOmBvyWjuYPbAZXb9YrNPODJiVd/XOVDNzwMjK2LRst5V1T6Rr2l+Z
6WXmPGHdEKhS4NLCuhf0EjeNHyhfs+4Foa5ifkKzmXUxstW3tZZT2fucGIIe
wdDMVBPr3qh9qgyTLTNz3tgo24rae0bz+yAv2MXqohubj/OBvehr5eNO6hIo
M/Xz5wyoS6DzpSM1ZewN676YLEzTLL7B1s/54lqJfq5+YxvrUixMKWJUbdh+
cVLwNSzXbZS0X34wvjw7qJHL9p/zg/dstXZlGp2HPwarrpc/nO5i3R+309t3
rW/S/geg5HzPr9EMGh+AIpGfMCqBxgfCYdijVpzVw3ogKjSka5ZmdL5BOPtC
XFF3icYHoctw/2TOOerBWFxM8mzcYuaCUVPa77VvmL4/BPU6DTKFE60vBPLw
e2uSbOqhkApEvXFV7P9BKLZDTBbSV2k9obAQOAmVVWx+eSjWUrcV7Xb93b8B
ANVfnw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90VtI01EcB/B/QrputqxsD1LTyrnQ6bQ1nZv/r27zkojOQLqoD5N1sUwr
hS5We9AoQtoMl1pSZERlsJK5aZlammJF2hYKy4lmV4jai2+ZFZ6fBw6HD99z
+Z1zwo3l+aYAjuMU//r/kZpwvLVCs3yod0F+vqKvYOXqYDIHvl3iFC5agL2n
1jbol5GFMAUF7Pf4B5nXoVL9znvdRxbBfvONaskIOQxGm/XaBwdZjKv1Ydn3
beQICD1Hh76eJW/B8RlP1Z595EiIjMrYcCk5CgZLX6nlz0vmbfh5ItZcOECO
RofL8rHNR5ZBUDEhO9RGjkPPj7BVtTqyHNGnS87XdA0wx6OmOmS2tZicgKLa
B/mBBf3M2xGadUAsKSErENLdP1h+kbwDr6sq/d+HXzAr0TIpGnb8es6ciIkv
327Fz/UxJyE30yowfSKrkOz171aWkJPROWpNSJnqYVYj+9Xw0rJGsgYZawyd
eTqan4JdszEtLn0vM48yse3GtPYZMzC6VXvsSF73gs0A3xRQOSln5lJR41Y/
Cnc7WZ4K/+/PdxRFHSxPQ+PmFmduTifL03AmJWi0zvGE5VoEF8skZdWsPrMW
pkjeHbOR6tNBHjVWPD/N3sOsgyo9UDSVRPXp4VVdkNpPUn16+NaPN3DttD4d
gyvUV5pLmc3p2FCfGBNtoTwD8zMRoYc30f4ZeF947lKdhN4/E/fsc2+7Gth5
5kyM8U0jd2/T/bNgyKm+/Fj6lOVZiNOMPDzoov/cuei/qEEHOw==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgs4lPkeB/ChOkkprC5UJ7Ulp8suLdUo+ZbRkArDuBuDMSbVaVm0rexO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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0ntQFAUcB/AVTRK56WqCDnqAPE6C5BVKcDy+nJwgr7s9ToqosUxDumFQ
QMbGAW/mJLuR8jyakLy5issHciiPSNN4eYJhmKLWqZAegzYNQ0yDPYRSs/H3
+6Od2dn5zHe+v9397S5ZV6bd4CEIwpoH539XPqQu+6ZkrzO9D/Vban34a5X9
EraA2YpUrJeyH8UifVFq11NsKX7YPTaiWcx+EuNCWUHi5CBZBoe5tVg5wX4G
BR+0hsm62YGos1mVa/vZQXi/arIEZ9ghmD31jsXPwpYj9fhjnn8a2WG41h1b
e9HMDodo8P2yUsF+AQVvXX13/OcBciS22yPyDr7HjkZvwPVu543T5BjsKKzt
8vqQHYvrvmlt35SzX0Tgr5+USqac5DgE62MLnq9lL8eA4wm/BX7sFVgRd3nn
VBg7Hsaz3wbUhLBfwt6SW68GN5wiJ6DdcrdpSMZOxKxvU6mvmq2AGDztMOr7
yUmYM12pu/1xHzkZ/qi2eHuzU2At1kJefpKcCo+XzxZ9vY8N3NbaTPHTxx7a
AFwoPBZxpKeD8jRkXDJK3FltlKdhVH63KrOomXIldiyr/26Tp4NyJT6SRyjO
3TlM+UpcaPk0ZkZxiPKVWJZZdc9W3UJ5OqIXNtTtbD5AeTq61N/7+186SLkK
skdSdhtCaZ5BhceXqEyukzRPWAVz957Ld1w8fxVm3IfWBU7RPCEDw86lJc4J
up8hA0/PGx4dHG6nPBPzX7l6xTZHNmTCa3byqxDxKOWroU/orMp5k/PVmNkS
HajazP0s6EzybY3baF+GLBhrkgwxUZ2UZ2PqyFirY5D72ahUvF0Rn95KeQ5i
j9+/Zp8gG3Kgkp82Dcho30Iu1vrUyc518PPnIqAm96bow/vPQ/bFoJwgKb9/
HuYST1hDW3j/auy6tX6+3czz1TjacT7B1cL718CqvhmVdIO+HzRYPLgI/Rv4
fhp07hmxtm+l+X0ajEg2Vrtyv6C+iO1um3zOSDlEJN9L2Tz6k536IvRDo6HT
P35GfRGvTybFFR22UV+LSO8FYpRpH/W1MP894i7UN1Bfi/1im89zzzZS/0Hu
9iyLWriX+vlQFks2nv+FjHxYSrcEhIx/Tv38/z9PXz66wv9ari3n/0uHCmmj
gANk6DD2x4keZ+R+6uvg8U/z/Z55TdTXQWj0D31jK80X1qDGo/73pUNNvf8C
5q+wUw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/HTMsmKmrro5iXD7rbKzFlm+3mZ25zmJpF0m5XdM+tNRWFt
zZloGE0hTLoLKmah2bRhtTVbtq2ioujCKlIrzXJZWkFrVPh/3nTgcPjwfc7h
nPM8T9iGXRmbeBzHyf+e/67s4D+r3B03os08qC9itWF5DH8kMwdl9e9bolHM
w9F12Vtk+n2HzMcYW1lhYS+zAJ2+iUOzO5jHI1Pv+6vgIXMQgo65JX5XmSdj
S2Qk59QzT8H3uka1IYM5HKLRLueBUOZpyHPEvX7XYiPPwP2cTHO7hXkWZGWy
Yd3VzBFYVzq5c9hBZiH6rq7Zdrz/NnkeFjkcfadLmecDPac0nqnMkdDNaj0w
8nkreQFKvs5x6RYyR2Hv3bBzP2ZbyQvxbdz93ICWW+Ro1PKcQRuFzCLw1+fc
PKkxk2NQ6dToAqJvkBdBENI9s9vZQl6MgwOj/F5Jr5NjMcYy71deOutL0DfR
EWAfZyLHIQknfvKnXyMvxVtF/tR7q4xkMYy+4oEu0RUyYIjjcabq+kFrgXsz
ojnTygbq8eC/tYVaJ1yiHg99bWbg2p6L1BMg/yGfFPu6jnoCRJY3wRH+9Dwu
EVm5Qu2QI6wnolPiV9X6qYp6Ep4E1GxsLKql/vft1fmzVR0XqEvwuOKatf/R
SeoSDI8Z4HkfGKgnw7/nxFz7q8PUk5HXVdUeJdpCXYqx9a7g5BE0XitFb/DR
gixHGXUZmsXGHYcEFdRlWGe0RzW0kzk5VsduD7R9Kqcux55mmWar+wz1FJQ3
cyHZAnpfbQpU51Pq+5sqqSvgc8Rdcri3hroCnvwPZSXX6Xu5VFyOf/8iVci+
PxXuupfFoW00nktDmtuaFL6Z/pc2DeWbzj4Nec/6MmhyfIR77DQf2mXQW4du
/tlxjno6Rtc0GCv3s/vTYTy7tG11Fs0Hp8Q38forazyNg4YSFSsUugE1rRft
f7Yo4dFPD4zQsfWnQsjnIeHeXDJU2C9tKri7k/aDVoXdrsJS7z6yRYWPXsO2
pmK2XzKguijTfeFum/8Ar0h3SQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz3tIVHkYxvFjBonkZGZhZeRGhWmYpU6lOT6jqenoXM5U08VMI23povmH
GmjrlLIlOYVYsc5q5pjleGmwLJLIMd3dWG+5s5AUSxcUK3bERVMEDSvmfRfy
wOHw4fu+53fOD0cyxbR5giBovt7fnny5D9ScDnd9ZnXov4jIG7tjP0nYAu56
LUiqd2O74EBu4JEPnmx3nC+eqhr1YXuiMlNnzHZie+Gcm/+g7t8/yN7QjfaO
yCfZPggtS1ZN97HX4Krz9enbNey1sKzxyVykZ69H8eX2eDcV2xfvvPcWFvix
/ZBRuuepxIO9EbpVy4c7x34nB2B7+WphIIQdiNUjLQ9Mw7+RNyPdaF53cpa9
Ba+C9kq8mthBMGRtTrZdYAejonDdgC/YIVDmdwS4JLOlWOX5sq5Rz94Ku9Xj
SYCZvQ3mU+GlLw6xt6Nl5I72T0UnORQy4/DZotYOchguuvhnTfQ/Je/AiqB/
TgRVcg/HpVzlvN6HbBlSOu2zbSE8H4H5YStTPH5mAyqja/XztnaH9cBfNs3W
0lTuciwsLGnOSecux7ATUiYzrNQjYex+nNda9Zh6JNSmofQr5x9Qj8Ie0aCK
P3CPehRkBbZSlbWF+k6sn9BciUl4SH0njh9vWJK9kuaFaDy/7PqjfaOFejRe
TYxXxvSbqcfA+dmGw0sXNlKPQcn4jFReVE89FklvO/aJTrepx8I5ylBr+pv3
d+Fw2q0tr1sbqO9Cc1Zxvqe2iXocuvorQmcUd6nHQas4WtfoQucJ8bDURgeL
gfx/8bi249r+g0Z+vwLS0G7f9lk+X4GpLqfBl/d+pZ4Ae+7NvEHTT9QTMGay
xWYYiiIcPRFvgg1h5ZLTDusT8TFnbU+nRzV1JYYyM2oTy2uoKyH9ZXrIFmem
roL2fXZyARqoq2DvEP2zbpEFNXpkm86NfW5yGGq4WyAs67PQvBozo4unmnvJ
7WoELpdPJsWRBc2c/TnWayDp7WtLLK+nfQ2mgiO6zuTw94mQeadO26xkiN/P
60Uo81KhM9TRvvj9+wXtnPO1eHSsrGR/fjPta5GftkB6ffw+7c+ZF3b/7y9N
GpTi
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzn9MzHEcx/Ev0Y8zKmI2lx8tCWmVSnR1L3fXj+vH3XU1XdZIyWwivxVm
d35NSUXkR0qiWvqBbPoxznWlcvk9k7aSJdnCaWS3rAm79+eP+m7ffffY8/v6
fr6LElOVyZM5jpP9u/8/2WXXeWNnAK/tkVlDwsB3Rw2d9swcXh7sdjo/h9ka
Q7VjQzYOzHbYtlcjcpzE7ABB8Viu7+9W8ly8tvwdLh5l5uOhIL0uc4R5IaIr
NOIVvcxOyBh5/0VuYHbGij9Wg2+qmV3Qc08iit3O7Ir8YOv5NiHMy1DldPdz
Gp/ZDV3Jt+T1A4/J7niezNkGVDJ74FN+9nDLKWZPJPH7T6gXMHvh6ezRsaD5
zCthNMzwMQ22kL0xTfRxNCmCdR9svKN60XaA2ReJ2rLDOl/mVVjQPjNyv57t
/dDSrZSXuLC+Gkb9q2s8N+Y1ENeV66aWMvvDfsd92arvzWQBAt1S8hT1enIA
mnK63aPjmAPxLEGSMaWQWQhjPy8glmMG9gjiXrq8azJbDVxIf+XtfVlHfS1s
xn7EaF1YXwv+NoPxWIeWugiNxiODcfvpfbUIM8tthX2ObC+Gt9RvsiabzlOL
8fjJuc3vn9H3OAlmj9yraXUuoy7BRde+guCm69SDYNpUYUodzqAeBEOW9qRH
1yXqwbiKOplt3B7qweiwaZ/T37yRegiuaw7EnAzRUA9BztLYL6qqo9RDx1sd
ijtVaeuUG7KoSyd0KeJTlvckDuyjHoY2x13JW017heYeBtPb9bVzz3uZzYWP
t3qCuYgJPQI3ZAt7GvNU1CPR9WD4yDxtAvVI/FKlp9WWbqLzZfBMq86zr2D/
J8PbJbtcU0NPU5cjU+j+cHXHWepyXMgRudc05lJX4PubXn2dPs9sKODps7T4
z/0Cel8B/18e1r09xWbrFGio/BCzu+8K7aNwOKLCSupQRPso6AfOLJ7+le2j
MMtB4iX4Rl0XhS2z+JbSopu0V0LqcajlOI8MJdoteKaB0kLaK+Fa5G+RO0Tn
6ZSIb8gMry8poX30eCMaqp9+RVaG24/+AqnYjMw=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlHtUzVkbx49QNEWiyNvo5JpCZF5llL7pOpXqdD1ddC6dW2ZGyYjkciQZ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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90wdUU/ceB/BQEAf2yUMFFIopbtSKWgGpyjeIouy9hQxCgls5CFKscUAH
OPBRedUiqWhVRGlr1bJDZE9Zgow2iAioQFERUcH6Dr//45wczud87/d+7829
+VS42038EYfDKfvw+d9/9qfdlLpn3ZSS/HH9bbVcb+bBDi1mDq4JDslCJzBP
Qn9n/rFTb4rJ2oh75Nmi+Zx5BrYdFg1btDPr4/qX0XqpJcyG4DoMGVf/31wc
idgZ5/wdszEeWzbw10Ywz0OEwGHqWRvmBViZHb48SYt5Eerep/xyOa+IbALb
hWoOhd8wL8Vwf2dwfhLzZ2jbHaa7PZzZFB977o88a868AmoR57pTOgvJKzHD
YHDyuzzmVTg3PFn4QxDz50g40vVJhBPzaqQ83xO6MPEu2QyGzoLhzlol2Rxa
ffUPtnczWyCpZ23iVVkBeQ1qi0+3OLszW+Lr6LqK27XMX2DEkTcU+EpBXovu
zZqt0+KY12FKf5rhzTLm9YioNx+e7c36Vig3Ga0u6GA5YJRZdKlhVt64ZcCz
mWWfayKXch6mTKpq3nWSLOPBMCYtIDAvm3JrHLkT+nvm2G3KrWHQkpM1b8kN
yjdgTEOY946XQfkGjOxY2TjkcpFyG1g1R5d4rj5KuQ18tk54X1UeZzWeb8RT
9Xc5bu0Xxi3biI6etB+H0m5Qvgkn57lkXYn6jfJNmNeb4avWc5NyW3ysfi/q
/KHblNvigp+7nWvf75Rvhnmj2uEnx+9QvhlbtCKDj04gc7agKkdPf40py7eg
/Eb1WNJPLLdDjF7UQaMXLLeDaCTIsLuS5fbICGn22R/BcnvE+MTemWjM9h2Q
buA1XfzJLcod0K9jsuHXsj8od0Ro642x4wFZlDvCaGxp0QIXMscJL6+7tr3l
ZVPuhBNBperWCWSOM7KcIlP9DQsod0bBGrMKU0Ml5S5YUZ1hFO52d9xwQXjo
/YApDmSZCxJ2fatQLC4ct8IF3Qu84nX8i6jviuAd+y+8ySqmvisumf1lbqgq
ob4rTPXK/3z+qpT6rphW5nM6MbSM+m5QO99aPphEhhsWpVx1nuZTTn039Hyz
fEPCzgrquyHK0Wz7wAjlHHe8e/26t3ci5XCHtmPz4boYsswdev9dZx0uqKS+
O2zK237R4ZE5HpgwFMS1+5sMD4z9VKrQbyHLPDCyzF9vh7KK+h4Is/FbkTW7
mvqeEJmnHmrSrKG+J0af9O3UjaNc5gmH3LaM1NNkhSf2xdQ2Txeyvhc2v28K
WpFIhhd4hiaRg0vofDIvLFTv5105w/peiKz81H8Lj/W9YfODVWznTro+eMO9
yX6gwZos84aG/zqJ1yx2/d6YdMXxVYARu38f5Bd2FM2RsPv3gWBEe2a7Lbt/
HyS8vSq8+Zp9fz74V4hT8m+XWd8XKsuN6beM2b4v7jn9LM9fwvZ9sbTO0We2
lPV9YbjQfO9KG9b3g4bFUMUcKXt+fmj8sYX3ZIA9fz9w+Q77XCLICj9M7NJR
hVuy5+8PD80vB2vMyPBH0hGvYs1ZrO+PjTbqr3Pf0/ul8IebeHZKZTF7/wIw
/VpysvYa9v4FwG//iJ3jQbIsAIqakfuL01g/AK3TtYOyXrL+VugblDYF3WH7
W1E890F2aTbb34rApp4Egwp2/VvhrlTedYhl1x+ItLdP3bKfsv1AJE89cV3c
wvYDoZPz+OADdj+KQLzweDb39CDrB6Emc/IjB3Z+BEF/VlmyLju/LAhC+6lq
l3xZPwiPzHMq9ZtYnw+tXbfCpWL6/rl8dH2dX3X4JnsefLjPTR4qSKTnxf9w
vGTa21EZe758BJqc//5AFFnOR1t51x9fxbL3jY/dU7TuOjwjq/gYXRgtbGW/
B44AuagVPYyj950rwOXjI0V+JfdoXwClwvvAHmsyXwCzGZqnHP7Dfh8ChEw9
Y5qVQ5YLYN/50uKrVXS8QoCB7D3yg2vIKgF0N4bIX+STOUJkhEVdXtZK5gph
1LtZr6OglvaF2Duj1Dtmch3tC3H9oeriKQlZJsSJN9fSFQb1tC+EyxzbyFW3
yAoh5mfw8gy4DbQvhG5q9om8ZMo5ItT1LqjPqCdzReDcsVrZGEzHQ4Q3izYp
H3/USPsiDPkr7QqMyTIRUvue7dXoIMtFONNyU+nsfp/2RZh/Unfk2RmySoQB
1wGrsCIyJxiWDyR9GrFNtB+MikVZC3qMmmk/GH2t+nYdWmR+MP50Ti7Y3kLH
y4Jhd0yk3/4R5fJgZGqs5dkdIiuC4T8QtthvgKwKhvWpp7n/xgPaF+OY5Vlp
2UvKuWLkfLdsu+kjti9Gl9Kgt3AbHc8XY668JLo9niwTw+j9xYSafWS5GKrv
MybonCQrxLi17KFXdxZZJYbFXcuHfw2y/RC8dnKJL3lI5oZgRYf0kvXSFtoP
weiwjjJ1PZkfAs1z8XWNB8iyEJyVxy6bsZosD8Eq1blCdW+yIgTxq0brotnx
qhA8SdSySI8kcySIrrTIjA4jcyVo2H1V06WL7Uvwa5ZT5y4l25fAtfqqvYVe
K+1LMN9Xq0q5niyXYMlj2wR9V7JCgs+eh70xdCerJEif+m1jSjyZI0WRrNLF
OpLMleKLn9XUH90nQ4pD62+o9DzbaF+KwAZ374QUskwK3qv+9Jp6slyKbRfG
0iUz22lfCn/no+cFLylXSWFinJ6d6UU5JxTy3NPCng/+B62xA+4=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9z3lI02Ecx/GfRzKE1TyYurJUJMMOnKXbPD+6zSso5x/TefyRllmGGqSR
FY2wTC1cJGZkGrrWYtbMlemSFqbZZQoKZUiywOgi0qLQplb4fHvg4eHF+zl4
AvNLM/Y4cxwn+Tv/rTQEr9rLYt2HbMv6Fl/05lqbmkfmcDaz26x3I/NQuSJf
VzL/mFkAYbpZUP6V7A3+exdj7juyL2bc9be14+Q1OO04pIl8Sg6Aca39cp6J
HIQ2RbEgvJUcjB3CjsLAHPJ6TK+LEb3kkTcgdfjqoGh2kDkUR7lfzw5ayZvg
P5e1Of0EeQssshf7x/aSw2DNU02+XhhgFsM0WuGh8KAeDv+e2UiTlLwVNZXT
cV2u5G1w9q0TvN1F5yMwUd0kLLn5iDkSugJb8qkb/cwSGPo1koHhh8xSeCrr
N44VkGVoKlNpvOtszFEoqug6YLD3MUdjKmnJPfHTfeYYuKrH+edrrcyxyP5Y
0+zSSo7D0uHhk1WDvczx8OPtlpvC7jEDjSFKI3+ge9laYMHSaJqbpP0JMMin
5kf777CeALnou30h6y7rifgSPfE5IId6IhZDh9pz4uh+OYrFAdLfHtTlUP/o
rT3e3Mm6ApfKxZmqTmatAotW/Wqt9TrrSoirpXlPsm+xroTPSHDhh04T60mo
iuJ6ZVV0Pgml+5z61P/vT8YqhyXoSn0H68mo/NlzziKkngJhWGzDhbIW1lPg
1XCk3i/EwHoqZp5netrd2H+0qcjVBYY+8KT/pcEnI1dW40TvpyF73Gtk5UUz
69txLGJnyxmHxfYHEwgRTA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzm1Ik1EYxvE5o9VCJ5FasWquENGZOpuZc+7STZ0bzNKsoFhq5WQr5weL
aMaWmRFEhZFBvoRTFuEQZUWYy2FqpsLKnDOjLwWhIUKlhibRC537Sw8cHn78
78N9okotBae4HA4n9c/5+6cvbKqtUsEf9v7TF2VxdNX2+BAyB4P+lcMVAvI6
6IoM4wNcchgK6oTjo7MvmDdBfq3I1PCWvBna1doS1zBZiA53fn/xE7II8keF
kVuayGLcKK8xNjrJu5Bkng2OqidHQ1QfZ9JZyDFI9o5JY2TkWOhCfP71a8gS
tC3dfTV2Z4h5N0wrSk1iMTkRT5tCY3/sICfBdUB37/zMILMUExqndWKOnIyL
/G2r1VfJe2C50jncuDzALIPi61re3Bj1FEx24uHtFep7kfFeGjHiJqdia925
hKAK8j5M22TtsVpyGgSKBH/39HNmOZq5wkN8PjkdCyG3EjqO9DMrMFjoiVwM
kDNQ0m7cqQ7QvBJdD05smPOQgbSW1EuaLrbPDswLU3puHqT3Z+Kse3nymJPZ
nol294ypoZp6FqThn74NialnYeld5tTPeOoqvDljFgU5qKsgWgy38jXU1Vj9
bOa1WGm/Gr5yn1cvpvdnoz9Cb9DXeljPhlhZxjO1PmM9B5bux3EbzX2s56Dy
pUjU2sfMyUWd8fvrjI9s3p6LKluiRDVE9zU4/qukbCSU7msgOTqxcHKW7ePk
Ifj+/rQLNG/PQ1K+b9Rx2cu69r+uhcTRY+wN0H4dTl832NJlLtZ1qBEsl85/
6PX+BksmGE8=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQMC1xcX2HId3w/hfbDv/XtD/g+cz+CwisV7rjsn
jM/hUHskx20SC4wv4FBWl2USJw3jizhU7y6/UcEE40s4MDF9m/bx7zEoX8Zh
NsvcQh82mLyCQ5qnI3P/N5i8ksOfb+cNit7D+CoOOvGSU+dfgPHVHE48dyhX
mAvjazhsZr1lLbwKxtdy+FVwdY5+F4yv42BlpLQvtRLG13MQ4bi38k4+jG/g
8DiYVbZWF8Y3dLjieUK39tpRKN/IYVXg82Uqu2B8Y4eVcnPYdjvB+CYO9ZeK
Bbk+HIHyTR0er1fZ5z4ZxjdzmGm07nMwF4xv7sA9OfuG3azDUL6FQ9SUMjVv
BRjf0uGVcGewFwOMb+VQ3RbR9jjiEJRv7bBqRZqmYcFBKN/GwU9ZY//dOJi8
rcMt4XMMxxfA5O0cDn87t0T4834o395hcYZk6X3LA1C+g8OH2kD5ogf7IPwG
B4fdi0N+JeyF8hkcHQ4JvPHc9ghqXoOjg+DRBQ2HNsP0OzkIz34d/iMO6t4G
JweO/SceZkTC3OPsoLNvw6IwPZj5zg7M6YaHV6vtgcq7OJje0lo/vW4vVN7F
wfFZxnrG3F1QeVcHv6aOJMVsqPsbXB0Sfi09YHgJ5j43h+r3Pf++bYKZ7+bg
cWpb3etGmLw7qvoGdwdFl102gqth8h5weQB50PbR
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdkw1QVFUYhi+ChqyipgnItrIImIaFiCSC8rKwgMuC+wO7IKAIMmMmiRkO
RtDCEOwUE6IsuIEC/lQiCgIKGiQqLAEr4E9DsuqWmpFEYI5KidPP8J1ppjtz
584zz3m/c879zhEm7lAkT+E4bts/779f9sweOJK6xqbzwiSN+T/XZlbzZjDm
YCUqVv86nbE1JClTX87400A8G8/m5O3Ie8R4HuSWuQszRhjbY6A/IGXwCmM+
qtPXzE0qZ+wE4S5LmyYdY2c8Dap0i89i7IIaH4vlhjjGbjh5uH0ZT8X4NcQK
178QLGS8FA97b/S2zGDsjoGjM2eNnuogfgOfffV+hSSDsQfiOU/dLXfGy+H7
5JHY6UQ7sSc2ONom9IQyXoHj6YkdTvcuE3vhTrW9XHGA8UoU3Dz47rnSS8Te
cNpi+DhXzPgtiAZ16ceDLxKvwsTeLiu779uIfWB4gDsevYxXo+jqc+W9Csa+
KBtyTh764wKxH14t2iVIzGS8BlrelLk1N9j4tXA8e+pskhVjf+zn2Z3kHWMM
dPjd3n2Xo/VpgLoXCnfudba+AEg/SjBpd1F9TQAiRgLdPCO+IS+Cf+myHjsT
jdeI0J1Tpz3T8TX5QJhiupO1ukbygfCb5ek1GFdPPgh73lxcF2hRRz4I+r7H
rqvivyAvxhJOnzW3q4K8GE/47zkk+ZaRD4ZjVUELr6qYfDBCJQ6LjZaV5EPQ
OW5nXWV7gHwI5OfmpSxYSfW4UIyEWPwenlpFPhQKV8ergptHya+DePSDIwU+
zK+Dbv6KqovOx8hLMPZlufnMglryEtz2SZWmSWk/XBgWtTkIpw01kA/D8OPg
042LiTkpttv0T43NZvuXYklTTvPaxGry4ejcfP/aaMEJ8uFw4Ru/7emqIR+B
FdMWvbOFKyIfAdWB/HDTedovtx7pcVkDFj+Vkl+POeZW0Wn+IfIypDV62myy
LJ9kyDAh42WZIok1MvSJty7lBx2c5DYZ+DUjo4Z8Vl+Ot/fdDyvcSAw5CmMU
xt1XPqe8HMn8x7dcZCwvx93fhDtds9n8Cpyt3PTLUD15KKAzXYtWJlL/NArY
689l5NZTvTYF2tUwfjjM+q+EfmVEqyCKxkOJ8e7i5YsSqL5GCUHLiz1CMZtf
iTRjopt1HvWTi4S7l7PgeBebPxLGvutyq1VUXxOJ1d5eExsb6Ly0ReK7SyW1
fTV7KR8FGDoPHRzPoXwUxgu3bB63zad8FFaXpO3Ud2spHwXzpzctBrNF/pN5
FX4+PGeGfckOyqsgCon1ztdnU14Fg03mM+8JHeVV6HwwLJdsZ/9fjfn5W0ce
TlB/oUaZ8kez3oOddzUc6pXu0x+WUF4Nx/NPU5vt9lM+Gg3Npj3Kv4gRjcFX
+puLf9hH+Whcn2n2k/az+aNxuaO0aSCJ+sHFYGdfY/xL29j5icFYWti6T1LY
fYlBk8ZSU95D96ntf8xtQO3EWvP+1iOU/4//BiqcG9w=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzV1I01EYx/F/DkmNaFqGgsw0My11zrfp8uU3t7mXClJQZwWVkheFLUJQ
wWqlFwlqYzNYYGU4IdouvBAalThdc6I3KtmgF5ldOCEwX1JRmVZ0HsIdOBw+
fJ9zTly1rux6EMdx+X/235MW39N7uyDMPfRPS0UvJtuOC/eTOUR4X1b9CiWH
YMj97btofZSZD/+EqrZgjXwEjVWfej/PkqMguxZSzBsnx8D6JNkZ3E0+hm0I
Dx1uIcfD1XU0u+gCOQGG6A55VjQ5ETVSo9kvICdhfKBPOOt1MZ/CZvebm8Zu
cgrETamLT0fIaZhtXYm1Ccjp+DhjK/wx84FZhHl+3rohkXoGSqf8Vr6HeiZ6
Tpc+2ImnnoX6DZmhs5J6NlwnvwhtkeQc+CzeGN6Sk1mMXeWa1tdEPRePFVtX
F1rJeWjVRaUl9dO8BOF1FndFCvkMmvWS4SU7OR8uEVdx10QugLOmt2FCQ+8V
InPnym6nj3oRdB3rcZJQMrD1um7jVi6zHuB0beJnkdSlmG+pTTY/HGZdiuzV
9KCyLGauGCbeiYjwOOrFEK9ujIY5RliX4VHX/WrBnfesyzAXO+Xpf+5gXQ6J
1ZLisA+yLsfivu2c4FRmTgGH1nyx0viOdQXkFr62vv0t6yVoHjPJZdPM+hI0
1g8s/2xg85wSNZd0PdIpuq/EjWn35Fg8ddVe61VILx8svzxnZ12NjHtfI16t
MOvVWJAltKsP0P+avdZrsKxY2Txopn424H6AuXMBPcDc+YD+378BpG800g==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90QlYzfkeBvBDSSWDJmRpVBqkqGgxKb1aTbtO+3rO6WzpYZRM3bo4GbsU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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90AlYzfkeBvBT0aOEGrdExUGYm0SWira3hRYTdVqO9rOXbtaWp1WlGMK9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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zQs4lIkex/HRRUW7lcs5apXRpmwb3V3a5Bcyud8v4zr3GYctItnazfQs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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtI01EYx/H/0swuglhQQeS127DpSuclpz/nZfMy/1AvrCxHqWlFNaZF
GDabgs5UKoqiFPNWpJR5wU0zV+pmQiBLTU1DUBEDy1K8QWBF53njgcPhw/c5
8LievXI0ZR3HcdK/999Lx3GwUi3d1G36r58hxTm+floHMof1933zC5zI9shL
kjvX2JAdMWink4YuWZi3wWV6KJ1fIO9A1vGPioND5F3I6LNaPXvJLvga0HFj
vIHshiWn/OSmYrIHDB/as18eI+8Fb9aa9fbk/ZhpS7Ht/GVmFiItav5yURvZ
EyuaJ4llD8giqOLjx99Yyd5wtEhlpY1kMYb5rNS7o+RDeFjRK+6RkA9jePmt
uvZLF7MPdP52DvY82Re3vLpXdvZ3MkswN5WwlGEk+8HUmCKp6O9g9sc15VWj
ex85AKaR8DznVXIgSkzC3CwB/T+C05oXY4ve5CAcqGlaLZmkeSl6zqkSwszv
mYMRKZ9w0MnIIZjep7w40v+OGZAUXOhKT2U9G3g2Y3n1Oo16KJr9Z/lAUTvr
oRBMRecHzbayLoPg+5hCoWthXQZ+a0tysMjAehjq6s03Fdpm1sNQ1KodsLgz
c+HILNSWbjEYWQ+HoGxuT5JbPesR2C2WbLSq61iPgM9mtV4SV8t6JKoHNuR4
ZFazHgmv8skFaeMj1uU4JzyVnSx6yrocK57LVb9tnrOugDixuPx2If1X4ISU
397zg81zUTj5+dOcqKaS9TXmotf0NeZicEn1Tc/Jq1iPwfxjle14BjMXi+sJ
ZyZyjdRj4VcvHD3fzfbhlDDfaQjJtdJ+ShjiNfc69bRfHJxdgzQdi6WmP3nD
O3Y=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11nk01XkfB/BfT4qKSaZGNUY3qplHNdasg7clhOLad3dx79WiTIukxe1E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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzH1MDHAcx/FzWhq1cm4rW+lhNFKXHk5JdZ8e73SlUTk92YlKLVdDl6Fp
kkVua6vLNZFUY1lWoqfF6eEYWQurLE5Ceti4I7JkC+v7+8d3++271977fR1T
snencjkcjv/f92+zsRqpzQlY+Vi7JKOohP8pttmMmYO9vZJ+0+XMZtg0ZJGU
O/eIbIXN1d26a++Y+bAbW2ZrPsFsgxJHhVGhY7bF+GjZ7/oGZgdoPvSbG/KZ
nXDZTl1tlsS8HgPTnv7fnZidcXRxhbTKmnkjVJN39c+f6cguEP560VqTxuwK
exkvP/AwswDeeQLZUB7zFjRmx/ZyE5k98ObMV42go4/siW+lovgnV5m9oNTY
DK42Y/ZGyc34GwrnXrIQ44IavxYn5q3QG9sVQZ+7yT5IrGu7t6hn9sXgSdGa
semH5G04zo1T1xoekP2wLmPO3SFHS96OzLKii9cn7pP9kRLdETLk3kkOQK2i
tkad1U4ORMSBQ0JVTxtZBKgT5OWmrWTg48ikyagJ9QJghTH7qbK4hXoQZrVi
2aqiJupB8F+IOZg20Eg9GPMxam2Fqpl6MMSusp+S9DvUQ+D4MoabvJbuFYTA
Td2ZxU2ge5xQuJyeKjS0XqIeCqFq2GOmUk09DHWZlYYvTWXUwzDBtU/PSsii
Ho6uY5btGRs01MPBf+XWoOPXUxcjRR7UNT98hboYvgua12JeBXUJIuPkuZ7C
KuoSvOVdmN2fXk19B7z6J1V7HAqp/2dOBOQW561tko6IlnoEZMr3hp1z56hL
od9lzvvRd5b+S9GTutDGyThFPRI53bfd63UnqEdiap/ylqV5MfUo1JX6WJfH
llKPQnRhsnQmTa39A67ULPI=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIU3EYx/FjRXgpL9GLjGAaXkPN1DlTpz8vU6eukbTMezbNLqKmqS/C
nJJYQQgViCmpaYoZZYKhlq7NW1IipnlhojUvC5HYIiYlZIX/pxcdOBw+fP/P
8+J/7M/lxmXu4DhO+Of9+6XHeqYpT2g+otyWPviW9O6lCgsyB72VtvSzKdkU
cXJNZeo/W0PueMVxbWOYeT+kJSlZ2nXyAYhfnBYYhsmHYN5eqFlVke0gq02s
La4hH0bkQFX0VDbZAZl3SseCZGQnJE8sl4uFZBc8vHGtPTeLfAQehRligYjs
hjMTucbupSFmDxgcPzjppsmeqInRtuSnkY+hJ9I3TWdN9sLY+eW1SvUgszdO
uUzNeU4PMPvA7Wm9dvIXmY+SB/E+7gKyL+6V1Y2kWqqZBeCswuU5fLIfKp7s
s/WeUzEfR5HrqF8n94bZH5q8hf6EpX7mAIwmuBjlF6gHQpWoaXv7rY9ZiNnW
sHTTy6+Yg1BapONLjORgSA0Fsz+9yMDmkGUL73HPthXAyrjZXtf8btZDMP9s
90eThpesh2DTpHNBNdjFeih4gbyVRDOaD8X3q23+thfZeS4MG4WP1AsN7Lwi
DPyZAoV9Ns2HY1JXoJ6vp/3huH89Il6mpy7C0UZbZ1ky7Rfhq/RkTttqL+sR
KKmz4dYnqUfAMqUj/cvYa9YjIZlo3fVunN2fIhIbsYahBCHdXxSqcpotqm4z
K6JwUBLY6NNE9y1Ge9JWWZFeyboYN6u3jL7uNB8Nm56VzT0BtD8afSKt86dF
+h8xSCqPzlPupP0x0Kc7LHZ40XwsnnsGtVcbaD4WGbwf/WezqEvQnJ1a3GBK
/T9zJ/Debr64t6tP+Rta4zy4
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz21Ik1EUB/AnP+jSRUuClPzQXKwUe3Fas8z236ZTJ02QskDIkCSybEoF
1Yf20OvmFhGlYo5lKlTSKg0CN21u2kyNFLQE0SZZVPBgZkYmQyq6J3AXLpcf
/3vvOUdaYiwoDeM4Tvln/z1pSUabKjIiez3/NKP6FeX+4BCTOVjCG4bSwski
DDXK/cVBP7MEA87AKf0YeTVaJMaXBX5yDAJhcx03+8lxOFOFwNc28jpM70l2
2WzkeMzONxUesJLXQ1xkzR88TZaj72Nf3nkFeSP2XRcuRL5/wZwIx42W4ICL
nISpctMnWQN5MyLivPyVAHkrJra4Ta/M5GQcFGpr7svJChijRWPCQA9zCpYf
qzh6tpScCqf03DKZQN4G0+gqS62PvB1W88OFuuNkJSzFMznaDeQ02Ovrvmse
dzPvQHzY2xpZmY95J54Iwb3pd7zM6Yhqj2jjF7uYd6H1pLZqyu5hzkD5SGCN
ubOTeTdWDjsE8ZEOZhUUZul0a307MzAR+0U7V8nMA+POEn+Kiu6rsd+lHLdX
s/94NTYlfPauKKN+NJi8bKvggqw+r8G9BH1h7CU3y7W4Vnx4oXnoOcu1+DH5
rOtiETOXidzF6spGJZuHz4TmKtQ9t2m+LHxLHT5kN1CehW6dI/FdP+U6iOZj
9GujWT+8Didks4Y3rynPRq/t7k/xU6qfjVtJPk/+I5ovZ6n5HDQOPjBkj1B/
uUvN54a814e8DzGX99+/Af4bI68=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw103k0lfseBvCXVNJwJLfhNNhRt+RWklnxUDJnio1t2PY2bBoMh3Iatw6h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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxF0gtIU3scB/BT2YOyTUMvaUmmYtmLZTN7+PjanGubzj1YrBdiWayaaCXo
vdllmdDDxIwwLZFMFqRRZOarqStbYTetFMvMkoxSirKUG3RbWdHvdztwOHz4
/n7n9+d3ztwtafpt4wVB0P64fz758nhckR459U7LL32IDqwUSceJ2QJebF1d
nfN/PgXZb3VLr05ge0Dl3pp89tttshfS0jdP6h1hz4TN5WFx9bJn43pkRqXP
bbY/PqpE2ql2dgAu2Ov+qSxgB6Gpy/Xp5l/sYBxw+T0SydnzkWRvzj4pYi9A
oOxzz9k3TvIi7Mktcvujlb0EXwY6hlZ0sSUoaN4vy2pnL4UwnPopt5MdCkVx
xGhIPXsZDs8rvXIsgy3FbklKhecMdhi8szPlA9PYy3H/69PFB/pvkcNRnrjH
6bSxV6DtSZvRfpG9EsMp0wN6AtmrYM6elValZK9G04X+kIDjreQI+CRZ2pJl
N8mRqN/bNSeo7gY5Ct3KW1XT8hzkaHhGtTaOHmQDvt6L/n6YSfVWIC8muSPO
yP0xyE/ukWZOpnprDAxe4vLzEu5fgwRnnvyKWzPla9AoueQ5ltJCuQxpp/87
MthCtsrQ+8K50OpL9UIstn/cKZWc4zwWu7IEwyUt53I4Zk8aljmbKJejpGNb
1NFwzuNQEpobmd/AeRx8izaZx16SBQXmFy9+1V1mp1yB6oTSo0Y/srAWHa5Y
uTmnnvK1CBKnD/r4N1KuhOKb2XhxC59PCVPG6051GM9XIXCWp22kluerIB2K
GOkv51yNYs2J9A3+vD81GrtGJnrX8vx4WHcI90RvaZ41HuXRZxo68xsoT8Dk
GmPWqXd8vgSYgvPUBeNqKNegTy3W9H0lWzUwWdZt2Ke4RnkiTmt2hLg5qilP
xIkyW/jEy/Q+QYtl5k2JW5upH1qMuXXDfV8t1WvRtNDgfs2H6h1aDD4bCpnQ
U0f9OiTNKCsMLqQcOqj9/pW9d/B5dXhWU6WwTL9O/TrsT20fMO0iC3qkmsSG
jd20H+jx/E+J6pEX/496HHK3aUqWkx16jIYpT1n6+P8yoPRh++OiHNo3DHh5
5m6utJC/hwGhn4PWP+in/Tp++zs6v5sE
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10WtIk1Ecx/EnLVZaoWBgOimXlpfNS86ydNtvuisEkhrEukDmyl6kvQlf
bIsZo8JojByGvtiwURqaFluC1vZYU1fQLNMwEwWJQizChDKWi4rO/4HDw4fv
OYfDOem1jVXGGI7jpH/Hvz99CdOeC7K4EP9fy4rQ1qgrsIXMITLalu8TkDdi
WGJwIJacgJbeN4F3kTHmJMwZ7xZmL5GT4e6XKVPekoUo8XQ+8A6Sd8K2p2uX
4BFZBE1R2fU2CzkDK7WOzIYm8m5MrI/pFd0mZ8HToBuy28k5kKxKXledI4uR
m19pmBCS81Bzv/um8eMocwEsPbNGrYpcCDH/3vXz5QjzXph9QZvzDLkIv40d
8qnTZClqzGtHemTkYvBBhItSyfswFlrKnYsj70fy1Xp18WSQuQTjsumj1u3U
D6ClsnGw+hD5IBLbc87PPKf5pfAk3Yht6iKXIePYyb5MK1mGtXBBdWkKrZfj
rGnyoePLM2YF5vUvOrztNB/Y0PxttcHEuhXwpRX/+OB6yroS8p6BgcuvnrCu
hAjpi+t+MXPliEjnPTl1ftbLYZJOJtZl86xXQCF0LsRL2X7WCqibNYdX7MOs
q+AcThuyfA+wroI/2Oq+lUr7qxGMb53dVP+YdTWc5sWZqSvMnAadijv+T/cG
WddAea1fvkzn4bRYyDvV3Sem82vhzTq+7Ws83YcONlW4hhew97fqIIpKNtd/
pvvRw33R4D/BUddjR3Ss5dL4CP8HSMkJNw==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tI01EcxvF/WWIqqBVYXspKLK+YTpvT6eO8bbp6Ib7JFK3pct2WL7pQ
ezGKtNHFRaMEA3HWbFqa2rykWHibqRSptFIQc8lKDKU0K0MrOr9edOBw+PA9
53DOtkPK9PzVHMcJf88/Kw1XS+VJoaP56V/NxZ3QF/er7MkcFgN26Mp/9DI7
QFvRcSxsgewKzTXrkG6SvBHL2pGClffkTQjBSEN6D9kLD8skedFVZB9IJ5ea
G/Xk7ZjiGfgaLdkXg1663o9qsh+KxG9EvpnkXZi48+BnGY8cgAKryTBn7WEO
wt2XmXb2BnIIzgsy6rPyyKFwWr9BfERB3o3TvXVXcYkchiKz3KjbSg7HhbWr
elodyDzYTHaaie5u5gjYlsL7xq6TI9EY3Dp4mSPvwU4Xx6zF2S5mPjRG/rv5
m+QoePcHLu2fIAvwVX7QUiEmR+N491Sl83gncwxa3CVuNR5kIXw83Fr0H2h/
LAobNLIZK/U43G/nTPWeZKCzVLslNIxZDdi6znyXvehgPR7LnqOisqEnrMcD
QdnNuZ/bWRdhXfCrPimfWS1CDs+cPVzSwnoCbuQPW0TLJtYT8EgpULz9wswl
YuXW82nv4CbWE1GknzcGyhpYT8Jh26hLdUk960lwvmcoPptWy3oycpXPErz7
q1hPhqq2QHXxdg3rKZhzGHcXGKpZT8HswKc2+Tl2HyfG60leaeF0I+ti1M6u
GVJmPmZdgrEYS6LcwKyWoK7aKedABPVU+GckuV8x0vlUDPgryjf70/vT8M2g
qllpov+nwXBKmey3yPZzUngenYlti6cuRVWkzF7o28r6XnSapxaiFM2s/2du
3z//AqXgQ3A=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0nlIk3Ecx/HHDjBpuKRSnKHLUss8MvMq20edx5zLtHASiWUXVuaBUwOj
Z4oHSf9ME5tCYqUZK4osMu/U0g7MCBVZqSnqVlZQ0YJqFf6+/bEHHh5evHl+
/C5xWmbi0SUcx0n+vv++9AhHr2SF2jzpWtRnybTaMG9eReZQ8KapLkdAtkb6
gQIb86/HzEIMq4qvN38hr4ZBvOCm/0F2wIDpZ9/sDNkJdnp9/LdnZBcsLe0S
fNeR12Mu6ZL2XTF5A/g255rQBLIb1qUosrJdyB44JE2ZynUib4b7aGJtVEs/
8xbkjbTblweQvSFRT8gOv+1j9oVgzF8huEDeCpNo0uu3B9kPy5O1GsNoL/M2
zFTZe10NJPtjQj22UOJD3o5Pg2cO6gyPmAMgSnDc2N1NDkRxQ0KPXEUOgqfp
6Xu9NzkYZ4dSxXx1D3MIZjtrXxZZk3fAvFIYdMTYzbwTWbH9Nz/mUQ9Fjkro
uMmP+i7cC3f9uiy4i1mCjClNjWRPJzNgXXi+8tWajkXzQN21zFK1TzvrYTBd
PuF6q7eV9TDcdlXdSAtpYz0ce6dFryeL2fh8OJQZFfnVUho/Ai7jHu3puWw8
PgIaWZHRcPch61JIOxyVFXH3WZdiv1VSs8hIPRL1Tc/ldheZ+UgYI0Rlyhds
PlwUIuNCGj8UsvnwUVCmjvgN03y4aATPOY68pPPlo5E8NOBsdqf7EgNxZbXD
2mNs//kYaOdbhzS19L8MLZOS0gY3tp+8DOeq+lX7dHSfYlF2x9ZzUMfOn49F
ts2pHs+TtH45FK3jXLltPetyiH0flKSe1rIehxXHZdONVvmsW5hTWHQLc7st
uoW5+P/+A/0UPbg=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9kQk0FXgbxi+TPlGTSkP7VSRNI2kj26MkS7IvcXFXTJu2MV8mzZUahVKO
NCjdLJE2WxHiWtpElizRQoWiadGn8o2W6Tve/+ece5zfef6/93nfe7WEwS4S
RQ6Hc/vb53//2Z9aW9pWM5Wb5SP01kK5PmKSuSpjDp6klt779P9cGS7B2x1G
KTFWQ5+y1vYyRcbquGk0trzz9Q1iTZypeVVz7THj6bhj3RqYV8aYi66F+qpe
FxnPhuViu5OeoYy10Xe1k3PcgPFc6O7ltm5RYjwP8Z0X5zt2XCeej4d7xk7R
SGe8ALcL57t2bmGsj7/u3zLNnM3YABcPblNOvVdNvAjSjILBJkvGhtD80GPw
YS7jxRCqJW1tiqkiXgJ/Fx+NgTDGS+Fapj1tWm8l8TKc3Tdq8aMCxsuhOy5E
4/RUxkbYZTbfYsIYxsbIaOcmmPTJiVcg3rmq6KNaBbEJGh9mOT6YwtgUn/Na
X/HMGZvB8tGB1zl3mW8Op1NhvXt1yoktcNyjoDa67Box0D5O4vz9ImIpEFCf
LUgxLqPcEp3rA9SuClluiV3ylp64AyxfibJPgjf6k0ooXwnLqb+szrpaSvkq
jJ7536K+cmLpKpQotacofKH3HCsEGpy5qTLI5luhaX/P0Y6lzF8N4xjJs+UG
dJ90NcITu/sG3rN7raG1aKO11yaWWwM9quHdb9m9a5BYuHBP4zz6PqRr0GaS
XuNrx+63QcePEnnva7pHaoMVKPb5gcf6bbGvZGi/eTe7zxaHmnKa1GPY/nZo
jvvzokSR3WcHo/FHhsv7WW4Px4M/rNBLukK5PTg7LGPDZuVTvhaGratsh+0u
Ub4WbteyIkab5FDuABOOd0HX/dOUOyC3sV9vt5WM8nXovpxnOMvjOOXr8Ekr
ozH3azzljihOalJVrzpKuSOWJRi1K3QmUO6Ep78tzj1z7s8RhhOsahRqshRP
0HsnBAny8+bcPTbCcie8efmwVactinxnnE62+zVa25R8Z3DfPfs1/HykxYjv
jBJHceGUmOMjLHfGaPN3PilRSSPMccHz+7HaS6JlIwwXHGyzjeI3nCTfBZH+
hSdXp58i3wU5Pn/9PkOZ3nNcoav6tsK+gnK4IinFpCdtB7HUFYuDQzqm19I8
uStKvS126LUeI98NlRtPquuHJpPvhiUKMzbpWFMudUN61JzNoXNOk++G+pOF
oxs0aB7HHRqRaskzBenku6N37oIPSnXEUndM/RL+qreI9pW7w7RTS1IXnkq+
B0x+bG32j6L58IDAsdYsMeYE+R7IjAwZF9iQQr4HZunwXh6JYvd74vzed/cv
dtM8eOLU9M1DARvOkO+JbWXNu8/apZHvidI3UcUy00TyvaDyat3U/uQj5Hvh
Xo6FxcQ/Esj3QrU8d9jFOIp8L7h9iY2ZXEPzOOtRt7H590OmZ8lfD95Sw48p
Qxnkr8e0umdpsi/s/vUYF5idlpWSTb43NCOyraLPXiLfG0mfX5Q/tc0n3xu7
Osb6Zh7II98b2g35qh9DiDk+0DfTfJmvcJl8HxhzY4tHVReS74PqL8Hf12Re
Id8HB6M0EpPrrpLPQ8XjW107h4vJ5yH6Wr+CKOka+TzEK6Y3xu8vIZ+HfvW9
ojTVMvJ9MXTuJ4Hm9lLyfXFjasSgbiTlUl/ElHBHh2XSPLkv9AaG8v+2Iub4
IdPr6B4TZ+b7wfXE3LThK9Qn9cP78Ahzv0O0n9wP+pU6a+QPmO+PiPG2M8PX
EcMfWkUNzY9XsP39oZ72JmPLU7a/PxrHuE9eVEZ9HD62NTwW9TZSzuUjJKOL
05LN9uFDyX6CeJo73cPnI/3W3ZZgs3Kaz0fYarmCgZBYxoffpYUbPHvovZyP
3cHz3ttZyUe4iw+Vdp+mNQ7EHAHuWE1cd9SOmCsA7zsbw9mxNA8CrHo+3ejy
O9YvgHDeGV2NaNYvgP6Wld3KIF8mgOH+Ww63xxPLBTjvul3h62bWL0Dh+zkz
f0pi/UK0XS8edtjN+oW4efihWusT1i+E3oULXbIW1i/E4RnbOff/YL+vEH4d
xwfF/yGWCaEvcDi81oX1C+F4ePOg8qwK6hfiwqN/G6a7VFK/COqlLbwPk4i5
IjxdcPWXuK/0HiK0hcTa5bynnC9CrDBtTPzkKuoXYcj5qHRQl1gmwrY4yafp
wmrqF6G9wnjTk9Tr1C9Cl0f9Gr3Qm9QvRt6VwRfLhoi5YhTWPhBbJt6i/m+8
PKguJZmYL4ZnjMqjdgdiqRimiluzdyjcpn4xFg3xzsXZ11C/GCoJ4733ioi7
xOB8NK5c60XMkcDvxib/gVZirgRSzVF6jybcoX4JLnBad5dMJOZLIMlY25d7
glgqQWVhQ3GVE7FMgmVx55UOrKqlfgkSPmyUeS2to34JtGdwgqtH3aX+ALz2
NH5xw4OYG4CCVkebrHBiBCDH5vKOtCxifgBWWg5+FxRCLA3AnaJzOy3OE8sC
YN+7X/nv28TyAAzMSR1T3EncFQDVXXdEQ2frqT8QwlbN33zLibmBMCpxsm23
IUYgPKzvJsXKifmBMCjqzdaxbaD+QPTV2rY0zCCWBSK3sl/8nEssD4TDgaTE
LQ/J7wqEtCp87PxQ1h+E58cEHZ95rD8I9ccin0ypZ/1BaPStSt1jxvqDEOrS
nK4/m/UH4cGGzwX8AcplQUj/+amDx1dieRDywgrjG83pfde3vn/ta+vdR8z5
GbN3vuOmbW2w+AeYZwBt
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0AsslWEcx/E3rGGsY5oMK0l1xBoVCi8/DgfH3VJna7KFalhqS+tinLBS
qBnlloNQJGWHzkIcHJfltrZsrMVyrTFLUyHpNv+n1rs9e/fZ9/88e/ZsPxEf
Gq3BcZzo9/rzZ59guPwsr9ujWteC23PfGo16PWYOxv0aPcsbmbUxGlktGfw7
LwCvqylvWusmb4ajmXns9U/MxlDWama5zDObQSS3/Rg/xmyOeeXPouRxZgvk
mQ89nhhitsSI8sHOqS7mXSjr9L6Y0c8sREf+297EWuY9iOOPcT45zDbIyK0v
/BrBvBdNn/s+SPWYbZHKF2Rv0mG2w2sjPksy3EXeh8niZ3azc8z7YRp7TdnY
xnwAjjGCpMU8ZnuMG850dd/qJDugbty/4aRUTXaEZdpYa4g26wfxzu10tXq1
g3wIofeLE5clbN4JIaMGdfoXmJ2RmRLhOqvP7ILl9purPrpsP4/qjPrDghvt
ZFeIy82TA4+qyG5Q9U+H/TjHDIgCpq94DLSuWwZ4Rm4rc+hg3R19WsKsNwlk
mTsKl55IzaJpnvNAWM1ash7XRt0DgXEm3YMBzdRFUA3c1RlUkGUiKExKvmRP
NVH3xPARw3idfNY9EblbyDlpsf1eOHNnZHLCqpG6F9JTuNGonDrqYuRvmfs2
Y0+WiQErI2nvwlPq3uj5/uhUSVoDdW+0BKtevlqqou4D/mqq3Kgjn7oPZiqi
reUxpdR9kZjB2077PaTuiymxsC37fAV1CRIUl72sEug8mQS2NumzK0Ka5/xQ
KrBYqSosp+6HDeFDRY6CSur+0BaHDTko71L3h0GLxWKxaR71AOzgZxVBana/
AKyllThvtS6gHojMkkvS3Bw59UCYDBwPfz9zj3oQ+qqWFiqT2P2D8GLs9uCo
mr1f8P9GMKL0Wpulbgqa/+dfEdFdOA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQMC1xcX2HId3w/hfbBvyjz/zoAHxmdwiLoq1K3A
D+NzOBwUNIzT/3YMyhdwqOgJP3T4CYwv4nDx4t6a/WdhfAmHtqUhhWeWwPgy
DpLcgYp9VTC+gkNKQGkNRzqMr+SQq/ePZ5MWjK/iENTyVWPp16NQvppDd6bx
P9enML6GQ8rVWA3z2zC+lkOEIXtr+x4YX8ehsi981ckVML6eg+Ej0awrRjC+
gcMV4f9rtzrA+IYO/I9O5/7YdATKN3K46cqxIdAHxjd2cN0pL3T862Eo38RB
XGi9b1YGjG/qEHZ4dlXFkUNQvpkD19dTU8MLYHxzh4Pt9W/bnGF8C4cHpbOd
vdYchPItHYr+peWVOcD4Vg4n/q+NLJeH8a0d+nZMbMhmgvFtHP5Jf+B+cfcA
lG/rEPbn/OKqNBjfziHNdPN/jeMwvr3Db/vNEQ4BML6DwztVBYbY31B+g4OD
/FyD1isnYfKODptFtsx6oA61r8HR4eXtlcfZFsL86+TgylcsoygKja8GJwc7
venZ4Yth8efscEtzu/DVIGj6aXB28H7MkvNBF6bfxUEuc4Pbi/rdUHkXh9eF
4tM+cm2Cyrs6hPo13P44cyNU3tXBOr03Nu7kLqi8m8O9v0XX1s3aBpV3c6gV
2n217yIsfNwdtH+cEGVavRkq7+4QV9H3fsmdA/sBJD30Uw==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQMC1xcX2HId3w/hfbBfFZ9nv44dxmdwCH51tJ+V
B8bncJhe99llFzeML+CQo3pc5uvvY1C+iIPFg79ayq9hfAmHQpFNZ9juwvgy
DtL2XxM+XYTxFRzYepbHBZ2G8ZUcVn7y2P1iE4yv4sAXInJo9SIYX81h26mL
7/WTYXwNB6Uuxme5iTC+lsOkF2/PewTC+DoOmu77svLMYXw9h9a+zK6rKjC+
gcP+czdW8FrD+IYOk/4oml7lhPGNHJgXavY6PjsK5Rs7WJfLN0ycBOObOATP
15uv3QfjmzoEPfX1OmYC45s5RP3foDs9/AiUb+4w50J6d+ySw1C+hcPf9zVq
CW9gfEuHz5L63vreML6Vw/lJqdXOfw9B+dYOrXt7ahcnw/g2DoXl/m9+3j0I
5ds6aBz8pxK1EiZv55D8L4Av4hqMb+/wVn1FZ0I8jO/g8Dtvl2Vr0AEIv8HB
YbtHy7arQXuh8o4Oaz2rZ51ftAcq7+iQurr2hPepfVB5JwePEwf9lwZA1Tc4
OXT93rzizWOoegZnh31JB9Vk+bdD5Z0dvm6+M7uyFKbfxWGC0bo9G2Jh5rs4
cElJrDgjsRkq7+pwoOafw5WA9VB5ND6Dm4Np4o8TKk82QOXd0OTdHSrfRKZ8
z1q1HwBFnfP4
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0HlI02Ecx/FfS4crKhmCJUHNM49MnXfqPtPpPBdJYCVkBCLmkWBqmeWx
0kqUXErNGuVmIEhu04GJ2qw8qDCTMjssMTvMP0JJqoXRgc/3D/fAw8OL9/P8
8X1ER46lZvI4jov8t/+ftOwndQWR60bMK1qQWIQZ/FIBmUOKQKRYY0u2Q7DN
rzjF8jCzPTQTg9OHFskOqJHODc9+J2/GxbpRT/Nz8lbUqiZNjaPk7VDv8vTx
0JCd4fC4qTI/g+yKkpb2G1sUZHcYj2fqNjiTdyBIXvS1fWGI2Qu3uwprLrwj
+yBBcKo90ED2RdWc9smlPLIfNokHspWnyf7gqS3dZ86RA3C4TT8/JSWLUab8
+KxgeZA5EO/rld+K3pKDoHKZrRy3kIPx5VGDSNtBDsHVh/wPTnvIoWjyd3Z3
evqAOQyvC9KK87zJ4fgs7F0M8yLvhof+pa425z5zBFpmt9n11ZAjcdStvMNk
S45CruSKJkRDlqD4Vem0RUYGug64Gwp/3ltxBaA6wc/6VDLAuhS6/nyj35CZ
dSmkl3tqeSrq0fC99js7rfEu69HI1Qhnlqr7WI/BeT4v/bqpl/UYtOYc9F78
0cO6DOIIw5+1dXdYlyHerdnxRZaJ9Vjc3G8J2VfexXosRnoaEjcudbIeB4db
VZPzWUbW42DzRrl3ZiczJ4cs3C/ARatlXQ71eDWv0LWV9XiUu4jH6iUdrMcD
orPCqPUG1hPQP+8RmnpSz3rC6vtcotV7K3NJUNfJR5zS2TwVSShzS27O6KT5
k1e7wspcilVPwUR325TAzP6TU0CFaseFsX7zXwIvMyY=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1EYB/A3Lym5bKJF4Kx1USTMpnM3ddt/uosXWK4GRkqUZiMSE7rQ
Vd8SHVGoH6KLBGWBImVlGy6z1SznPohE0JgEXb6MpLHYCLFEpKLz+GEvHF5+
/M/1OWdLw/E9TXEcxyn/tn9/+oSBB63qNb7X/xXRFp6ruW1OInPIdhy6UZtA
Tsa4ZLcrmSMLkaktLZ4OTzFnoHrc+k4aIG+EIEGn+fCRLIIb88tRL1mMk/XB
50Me8lbYfgw74wfJ27Et0OVI7SXnQBC8laOyk3ORNyX7LTtN3gHHkBMtBeQ8
LFbarFY9OR9zX4f3pv7yMktgHt3wKiWN8gJ0Si+Y+35SXoh7zQeOXPWRpahV
rJ+U9JOL0J6urFs+SJYhfL1el5hClqOt5/21p+cnmRWYF70ccM+QlXgoWlT5
GsgqzPRIO12Bt8zFMIuD3Qv95BLs16QtJOrfMJcibCnpzhdOMKsx5uni+4Ie
Zg28jovNayNkLR7HzVoMLWRghLdfuVvFxvNAY8jfMT9A8+kwO7fObz9FuQ69
EVu0ZprWL8PI/c3fRZvY/vgyBN2uwaLLdJ5y1C1ZPkW/sf58OW5+Nuza2U71
0aPjrD0jKZOZ12PfnXjji2eUG6BpVAvdx9j98Abk2kMK1cp7NEI3dnjoy2rK
jTBWyH2jfrpPE5zZT5ZMq2h+E0KtJ5pS5FTPCpw5mj4hzqLxMeYqY/IYc1Ux
eYy5amQ9ahNcCrF68NUr+R9BDhPY
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tI01EYx/F/hTDCUCgrsBc5VOymma68bftt7qJzOStMsNKaaBHeQnyj
GUNIy0tEOrREydZSU7TQ1tJMU5eFK7uAGkZKTFIslpqIBXbB8/jif+Bw+PDl
nIfjpc86mrqe4zj82/9PWu6jpmzxxsGeVf2QGqvMNvUmMoe6+PRA6VoXoKxR
WzO9/ILZHRUpLomSRfIWyN9Vq7xmydtRLqptq50h70Dv9cV2/Qh5J0amrTUb
mshCSGq/cL9Kyd4wFi4NVSaTfSFSpg/XeZD9kNPPubW8tzHvRqA0Z8XDQt6L
xO9HwnSdZH8IXn8cvpdE3o/sfJ1MuzjAHIjSutvGIiP5AGIjApwhjeQgDCV2
l8/EkYNxvsxRv7LWRbD1xehOfSAfhH/L+GZzJfkQxkOFyUILOQSexWqR4yo5
FHfCWvX1meQwZM2Gf5tKJYdjMsVLPNfVzxwBh0R79sIEWYzTmM/UJPcxS6Dc
16/v9iNLcXFSPj1/7TkzcPJzQsxcRu+qDUBTaN7M/fqnrMsw9cz2Ns6H2SDD
pHjs5ZtjPazL0WC0e3w6QfflcM2odp77ysxFoloxrOwYs7AeCaF5QpAb38m6
Aj8rxeLmKGaDAn6egj3NzfS+EkmygdE0B81XosBaVV5SYWVdhdyb9vplxWPW
Vbi81afLO4+6GpaSwT8Nux6xrsYVX9NvwwjNj4LzuNW8EETzo3Dmya11SwFd
rEdDZW8tnsvvYD0aLkWXCh/cYP/hNOC23V1Ic6X5GmjU9sbgnHbWY2BKGHhl
invIOs+cltd55g7zOs9cLK/zzOl4XQdnwZJbm1t7z1+u5lO8
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10Ak0lXkfB/AnSRnLaLOkXstEi4pIScpXoYVs17Uvl+teVyuSTFTXUEpa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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQMC1xcX2HId3w/hfbD/uNZL244bxmdwuDI1zLoB
Ls/hICUxtXLhv2NQvoBDe58Vf/J3GF/E4blRq2vdWxhfwmHPDJ/7W57A+DIO
alF3PlffgfEVHKZn8DLuOA7jKznc77/gdnkejK/iUBQnEPqjCsZXc7D4ELHZ
IAjG13A43ROwaq0GjK/lMM8jY3ns06NQvo7DZ4d99m3dML6eQ6h+0Q3uVTC+
gUPhdKl3m1NhfEMHNUlXsX17YHwjh2p7RZXntjC+scOTo7+rJirB+CYOhkrz
Xl4JgPFNHbhPPVeYnQjjmzk8rTxyhr0Vxjd3UJA7V+wCN8/CITxVN9yhHMa3
dFCoerfocTGMb+Ug/ylj5+1dML61g6eorJ+BEIxv48Ca1b82yhLGt3U4ccXa
MUEXFh52DitlY7+sbIHx7R3+iO/I2SMJ4zs4cM8yq09rgPIbHBxuPC+9XvUD
Zp6jw/7yZ58t50D5DY4OzGmlVnaysPTg5JAyrcx/wzSYvJMDt+fHlW6GMP3O
DpskE+ZvkTwClXd28Mx93Pfp5QGovIvDy4CF36UeHYTKuzistFx2stN3C1Te
1UFV7bmXXNE6qDwan8HNQTLCIUTSs3U/AC583UY=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9kQtUzHkfh0dElhDRuqzNSBe7lUii1Kd7uqlpSpcp0zRTI6KLypJ9p3Ip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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91AtUzHkfBvCRUEpN74YUaYmVg1QubzH1lC5MTRfdTNdpmmnGuy7Ru5oU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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0GtIk1Ecx/GnwFjGYi9GtrCZFyyad8ucpfu5q5gkTmNC2ZokIlFaICOy
ejIYLqaFJUm0DUycOU0qnGumM7VpUgmKJMJehHSzXiiEtRFS0fkHPXB4+PA9
5w/nxFbW6qs2chyX8Xv9+dMnenu/Ljdy0v9XKwqtYDX0bQuZQ8ePKUPVPwuQ
3LoqNAnJImQrAz3CCLIYU3krZvnnAPN2pJ1P77e/J0ej2VLRmPmavAtlFvcY
d5McB+9ZST7nISegOcehCl0kJ2LEOL72+Dh5D+ZDyyclRvJeyJKz1itqyElo
NXUV23LJKThlj+irSSSnQboQftIrJqfD7C9J7ax7wZyB0uCt6+Pl5Ew0xM0O
HlmeYN6H9su2Xq+PvB+Ol1Lp3J1x5izER9lMchn5AGIKxWbPmTHmbMydKPPc
jifL8XGHayIm8Jw5Bz/7O+frpeSD+HCsiedfjTIfwkDQqXZeIucifOWGLkFB
zkOsZPqc9fsIswLWnqZ3gtlnzIBMP+k7OsPMA8NvIrWP1MOs50Nf3fFw2yYf
6/mw6HwPlooGWVdi0Rm2+1s8rCtRWr/565rVy7oKMxdcqZJmtp9XobtRtPTJ
PsS6Gnel7pY2AzOvhlXzJVCeNMC6BuuLhYf7rtJ8DaZrdy8Uu2m+Ft0Nrsp7
T2m+FtNDp0v0Njqvg2Nn27V2CXsPXoetUQaLsovuX/C/+QKkRG8wBqtH/b8A
SQb8HA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11XtUjfkex/GHoySipDJhKtRU0uFMh0qXj+5Juqd7u303aYouMyOXraES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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0m1IU1Ecx/GjRpm+cKRRhsoUM1NJneZyaf7m3NS5uQxRyEFPWmhlI0ML
hG6LCOxNSg2jNHOB1guHQSmYTssHikxIY2kZhJHGRBtEA82s8Pyj3QuHy4fv
Odz/gRt+9MyBMm/GmObP+vumR+KwmtL9Ruxr+pZRWn/yfO1GMkPK1MxEmS/Z
F11zyvaen8PcEkhrJVmbfpGDoGjTCiHvyVsRe2H8zZa35BBUP0y1dd8nS6E2
uRy3rpMj8LpU5SW7Qo7Eu9t1yaoGchTUHS2KO9fI0Wg4Js/e+W9/DAZmlgWn
gRwH78jEmq5E8i5cXjFe1bwa4k5AUEe9qbKNnIi5pZSvkkKyDNaw1crxGHIS
Km3rnZb2Qe5klM2Hxg9MkHfDlTNuLKogpyDNVaIvaSXLsXB6snRUTt6D6KYd
+oSR59ypUE+7w9eFkxUIKUqzFY0+496LeI2mylVFPQ3WVmdjSzk5HWOxss+z
ubR/H04ZhrSPCge4M9A7O1nrVpKBjKQT9S+f2tcsAF6+qouBMupKLB8XZu9a
uAUlLB87zYuMeiZG/ae7z873854JnfTgJ1kAN1PBpNleE0fzCir0fWkM9qnm
32NZgN39oymwm3eRmVrURWYaJCiWQo3mPt5FZtmiLjLLgcnn5kyxnO6fA+lg
cVhAC90v19NCLlp1Xn72KJpf62lBiyRnW8XCJep5iOiM7W2eeMx7HoL/N9Ph
gyOg+Yaxh3cdVgxH8h2LT3jXw3/sUPa9mC7e9bB0mB9Mbab58j0tiMwMSD1c
bt4Wwf9fQWS239MQWRC5X2RWgNW4Dd/PDdP5ArywOd11fcP233kXXwc=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVz38s1HEcx/HvbhHRsJ1h04bkR5ku1DlcXufncQ6dzDTV0vRPq/woW466
M9WUG2OSxOI2/bBaSJw4v8Jmfs3QFmtl+VFt+XG2RKVan3c/vtt33z32/L7f
38/XMfmcIoXHcRx+3r+edFm+1KaKt/V3/NZSYEJigSFzO5nDp/zquNYtZBMU
lTSdzTMiW6I3OqPY3JjMR9R8c+llQx+zLaoF6xaaYbI9OluSFGZDZAckvhNa
cf1kJ6gWrlsLdGRn5KRYmATXkF3QPfo6/kQ92Q361J0NI4/Ju3GjvE5TJyJ7
YPzYzfgUG7InXmXpNpRzvcwCrDwxvtthTX0f5jxrfG5NU/dCWZn+Qcuf7g2p
faRG1kjdB12FKxOGBPJ+eJ75qKyVkw/Aq6s1wm3tBbMQleeXNLUbZF9M+qY2
XVnuYRYhKT9SKJaT/WC2Mpm+ttjN7I9L/IIsrYx6AApci6f4lrRPDLVluolv
A/kgSqe9k6x09H4g9FphdvJhMnCq7ch93wq2XwUoP2Tz5Ln0PQkmTPmbhc1d
rEug5Wk1xlU0H4S+/NnmISeaD8KhtIEyr3GaD4bWY9FwtJHmgyGQujwrD2Tm
QlDVIoydcmf7VCG4s/ptauka7Q/FW0Vsrq6S5kOxuWO8aj2nk/UwOH52rV2o
bmc9DJIa3smKQWYuHOJHF1drRa2sh2PW+s1X9W0d61J8UdiErnq0sS5FnJ/W
/3TIc9YjkDa2GWB3nH1PFYEMtav7PTs6fyQk5bYj30V61iOx6/18fYyC7eNk
MG3fdOiZoS7Dyozw4eCFDtajMCKVDexVM6uiMJpborg6RueX/2+VHEuFec6G
p2wfFw2nZfnwViM6XzT2/GsuBkVpanNlJvtf1V//AH3CTSg=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zQlczPkfx/ExbrERuxXKOIp/KA0RXW8d0+huuss0M83ZRiKyLPXroHKt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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz38s1HEcx/HvsorLiaZGMe6iJBkV7ggvzjnn15GzaqxJNWvlV2vlV1yN
Cms1KrdaWdFmhl3Kbw2Rfq3WRUnFllFNpOjKr6jm8/6jvtt33z32/Lz3eX8F
sYnb9y/iOM7/z/v3S49xT0mSJ+9By4K+everOwTey8gcOCvlG5EJWR/dR/LL
4wzIxkjdPfSoebqT2RROv0rPSAfIZuiZsxj1e022gK+HiRzPyNbQmj2dPHqR
LESfU7zRvhyyDXiHDHILT5DXYZcu9YlzBtkOFe6C3LMKsj2iPjqonSPIDpi6
ErP0upjsiAmPC7N7u+8zO+GdJjjdpobsjB/6Y3fLu8ibYR7ZwDO4Td6Ciinp
3Mk68lZ0rdHTNZ0ju8Cc/1i98xDZFS+0B/vSXMhu2NQ5vDK3r4NZhIS6+g0F
be3MYgy5NiYLK8nukEeuaLNdTOc9ULlR2xunIG9DqN2zEYN8sidK8tKtHhnR
vBdcj0VvVTmQveHjJhd0jbcxAxPxxbkWk8wqIOtcubvS8B7rPpiuHks+LWNW
+WBkZLZxyctW1n2RNq1XJK9sYd0XEqHljGCYmZPA+KvlkEhHXYK1MVcTHD83
su4HPk+SvyPxLut+CMoSj8Y2NLEuhXWL+JPV23rWpcjJ6VV+GL/Nuj8OJCtj
9lRT98d8iOXxUfsG1mVYlX2tylauYV2GJKEyW5JSw3oAIvRuBDeL7rAegC9X
0wQR26nLkff8cLpXUS3rcnSUlVrYfGPmAnFYe2VF3mAd64EwndFMaOrYPlwQ
iuZvrL5cRT0IdoatcUEZNB+MqIpMsbCJ3acKxs85uwGxjv4vBO5R88v5Utov
BIYR6y+5vKIeirHJ+qmA98yqUBSmZXUOlFJXoL9scIf1O5pXQFhwKn3uJvUw
tM9kK89n3lowwsD/XpsSe7CanQ+DZ7HEgcdn+7X+Zy78XyMc4dEyhfphTctv
Gf1jKw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1z38s1HEcx/GvVor6g2N+zVKGOMeUHyVxL875mdbSD4a4yh+ucupW0g/r
/OGvmqklNeRSTYvpIqTuznERay2TGln0azONiPmRph/r/f5sn3322PP9/uOz
8ZBqT/YKQRBC/t5/Lx+bdzV54dbdxv+akqbsK/UNs2ILmCoRGxLXsteg0cV/
SWHJtkHe5y8Yne8i22NO+6G5c5zthBfWlibRD7YrpmptpR/fszfgnrzyku0b
tjvu60+/tOtgeyA1c3fv9DW2FwaXcss8FWxvOKl1fgsObDGSR+vKM6efkyVo
OWZ7VdbP9sfJAmXWp3x2ACrb2s5MuLE3Y1lc3SHqNpO3IGmxStXTww7E1xFp
hvNBdhCSdSvtThg6ycH4dUBjyOhlh6BIbtw/X9pB3gqx6cLZuOPsbdDoc0uK
dSZyKBxK5eXuN9jboT8/HJ842U4OQ15M2kTymJG8A5tc5352+XAPR1urqFhd
wI6ANr/WeXUKz0uRdmqdptHLQAaumwdn+4+SLwKth83qPkc99UgsNEjWi9yf
UY9EvcedwIGsJ9SjICu8WxvW10I9Cr1Hbr8NFbdSl+Hm5JhL9ffH1GXIHrF5
6qltoh6NYZNXMFbpqEdDMXK5KSCygbocinH42Q/yvhxpKvOcpIz3Y5Be2Owb
6NBIPQZDr4uUQTM0L8SiYnaxpF71iHosJnz3ftPfonkhDhHLOQPamTrqcbBI
enDOKldLPR7tFbs6Ux0fUo+H8op2KOc3WUhATfqQxfJO/n8C3Hy8q15puo1/
ANRnGBU=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQMC1xcX2HId3w/hfbBffqA88Cc/jM/gkNRXL7AK
zudwyJDbH8LPCOMLOPB3LA7M+XkMyhdxsFVJnZX0GcaXcHhya+e87GcwvoxD
wYR7Sx3PwfgKDixHLwmLz4HxlRxE5mk9vdgK46s43Fr+6MPBTBhfzeFkj+i9
4gQYX8MhMUrXekMSjK/lsD127iLrX0ehfB2HV1+2HPtzAsbXc7gp1xz04jSM
b+Dw7br9f/bNML6hg5WW8JbJdTC+kYNrndfS4ptHoHxjhw9u8wpK78H4Jg4z
RU+rMdjD+KYORxcLrdtz7jCUb+awMHLZb/d2GN/cYWPP3gV1UjC+hYNM+Yu5
3rowvqXDjXIRuwUOML6Vg40km9rmchjf2uHcJL7sHiWYfTYOd0QZvk/Ohcnb
OnxnvzP9hjeMb+fQmn/fyWwvTL29gwTv5RphPxjfweHfmTu6FrsOQfgNDg6+
ShwstocPQuUdHXZOXM620A7Kb3B0aLXij538/gBU3smBUyzz9NU9MHknh9oL
AT81XKDmMTg7MFfosgv+hqpvAPIVOJ7tPAVzn4tDaL/3oYmmUPc0uDhY9PZO
n+YBC39Xh41h3J5x5Uf3AwAnlNUa
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQMC1xcX2HId3w/hfbCf8vJ7SgYrjM/gcD5Ky4yb
CcbncMheG8XnxQ3jCzg0nshXP/PrGJQv4jDBtUB1x10YX8LBRDxAxnE9jC/j
EO9vu95+Foyv4HCHLZw3qAnGV3KwsHK7s7UcxldxkF8ftNAlEMZXc/BbtIFx
oSOMr+GwU2jhCjY2GF/LwUjjEvv/S0ehfB2HKMWCPJ0TML6ew78FZz8L3Ibx
DRzWr66fHfYDxjd02CU8v+/4LBjfyGHG42/6LxhgfGOH2Y94kvueH4HyTRyC
NMzKJuvA+KYOyz6rVK5khPHNHCK+ea1c8+IwlG/uUCYr8X3hdhjfwoHz/eK0
19Iw9ZYObX/uNU18DpO3cogpDufKaoDxrR3q/Cu8HkoegvJtHH7t042154bJ
2zpEXLDk2rIdJm/nMMtyo0HEFRjf3uHy+0mzb9+DqXdwCL1i7r1kFVS+wcEh
cEOI2yJOmLyjg9/vkmmlSVB+g6ND5fyZnMdDYe51cjgo1f7+xkeYficHqWU5
Yq+ZYfY5O7zu1ZzYV3EQKu/s8Izd6o342v1QeReH1rRfa3zW74PKuziUT732
y8UdymdwdWA9sD83mvsAVN7VQT57W5TrKyifwc3B7ATn/WVzYfrdHB7lB+lO
XAEz391BQbYhdzn/Cag8Gp/BA00ejc/gCecDALPZ+eg=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtI01EYx/G/ktGiy2iRpkkaLtS8lFpzNvOnm5tzs5q9UHqTJSOLlhZF
iAUrFEQyWDKjRenISkLchLQ0r/OGRiKUrZSoqNQKcWuTmlFWeB6jHTgcPnwP
zzmhRwqztb4cx0n+7L8nLb79dlHyysGuRTlSvtnWHtXyyBwqjxvdxUt9BUzf
CxvLlzoffoUWk82PvB5OhTt7fm6AOQA9y+uN1RPkTVBH5X9KaCWHYH4sbORp
J3kLnplOh+jqyWGoOXtBZ60kb8WLm/H2nCRyOBa+aLeNCsiRMDl+JfSFkqNQ
Xa/xnYwjx2DqnePwGJ+8HYfafTxlTf3MO9ChzLycUkCOw6p44fVJPjkesT/P
lPR+7mNOQPTI7L5AMXknjIaSmSJ7L/MuDLa8PSkNIIsQbfUYRs025kQ4h3Jv
jOaRxcgzuLgT/T3MSRAZtcu6JeTdqBL/aJsTdTNLsLe8MaLUQk6G/+pLIour
i3kPFsqeqGbLOplTUNdwfoPPdDszUJu0v+JKdtui9UDV1ftmk4x6KjqEngHu
IrM+FVJ5pMAhY/e5NHwUFKsqHK2sp+G5cqLBrnvMuhRrusKDZwZovhTTQkte
82uaL0PdPb5zs4a6DFOv1OZOFfV0BEn8T2mvPWQ9HcMKX37B+2bW5fAErYu1
qltYl+NOk2Y8f5z9h1OAp9kYIU6k+Qo80jlzZ13UM3DX0iDLqn3AegZswuCQ
Hjl7j1Pi3NCtDwdKab4SPPfX4cAcej8TMXbewUqzlfVMvKx5c6xdUcu66n/r
vcypvbqXuSyv/s+/AfwDO2M=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91Ak0FfgeB/CrjdemrC3UzYthVONSkkl9EWXLvm93v1RipKbG4LYoRUo1
iZFRkzQyjdJiqXGzhBiKShPJ1uI1ObY2k+n1Tr//u+fcc8/nfP/f+73/e+65
C4SRHpJxHA6n7tPzf6/sMaP15yiryTXlnzWwWmlYq+kXVWYOhE4/vTs5lVkF
wqmpzib/3CLPgFpN92PVMWYNuMc/6r/WzjwLuY8DD/beY9bBRCMbc41KZi7e
tVwyfpHPrIfkw6Ki4CPMC7HAtTo6NpDZAKPzAtQMrJkNoTNv2c63Y9XkL7Gl
3OG29XnmRTCwO3YuVo15CRrKfPY3dlWRTfBdSfP88nZmHvZtEGxb7sBsiszX
JzXcuivJZphV6N59eSXzUlQFP7J6cpx5GeZy+sRrhivI5tgQ/v3ckl7m5dh5
LHpDpz2zBczqIle6TGZeAfPQax2vpzBbInVoy2hQ/03y1zAsm+T1MJ55JUyK
JTzj/ey8FeyCeX+ZyVi+CnpaPbGVA7+TV2PR3eH9rStKyYDlfpczPVtKPlsO
2Hm86+62K6bcGqGJYcopWkWUW2OabtyO6dmFlNuA+5c8ZuKH85TbYFVlz9nm
69mU20J8wc02YV0a5bY4Hbpp0eW+nZSvQW7yuLjAkejVn/M1ODNc3uPvveOz
OXYYdNV2VQ5Opr4dBNWHkiJfJ1HfHh03JYO5IYmU20N/4Q/mHxMiKF+LET+O
cawiid5/LXKzxqtGOaTT+6+Ddkcm72h6LuXroBN73PIl5zTlDjB0GjHlpZ2i
3AFrip8MPRadodwRrd/8+KxE7SLljujtkRq1xBRR7oSjad7Fb8KvUO6EeMMt
H2WhVyl3xlDTLH3L38spd4b+Hv+yl++uU+4C/grupOmxCspdoOvh9latnsxZ
j10xv8W4XWH5emw7wh+sUblJuSsyGj1Em90rKHfFcyuH8OwOMscNNRG82kbl
ys+GG5IvxMaJzdl5N/jatz/JdiEr3LDXfd+OX4JY3x2eeZvPRsWQ4Y6xa2N5
p/VZ3x3ymf1mhf9ifXfkVCjfdl3O+h4ojMzXbz5Bnxce6P151/sxFdb3+PR/
c2aOYy/lCg8MZiSaJjay+3kiONAzIVLA9j3RnTVV8JpD95F7Qiqak2ExRFZ4
osbXqtjMmMzxwvTGoWXRbazvhQcmo74nuti+F5yUNrRUG1ZR3wvRb7Sdv/g3
meONN6KOzsIDZHhj/Obu9ZxnZLk3gjT8nqrfZn1vTKvi/6i4xvo+sA3r91XL
Z30f8O54jnu/uJr6PqgY1X1g//++D6yS5u+O7WJ9XyhUXqVs1WR9X1x/E517
UMb2fbFbXfPViX52f1+MGmeMnPue9f2QnV2weR9Y3w+h8T+0bexj358fdPKa
2ziz2b4fTERLW7ZdYN+fP2zvdhjYcNnvxx/naj925ViwfX/UtUdXa42yvj94
aupf8d3pfpwAnIbOhev3yQjAiHpsy0+97P4BeKv5IdAv+hb1A3B88bKo8Iwa
6gfi8daVY+9qKEcgjLJqcy1sKJcH4p+C5KOHbMmKQMw04XYUtrJ+EA6bjuVl
a9VSPwjn2yq+ND9IlgdBdsomsX5OHfWDkBaRrmxyjXJOMFQTLCuuZFOOYEQa
Hb5U9pYsDwZvQNxg+pL1g5HTXrR36CGZE4IKjzivBTzWD8Hry/3V/zG+Tf0Q
bP/V9sNQQz31Q9CXIQh9KCdzQlEWdbZlrWMD9UOh5u6i8WsAWR4Kn1fpTXXh
rB+KK5UpmRdLWJ8PyYEr3V8F0XkuH8Kg/ibXJ7QPPhYv3DR3vJjO8/mYUGXi
1BVFlvOx8/37vJRiOp/Dh8Ge5P5kZsWnfrVlZ+8lOt/JR2pcu9edY7THEcCo
WaUxjs/2BVhrHRtSuofdR4DVN3UPK5WT+QJE+6Rnts74g/YFWM+bnC7VJecI
8G38UudVPk20L8BVfvmR4CpypwAxeTfu3lW6Q/tC7Evycnn+WyPtCxEkUvhK
9CmHEIf0tU0DJGS+EIFTbqxU8rtL+0Jst5oxYVMUOUcInZRws6xaskKINu5A
ae2pZtoXQiVr3smlVWSOCNs7VrT55pK5IrSOH3XqX0SGCK6BT3nl9mS+COsa
Dl6u9yLLRcjYkyaRNZBzRChwVq6bOUZWiKAi6x140cP2RYjvi+AdXt9C+2I4
D2mFfEwgc8Von3rfd8Hke7Qvhk1BfETCEOV8MSZJ/nzVM4FyuRgWL89NVHYg
54jxOGn3lgYrskIMt5P37ie2kjvFGBfSZPi35n3al8BvQeJzoZTMlaBH79ui
0hNkSJCSr33ftpzMl8Do1hLNYdUHtC/BdvWF8029yTkSFC0ZrtfsovMKCZ6t
0jHYqkx5pwTXCxyK+vXIHCk00w5xx2zJXCkuqn9XuHEnGVL0bcxctraCzJfi
kL3fjLoeti+F3pQXAS1yti+FXUlHqnU7WSGFIFHQ1bCrlfalOL9d6dLVCWSO
DNGppV9rHCBzZdhw1qHUMJUMGbbm55eN6TykfRk+LC3Tj7Aly2UYjAjc7zb/
T9qXocC1aNy5b8gKGbwvWKRpzyZ3ypCm1791jweZE4an9weX6I6QuWFYcsNx
r+yLR7QfBsfMgT9mnyTzw+CwcDm3JIssD4N9sqquMLqN9sNgPq0suzyerAiD
/41XowZl5M5P5/dV+OzmtdN+OKbV/62xSty++r8hQ+/t
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10ws0lHkfB/Ap2UJvsoiU16hNtqJM6ap8XUqK3A0yY+6DNiJyiUy5vMll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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzHlI03EYx/EflpZGYOUfIWpa4rFEKu2Ypft4bk5NzGOoaSIoeKViLvDK
P+bEPLAg8UKYFxrhXRrezoOxDI3MAsmEPEhTyRxmTSp8vkR+4eHhxfvhaxGd
fCtGh+M4/Jm/mz3D2boUZ4OJwX1tCnKW8yxm9Jg5LE1MV+nujJOPwvyHtjpg
mdkQ0e0+TsOLzEYILDpkfG6E+TSOm3Z/r1czmyDK9nGaJJ/ZHCZBeS4twcxn
YcAfmxTHMFsiSyp3sBUyWyHz1CxPaMRsA+WHPn7A/BiZB3XrL6lVLbMdinc1
ITuNzPaQiYWH0/OYL8A2556G78l8EXHGDYGTbaPkS3jEcx1NqGR2wNyrnqKh
n0qyI8T+ywV+U8yXIV5/Ur5Qx3wF2sASRSrHfBUVJe+tbSJGyNfQbN4V/MWG
mY+kxsTYSEdmJ6ypWmR994fJ1yGVuB0pqxwi34AsdEPUP8LsjELF2J3d1wNk
F+xJ94RpvH6yAPptA50yTS8ZODP3Rp4sop4LyPfm/bl61l0hSV3fkMSRc11R
qnSKCNF/Sd0NFeNma006PdTd0OT+OeVuB5lzh313lUYQTve57qhoVwekh7Lu
gWPlUSt8bRd1D5jpfl01/dRJ3RMLzdatH5PaqHvi3UN1xolsMueFqVVBcUZc
B3UvGAzW2zQWP6MuRF/8fN2wsoG6EP6d5+c6RQrqIizpBb3oeVBNXYTajm+F
6Vtl1L2xHWmcKC6vou6NjNiZpnxNMXUxwjZ1V3qLMqmLcVtV07tlWUrdB4tB
zwNV2izqPnDejs7STrP/fdE9/1YhCSui7otItxg7ZZecuh9UJ5+2K2oKqPsh
ftchOzwhSrDfb/7v3APm/A/0f/4NghhMYA==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdywlI02EYx/E/pc2VpFSG2MIpUs2VObc5Tdd+85rmnBoKglEwDVQcK4JK
81hGaGWnZBaSSC6zUubtQtO8MuZRIE2h8mRqYE5iBSVd+L4Ee+Hh5cP3ebzU
2qMnNzAME/Z3/v30uZofnZJuft29Lqvskv70h6vO1Awy3vnzZCxqJ/zKze42
WgeJXbE6pOJNzVPvANvDQZA2Qe2Oxxo30XInNQc3ImQySxk1FyfS45JUBdTe
ONaTfLE2l9oHD1M9bvGyqPfguDmkyiSl3of2aOdSL+sAsS9cWIHc/Bnq/QiY
F3q2VlD7wTaozdFIqP3RVSxXV9b3EwvwfJUXND5MHYDpGNODxRxqIbQtjY7T
TtQijNZNOl5L7SMWw2GTJeupM3UgpvJKt7lU9RJLkD/yXVEopg5CpfSTkpv4
ijgYFVvLpSYx9SGkJdWMff7aQxyCb+6cjIIDtIfizRdPToontRRRuRp28hrd
PwzWnNHonUQtg6ta6DXe000MFIqqbWUznevWAXKbpKLJ0kW6HPIns4Y7wcQ6
OVbOuuj7HMg+Ewa3YaGP7XcH6WFg5vRLouJ20sMxnZypOf+RWBeO7MsJ75ev
tJEegXtc/VjZXWJdBBQ/B/i3+1tIj8RKiZ+5c7GV9EgIyg17DTzaoyAuSeE3
CIh1UdjOWTh4P53sMwrwMSLpuE67ArvDf8zuXGoiPRr+yrcLsw3NpNuZibHr
dmaO2HU7M7F2PRYv85qLJtwaSVfCVyGsfNHxjHQldt3kM0V+BtLjkB7fOMjO
bCA9Ds1rplFtaD3pKuTnqTeeEdN7FZx6JyU1Q7Wkx6PuHLvcvFBDejy2WI2s
UAu9T8BcX9uFxIDqdeO//wBRm1J7
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n9ME2ccx/EbboICG0wMLAVCETpsHIGKsq60/VRpkZYfLdAKkQVF5zCi
MIfgJqmNaNkapugE1DQgI04QUCZLJbhCxfkjosmIBsgQ3ZKJqIEU3ZxWXbal
3+efu+RyeeX9fO/uuZywuCznEx+O4wr/O/+/siNorK1cvvDqoFduZcBue9mA
LzOHbTHKrN/8mf3wvL51tNyHOQhxJs+Mw3OFHILwyEdVO6eZw2CdaJn64DJz
OCrMI0O+7cxR+PhEzbX3v2aOxg+/Su9cMTDHQOSZCHw9n1kE4bWdoZN9l8lx
GFO/czSkiFmMLx+q7jojmZfBKdrf/8KPOR798zwbJwOYExAhVDwsDGZORGDs
V36qn34mS5CTL1ooDmZejsfT+XuejF0iJyG0ufRNUyHrK1A3cDwxfRfrK/Hg
Bmq0N5mT0ZP+zDxbxPwhSv4wVDW/GiJL4Wh4mT/Vx/wRhlqG3fUiZhnGJMM3
gysuklNwq833ou2YiyxHnrPTJ/zZIFmBb/WGt9L8WVciW5zaueSckwzEeDR2
ccmA1xZge5TA9kDOugraBYE2bccF6ips/P1W7HVBH/VVWLuv1tS66Efqq7Bj
3dnpxXPnqK/GU2OdoD+ZbFmN1vU7wuxHzlBPxZPBbVERK3uop0L23uFL0UNk
To1A3aPyETWtt6iRv8m6wfxLO3UNpJ83TNQruqlr0O3rDgndTObSoOgtUMz5
nKaeBouqc+kbM6yvwQrP+In9j9n91wBCyT+Oqg7q6Xi1qMI/w36Kejq6wu5r
I0u+o65F8T3N3+EH7dS1uF56v7kpoYm6Dh19jqS3hyuV3q7DvCBd6AHjAa+5
DMyM/6kXx5qpZ6CxIMAmi7NSz0SXbCC35Uwd9Uz0yN3y0/X7qGdh9vv4uRR1
GT0/C1ul3Usrd+VQz0bbu5Uat6Sa5rORuClr1Lh8C3U95t+I2zNZvddr6DG8
+6Qg7N4xWq9HQ2NB49MLFV679LgtLPtrq+AQ7c+A7WurZePPj3gNA6RTdyIL
nbX0PgZEf1OStLfL6rXLgHaHrWi91kLzOSjorbVKGz6l5/Ns4dnFM5fLm8/F
ktLsqycnvqD5XDgjdE3nU9j789Zzebx5ni08u3jmjLx5I/yK411tp2po/zy7
jJCM3k1OVtTR/k3I2zJrrgk6TN/PxJs3YeT12c8SMul/cpmgjBc36wJ6B/8F
Gna7jw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1z3lIE2AYx/HNGi4dMmuW0BIvTOcUXa7WdO7nMZ3OCIVWSySpzAvMIw+G
1kpBk2SGUtYkoywCQ0smeeTmkYYGhoSIKJg1BDFj/ZHaRQe9zwsvLx++Lw88
fmcvZuS4cDgcxd/776UjnH9YrHJ7bf8vp1opCd0b40HmQCOtzy7nk/lo7Ixy
mnaShdAkKaYLHJPMIni5BGzr35O90WppfBAyQxajXNn8XdxN9sUid6VLZib7
I0unLrtaSg6EzO9m+rqKHAS3EXvzimOCORjyubJv4lmyBLz23z/3LZKlmFJ3
X0rvJIeD+27i1Ek+OQLPzQE5YU2vmCPhNWafd60myxDxNcScrycfQlDR3K/M
aHIUlKVi7ylfshy3IQg1WceZD8PWLDyfl08+AtuQpdrTn/4rEN6zq6v1DPWj
WBW5Tg1sjDEr4YwsrNhRRY6G8rKxt1A/yhyDet71R7Ncsgr7cwzDogByLD76
eBs73MlqeKyJlh4baR5QKb1lUxSzbgIkp9sHtww21uNQXHn3s2h6mPU4VG21
WE1Fg6zH46V8vaOnl9kUjycVT9PqVC9YT8BBra4uucbKegJGM89N1vhQT0SD
8xM/0DDAeiLu2Y3CvFyar0F4//E7uxv6Wdcg9k2YI758iPUkCIInT9z40sd6
EkqC0wTX2mnfZGS03JeVtNB+yVj9sG151kZdC92xBc/NNepaWKy8ZfMF6inI
+7GxYKkdYT0F3OXRPt9WZk4qCgTVe5auUE9FVqb7ppVHXYfaxrfcA540X4eh
puzcjZlx+x9yLxLD
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0GtIk1Ecx/F5m2kqQ22Y1nIyLUJsc5qXOf1tzsu8zCHeEkNazrJAB/oi
KG2IdrHQMiWsLMsR5XxhhJXmcraZoRYUaCBBMBXBFHqTaE260PkH+sDDw4fv
OZz/c4S6mny9K4fDUfx5/37p4X3qNci9J0b/6VvKbk+bnOtJ5uDt2J3lSXfy
DiyIJjUxXmQe2rq7QovW3jAH4mFPQ3zNKjkIHuOl3OlF8h5sBF/sdy6TQ2Hw
6movHCOHIfzKx5uSZrII/IGrkU3V5Ai4R5eVeEvIBxDoG6W/H0A+iLs/Rf5T
znHmSPjrymZkwdSjoO1osfEc1MWo77ulMXSTJdhIks8GNJKjwf/c2OqjIUtx
zTS1s6qGHIN2S+z7eyo7cywURQ2m8jUb82FYzX6PZXHkOLxI2jcjWSLHo85m
EFjqyAnI+GCxD50lJ0K8V9784B1ZhvMhys6v1eQk6GVc34U+shxnnId2aUto
nmRM5ocJhxfJKRBUXhiRdtL8wPV+rWN+idkIeEzMKW1qWq/AZkfLs9kcZqMC
AnuuWZdH5ynhpq7cz5m3sq7EdG3QinDgFeupKBeeHNQljLCeCrdLpr4Ck4V1
FZylAvH3L8xGFUJVLhWn7S9ZT4N3oSbSTTrKehocN/LaThUPs56O26uXzefS
qKdD1fSjrps3xnoGMh8lF1l7ab4MdG788qvPfc16JlaOBAUL19l6YyZcKvLb
ua7U1QhIbN1MDKGuRmFcf4RrMvUsHA+vqNpUMhuzUBtdbnrKp/vJxrHlE9KO
J7Q/G4Ojeqd4jv4vB899RAWOdbqfHFjrRfyjfrQ/d6uN28zRbOsa9BSvDZlN
NF/eVhu3maP979/NxD7R
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zQs01Hkfx/FBcqkt6bqniyGpqC0aUiqf6EauM+6XuZoZtlpdhS6mpyu7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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQMC1xcX2HId3w/hfbC/nz2921UAxmdw4PoS9qSa
A8bncFj4y/uuyJdjUL6AQxz3ijILOF/EYZsv6+nNd2B8CYea6Bdnua7B+DIO
L9nCfPvWwvgKDj7imiHxfTC+ksOVek9TWT8YX8VhhbZmxTNDGF/NgWXNtbql
z45C+RoOdokbrOPfw/haDsvsZm5O6obxdRx+rRYMW9gH4+s5cF8sjN9nD+Mb
OMxycviZbAzjGzqInWcQ8cs6AuUbOfyyuFEx9d9hKN/YoanmmtjN1TC+iYPP
rr0/EnJhfFOH/Ty+nZPiYHwzh+3J+4QeO8L45g4O6auWp+44BOVbOBxbv+hG
X85BKN/S4SZbUfZ/HRjfykHs6x91u90wvrWD/DTPmTYBML6NQ758J4uDFMx8
W4f1ljNZK4xhfDsHDn41p+VeMPvsHVY/lj/0LBym38Fh6gad+rTp+yD8BgeH
bdHMLteu7IfKOzp0iWhvWBQI1d/g6KC43fBuQAjMfCeHmJWbeKQeQMOrwcnh
YZnMSbPbsPBzdlh55p/ilmdQ9Q3ODiYGmWmptTB5FweVOxKLZ6pDw7/BxaFt
4cdNTz7D4tvVQeZYcpZZKcx8V4cXOp+OFtXB9Ls5bFJ5c77wKsx8N4cKo+/T
im4f3g8A8ATmTQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz3lI02Ecx/GfRrZMQUUrPHLaCl1ieTvT/KjbvPIqQxBkqSxRwcxEu9AV
KBYqUWoGWdqISMlaziOXt86STEilJDw6TPBKm0h/mB30fPtjDzw8vHg/Dzxf
h5TTx+SGHMcF/tl/T1pm75TZAcaDXf+0Emj9+aNdpRmZg8g3ubvaksyDs7HV
95N7yGawbViarrYgW8J0h3Pt2g8t827sSxKkaifJtigKvyiaHyHzMcW/k6ht
IzsiwWNhXlVMFkD8y7zRM4W8H1Z8rbxUTnbCRlGVxuc4WQjh1Uclhn5kFyxs
jZd1HCC7IlMTXDAM8iGshRrFSVzJbhhqP6sb6Rxgdkf/y3r7h7VkDwyYr2bP
WJI9YfOAH1Rc18/shdzcMxlDNX3M3iiarYnelkD2QaaBb4lysJfZF6MxDhXP
x8kiuB+88HPRmuyHaRPPCXVtD/NhFPb0aIRd3cz+mMtrbqirJwcgx+u127PZ
LuYj4L2dlKWWUw9EWlxW4odmMjAnKOnVxDIrAIV6au7VjQ7Wg3DfxsUxX0w9
CLE60XjABr0PRotN+t34aXZfEYyZjLx721VtrIeg+uZE4ap3K+shsE8T7Fxe
py5GWmU5X/qtmXUxqtKTyixy1axLoJOc2CzgqViX4IrbC/VQEzMnxdjo3nyj
xQbWpaiMe9O+ea2e9VCEXHdXDvQ9Zj0UkZ11bZdMmLkwtOa0tCcvNbIeBp78
k5P/CjMXDqW/gbmi7Cnr4RhzkTVy6/S/CFicrxq2EzErIjBeusXbVNXCeiR0
fNk54TLNFwnRqV1fJFlPWD+KTqw33fp6m3U9c1F6PQqpWVaX33dXsB6t1/XM
xfz3b8DMRn4=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0HlI02Ecx/FfBWpGuT8UNSQ8Qjo8MzO1bR/PTZ1zSoUkQkjaEjwqLVuR
06YRaaRRNIt0ziMw1DxKvLNVHqCifyiaGIaa5kRzZLHMir5P0AMPDy/e3wce
HoeEtJjErRzH8X/vPydbvDFtOt/8XddfrQgLv02rFsyYObhnOaWe3cVsBtfa
0POuPGYehl1qTlhYM1vCNSdwbfDnW7IN5No9Fyw/Mtsh9dZAqbqP2R4mjrlR
5mXMjnDZ8TnPI4d5L1b9wtcXspidIS+U+iyAeR/Uotx5N8Mb8gHM68rK83KY
XaBPPljHd2J2g7EBXVWTOrIHNN6699cbmT3x8OZiXY+a+RAidKq7G+7MXmja
vxj/8spr8mHYTWcoxLE9ZG/INuYWTaKYj2BkSpVyw4vZB0kKTbTf7CvyUazd
n4ibcegm+6Jvsqkkf7OD7Id+nfXMuFkn2R+lQ5/cR8OZj0HauS43rWwj8yFp
m+/W9LaSBdApFHoJr50shGFOvdx+nM0DMRWXv1TvpnklMPTDTiawf0E9ANsm
zsUXXWugHgBhk7de2vKceiAEpmlizUgd9UBEJ+sLlyfJXBASnUO09bNa6kHQ
G75+H16qph6MzFVhSpvvU+rBsCq+86jV6gn1EFQO7RzNtiUrQzDVaLiUv/SA
eij0ZzQWlhvl1ENRH2e0KisicyLITjlfLDZWUBfBporvyYsjc2LYdm9fDR4v
oS6GcUDVXO3D3heGLZkJAwotux8Gr9tuSXyLWurhQAH8Pfj0X8pwNGeYX+19
Vkk9AqJpeWzVhxrqEWg5md7jKaP/4CTIttlcf3z6HnUJxgoG+8dWBNQj/7cy
EgFcR23LXCJ16T//AvfPQEQ=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1z2tIE1AYxvGlXyylaReaXW0slZK2uXlp7fLMzS3EqGZmRjeUIdQgIYKg
aMPExqikD33LkWzkpsaIrOZ0Llypa2MUXYw1oyC8BWk4C8m1is574HD48T+8
8G5vOGcwpnE4HNHf+++lkz3uaFasGg3817xq7sbc0bVcMgeJyTc17hxyBj72
Gw8J1pCzkaOf8DQmR5jXQez7PNU0RebBmWHL7Jshb8aLyKviSzFyHoSz9VFL
iMyHMrx+psRFFqAnEc+sO0vOR6Mppn1wlVyIr9Hq4TNV5J2ISFfeN8rJRbie
6s7KjT1n3g2lrPtDUkcWwb61oPSggSxG7duHv9315GIM+qPWW55nzBLw4nd3
LAvJUpxMcKdF9iBzCSbryheTXHIpfkjUml3OYeYyCM2uzv1icjk65+Mmbzp5
Dy5ExD9HXU+ZZWi4Ft50uJq8F4qB5hqVhSzHvpYToeO1g8wK3NaIm7wbB5iV
OKLqShXJhphV2HDAwzV1+JkB23JbYTCdzbMA3wv8qZY8+q9G1rub4W1mNt+i
Bvyh1Ysd1CtwmTc+8cVDvQK/xgzfNAs0X4Pw+cen2toDrGvQHvS19qR5Wdfi
/bErAiv/CetauK2zkul8Zk4lpAsXy/pGfKxX4jXf5s1don11eGk2xota+1nX
oeq0ZuyOvJd1PZacDntwSxfrenwauufgrngU+AMarPih
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10WtIU2Ecx/EzJzlMYmIjDcWKMrO2lvN+22/zsk2DSrNMSyUJYROakU1f
GBM0pvkiC3UgZE4NNU3LtDYFM29hodmMKNhKJ3QxcBClFURFz//A4fDh+5zn
cs7Os+czz3lwHBfz9/73pEv4ul2f6D0z9l9uudlLxK/1IXNw51R5HNtEFkB8
v2WimUcWIqcme2Dz2jTzVnRIbxcL3WR/rIdZ3jXbyYGQFg00aG3kHRCulrTE
DpN3wbA2W/qrn7wbFSLtW8kNcghKx9ts0lZyKPqXPAvby8hhcJ7wqwqpJh/A
Wn1Qr6KALEG+51FJkRdZiu7Tud+idFPMhxA375txjUcOh/P6VJOlc5JZBusd
c4AxnBwBr49vXi3uJUfiilqgjK4jR2HLRtDCBz+aLxo5l2Jj5h5Qj4FqxWDI
/TTBHIu+tGcRG3zqccieMPvn+ZLj0RggPhgqIidAZSvsMcnIiegcqvsdGUzz
JeFi5Q/e0OQTZjkSFcVCzWfqQHN7eZPcj9kIhJU5uguWaLwCtY3OkdGxx6wr
sMFx9p/Px1lXYtnxkHe8i403KmF16ezbO6kno16pXhHcpJ4M254emGdo/RTo
795SLNaw72NMgePCmVV9NZ0nFe91Ha7KadpfKgJ97MH7NWw/XBpkmfzGy9vo
/TRoTpU/EgTS/1WhNX9QPJLFbFRBmicyJeifsq6G+7vBo6SBrWdUwzS6ENxR
TufX4Os8p+0T0vk1eGHRthxW0/rpqLj60juJP8p6Olz7jmTd67WxnoHldVnT
l5NW1jMwNxsv7xocHvsDtJ0XrQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zntIE1AUx/EVBVJCUglGFrXZ0pXp2jLnmvu5+UpDzWoDYy4KlSKakKGz
KYpOS+glZCrtHyW1NdOW0ZJk5WNaSplM9ofaH4vKpMBQAlN60TkXLpcPXzj3
7Dxtys5bLRAIZH/vv5dPkK+1ULVu2P1f8+rvpulT9wPZAhy/bZGPrGUHoAiZ
ee4lDzkIK52Vw+0L7M2oC8+2nZ9jh8ByQu2ZHGCHYubTJvVoL3sHFnTtkpVq
thDC7Zr8W1Z2GOoUr2zNpWwxfmi9rfZodjiuZd5TtoSyJfA0dx9b/DBE3ovQ
tpNfDC3sfejbGrx+OYEdjdK77+X4PUiWojLiV4RPzH0/Gi6UPcx5x10G00Su
3nmRLcfub/NJSyHsAwgb+uqdnRkgxyC20VsrKmEfREl9dU/B5X5yLAKmBOeC
rrAVuBOun7IkviTHIWOwQZex4QVZiZyx2Q5zvJt8CPLy1zeCl5+TVRDrfXPC
iV5yPNKOLG6JjOwjq9Ffa71UY+QO+NsHXEfV5AqgOPDtmCPMRT0Bz97E6Qua
nlBPgPLnzY9rvN3UNajPHj8jruqirkHVeJFfpXNQ10K6UeWestqpa+Evk3Ta
Jh9QT4QxoKbcqSBXJMK5WJX7NJ3nJ+HsqvzGti7uSYjqHTJapE7qyfBoXem7
ZI+oJ0MtijJPC/n/FDg+72kqsndQT8E2c3HMVV8b9VQUXzcUGkZ5/1Q094hc
WSM0T3AYtqz64Hz5Y/cfaT0DMg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzQ0s1HEcx/GjCdF2a1Is1enpKrNLoZLuc4l0Hu6ODakwdbVUaO5KrfFX
tqK5LlunJ3pEmEo7Y5466pKaitRlNWvoSZmGHpFqvr+13X/777/X3v/P7yeI
TwpTWvJ4PNnf99+XPXzT1WTfKc13JvRF7KHNf/LGmpmHvXaaeEsrZhsIRJ5J
38fvk/m4U9YWEDzM7ABDfXq01yPmmbgg1ndsqWGehYSlGQtmX2Kei8G+oYSj
BcyuSA05lv2imHk+gjZPudygZF6ILi8LpUTDLMTPns7PH9XMS3AzarX+g4zZ
DXxT7G79LGZ3WE6PbvOvN5JFcHUen9dbwLwMF0XLop0imT2g9mou/NJyj7wc
bZaxqn6OeQVSW57HRSQye2L/yWLOuYbZC+2Fud36m8zeOPH+QU9nHPNKlD82
bYsqYV6F8XnNzmGuzKuR+c34bMfYXbIPDksW87/VNpHXIMfPPs/YyuyLXbN9
NDtHmNfCLlpUlV3fSBZDquyzVr4wkAHtWFtuDJ/MAXMeZQj2RNRQl6BrpKhy
7UA1dQkc5xz9pbteSX0dNiWk2Bt/sL4O3vfj7laLyTw/6B1jA29MovM4P+Sl
qG13JLG+Hlndae8WZtVSX4/WM1MrVLbsfn8kqOqMo4f01P3RF6OucHCroh6A
pQrJq0G7CuoBUA037fe2uEV9AxzE3SONjqXUN0DqmHZbKiyjHgjh5L59keXF
1AOhFMaeznxaRH0jMioveCvnllDfiIG619sjfOg8nhTZ5208iirYXor2Vgsn
QelV6kEIfVhVZ21H5oJQ/cvKqvw868EYbu2f4dR1jXowRFFvC3M/XaYegiVj
7TcelJC5EOTlH5mW//kK9VCManNMgkwyF4qugI5R4ddL1GU40KLpVXfmUZdB
bkrXHQ/VUZejt+zxS13ymQlDjuEDLtoV4afofzmCm+R7Be3aCRvkSDwXn/K0
VkN7BW516BYdy6EOBTy3liWHjZI5BUbONgz9lrG9AgUXDxpsVFm0D4PaxV1o
GDpJezNzZjaYmRdutjcz999/AKg4mdA=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQDQMC1xcX2HId3w/hfbC/HW+x1osbxmdwUN60Y3UJ
XJ7D4ZbZHltDThhfwKFuuovUNDYYX8TB+3awh+GXY1C+hEP5IQ4tjUswvozD
7KdvlysehvEVHKruSV2V2QXjKzmES3sc7O6C8VUcfLWkHf5kw/hqDvL3Jsct
S4PxNRwqXml9fpAA42s52Cje/zfFD8bXcTgu8Ms/JB7G13NglmXYnBUE4xs4
XJ3bOPWNOoxv6MD75bPBxDtHoXwjh0Cx95XTLGDyxg5nL87sDFgFkzdxiI6f
nvFAHcY3dTg6b8Luayww9WYOfn36n4S3w+TNHUx2TtijsRDGt3B4v/bKlVJl
GN/S4c6/RvWEsiNQvpWDkKNJzdd4mLy1Q2rt+ryDyTC+jcP73F2XV9vA7LN1
eDXtu1d2EUzezqHwy/6/i9hh8vYOzbZFr7/JwOLLwcH5hwKffweU3+DgcO98
XnzXTJh6R4du/QsVQp5Q8xocHXp2Cv5+PQem38lBaKLV1GeJMP1ODmte/7lU
M/3ofhW5GJclj50cPl3yTRKIOLkfAHDtyCs=
           "]], 
          
          LineBox[{{38.30504474045179, -0.198}, {
           39., -0.17899293864450408`}, {40., -0.1825524179311543}, {
           41., -0.19069035535569626`}, {42., -0.17755713285187127`}, {
           43., -0.16807112802260818`}, {44., -0.16422813515418858`}, {
           45., -0.18700429746746458`}, {45.68166985379153, -0.198}}]}, 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0X9QzHkcx/GvpuJ0Y3fksjpcTNaPQj/I1lq9trRbSe2uzFDcH1EzzbmS
MH40U4PZs8w5aST5FU1F7irFavzatbjkDynSmagOU5i2pcgSFuP9/sPuzHd2
HvP8vD/7nv1OSsnUpboIgrD0y/P1mz/ittK1ipENpm96Ge4t1gcaRWwB4p8y
vPpHsUdAUtCmlnmwxVh+J+fERse/5DEYI5kwuGeILYG8f+XTvgH2eEiyVaGT
O9g+uB7mpi+2sCfDc+BVurGe7QvHs0f2AyVsKcq7BHnCbvY0JCuiDqbo2TMw
rqHtj1wD2x/LMmffnhfCngWHy02re/MNcgBiRVNUVeXsQNiyYgJ1vdfJQchq
HwrwrrlGDkbh00ZLpJg9B1bXglZlq4U8Fx2XU7t9P7FDIEo2X2m5xZ6HYUH3
Q+pz2TJIfaSY6MIOhb6l6e+kN+wwVH6Q14Ua2HIkVfU2GUex52NTUf+Owfyr
ZAW8JMmlbmvZC5ClaqxV95jJ4WjqcbwfPZE78OLkusGmA+Q8oEdp17cm8nkl
oH6uVwWbqH/xwwnNj69coB6BF537HhWdOUc9ApPsEWE5+43UI+H3+ribj5J7
JLoe3BkmqqijvhDayxV3tdpT1Bci/fjvmrqSf6hHoeD/odl7P5ZSj8Lq30Yf
zG+n84IKp6Rpkpzo09RVuLin09XeWUtdjbpt2ePc7p2hroYkc9PmnR18fzTu
1RaH2+K4R2PlkyOH97+nfYUYbP1zzfaqtBrqMfCcK99ywlZNPRaXytwTTfN5
PhbFsjSf+ni+fxF+HvCLmpF4lvoirDL8YB1+iPeLwwLHknyxB8/Hoeuir3tf
LP2esBhzojN+ndpL9+UthkU2fmajjM4L8chvtlqmm3m/eLgUTvsxILuSegK8
FNJfrK9PUk9AUmOxo1tURl2DlmrTiqHpZGhQ6ZW+b5crvw8NPo2sPmfYWPLN
Zg2KPPqCjMpdNK9Fa8Ox4MKxMTSvxapIT+8Km4LmtahMqX7SvWU9zWuRVhbm
cfbwBprX4dbRfnvGA7oPOpw/5P1fXzvvq8Nb/yQ/mz/tZ9YhVSjPVf/F//+S
7w0n5znZ7GQh0WneyXlONjtZWAqH4d19+eMa02f/3bRn
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zFkoRHEUx/EbQpbpkuIB2TNjyXoxtt/YipqSKU2eUJa8kCGyNBPKC1NE
HpRIwgNvsnfHOtZRZMsLSiPRGKGGsuV/Tp1On751AstriyrsOI4L/d2/S8Of
j9eluxjFfz1nBkZ7d4gcmYN6b5tb+9xmdkZkrPyt/5vMw2eWr9F/kL1Qxn0N
hZjJPtALS83iItkXH6c71p4+cgByHPZdXRrIQTCqLHemfHII5Nc7woEzOQx5
MxFfD7Yt5nB0zznxGCHLoE+VJmv7yJFAy5xU1kWOxrzmYnBAS46BtPLSox/k
WNxkqe6r/chxeF3WtiCKHA+JbcXev3GTOQEax5ED5eMGcyJys0c1XDtZwJOk
qVOpIifhXbexMtS2zpyMVrdiWdvtGnMKjK1meeibgVmOquG87N4o6qn4dpXW
X1qpp2FiyipMGqinQ+jtORyOIWfAvBqs9rxaZc5E/djzbFLJMjNgqrKkFJ/M
/1sHGOwEh8NS6gosTD/cuk+yfzoFGgvOniSmddFSeLRwblPg5VhZzqt3xR8v
V73D
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90GlIE2Acx/EVYaUkE4xMZpk2WxLDK8+mv+m8pqnMIgUjb7S8oqFhpMs3
ZaYvSswMUiknE1OXpiHNNa+VF+GxSkM7sBdhaVPMY530/Hvg4eHD93keHp4D
ybmytK0cDsfvz/y70uC+up8nMtdr/2kpoMYn+7OFJZmDs6knZYsW5B2YzzBN
XPwxyMxFnrq1VrVGtkZdtGCy5CvZBtODZd2Wy2QegteiywVDZHuY5V+3mv5v
B3jF3B1raSYfRObbxD0bRWQnuBvkVf4isgA7Z3pHWneTnZG+/GtWxicfgZth
i3C7doBZiDrb2Inw22QXePrGqdQysiuUQoVsPJHsBuXlPuuBZLI7+tfd3mV/
6mf2wFinrFHSTD4KV3mCSnue7Ils3rjZlDOd90L8G1ns8jp1b4g9CtMr2sk+
OFO/0VjV3MfsC9UqrydrG9kP7kLb7/3DvczHEKqbSjHVkkXwr1wQKHVkf3yQ
FPxcWtExB8Do7fBeU0AdaNjnVJHZxLoCkA7lVpfqn7EuRuaDobt8Qw/rYqhP
7JK/tmPmBOJQZUfDBd5T1gPhnJQynCmmHoTykpqcl20a1oNwK/BUboiA7edI
cEPj4piTT12CmmunR0tXu1kPhnK/VWqSsYv1YEhruXsn9Z2sh6BrNKpIzmdW
hGBTX62ZCmhnPRRNh7NCW0eYFaEwzds+KT7XwXoYrqbFx7ga21gPg9yA4viU
h6yHg7/4JWom4xHr4bD3NPl8vEf3S2G6kmAxq25hXYrn9RlNa0L2Xk4EzIsL
Suces/sUERB9SzRq5rSsR+Kmd9nmHWv6v0gIjYX2/GGd9pLNgp3jSiSM48eT
uXEvtL8BpaQ3ew==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz38s1HEcx/HT6hy2MhOGwmWnQw2XcPnxOo5z58flx9aoLRxTLf2Yfm2l
aYrMjiSpyR9czjQnan7/gZTTTVHr0nV+bP7I1B+x1ZiOfqzP+x+f7bvPHnt+
P5/v++uVczY1bwuHw4n8+/zbadlPac5F2OoH/2spSuF2Y/G0HZmD9Hazj5lL
5qFQ9NVkXB9ltkcpL9sn6xvZEUJzk3LsPdkF08tm0fAbsjsah8TLHS1kT2gy
9Yv6RjIfv3+4moWZZG8Y+hvEocFkAaLWe8pHZl4x74VlKvD2nW6yL1b7LSdy
Gsj++G6X6pDNI+9HjnWox+HPL5kD4Jkml3y0jDAHouLmrNFiIAchvLqrt1ZG
FiEr5dSKQkg+gJ9f0vjL4y+Yg7G2p8clREk+iPE+G+WtCnIILjg4hhw5Ocwc
ijG+j2epnByGpWsGXy6HLMb8YN18kZZ8CDLno1LnGnI49g03ZRyfGGKOwPmA
snadkRyJrrsCO7U1vR+FucpLhWt11IGoHR+2czXMxYDY1iT0t6IugV937wOP
GXa+WAIn14KIoED6n2jkqdW5z0uYi6OxtVVYsM6jHoNttuVTll3UY3BP2tpn
Y6B5pGizcr9Y1En3SzExWW2/oaLvx0Ll/Str1UDzxaKvIXHn/RrqcbhSYRpo
rqXzcZAOuOjsBQOsy5Bc77Txmt/LugxluZ3aT3PMnHgsCJ60aSX9rMcjX3Ts
EVfYzbocC0tn3EZNrazLkeqin1NVaVlXYE4ZdllQ1sK6Ajy3kvr0tGbWEzCr
UnRMzj9mPQHTTRZxfgr1RFRezfBauf6U9UR4GN+qmx92sJ6ECr8lTejuTtaT
NvXkTT0ZOu93hirds8E/Xxo8ZA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIk1EYwPE3FzM1TEF0ieHsIqZRus1m6vLxMi/zMi8VVoi0mUTJ1EpZ
pjEVUxBN8YIJYZjmBJt3zcRm3ho57GJiKmqGZSXamkJZOCv2HKG9cHj58X/O
+XCOgyg5+qIRRVH8v+vfn3wWkw9SeKbPlXppfKZmXQaHzYkpGNjDCokxI94F
wit+brG6EbQF5E2wBFJj0q1gqE0xKpwlnQFMq1xGwiixHVzL0iaL5cRMkFoq
adJS4v1wvzm950c+8UGwGKNZqkXEjrC58o3TdIrYCeSx69xcDrEziFaeZjap
htFHYIDSiVxKiY/C2tJ8mu4ssSsw2U5DNzVDaDdwbHSxOSclZsFiUZlunwcx
G6q6ve0/lBNzIPChWLVTPYh2B9Vt9+jfG8THoWKBHvZlu3Mh+2uZamtuAO0B
q1VqbkEq8QnwcmcpnWOeoT2hNVu4uZavRHvBp8pU9ufIXrQ3gB2vXXL9MZoH
P80VW+/FxCeBYe18ep7fifaBwwfSJGfY7WgAZWF6ebFNq94ygLePwu03Etuw
+8KiaZzC5DVa5gsl3/t2zPS2YPeDzcsOefc4pPuBZna2fzkKz6P8wXcylWk+
04zdH3YLHHvicxTYA4BumWCS8qsJewB03or4eJWL8xQf0jLp3U/oOC/jw4V4
bVtWRQP2QHjh16jk3iH7AyF/yS2mb70OexBkiee83lSjZUEQGVA/fqylHnsw
BI83zEzP12APBmt1Uhw7oxp7CBTptHUlHed99D0EXu61tVXzqrALQP4qmjZn
VoD7BaCJZQgLjSr081QojNOLuZ6SHOyh0FEzZmyzegN7GNwFXeK76UrsYUAb
qV2WUNl4fjhMZXQtdMlrsYeD66FO7cQlcv8RYJHUosptwPeWGZgSGnQDU5H/
GwwsM3C/gamobf8BQUBi5g==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n9M1HUcx/Hv4WyCnrgFC/HG9DjoNGHA4eFJyEv5qYT3GxF0VxiHaRnB
0MJ5d2rDoHBoDUrvgsnWTfQkNw8VkPvKcbC1EVgzRSFs0RE0oDuiJmlU6/P+
I2673R57fj6f+9593uuK3tYUB3AcV/DP+99Peq2631yaEtTn+k+/pvZN1Qh/
f47MwS8ZvPyWgLwMgb7qiLzJXuZVWLkm7LpwmByCDXZlXcUAOQxVMMeU9pNF
MP1ijTLdI6+FVAb/6WtkMWTfZh8OryRLUD/008k7CnI0/GvjfCO/eZil8JeV
3ku8S96AKy0HC7tvkjci+Zx99ot8ciyO3AL3oYAch470hj8XIsnxsNWmKvYO
9zAn4IWRhoBqPVmGluSUj/6acDMn4qsW6+dHhsibIJjZb1zXSZbD0FgRw58l
J8Gabp2eeJ+8GbmvTns+ySQr8EPvgYNaMXkLlLcLW10CcjLMIp9j8HQ388tw
Pon1tHHUUzCyWaixPb3DvBULhT/GP95I61MRtP7K7JaL1IE/ml+Trl/NugWQ
hyimV8ZS34aCQ9yNqmgX69sQ5W06lvQmz/p22MukT1JrqG+HbLdtPNR+m/U0
+CuazrkPd7Cehq3Fx7Uoop6OeeOXQUnPd7Kejka4q4cTqWeg/oHywvJxOj8D
52cTPj022cV6JjyPIupHQ5ktmfhA/MyYIKT9WUDm3Jz40k3Ws+DxzZwKi2Pm
svFeXa+8/Sz1bDR6RDXJV9tY3wG+rHWpLZ/6DiwXRGWM1rLfw+2E0+kI3P/s
Fus70d5gHJvx3mA9B9fXfHZhsIr25yBlrH9yiY/9Xu6V/9uyyFzuop4LkVhe
XGKi79+FmB7d+QI9/b+7YDU3Fwc0UVdi3CWaCOdpvxJpJV1TPZF0vgrftBkC
V7Sw54cKOvuCRmij81SYNww4zUvYel6Fjlhv1qmXaL8a7qOhh4LeYIYa/tI9
jug+ug81Wr8Ofmh2svvj1fjZXimT36X50kDi9T4dBjMW2aKBQtufpK5l88Zr
UOSq7Pg+nuZPi6mL0rmefex8aOFw1GYUrWDdokWNMqYwP4c9D6+FSjImfzGE
red0MKb5zN5yNi/Q4TtTRd3RYJo3HZZ1nwl9PZzdH6+DzyRofeyn+9XjeHBE
5L532tl+PTaVnzk5ME/zoEfwJUOCJIet5/U40fxuiTuQ5i8Po7uHuspPsHlD
Hgz1k/6RjztdfwNtY9kV
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQMC1xcX2HId3w/hfbBftkzC4xKcz+AQ/GOvpLEA
jM/hcEE3Mes3C4wv4PBoT9A6zx/HoHwRh9TFrV3cr2F8CYe8/W3azo9hfBkH
+3uy9w5chPEVHGor4sVlj8D4Sg7d/Ic8FFtgfBWHalsl04wqGF/NYfH1t5NW
ToPxNRzWKt5fcKgWxtdyeF+pJTXfFMbXcWCfXrNA1QzG13No65AInsgD4xs4
WCq6xGpaw/iGDn/lErualWF8I4erzq9rVn48CuUbO3hsX7ykZzmMb+Lw9JKi
xkEvGN/UwfpCZPenjCNQvpmD7VROTvUdML65g61/xOOsEhjfwoHzQB3zPR4Y
39JB4Rn3W2YTGN/K4Vr0Y6vPITC+tUOaYmzpaVYY38bh7/8d64TTDkP5tg56
WyZlJifA+HYONm13c78ywvj2DglN+mHzYmB8B4c97Yc/tCRC+Q0ODsuKu5Y4
X4OZ7+iwxVvkbl0h1H8Njg4mU1LePeSE6XdysMxe5nBiM0y/k8PC0ql3hd7D
wsPZ4efZSO45HjD9zg5zQs9o/zh/cD8ApPbFhg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzgtIU1Ecx/HLTJhZuaTQStu0klKRlrZMnf5087WVroVkRZBbCzLBzKIa
FetlOiqpNC3FKSOjZPhIa5rmlmVgkgSKhkQv0jATU0ollIrOn+geuBw+fM/5
n+uny9YaBBzHKX9/f3Zaon7rIfn85+1/NR5jdXT/nLeAzKHBodb3CclCDKXb
6hSuZBF6qgqTFaOdzEsQ6Ovac7eX7I1JT++Fx+xkH1xcLks5aSFLIBpcYa68
QfaHR3m8xqwhr8bDK16toz7kAEy8tZTq+58xr4X51pcx/0ZyIC7cWzQQUEgO
RpibS9b1CHIIosTCm5L7T5nXIywhKXO6liwFp/ZyS5WSN+BcV8Neg72DORRT
wYsn0qrJYYh96SfLqHjCvBHXJRWq2hqyDMXu4jqBkLwJXXXR+THrnMzhOHAk
cbK83sG8GdN3Bq0jauoRyP0q7VG1UY9EmTataJuFehQ8donrLw1Rl2NAoj17
Wk+OxmxK0IhhvJ05BtawnJ2vCsiArfnTKXUEO28CapbN7Atpesx6LBp3Hx4u
LWA2xcKYm1eUs/8R63FIVEnM7quYTXGwHlR2/4hrZl2BwiptV0k2s0kBY6fA
d+4bdSVEt3u3z7bQfSV0GQgUpNL8eEjfVGuW2ppYj4fs/NSOgXc21hOgfT3j
dHY0sJ4A4Z4y85iO5ieiRFxcazTQ+4nweFGkv5xHPQlyb8HH3vIHrCchKtTT
+N1iZz0Z+e/tur6gFtaTIS0Lv5Z1lP5PhXSnnzZzZRvrKkS6zLUONdN8NWY/
K2rWDNN9NSrTM8OvurSyvuV/m3jmtvI6z1wKr/PMpfI6z5wG8uMfTpyxMUPD
O8+z459/AcflTow=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0g9MlHUYB/A3yBIq4QbU8Sf/JAKBhSgKx3HwhTvxOI47Du4OxoTETZ0Z
KSbLrZS3Q0KMBCX/JGYtdqBACIh4CMmhcOKCDlfkgtCxMIn449rwT6eZjefX
1vtu79599n2f/d73eZ4lG7enbnLiOC7n6f3vk13uN6p2yFyvds7pbmxRxk+u
5+czcwiNuKGVzmOejzve6poKJ2Z3+GYZjtTdt5E9URe3rvvTW8xiNL2Y1Gsd
ZfbDs17DIbph5sXwc1zvmGhhfg37vRWRs6XM/kjrGz5lzGUOgCWoRxSWzhyE
AR91wqNg5mBcLHN9d2q6h7wco9/Z9uZ0ML8Js02TWX2UeQUKdx6ZWaNiDsO9
RvPqT4a6ySvR4zs0uTuXeRV637GZbjoxh+OMR+Vvv267Ql4Nt+pQ7d3bl8lr
YNq6yFPq3UWOwBvj/EDFMSs5ErnFpoaF0d+SJZC6TNmfVLaTo/DWSbObprWN
LEVt8YYmTn6BHI07NYdUzx0/T5bhWlegY3KsmRyDxAPPX3BZ2USOhZdILlt2
7RwZkMzuifaxfzNnHojdFfx4NpO9HwcvsdqgqSDzcQh8z5it07M8Hkv6xW6d
sSyPh7d437n8L1guR1vEz1vGnVgux/Auy4LPQ+k8ToFVNQvEDV51lCsg2rJJ
dSKSzK2Fo+9mXffQacrXwrO3oyQritUnwGmfcvttWSPlCXj/svJQmwf7/3Xo
j2l0zj/ZSvlTT9RmK5MtlCtRbRpZ9FUY9ZtXwj+SR2kzyxNR8me9dHqQzCdC
9pmlvTXgIuUqOG+cyO5N6KRchdqrAeGvxLF5JuFH3SXfgkesPgnG36em3Tew
ejWKDpuqA3tovrwaFv3uv6Qf0/dyyXjcbGga/KGF8mQcKygo9L9F5jSIrtzs
V3yc5slroD1lC7keTv3itKh80BjdsNBMuRaOycoPN+ezPAUtHnaVvL92zkjB
3pn9I5miM/R+CuzlMaLxMrI1BWfXL64atNdTvQ47nomSFN0/S/U6jDz5wNAi
ZvPW4UH7vK15HTQfqw47l78a8NIytn+pyLnXN1t/mIxUFIuNfFcI7TefikJL
SV6ZC83TKjCX9n9DYD4NIR8d9HEcpH2ypsF5/VLNJQvbHz3GnIeyvvyF+gM9
XjDvkSn++Jrq9SifGJ14fYz6Y9ULzjcIzheYF9gqMGcU1BthkDysGjvN6o14
udxSWhVE/bEaMaN4uG3wezb/dAyc+PvtK/HUX6QjL2OFRMtyXmCrwFzGf/4H
+Izy9A==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0w0s1HEcx/H/mR602UJRDZXFLhkpd5XChw7nKXeayHpY2nlYHotWqe1S
ZhKx1ZGiBynuStKF5PFyUSJWsR4sJ9psPVyPeliP8/3Z8t/++++1937/3/b/
ff8LIxNDZAYcxwX9vf892TWzvzTJbUZ787j0HlFD9mWjxswcDA/ldxebMU9H
XLhXV6wJ80wI4kcsZRPrZ2HuV42+68cd8hy4HFe+lQ0yW2K78/4nkQPMC5Du
UhoqusFsA96eC1X5B5kXwXs0TSxIZLbDt7m68+W+zHycembj+Nma2R7u0Qr/
s31asgO6C3rc3KTMjiiO+bK6R9FGXgp+2vyRqpvMzih3sEkx0d4mL4PZaL2Y
Z8H6cujX5Kkf17DugsSM96kJyRqyAA1y0cNXW5mF2DU7d/2bslbyCtRojbu8
3ZlXIvj0MkN+SAt5FbY5t6rn1DWTXVHSqIyPMG0gr4ayMLY9OfoWeQ0+NWnt
KlKY3bCxzu/3U6ObZHc43DJo/x5aT/aAxdjTeIPhGjJQr9uIjA1V45YDartN
i2MiyZwnIl3zOl3TVNQ9MXvMqsPksJK6FzbV8pNHHlyi7oUMW36WU/Rl6msx
nZd/33TsKvW1mC+wWqRIrqQugse7dIvc1+XURVBm2+3NOV5B3RtTbafYpraR
5d6IyVb31g3SfpwPjvGyftzefI66DzJclL3mYjLnC5Vi6MrUYxeo+0KY9Kao
Z0EZdTE+hvs8L+kiy8UIVL2MvdZ5krofCqZVmFZ1nKLuh+EZ5zKLdGTOH02e
h3RjA2eo+6PASXY0m3eWegAezTvzWiQsph6AzBMJ1gqjIuqBKMl9cVSmL6Ue
iIdx5h+eV16kHoTq4MIEM0v63vIgFL20Cevbzd6/Dg07JDqzanZ+66ASqrw0
TtepB8O3eaeu8Gc19WBciY7IDdOy85cgoHD0wK8smh9IcPfIe6W6gOZHLsGj
qPrQhXnkFgkEwuZ9OavYfEmx5EZ66vekWlovhb2x5l5/HFkuxflG89Yte2ie
W6Q4mJmnsdCz/ynkf2OS5ZPcMsnc+gn/ATYDjwM=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zQs01Hkfx/F/KbpQop7aQpOHlkqtVFSsT4R1Wff7JTNjxgyJeKSby/+R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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdkgtMU1cchytO2UQdDBSccwiDggTRWhAQpT/eIAilpcUycATHbKQEEWQU
dVTB57qBFQkgY9EqU8KjG0NFRQpFEDW83KJDOjd8wNQBmSILumwu/E+WcZOb
my/f+c4999xjl5QmSjbhcDhpr+9/n+wyv63dtm5OR/MUjQnazHJLWkwZc1A4
cTFHMIvxmzjQn61se9ZObI7k7g/ecXnM2AqJxbPEd+4wtsEe5ellej3j96By
b2o06hgvxZoqswdJCsb2yMsfupsWydgBn9vmzOsPZsyF+kk+l+PK2Bnz+7td
a/+4SuyCrNXylqdPGbtiga5yrKOWsRvM4x3d7Y4wXomCeK+S7T6MeRiq5qbJ
FjJeBUXgW8tV423EfIyrG0UaP+bdEVC2XzixnnkPBP123/FXpYF4NY4mXB/d
u4OxJ5ReiXy7sFZiLzRK+dUCB8beqB9O9z4paiFegx/V4Y9HljD2QdPv8g3H
I5uJ1+JMaNJszaIrxOtgs+q5T9FOxr54kXzuWdcMxgKY7gsuvLjlMjHwamyX
ZcDsxilWAYvaNanaTy6Q94OpxXOOb8t58n5Qr7BX2dacI+8PnxXLK/PNGsj7
o9hyRF739vfkA7DZctdgfHo9+QD4DsxsWbr/O/KB+HnEwDO9WUc+EJ7VIYtl
1t+SD0KKeZ2Rl64jHwTeo3tJHdtryAdjcIFP+X3uWfLBaAu49FPmE+ZDYEza
Hdos+5p8CJy2WhcEDZ4gH4qXD4eyP6o+TT4UVdYmVuFvMB+G0bI8a+H8I+TD
cKqp5+8c/0Pk16P0us/wN32pgim/HoMewSWJDdIp5oTD0/CKOyBSkQ9HcZK4
68W6dPIRON92LfOkYS/5CHTavnAYaVKS34C53RYdirlZ5Dfg+JxJl6obkfT+
SKSP+ikmRvPJR2JzbkBNVM4+6qMgNuyLHVaD1h+Fm17GK52Ne6gXws15k85x
sWaKIUQ5ny/XOBXSeCE4x5w2VZyh79cLUTpgUzEjRU19NAR//mA11pBPfTR4
S3gVswsKqI/G2fIzmS8ffkF9NCSOrSV9zYepF0Ge3tO/pUlFvQgfn/Dkyuz3
Ui/C+xKTBMdqGq8XwXGOonZnUQb1Ygze3nq4VWdPvRhWyis9l/dk0H6IoZvs
Wqi1jJlivRhxRRE1CypSqY/5PyMGEw6Gmbfu0nhVDB7cu1rK/4X2Sx+DFJdR
2wZjMfUSSE5/6RKhzaNegrWnom/dWLmb1i/Bp72TxnkHab/0r/3N626uS4qo
l2JbZ7nX/IQS6qUYyJRkH8srpV4KGxN+77L6XdRLIS+5IDxqQf+LE4tF2h5l
Vc1J6mMRleunsPuMWBWLxU6WZiOviPWx4NQfePfcX+x8b0TGqC4qkcf6jfDY
ntXX+6iS+o0oN/iblh3XUj+NOTIczbt0aDKT5oMMDtodOrPxr6iXYemx/krv
vDLqZbimaW9NmGTnLw7OzmLegzg6r5jGqmmsn8acD6f101j1H/8DjBAkTw==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQMC1xcX2HId3w/hfbD/5Wr74DErjM/g8PqdaX8U
C4zP4eAYVbma+eMxKF/AIcQ4TUXwOYwv4jB7bVuDw1kYX8KhzMzdmu8kjC/j
YGm56Vj5VhhfwWFXIFcN51wYX8lB3sj+gUw+jK/isFiZm7XKH8ZXc9DKetUs
JgLjazgYKrisyWOF8bUc3NV2VymfPwrl6zhEP2AWTloB4+s5TO1ZcqIwGcY3
cJhdeID9dzSMb+iwcbvyqx2dR6B8I4dP/p0WuwNgfGOHg66OU9JDYXwTh732
bClGHDC+qUPd9bPZV/IPQ/lmDuFiaZYhd2F8cwdPsx9fo/0OQfkWDj9bbgYw
LzwI5Vs6dO545lyWCuNbOVzgnv644tt+KN/aYZFQa5Qw/14o38ZhYs/982/v
wORtHeavSPgW4HkAyrdzeMr82bjk+T4o395h8zqBnVlZMHkHh0tN1esex0D5
DQ4OSzmuZy9hg5nv6GCWl2i8OmwPVN7RIWD+JYlHgTD7nBzuZoYc/60A9U+D
k0PCzDCtTBeYf50dvPiKmmyZoPHT4Ozwrd5ooVgyLD25oPIb0PgMrmjyaHwG
NzR5BB8AqWjfAA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxF0AtMU3cUx/FqeFRnIhENNbNOCeJEKA95aGvpr0WgPJS2jLgNnYLDiTrU
IUicNuWhJQJGExN1OqZTKJ1udDAIKEqH2LKKmZpoZbOVKWKMGlABg3FsGs7R
m9zcfPK95/xv7tzsLbqciQKBIO3N/fbJl4/z1Fb5ZHv7uAYV174d3ZYxiS2A
eM3MHJk3W4imi/lisyfbB0/9difnjNrI0yG0/PWFepAtQsizV7F/3mXPgsd9
p0vfz56D4pqDdcILbH+IRROk3RXsAKz6pmTqo1J2IBRejgeeCvbHKFvn6hXJ
2EH479Ai99gkdjBcoV2Z2dcvkyXYPu3svJaf2WG45YzXhqezwzHv6r1/V09n
R0C43zgaUttJXgSX+uSCDXHsSDR0qBtXebGjoI1pNi+wXSJH40bo/rI9LzvI
MTjh+7rrnzvsxdi3KSAlKp69BFf685sz89lSbA95oPz+1u9kGbKrI358vpC9
FOj6xGun20qW4+jRJcE9YnYs5PWbIz/P4/cVuDa/tMhi5w4MRSsL1leQDcDa
kiS9891+JW6PWFtTre3UlVhpMe+215+jrsI2c2lYTwDZoIJkdPNv9XrucTB+
2tB8Ivw89Tg45w9m+WrJgmXwOmtSZP3C88tgKprVduGDFurxuBczWxL0GdkQ
D2X5WEZRcjP1BMhUE03l1Y3UE7DpdmWF364G6okQD2ieXOo7Qz0Rd4X+TaKP
TNTViJq2xbO8oIa6Go9D/JpUQdyTkKt3B+T98BP1JPRFp+VKTpIFyah1dLvM
R3h/MnKN67+66FtLPQWONYUL/c/z/hS8erZ3Z7eZeyoeFh+369voPEMq/vbO
2vjdAdonWI7J4f1Xyxr5/OVIdUXG9Rhpn2AFnrccyw6+QfsMKzB8Wr5jeALv
T8OHHm07pI7T1NOQ2OMtbX/KXYOROzW2pMhT44YGLzs8tL3V/D0azDD12r62
ULdqoJ8yZSi0jr9Pi0Mv6gbCjPS/oUVGZY3cPddC81rM6HSLNh6uoHktHEsN
MyOqqmhehy/7FqusI7E0r8MfZ3wSfrUVKcbndbhZO3Dz+uFCmtdhSBY1aJLs
ovl0SPPG7BvSt46/j3QIhzpbhwNX0vnv/T8I6JYN
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zws41Pkex/FpRY4uq22dLlu5C2Vz3TioD0q6zTByvzQzLoNUoqwijZaN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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzws0FPgeB/BJKc/oZjeKovailE2r2Iq+8n4z3u+ZMcP0QJGyaZkVe9MW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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0H8s1HEcx/FvthSjaWWXdZsfGbFcl6jI8TrOj1y1dS2VaCk2/rhq3TT8
06lRiGU4JCqXOT+yu8JcfeWmUBvV+jGZlliYui2zbnYS1bw/td1n++yzx57v
f94fz9PnFGl2HMeF/bl/X3ZchrXnJY4DPSuajTi6EF8ldGbmMD2pzChZw7wW
Otf3fUe+9pNdIFU2l2gmmDei/kGbw5YR5k0wT33P7P3ELES3WbPIvWb2QNS8
c5D1EbMXbhpy5m81M3tjwynesb2S2QfjQyJtvph5K2rcNaXVw31kfzQoF436
aeZt4C+qLIstzCLo7iSmlv3rYqyfM/gcLGfegcGYxLYACXMglrefMK8rfUbe
ichkBX89nzkI8rKlvnbzU3IwBv3Url5y5l0oKs/KfrGZeTe0k9/mll/1kveg
OmtUUKgykUMg9bsyJpIxh6LIy8G/SdBD3ovc0c8pMwFPyGGwjvycfOPJLIFa
keT2y4PNh8PNs/PGw6RucgT0+sYLKWKeDBRXCfn0H8YVq4HL0Xa1DsbH1KUw
5QTmjaV3UZciearJkJHZST0SsqXGd3l+7dQjUWT9kGK9racehdzieeWXky3U
o+AkShD52uuoy9BVO3H/0EwDdRksq02pz1+SuWiMh9SMd6Xdox6NioTDZ6o1
9dRjUKD4OFPlU0M9BvahElX4sbvUY2ExrxoK99VQj4WWT5XU9TdRj0NhZZaT
StdMPQ6NHa1nB463Ut+Ht1cFwbywg7qNuXh4G/mKS4W0jzoe+dkLYbMFBupy
uA9eCy3OoP9W25jbb9NtzB2w6f/9Gzl9OcE=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10ns41Ikex/Epod1UUi5FNdJFYpVkk8pHLJEwrmHGjBlzKSXVVieU6bLd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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0GtIk1Ecx/GHkiaraGTiNLNpamGbOJvW3NZ+Ot3cLLLliwoSGiaBKyuQ
yllMcRp0o14oGoaag+xCCNGsbHPzhrPlZUuld2E1WVRKRQiVFZ5/UAcOhw/f
8xzOc+JN5cYjyziOk/+ef1YagqlbJ1T8IdeS5tSlfuFe/2oyh/q40PP7YeRw
CD93RFZ/H2QWQO/cFz36hbwO79vLZIsBshB1Sl57RR85FkmG3MnxO2QRHoPn
7bOQExBRmrJCXUJOBO/s2IX4QnIyJPyt4kkdeQt4fq5RJCGnwPok6Nj4cYBZ
jOqs65Xpr8ipaBENz3S9JKch+l3/muQGshR37ePzWR3kdNxoNNweu0TeBotU
XByznixDU7Drp2gzOQOVvgNIuNLPnImOqWvakR7ydggkQ3ERMtq/A6GasQyv
hLoch20D2toPfcxZuOjpHPc4yAq82G3PjgmRlWixVYc1T5NVKDgXKYePvBMB
7dr9pzg6Xw1TrV8tNVEHoqIy60puepZsBd6usrw+6WLmsqF6EM+fbXWzng3z
hGVx3sfM5SB1JHC5TUo9B522xMGG4DPWNaiYNq6sGn7KugZy+4LLLO1hPRcB
t/LhTFMv67ng4iZmjQpmLg/Og0Xlp510fh6MaX5l6LiLdS3MQoVjzxB1LTSK
3qo0Jf2fDvU1sZ/cqdR1CBjau5O+0vf5GMjbYP1WzGzNx2i444znkZN1Pc4X
hpctNlPXw/jm6vJDx6gbsKl17mjRPbq/AQvdXu+PJnqfgn9t/c/crr/+BRny
JzM=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tIU1EAx/G1ikZi2hZl6cJ81Fzi25xO58/NzU2nI6cMzBiGFZUw6QGW
FCu1LMlM8480zfCPQjOajzS1+cxnpgZZISpSzTBZagqaOSs8558uXC4fvvee
e+7lnH3HdLHHmQwGQ/T3/Helh+2H8tSQrd0t65oNtX64U7hgRc3AiljXydtC
zcJQUeCbTWtdxLZoLlkymL5Q74C+yhjhP0Fth9KBYW/RJ2oHKG0m+fWPqR2R
uPp8c9JNaic0FWoV0hPULricwx6VJFDvR7zWujHTnZoHh1WTvMKemo9r51dc
1Uuvid0RkOcRP95M7QHpSWYZJ53aC0X3Mn6yRNTe4N89zDWbOol90M1T2xmC
qH1RGByn6Td2EPthF9P1xq+xdmJ/1J5SdvU2UB/C4u7eSksmdQBWBZeOZHHb
iAUY4RzNyVtoJQ7EE9m441UudRBYUh9B0rSRWIjYmtmC9/1NxMGIUauujgU2
E4cgeW/KhPEA7SIMah59/XG9gTgUaxu19uP8emKgdeZ+453q2nXrAfU3zrys
ro70MKjkF/pSfxPrw1DxednGrZXczxCDK2BXp68YSBdDn1l20OBSSboEKU79
zqM9VaRLsGdaOCOaf0Z6OIRTVybT5ujz4XiqaHP0tNSQLsU5M6s7TUPfL0X0
mkWbUEznJ8MDaaOV6fsL0mWozR8osxt9SXoEPl4sMXuV0++LQK6KNyKfqCZd
jrB299LbYvq8HMUqdUZkIpkPQwFDvk6TfYb8T70C6blD+Xmn6fiRmMty3uaf
1kP6f2ZEYTCZM/8ujuwffRRsfc96tnHoflIie+ZtDNOPrF+9EsMuWTUbLHQ9
R0N1q8BXwqbjR2NWlyExL9Ieg65Bttur7WT96mOQmFzeN7Xc0fIHwNQ+pg==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n8s1HEcx/HvGBlTt8Vow0SaSXVOToXzcjjHcZZ1zo/82G0izTFplko3
2qVoLSU/+oGk6MdlhtDNVydMIrkt9YdNP9iStvxMO/RjPp/+8N0+++6x5z7v
z/e7fbYrMqNSjBiGwd/1700fzlhdlp95P7uuH/5CdX30pv9mkG7Mjmktqc2Q
abJFcWorNQfVFWqNl6GP2Ar3mzojOhepbaGd84BygtoOuqqOgGIdtSPkSu6x
6yy1E0aq5ROGQuodULSmvWGOUu8EPzX5wWsptSvkt1K/Df3qJXbDtqkiwUgf
tTtktn6TwbXUexAdW+atsaPmgmPf3Kr58JLYA0Hn3u+NO0LNA+skqtysoPYE
IxtPWC7rId4H08s2yYd3UXuh0hDPrzurI+ajqsd16KoFtTcqsrrmlodfEO/H
J95FtjyR+gAanvLSOJe6iQ+i0Fyf1LbGEvugZEbvUrzQRewL1vP2rFpHux/W
rAeSRNm0C9CyUqJ3dtQS++NVvTw/J7WDGCi9Yf3xQm/rulUAl7eI00bNpAfg
zFTTwqpZE+kByMu4l2ja3Ui6EO4+9fMzxxtIFyL2u7ksfklDeiDOtzXl5SY8
IT0QWpuoHEM7mccEITf9Z4lshc4PgknplZm3DN0fDGWRVddiHDlPFQyp/bXx
TN+HpIsQeaLYTtpC54swX+6QlxTyiPQQuDXn6yu/EqtCMCCbaq2iZsRoUKpj
vWcfky5GfMqYsVpL/ocJxfQau/oukZ4fisFnGdL83zWkh8F5eKk9MPsO6WE4
WaCvTRPfJV2CLy7Tk9IY8r0qCYbSHSSWFm2kh+PzTQiZmuekh+OQksvUSOh9
i0DAoEA8YkTuq2qDGemGvsFMJAriskfddvez/JjBRqUgEnOjEQpOzAD7B1OF
ShU=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03lIk2EcB/BXO6gM7RjNnJiKWkmJtXQdm32n02xqm3NzZkVpacegFaVW
drwdakllf1QYFdEhdpmBZupKZ6aVWYJJF0IX2IGR67AolAqfX7HnhZeXD9/n
+/zeg9cv3WrIcBUEYcWf8++VjlFPzq5TjbhTP6CeuQvvJA+97E4WUJGy+fvl
f/kwbC3uO1rpQh6Ftoaxvef7m5klcIkrcRvxlewJedjxXHUn2Rs3oQopfUD2
RcCT1SPDr5L9oWm5okEuOQAPSgzlymXkIHQffJW+wI88Cd73bfGlY8jBKB55
ePYSRxPzFChzbH27X5JDIKkpynnWQg7FGX3vTlkdeRoGydI+pWvJ01Hg+v5Z
hzdZDs2W/OwL924zz4Al58W36ZPJYZDvGNeflNbIHI5dzTf2G17fYlbg84uE
8sNnyTPhOGQ5NlpB62dBafvq61CRZ2N8eE+qxx7yHEz0SFsly6W+El1l8vJz
H8kqSO/9DDrtSY5Ah6I/fHFVA/NctHkVlPlvpBywyHvHqWwsFwFTYW7YYIed
5WrIdJJZk15SrsbFa6JicDHdTyR+VONd8HFmMRIhK6IyPrTS/lG41CUtdf1C
/Sjstz4KySqivgbtsZHu2gTqaxDRkjrkl4360ehftbTuaTP1o6H2qm/c50N5
DCSarnZvSz3LY1AY7yKtaLrJ8nlo9dzplzmM+vPQuenEpzXRbL0Qi4KON4vy
jOx5xVikWrdtGORWx/L5OLkw67Q8k/afj9pfE9oK8ijXOlvUwtOyJVG6jvI4
bK/V7s1wo/lxXD8eU9PzQxsqqlnOWUjg8gToPGTrszdXsnyBs0XOgg7SbXlH
HnZTn7Ogh8P/i/XphGsDhh7Pg1rHry2m9XocWG3oc5ysGrBdj+GNNcE+M2pY
PxGKU/lVukCWg7OYiD2hYuv9QBvrcxYMzoYBZ5q+La5ysP1FA3wO5L+fM5R9
T7sBmu+3A92V9P6SnA3OYhI6fXUZFZk0Pwnd6uqVV7NrWd+IrJ63EqOCzYMR
ZRfuLnNLZrnI2W6E2hpRpim/zvombj5nkbPdBONjk8lcR8+fzPU5i5ztnAUz
1zfj4POYyvZ26pvh1b18wykrvT8zRse9m1YynP6PFGcjhZvP2f7fvwGJrflw

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVzGtI01EYx/ExMFSMxAQti/qbbaKxbE4tc+63uelGGriUgXaj1GZLm2Wt
vQhnxiqlNYLNai/CrDdNw8rMvGBWKlErSNSSmEYleSmksA0hu+B5ig4cDh++
z3O4fYe1xXwejyf5ff+8dEJHGo3S4IGeRc3KuNV9OVV/zcOxyJqxkEByILK6
0qu9fHIoSi7sOr7R188cjqCElMROLzkSXzui+BdHyavwXL+j4HQ7eS26l00v
H24gR6PWdH3dlSZyDPIG05onqsgCjNc7WqQ2cizEK73qg05yHBSlH27648gb
UCw4I9PP9zGLELQwpys4S05Art6kVJrJm/Ds26QorJYsxvQt8dOBG+REnBNG
zH3RkCUYDvh5zex6wpyE2bJCLmyEnIzdnpKiyWyaT0Hjfld12RLyZsTnpLd/
iqX5LQjnxoQ1EnIqdtpyGwJ0j5m3Imq9xso5yGm4NPrqgUlFluKQq9J/Ppuc
jiHPqYmij4+YZfDVae++PEIGVojs8W31vYu2AFf99kH39oesy/G61V4pOdrD
uhwL7qTk7+5u1hWQNVntb020r8CevPc/jOW0n4FxY41qppLZkgErZ5uKlVNX
YsbnrXMc6GRdiZOXe51CXSvrKjQnvnF2VNxnXYXU/vwuroV6JoI9pVL33nus
ZyLms7xijeoO61mIMJwImTffZj0L5S+WBm8ztLGuhsBe6M2fov/V0L6LdhuG
aF/zvy3//Au3ewf4
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91Qk01WkfB/CbMrRMqRBF3I5db0pKhXxlaWix79vlri1GicYYcYupKKmZ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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJw1zX8s1HEcx/FvmlIqxww1KcbtmBpd6vy81/l1HCX+MgvHkWzJtVhbS/vm
DzMN9Y1V8w87cUnzh3IdupNfhWWHFibV5DY/WqG1NvlRrc/7u3333WPP9/f9
9swuTMm14ThO9vf996VHNKnThu99bf6vFXnr5/xHg7ZkDpXpY2nfbMh2KG7K
/STlyCL0W8Tx+V8HmZ3xw7fobNIY2Q3epdqkXyNkd9zYseye0kk+ineiK+1l
lWQv1HssDhfmkL2RddVB3edCFuN576olZnGAWQK9Y2KHoo3shwVXH7Fwh+wP
2UCAv8d58nFsFAhiyVI/cwAWpaaFFoEciA6vCs7qSj4BJ0HzQb2bLIVCfUyj
metjPonZWtv0KltyEAbqvK7dmuplPgXZgc0Si458GpWq6nadPVmGC5kzjkkX
XzEHYz3IOmRf38McgvWQ/KVEEzkUI1O3fSpu0nwY3MI2v6zW0L5wlG6V7byn
IUcgQqq7z98ly6H9ODZ0yIMM5D20zOh5to8H9PMyXt5AXQGJvNgUnsXMKyDw
48naTLofieSX5u+dmm7WI1FeFbhvvs7EehQMGQejJNWdrEdh1ODQHNnD5rlo
tKp2TRRsGVmPhrEmuPv3NJvnYrBsFdv4tlCPgTozYvaIkv6PhSU19PDj/ewe
HwvjaLvQ+KCDdSWct89tv2noYl2J9xUTK80ltD8Ol9PiuuxqDazHYfiJddUv
7wXr8dhjmTTMD9P9eIy0NVZPd7eyroLn3EzRz/JnrKtwyWVjTa9j81wCjM5C
jlOyyfw2o+n60+IErI2fyRalDpn/AKvqJZc=
           "]], 
          
          LineBox[{{56.83821811524157, -0.198}, {
           57., -0.19495786903551704`}, {58., -0.18096899945518108`}, {
           59., -0.18096899945518108`}}]}, FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zgdUk/cexvG4EBdLvOIqQbkQvVKKCjVa4AFUkCE7YYYMEqJtQUlBtq+D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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91ntYzPkeB/A5kZJbu8XajjQlmY1ErSLa3lFKSPebLjPTTDOlC9pUHHaQ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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03s01HkfB/CJajcRx1OUZ2unSBu6uS1Z6y0kydBEbmHGzJhRRBLFqinp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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQMC1xcX2HId3w/hfbDnurBz+l0hGJ/BQVVN1LVF
CsbncJiy0IznBw+ML+CwdAff/frXx6B8EYes/m16yXdhfAmHuPV/fneuhPFl
HP7sDAsQOAjjKzhMV7cU8tsE4ys5PN6/ti+5BsZXcYiqe/OlZDqMr+agyJSf
6z8RxtdwsH4lPmnyDBhfy2Hh84eLr9fD+DoOf+RlOV+Xwfh6DtwOGvGxuTC+
gcPrZVP3+904CuUbOuyY2xR1nR0mb+SQ1i3zdMovmLyxg8HF+We23oTxTRwi
hdZVX34J45s6JHx8c2VPMoxv5mBzY7UF75MjUL65w87ZDj6s92F8C4cPBmfb
F7nB1Fs6rKg8vuFvEIxv5aDR5rooWQnGt3ZQUs36techTL+Nw5F7R2S+NMP4
tg5xiddeC5UchvLtHKZ/tVS5L3wIyrd3+F3Adrv36AEo38HByOlnPbsElN/g
4LDrbnkVZ/pOqLyjw6p5x65l39sOlXd02NalwjZnG5TP4OTA8Gf2qVuyMHkn
B4W9Glp5Otug8s4Oxr2Zz9mebYbKOzvkKOw2kdgCk3dxKClaOYtt0T6ovIsD
M0cI6x5bWPpyddirXqazhOMEVN7VYY5yRo9LEix+3Bxuzl3P+t13JVQejc/g
jiaP4AMAH3L0qQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwlUzXkfx/FracNU5DGW6EZIbtKiZaI+bVRuq/b1rt1SZoREznBpKEIU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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQMC1xcX2HId3w/hfbA/WxIm2skL4zM4PBMJenaB
G8bncLBkdSqrh/MFHO7r6J77wQrjizi0Gt7e+fPXMShfwmER06ctOz/C+DIO
IrZnq7NewvgKDnPWrbkseQPGV3JY1Njb8XA5jK/i0H18cVHSXBhfzaFhko3/
Ozhfw0Hu0Fb2/lAYX8vhmo2JiTA/jK/j8C5ooffvrUehfD2HS/9lXuW2w/gG
DmetL+9jiIHxDR3WerEdvZUE4xs5OK7wvnni2xEo39iBwVJk+c4vML6Jg+tE
AZms0zC+qUOlf8jGr8thfDMHF5E9L2rDYXxzh1amrHL7x4ehfAuHgkOtxv/T
YXxLhxdT5v6ZEQ7jWzn47s3gZrp8CMq3djiZecCK4yGMb+PQcWBlXhMDjG/r
4LvqGLui2AEo384hd2vKHt+d+6F8eweGPYsDWn/sg/IdHCrF1qdPTtoN4Tc4
OEw6ErXuggKUz+DoUH237xnbJaj+BkeHgy0s6tOXw8x3ciiNfrB762ao/Q1O
DqckxPd8V4f519mhSq1zQ5n20f0W6vb6fdXODp8u+SYJRJzcDwD9+8v5
           "]], 
          
          LineBox[{{39.02897306260786, -0.198}, {
           40., -0.15868372577014414`}, {41., -0.14693187123039886`}, {
           42., -0.11706686317376397`}, {43., -0.1058865577649294}, {
           44., -0.11210371893905549`}, {45., -0.09951530137535546}, {
           46., -0.11458695343006646`}, {47., -0.13723450181559949`}, {
           48., -0.15738528943597987`}, {48.391163445577874`, -0.198}}]}, 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzgtMU2cYxvHjLVXwiropwVmJEahgrFOugg+g0Foo2AJK8BbEKEaRFYda
YnYYDkIEr1GiUhRqIkhBTUBA0FZEJekiWTRjycS7GLyNgYARrZf4vjGcJifN
L//zfOeblbxdt3G4IAhJX56v//yb2G5OD3a6Zf2m7iUtj1xiOkexBfjLnlb2
frpJHo3u4kLlbx/ZE1HWVPRqj4M9Ba+7epWz+tnTMC4767/gPrYbTNoRSQWD
bDkiHMWmuR/Y7kgxnc42dbJnY6XW7uN7jT0H17NXxf2UxvbEY42ip87IVsDe
eO9YQhjbG5emtRVuHs6eB59ubd/AJPZ8/HlQs/DwwxtkJV6HnPU6XsJeAIPZ
0Wi5z/4Z6flNZU82sRfCkJw63/lOC3kRnN/kV27ewvbFhZ33Pio92H7Y7jHs
QkPVdbI/YgOjnB6sZQegdLRmg7WimRyI8ObI6th318hBaB5bqqh14b4Yz2cc
n9rwiB2M6kyr1hjJDsE/4iuXdDl7Cdzz9s8d87uNDBxaM/UvZSZZBDQT6l6M
rOEeirupAQ0+77mHouvA4NYdOdzD8ECVdbdjPJ0vhqErf+DX1nq+bzjKXeY1
WU82Ug+Ho/dKuLd/A/Wl2HbC/DDw2WXqSxH/h0dAwt/11Jdhsle97PKmOurL
oJ9wKvnHdTXUI6DqzIiWmWupR6DqtnyEtzNZiETusFu1R/h9MRKq1pS8MU50
nqCCuny9PcPIexUaC0X5vhTeqyH7H0ctQZeoq1GZlPxv8UXuy7E+0ZJ624/7
cuTM9HLTuZIFDXp63i668wvfX4OsdWc9LFruUWjJTCwxvOfvR8Fv5bbVh2r5
/Ggo+h3PFvjy/aPxfJzB6W1HJXXtUItaYIpQkmCsph6DvlzPoqeJ56nHoL0K
dnXQOeqxQ41YyXkS2yQWVgw1JBYltq3Aht1umaGyCtrrJHsdzsjV1pcK6qIO
5a27XdtNZJsO1buSzAfzLLTXY0+Q3TDeyPfXI6Mj7YeNV8tpr4elzbPiZADZ
pkdpW25EyPQy2sfBste3f6CmlPZxGPmpotmSU0R7iW0SC/FDDYnFeLiHDR7u
qSqgvcRCAlzTfHbt/bCD9hKL3/0ZQZ3c3g==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxF030sFGAcwPHr6OWspKWiF+ccSt0sL91R6X7HeTl3hKluad5S0Wxol2xU
57xcwrUrpLsldqN1fyRnlZTFCSUv8UdR6GzVNbacHZpmSbvfU8/27Nln39+e
/36M5IyYM1QKhQIr9+9Ljt0HTWaATc9Li0xc6+cKddQaYgowJ2/vKLEiXgc1
W7+mZfzqRtuBFeuSzZZZYnvISLvF3TRD7ADzC0a2YpF4J+Sf7TJtNxI7A8fV
tM/4jdgFEqtG5yqaiV0hLiXLJU9K7A4CmWKs4Z/3wDynPbpCTLwX0r8bZjUe
xCzgxTduaBvsQnvCU4eE46xi4v3gP98neuND7AUe4oQT9suv0N6gH5K5tLwj
9oH2C7tsl93IvC9oh5Xne/NIPwAKOSNb00PMhmhT/hT9CTEHVvcMxUyXdqL9
YGLUTNN5EfsDsy3F4OBLfBCk+Y+L6n/q0YdAUD6RzheTfhiCnF8HDgeQHgBT
k8Yf9sMd6CPQqqteZpmIuTBCnbsxwCcGWLjPUO8Oa7dYCjBOPbckSX2GnQe8
mb4rUd067DxgetMMooYm7IEg+/2pw9T6EHsg8DiNWdtitdiDoLPf6U5vgwZ7
EJTTlYsDxTXY+XA3PlfVXFaHnQ8RbKOnWVKLPRg+VjqVSZbuYQ+G6nr3nHKJ
CnsIeGaf7t/snYc9BGKXaIlXQYk9FE4Jxco+nxLsofCWwoqX8a9hDwPKyFgV
/WIp9jB4oZM3+WXlYhdAW8y07NEqnJcK4MF7NtVRVIA9HGiZ1tZ5huvYw+Hm
xvFCuoL8L4TUz9VCXmcc19KFkHO5pcjcm24xRQSOxxoFyYsV2EUweKXUQ8us
xB4BhUmqtQtqDfYI0OsZJ7WCWuyRYLa1aVZS67BHruyT1bjqiwr7USiQr0+S
u6mx//cfLhg/Cg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0WtIU3EYx/HjXqR5a4iVmEmaqTibOm+pW/ttOued1DRjTfDYClFSUepF
QgMh1K5GoUhoKqaOLMgyl0vdNE00lKR0XiIpoguVShT6Qiv6P0EHDocP3+c5
L/5/L744QyfgOE72+/3zpUc401oisx8d+Ktledl5xasqWzKHLbU1TX5byXYo
rGx3mN4YYRYiNy7HoHhDdkU036CWWsluKO3K4CsXyB5YlUbsWZ4g74Fvi86v
xUL2xq7WHmVgN9kHqo3BrDu3yb44XuY8OXmX7A9td9fyeBk5AHXW71fUGnIg
zMfid7+UkcVwEDtvqvqfMgfjkujZTI2GHIKqGIdQYTJZAvtgU/ZSEDkUBQZz
TcXVYeYwLH74ZCj3IYfjc65vx/tQcgRsFwqtJyKHmCOxlpO/zUZiYT6AifSS
C35FZuYonPVa+Ca2kKNxTVBbKrEZZI6Ba+O+ITfNALMULpy115JhYpZBpxhp
3uvVx3wQkdK0kJGPZDnS5o1z6pUnzEDmqbHp1Ty2rweMU+nFfDH9T4H1tnlt
273HrCuQ3yCW9HUaWVfCv9tbNbvOrFfCsXp7wclU6rH4WX/xNUSPWI/FoqBd
pz3dw3ocTDcljtVHmPVxUGanWJ2a2Dynwkr+kkv53EPWVRBGbfbX8sxcPNa0
74pU2gesx+OQaDOv78t91tVw95i6Lj/MrFdDHlj/db8d9QTscNq5FmSh/QQc
regVvOignoj28dnn7jztJ8LbdRL6cTbPJUHcwosyz9B+EprrjG9NJb2sJ0Pe
5HnrcmM/68kQZd0Yzs2k80+BMsDOoBmj809Boln6I6yT7j8V4edmPEcl7P71
qf/Pc2n//Asucy2H
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0GtI01EYx/F/qyDTSKZYmlYuM11ibpqX6eZvF51zKihoRlEqKmSpoUnq
0iYoJGHLieIoGaVFiVCiUuE0LeelUCKKyiCK1GkpSPRC067sPAQ7cDh8+J7n
vDi+OcVpeTyO42R/97+Tluub9rPSrWOP7VqOfSXqEXs7kTnoFb2RB3nkLfAZ
N86VcWRXNF0UXvg8P8rsDqtpND1mmrwTwwJZYEM32RuK6tTGrzfIe+GbGv59
ooEsgNpjgX+zguyHnsqwj+dkZH+UKHcd6wgkB6Ba+Dz5tzNZiPpJa9jqjJU5
COb1glCxhRwMl1xLYbmRHIKsk1rpfDhZhImm4tdvD5DFWPRqtmhXRphDUfBl
431eKTkMFv+fV5LayYchdA/cJ21+yhwOldtgRp6eHAFryHZPQwc5Eum2/skz
fJqPQkF2uVPGNeoSyGcvvc86To7GuNyg2p1D92PgXKSbzByhLoVGwuvPaH3C
LIPZ8syvUzfMHItST6NTi40M8LaJ9vi/ZPf1gN/K/t4YPs3LMVc4e0uUSV2O
MRs/89AJ6gpEDIiPCPLZe3oFOodqbTuKqCsRJVk+b1gfZF0JbZnbt6zsIdZV
OFUhrw3WMetVuO3z4V3wBgvrcWgMWhv9lMOsj4OycnOjVvmI9Xi0HvWYNpgH
WI+HV0qkRJb2gHU1Ku90uS+19bGuRt3UemK+yMh6AqqqrwtO3zXH2nsC2nJd
Jh72DdjNaVC+MtOyZOphXQPX1bY0zlzD5hOxWrdQFRB3j72fiE01i1O/1ppY
16I+WtP1Ypr+x8FcEq6WmH74Xu5m3cFcskN3MJfi0P/7D3heM6A=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n9Q03Ucx/GvUmpmYaSEB5wuCTglTtlQGNJeMjcdw7FfLPQYAloXXRIY
l7U4+wplhqeGNDkwfo0JDdTCkx86ZD9AqJQk7JAcSNePM86RcKhHRVGd788/
7O57u8c9v+/P9/P93FeQ9ab2lfkcx+387/r/n/2W3qzLjV/c63ikCYm+vSL0
8wXMHI7kFsoCfJgXwWfI7Ns420NeCqsgMC/wAfMypPJNU2d/Yg6AXhh+T+Jh
DoJQ8asuvp15FZbkpPzurmB+Hq/F9FQ9eYA5BPnPFs3UJDGHouOabFOzlDkc
nVclNwZjmddg1JbZ0OS9Qo7Al4c+7pL3MUdC/ctoobKSeR0ygvYcVbzHvB4Z
+/9oD53oJkdB7GwL6zYyC9HUtaqyQMksginxo75PbnWRozEemnPMcpl5A7yx
jv7iEeaNWD7vG5Pd5CbHYG/fwENDA+ux+HOiaH96HetijOnXul33XOQ4nIus
En5YzrwJuy3m5YfrneR4ZAan3n73OPNLOL5aPHyXY5Zgn6c7Si/qJANTBz29
foWOR+YBy1mRym+AzG1G2s+v12jb6X5+Mxq/KL4TUt9BPQHV+VkFMaUXqSeg
zCo9cOdqC3Upol5egckyMi+FMS9b61l4gfoWxBkHM/82s74FIydKi8XRrdRl
sIfJvDMr6X5ehpBb34p2qJqpy5HXGSl+utVGXQ6Pa1fMhKuW+lbEFyW6lb4V
1LfiYqqqotffTH0bnnrHOHYo/ST1baielrb9U1JOXQGB34BtRTbrClgejq49
+PZn1BORcf9+7a76GuqJ6G59Yud3n56irsQL53d4I1OqqSsxZo3qedXIehK4
2KToZrCeBJfwg7sRHVbq23FzvOC0zk7P47eDG17mGZ0uo65CRsQz0VlhldRV
0KjjpLYHbP1kJDQ+vjfgOtt/Mla/9di1E7dLqauRc9nUsERO5wE1Aro8bu8i
Wp9XI0vU8+OFIFrfqcb7GwwGbRV7fw3Mvc3JXy+m84YGb/g784d82X41qJY7
sncnUHdqgBBBzkganRenRbmvLW3yB9ovtDClfHVmdsZC81osmHdk8jlDHc1r
4Vbss+q0DTSvg31lXVxgC50XdJhVDg8FXqHn8TqIL7WUnNJRd+oQceO0//Qx
Wp/Tw8ZLBkuG2LweU/bwS/1tZF6P4KPO2pLv6fty6jEuWLNxflUjzafgRZ+g
4N/2nKf5Oebn2DnHnGHOvAGFuX9d709vc/wL6KTNZg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0nsslWEcB/DjsqXjkkJa+iOlM0luueQgX5yO20FLZmpd1jiTe8nZauKN
PySNlqK0NZcslpCjHCLkLju2Soet2JxKqVBSk9Jlnp8/vNu7d5993+/zPO+7
n/nxxP1Rmjwez+vf/f9Jl6GqLMmD39O6pBnPqmyla5UemYeLlzoVcm2yDq6L
04v1NciGUH1w03CZ62Y2hrTr6GvVsjdgIH7Njvoh8iY80MzWiO0lb0Z+XobW
Wjl5C3wXtadkpWQLVAvGknVSyAJMefebRniQLeEYI7Qo0CVbwcbctj6yq4vZ
GjlPb9k8SiXboDIvtO6VGdkO9ye+J4UrOpntIR9pHvwTR3bA4IRNRKIzeRei
rcISPik7mB2xtVAtLHcnO6EmTT+zbB3ZGd2TL3N/KJ8wu2B01YGzhy3Iu9F1
NSN2m7Sd2RXvi77KhpzamIWYj4rOfahoZXbDwu3MUw7fHjO7w6SzwNaor5nZ
AyUiZZy7PXkPuGkffFzOPWE9n7f9yD0y0Lj4VtEralkyB/yqfiOedaX1vXBD
mhrjVcLMeSGMX9tUd4fO443SSIUu/yAz5w1Fk+nQwBnq+8CSa+rpS6S+D4yU
J6XvZqgvQn9aVrw0kvYXwTJ0zs61g/p7oSmTrA+YZ+fl9oKvHH22IG9iuRgq
jt8/s5H6YtgPT+5MeNHAcl8YOxiYjV1g73O+EAgFBsnnqO8H/u+284WzjSz3
g/HPFC31Zcr9Ic/ij35R0/7+uJufcyK9g/IArB6X1BdxlAfgeXurSe04Ow8v
EDc11OF605QH4rSuJLt9nr5PgiuKioZAGf2/FeYFrchXmBeM2UMTxdohbF64
YASNfD7GWdD8hOCaXUWSTzmbNy4Ew5UtNR3FNP/7lv0XWsFXSQ==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10QtMU1ccx/ELi4aBgg+czrAEkSCPDtGCVJ4/Wi1QBNrbNrDJZjQQRYO6
B5sJlZUQgREY6gYCJqMWFGktyJRSxJbWt/hAa40KpNsytsE003VbWFB0W/yf
JjfNJ9/zP+eedsW2PXyRN8dxqv+e/7/ZZ8GD9r3JvleHXutZqrt88+CkHzMH
hTTSEDaX2Qfh+qbltz1XyAvwR7q7rPoJcyBEkR9cm/eUeRmeOmdbv7zAHITH
H39m7eljDsaI4/PBhmbmEGyfP/9trok5FOYDshE3zxwGc2DduDWVORya8NsF
opuXyZEoz+p2rL7BLEDLmi/GDDrmaNTvbnxXXMscg7A3hPtrPZfIa/BnZkXI
9CPmtUj+9n5QxBVmIQYaMbTMh83Hor51V++zwYvkOHQ/lGjMEczr0Ft1sTxR
zByPk6X6LlP8BbIIdYt72op/dZDXoyYmd7bZypyAQpVrq/8McyI+7FMJGwTM
SfhHY/Ef0NnJyVhRkjT8kZE5BXnpGdEJS9l5qWj2a109EMYMyOLEtrhg2k8L
lNy41N+pZPunYbfl4F8p+bRem4b4u+f/FsWyLkabzvnN8q/oPK0Ye7qM6h2/
2KhL4D606HiTbpC6BFEpw+/4JJK5DQgcVb9oKjxHfQN+w/dt78+QuY1YL5A6
gg+aqW9E1IFEaX7SWepSBIy+jKhEH3UpNiv3S4ptPdTTMf0qYHxHgol6OpLW
ehX35Z2mnoE53BK5+jRZmwHXZMDejt9Zz8TOhV6VZXVnqGfCMRFS4NhC53Ey
nHBZPLUmeh+tDHNHxRNTx7+jnoXcsh7fT7ew/bNw78nOhSLvU9Q34fB7Ruu+
0G7qmzD99augqbsnqWdj1QObv7O6nXo20vzGrsd0tlHPQY7BYDCN66nnwNcl
3L7uBzKXC0fmyIRswkg9F5UGQc2+UnY/OY6eWrTyRRDdD3Jky0zyUrWB1sth
rZrkQ6Y6Xtsux1j9rfOPfdj7KVDB5y0ZOkrrocBZtctp8XTRvALJn7Qsnmyh
8+0KvNmgSYjV0305Hp1Xh/M9Bb00z+PmVPvPz0Pp99HyCJV62x7No/e186ie
dc8p8GLzSkRpjvxUUUTroYS5MLpId4zdVwln+/07lsPU7Uqce+uMoqqR3V+F
aGO9XvMj/Z9QQTLTwY/H9dO8Cl35JSuVKRaaV0EgzKveVtM/9C8ZV7MR
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10ntIk1EYBvAPJV2msewqGaRME7Xybl42n81515W3XFmKQzET0QIlVGha
YFFEphmyFWlDkYxmeUtym5d5yRQvqZHazBJDwkTojwixwvN+cPj48fCew3nf
46DIT8gy4zhO9G/9/9PHn31WILQa1G9rPWSk7b2bM4/MobcgzThuSebhS3f3
TP8uMh9F6Tclmq0B5n0wT0lYfLlOPoTkDHfHvFmyPWTiI0vHZshHISm7qHo6
QXZEf8/IbFI7WQDPb3bHWzRkZ+RsTednVpFdoLYUaBvKyK5oddg96neb7A7T
km2ppI58AuZV3k3CVrIH2qT18RavyJ740JG9PFRO9sLCmm6ndtbI7I2gteWp
znNkHwTLc61GrpF9kffL8PpuJdkPOpWza00D2R+DtWPOqyv9zKdwgefyPdSe
8gCoHS7bbYjIgeB5e5X2ceQgcDGBmhIh1QdjYLLGJbWxj1kIO928+Hk65SIo
Jq4X1xX0Moeg3TxJMefUwwxUbL7J/9hl2LYSmI+4JAgP6Wa5GDfi03Kl9cxK
MT75JIotvHQsl2DaqWVl4QDVS7Dh21ZdfL+T5aHouFd2689CK8tDsSPPrNm9
l5mTYkBV7HGlup3lUqgbXWs7BFQfhsOBw7Zhe7tYHoYfRvHSHS0zFw7jnGXn
qhudHw5TgjRRvsjMRUDDMyusjGP9UUZgIn1sU/hTz/JIaPYnTz3WsfsoI2Fy
5WzeHaT7RSHxgeNpgSXrlzIK6pqTJWot9TsaZzJTqkav0vnRsK4wmNQBb1ke
A0V5srFonPIYyKtSH37OpnnEgv/EOuOFgM1LGQtDLs9flkX7x8Hmd6GPaoXN
XxmHr3LZ2Uc59D5laOLvia1uHtKfF4jiK7Nl2JiMU/Dlw/q/49U6+A==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQMC1xcX2HId3w/hfbB/NjUg1oQPxmdwELNXb5kL
l+dwaObpPPiEEcYXcJgkZnNf7dUxKF/EIVT+jeOrxzC+hEPqVVPZ7KswvoyD
xFXzLukTML6CwzN5ly8bd8P4Sg78aa/5So/B+CoO682lzzvXw/hqDilqps6N
XjC+hoNMo9Ff7jgYX8tBtpb90ks5GF/HofjaU+05h49C+XoOR84s7rraAOMb
OBw+fuze3lUwvqGDsnSkgk8qjG/ksE1h8n1jaRjf2KE/eP4CP6MjUL6Jg5v4
DKdzrw5D+aYOF/Qn7pwnCJM3c4gVLHE2XAOTN3c4OOssE0sjjG/hsLCCe96F
FBjf0uGTyYXg+iuHoHwrh0NbMhYJHYHxrR1Un/7XcGSEqbdx2H9xfdTnHpi8
rYPJjgvrFy6F8e0cxPTf+5xIOQjl2zuULbsecNMCxndwMDiSVfaJHWpeg4PD
uwCHd78LYO53dNjy+ceaa2+h/AZHhyo759lP1sPknRzOGfRdFkuAhk+DkwOP
9o+1f6bC5J0dHils8ZF7CY2PBmeHVeZxlqUxJ6DyLg4/fq13sw88vh8AoSbN
6g==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0GtIU3EYx/GT2HQStZbpCqMS5yW1bZqac+pvus1rMhN8UdlFqIguar2I
TPGAL8oGYYXQYLSpJY2yC5qKYVqaMkoLBUtLrARriLdqtMjZhf5PMQ8cDh++
5/kfzrO5sGjnQQ+O45J+33+edIle1Rcn+vR1/tVcsq7KKIn5Zw55nsG3g0Vk
b3xRCcNVXmQRqhcVG/1ne5l9Ifvg6r7xiSxBuXV9fJ6NHIAhrwlpdR95E8wP
axrPNpMDoXA8sxvOkYPQ+dWzaVhBDsZRaXk+t4ociql7Jtn8xFPmLSjOmSrg
GsgRuDpf9yA0n7wVHgnHS8fiyHKMhVkiWm/1MCtgq7FK3xvIUcjsF9ZFDnQz
R8NXMSBtmCFvQ5b+cAvGyTFwDb6JFoyQYzHnf77D79IT5jg4js36m63k7VD6
pH1LlJHjIQoRaisLHzMrUdslbzO4upgTcHo0O3ZhiKzCconSZVlJ84mYjLH8
uOBNToI8JHwXksnJWNdWuXBZ2ckM5O7bowm7w87jgZlQa0vXSzpfjYvPjVXV
evY+r8Zixe5xgfgR6ylQDY2rj0TRfArKSp1+Yjl9LxUJSc6AzyVs33wqvpv2
WnynqWswXWQW5I6wffMaHJjSKcM+0v60uPkist3loq6F8V2TeT9P8zrYbYGr
rziYeR2uOWsHTw7TfBpMJ0aL9M3MfBrUPSFtb1fQ/6XDZlxWUbehg/V0rMlZ
q88WtLKe4W4+A2WHJOk/xU2sZ7qbz0Rjf1CV/cx91rPczWfhtUw62d57l/Vs
d/NLzO1Y0peYy0FvwXXnqRLa/3//ApJoPIc=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0A1M1HUcx/EzmiK2QjiYRAvhiJghgXABwXEfEAQOgeO44yEUyYkZKiC2
wMPi7xEnYUCIQxpzyOMlUgqN5EHihADTxoonjYbFqUiNp/CkJ6Bs9/3Vutv+
u732/n3+///+9nvTZSlP8Hi85MfXP//sZ36rNkNkNtBt0IJYuTHW9c4GZh6u
WamKw22YTaEW8fhrLJnNMct57Stb7ifz0euy+pvKhPVNWPqicf/Cv34OB8p6
T3nPsPOb4b+v+lT8t8wOWC2uaBcOMjsi/9ih4U0ZzE4YEkWJK72ZnZESUZJY
M9pH3oKprbY3t5xndsFUgrWv+TizK16cDKg+2sfsBp9Oh0Z/J2Z3jOvmk+LM
mLehPVUtDl7+kuyBKX6F7rUmZk9sdgwYqhMwC3GB/9XJvw72kl/BdPrhtzwX
e8he2OsT61lz9xrZGx+XKibOXGX2wbTYeqTJjJ1/FYLyQ0e88rRkXyjT3hRu
G2f2Q+HGjKTWy91kEZ4+0XHpdBvr/sj48/nhgiJmMT6yizfXi7rIQO0NP18u
u9NgDrDJ6VmzNEPmBeAPl36Ltc1t1APwY1rsosS3g3ognCuuWEnsyFwgdk0+
7B1MY307qjn3kokU1rej6OyjoHtB7dSD8FNqWHfgIrt/ENzdv5fkFl6hHgzd
xZXXuVut1IMxMNJdjtYW6juQE7XUllN9kfoOnLjxjX5upYF6CCybr6uvx9RT
D8EPpXfTrU9rqIdivX520C2R7UPxTJZcVyFlPQxrhcUO1b/WUg+D7AXHhyZ7
6H48CarGwjW77WqoS/Ag7+Rnoz2sh2Ms4/adAzK2D0fCZYdz9j3nqe9E572R
R1lXz1Lfia/l0zbKwArqEWha913oO1aV1COgs83JDellPRKLRWUdeaal1CNh
MW/bVSwg86LQ5GK3ch8F1KOgPNegeuNJ1qWIbBhO6jL5wGBI4aFMFL1fd4bO
S2HdnH9zK7/MYK0UmfudEoWuR2kfjXdTM6c+n8wUG/bRUNnfnzDfddhgLhrp
74XqkwdSaB+NkpY9ffwAtpdh4dMhj7crOXq+DOpcxc8tCx/S82VIWJ5Pbh6l
99HK8PKDgpn19dR5MVB9kn3hUjl9P8TgeOfAL7OV9L5cDPjHBJaFTkW0j0G2
/2r3nFZNezmcdvtlxfUV016OlzRxvwsi82kvR5UmTOPpTee1cgxMOSdVCfNo
r4BgzOLZ+kb2/gqMBZs6zmUdp/3jLu3asG6khPYKxD+l7L995CDtY/9vGJkz
sjYWejdFXYof+35xRnsjc0bW/ue/AUk17FI=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAmIQDQMC1xcX2HId3w/hfbC3vRZdcxrOZ3BgDWg5uwPO
53A4kzNdIPXvMShfwOHFE8ap/x/A+CIOMX/mXOs4AeNLOGz8q2JbugXGl3EI
apOIvNAE4ys4fO21UTSJgvGVHCaZWDz9rAPjqziUz71/1kcVxldzYDlvZuz5
/iiUr+FQNWvNauF1ML6WwwTtJYsnrYLxdRySdu/YMCsYxtdzcNTLTta0gPEN
HOImxF4VloDxDR1Kz0mflOCD8Y0c/hROPf7rxREo39jhQ2/KoyXbYXwTB9nN
0oob0mF8U4eoXft0dt87DOWbOVzec2Drsn8wvrlDxPH33YavYHwLB+FCk3Jv
Bxjf0iHgqvW1TwsOQflWDgw2gge+ScHkrR1uRv6sSDkPk7dxmPVjT/KnJTC+
rQPzPBupJlUY385Be53LxaJmGN/e4ZEe7x0tcRjfweFmksjWRC4ov8HBYf6n
7Mo5Hw5C5R0dEpQcWR25ofwGR4fg5oPaLDNh+p0clqbarF/ECfV/g5ND54Gw
E//VYOHn7LDM6feKRfHQ+GtwdnhZ3vV42XtYfLo4XJjyo+mD27H9r5Ovzbeq
dXH4dMk3SSDi5H4AyezZ8w==
           "]], 
          
          LineBox[{{41.119883742955075`, -0.198}, {
           42., -0.19410775894034404`}, {43., -0.18731502886098272`}, {
           44., -0.18042684434471032`}, {45., -0.15110111781722968`}, {
           46., -0.15297818731039783`}, {47., -0.1495164534604359}, {
           48., -0.1495164534604359}, {49., -0.1495164534604359}, {
           50., -0.14306115215386989`}, {51., -0.1495164534604359}, {
           52., -0.14185369859648958`}, {53., -0.14185369859648958`}}]}, 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1z38s1HEcx/Fvd+bMKv64kmHD6TI/EoUQXvl1fp07dptmKcIfZTorTEVd
ZZG4kNViIr9qTD9mflyHSxJZVyRJSz/0Q64m+mHmn36sz/u7fffdY8/v+73P
x26fMi6Nx3Fc6N/335ce88mGTH/TId1/LQSOqBp0n1eTOUTV1zQbrSGbwPP2
is3p5QfM5kgVGVtv46gLIWrPdypYob4BouMJ+q/TZGuUaSxMd4+RbeHD491Y
rSHbo+hb4fRIDdkBJi3VH1pVZDGUry/fWvEgO6Khwddy02ayE9Y5y0QBPLIL
lp6OKrgfg8ybYafVW8w8IW+BMk89c+Yo2R13zo/3KFPJHhDCK35VLHkrDCJe
n0xI3gbFaPZaqzf3mT1hVs+buV1K9kLLyd6EzEiyNzSDHfEFyeTtcK2rSh1r
GmD2wZDbgkAgJ/siYj7bxyOR7IciffiuFw7kHRi2Lpm/uXyP2R8Zst8TuWbU
A8C3/dm6mE4OhOSjdKpkPRnw6Na+rTRiVgHJ8X5Wjlto305kdPFLHuvusr4T
Lk7Ngl/lzFwQbJIO1/YL+1kPgsFZ5Z8vox6MKL1x8kCjjvVgxE2aiRXmfayH
QP2psP3icC/rIXArLj5UEU3zoThgv9g0nE7zoXg/WlYl9e5hPQyi3GOnvK9r
WA/D8+b9fIlay7oEvkeqg15O3WFdAssJ1ws5BcxcOK486c5ek0Tz4Rh6VR+S
Rv9zETAsnFFce0bzERDU34u3saf9keiOKcxx62NWRaLnoEF7qYl6FEzKe0o7
69h9VVEwCOf4yXx2Xy4aMl2Rdh9ZFY35lYemJo9oXoqQOYV6mUf7pdBcELct
7qUeg8SKEv10AJ0/Bhuv7hcHGnWxLoM65V3WCQvqMpyzTtlztrKbdTncl4Zq
0xqZIcf42y+zGZ3MKjnmiwfs89rYvrtyfP/kMhtU2cnmY5GlEJelGDp0fwD3
Bl7D
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1z2tI02EUx/E/ZpAXmNGkm2AOLVMxU7e8pPt53UzEy0yZImTD0BeWRGnN
1L/WlsLUwtA3GlZaWUa5ma5WrpluZUGC5Q2ExFsEWRmWplBG53ngcPjwhQOP
x/FTaXl2HMeJN+bfZs9l7FZRhKPN/F/fpPb1xuZJJ2YO79MvLLpvZt4CXpma
rFi3kl0wytfmGpaZhfhz0ncgcop5B8IEqjnuLbMb3JrKr2g7mPdgyeT6uLWC
WYQC+VJxrobZEzWlVfWLqcx7kfS7Wr2PY/aGpdBJKb43SPaBMF2CZQmzH8Z7
rk7bZgfI/ug4kXBDpWEOgHHXmzaVL/NBrNpP1VzreUkORE5RYv6ZBuYgSKo/
izQhzMEIXDc6iNX9ZDHO2cxDx7KZJZiVl7WNJjIfgqE9x8HXyhwCYe3Mdpk7
cyj2y6TTjiYLOQwjww2RIy0vyOFwErzb6mzHfBje41nYlNJHjkBM1fmW4aPP
yZFwbq6QLamZpRv/X0itmzCRAW3dgOXARzIP9KVljGTcYT0Kl9uD818VPqUe
BcUXD1lawBPq0ciL1T073UXmozF0+zq+Zhqpx0AfXXIzS0TmY1Dwc0H74343
9Vg0ehUrOwcN1GPR/WnNXzdD5uKQsu1Dd2ljF/U4rCh1mTsv6anHQzef7FNW
Tubjsfa6JNTT+Ii6DL+CMq13d5N5GcyChYvCcLrHyTFmijq74tVJXY75iaTG
Sr8H1BPQvxr2fVLCegIqe5uc56QPqR9Btt5H0eTaa/4L3CoMoQ==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11AlQlGUcBvAFmuIIOXJQGlTUWElsERFFjniQWxbcXdiFRUUSBcwMBSUW
ENcjDg8OudpFIcFgkREzjpBzXeSYRCrM8IgMJsQcLETYKE2r4f/uzDc7v3ne
5/2+b+f979Id8aJduhwOZ/d/1//f7GM6VLnP3bC3c06THglNNu7815g5MLcL
6Ch53kPWx3uK63Y3J5hNUdfyvdGDYeb5kKt+SeaOMi/EKUH9wOFBZito+BYb
GzqYrdHsWWjxuIV5GZLuTPGfVTK/gxNRirPFpcxclKuavi5IYbZFRVfuvAYh
80psdczf+cUC5lUwn/ENTljCzMPLq5czq7u6yavhvOCmQ0spswOS/ccslZPM
a1AOcfrFRmZHzE6d9ln+03XyWpiIFq1NcmN2gmSMs61vvIu8DjW6R2YjjZjX
Q7nU22CKx+wMr+IPvEeXMm+AjSpd5pqmIbugP97Y+o7wGtkV/rLdOu6h7WQ3
cG+lFrqYtZHd0eVWG91qwvw+EnOe3Bv6vYXsARMDQ7466ioZiOv7eLDRkSwH
Gn+OTHqhYes9cZR3LKfxCu0n98S7LRXTiw+1Ur4R2r8lsWYKsnwj4PnG8YIJ
1vdCzLbnuj8asdwLi/cYmp4WNlHujfyZifgLqWS5N5SH787qJF2h3Ad9y8oG
7URkuQ+yq7R6RdovKfdFzHenKqNX1FLuCyvJSSdzCev7wb6d55al+IpyP8wr
65ZURtRT7o/yfFtBxDraT+6P0quftG/lVlEegDrT/XqFmguUB2DyWf8Jrv05
yjeh2c8q45ZJJeWbUPfPA6u0WDInEMXNF1a1OZ2nPBDa3m9q29IUlPPxa6S5
5eiuKI+5nA99h/rxRmvRnDlBSH16CIr9adQPgtsPbXrn6nOpHwyXLdn3g1VZ
lAej++lB3S3RodTfjBSLSbNVxw5Qvhlmg6v3phlLKRfA99WTvBTD2DlDgMzC
R9PzGpJpvQCeUrW0Spg/Z7UAK22MP5LGldD9heBfqxrXTCjnDCGUmZqBgLLP
qS+EcVuOjLeHfi+1EMHCuJgP/2DvL8KKs3m8A7lnqC/CI9vXedvD6H5yEYLe
jHQv3ZlHfRG2xxmrWy9TzgmBn+vZ+yPTrB+CyQ16ex8HF1A/BGccJANHCz6j
fghqRqtloiZazwnFsINVzYyoiPqhaFdeujGcSO8nD8WQx13J8U72/KHongns
kr5dQX0x3jJIGanX0vmAGP5+sodXjlVTXwzlTO3JV/NrqC/GYlvLcq61ivoS
HCnR39YTQ4YEtSpO94ScnWcJnO0XeRTdu0h9CR5nXrLfdPsS9cNg6n1Do31K
+yMMndXhD3fsY+c5DJNcvsa7h+ZBHYZIi/T1B+PY/ITj2Z8vf+vNIiMcOv0h
5QvN6qgfjr+63BzH2Dypw1HtFHVmxIfNjxSmy/WLhrIbqC/Fp5XinMRImn+5
FBkdL9ZEnFdTX4ox+4yB2zL2/xUBa7uehG+XtHT+Cxy7Ga8=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zQtYzPkex/Gxu4XqrNaScjk7UaJICEnp0z2i6DpMTdM0TSNHSNpsYjZE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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90ltI01EcB/B5YdNctFBwpGuXxKIb29zUzbZ9d3EOUh8UQopRLSQKcVHD
FylnJdXIntxmDiUoIzGsaZEUuFW2TZY9SNbDWhMSYRCyZKuBLSr6/zpwOHz4
/s6VI7bZ2zrzWSyW/E//O1Ljfbx7TrMlHPinlK5/h0S7byuZhYRbcbmvhFyE
A1mUXfsRYszD59TAbm2aXIajnOTq6SyZjztp+4vWFXIlOCmxyxshi3CBsy3H
fkaWYPnd3KraQ66C8kNUGashV8PP9wwKZOQ9YAvjvnUpeS+6DnsmbGryfpT3
+m9NtpAPwtSZD4+TLMVs5cxw7//1ZchNOHoSv94wlkNz/oRonk+uwb2ZQZcp
j6zAKcHDsZs6shJuj6W58Pk841oYVJciCyuvGddhdCpeL+wi10M86UlEzGQV
vl883qoZe8VYDfaaT1YbJDegIrt0cnHzJeNDSN7+ZrEOBRlr8HjO2fOgkHIt
2OG6hkVrgLEOPHUqNlRM9cDyxs4zPgtT7wSk3PeZtQzN18N33W1M36dcj9J4
0ebVDJ3HAM7sjYJHEsoNOPYzNlIuovsYYebGhx0dzH5OI7rHq6d2PaH5Jsj9
20PBK0y90wTvgF2ZC1HeiORXx6eSKOWNUCrEqvV2el8zooKR0W4zY6cZxQXN
4/1eypvQNq11vX1KeRPY7WeP9MnpP1sg5JZWWYPhgOFLXsW03oKNpRYbr2Mh
8BvFsPtP
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz39MzHEcx/EvoZax6Chqye9YbunQr7vu1dV16q7uOpT8qK2Y32qhRq2y
8mNtobpUitJFKzSVOmZcXWjjxBQNmXVqSsWtObPCsN6fP/hu33332PPz/ny+
n4VxCeqdkzmOU/x5/37ZY9etTRTZtusnZBZXLpjqf3EmM4eBkis5FmtmG0R2
Lna/OpnZDsUFegfT+CMyD836qtJrX5gd0dpZ78QfZnZGVcjJkftdzK7QG0fd
0tqYF+FEYU2PuIF5CVSNprcbzjAvg7w2rHq2iNkN5588Ny0IZV6J8uLk5NS5
zO4wKMsi0+cx83E13p6/r/ch2QNmuX3F0jLm1fiW0newKYvZEyqlNFIiZRbA
KLzj930Z8xpsP1BT/PXlA/JaOA7GFQ28aSOvg8bmVrRBw+yF6EbT3osmZm9U
GcdqnVXMPogZ8LYb2mYg++KwaLmtq5B1P/QlpwtShlkXwmfs0qHqFayLsHlO
aVb/C9b9IemPzwjvbiWLMTal3ZvbwwwkmYs8n0yj9ZmALPGzd5cTmw9Ar6Wt
UpxD6zMDYFF+Gnp4tIW6BDPaNS0bE+9RlyDWdbgmILeJeiA2GKZnT0q4TT0Q
Xm2y4aHrrAdB6mKOHe+ppx6EQbUVb5ffDepS1O2zL7zZeZO6FBmGL9depJG5
YPCVx2zzXtdSD4ZLwpy7JRY2L0N1lKC69R3bX4aCE2FiYX8D9fUItNq+9gKP
7f+fuRCM8I9rHBPY/iE4VPbjl/N+MhcKScpct2eVddRDcTbe4e6nUTInx36e
ju+hqKEux4dTtU35uuvUFRDGvcoLMl6hrvjv/DD0pO4aeJ9F98kMQ1J+d2ii
VRX1cJi0t/3bzZXUw7HC1+mxLv4ydSWMrlm+GkctdSVUO3SD+VvKqauw48gW
webC0glDBXnHpuyhikJar8LpnRU/e+fnT7hFBZ/VstNbZ52h+Qg86tDErOrK
oPkINFhZFgbfOUfzEXjaLFW484poPgLHywJ9O6IqaF79r6GGIDta75xC/5+p
RtNuQy5nTfdrUeNjzEGfcp1W/xvIhYVT
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQMC1xcX2HId3w/hfbDXD/3quoATxmdw+HHxYsop
dhifw2H9VG2BNRwwvoCDx5LClCXfj0H5Ig7LhXz03V7B+BIOjs5q6/dsgfFl
HLIuSU3YNBXGV3Awtrn3/kEBjK/kEMW++Ye6CYyv4nAm8Zt+wOejUL6aw8uP
V+cFz4DxNRwE/718l2AF42s5tBdrWRb/OALl6zjM+/8i9PAsGF/PofPt38M3
zWB8AwdBI99cN3sY39DhwQaNhOD3h6F8I4fWOwXpmxtgfGOHs/O9vEuaYHwT
B9fwjc0/hGD6TR16XfbuelwKkzdzKNPt2tBQBuObO0hVvtn299IhKN/CQS30
489HQjB5S4dt++JWG/yCyVs5LJTps3k/G8a3dti3Qnz7M14Y38bh/Rnxj8VP
D0L5tg5/97bxr9OCyds5BH06Ul1WAePbO5zYcMfGw/EAlO/gcGJpi/J8aSi/
wcHBpOhrCqP1fqi8o8O8yBOPjX7tg8oD+Q2XTKYdgvIZnBzEM+1Ueb/vgso7
ORyZuVrik+1OqLyzQ5jKI+EnPdug8s4OS26fmBt5awtU3sVhEkdzaIzTDqi8
i4MNyyOxjo/bofKuDjP+XFiY8gHKb3B1OOmWemoHL8y/bnA+ADdC6uk=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90AtYzPkeBvC/itOuSjfWbFG6qA1RSLnUW8ToptvUlJrmUjMjm3ha1i3m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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxFzFtI01EAx/F/FqFDSGOYoLUusjJsN62Wbe43N+cis1y2LKkoUUdLN6YR
Mo0tNMkeYoYkGeW6yWyL1UBWpqXLrfChHkajmCHdzaWLHrLEbnjOOnA4fPj+
OKuOGDSVcQzD5Py9/156kkLXjFJW4OG8orIlFucFVcwMBNpGU3UcdTxqbfs2
GOb8xEkwa6IV7RFqNkx7OInhMHUq3At2jy56Qp2O9Nm2NY6r1Csx01d/2lpH
vRpfdfazb7dTZ+B87snpjBpqLsyiix9bY14H6bOpYHtsvx5cT9T0bWKEOAsO
VnKv10bNQ6Lyc7fvDLUAntqOc2PF1EIMeZzJ5QupReAv/e5vUD0mzoa+dJTN
XKHOwe3nl6vsTuqNsLVFpJOTPuJN8Gj3L4uXUG/GXqOPZ7g+TCyGZFiWcJhP
+xYEyjjMpR3UuUiwN0/9nqb7rVAf94qMJdQS5JkD716toJairEGrC9U8Is5D
Gmdk8PWLAWIZvnitvIouaoBv04caBwbnbQEOKthPe4QPSJfDk1lk7v5E9hY5
ml9CxismeyYfbkFvuEveT3o+bqUo1s423SNdgeWLf7Qc8xNbFKg+JarvnPCS
rkTWoZl0aWcf6Up8OCAsFevvkF4Ah7BExrhcpBcgs/JXUU/ESboKLbt+BrOr
3KSrMN4hlqayPKQX4r0heJ87Rv6zFGLoZjm36SjtaqTUuTRvQsQWNU6M626o
5u6Svg3Gnf3W1jT6/3//ASnOBKU=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgs41PkeBvD/ojgScSqHWk1lSyVFOS6ht0ZFueUyMm5jzDBalzaR0UmT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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zwtUjAkfx/GHlrK0bvHWWzTJyUqRpO0i/YpSKbpN03QZc2lqxqqN1nXJ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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQMC1xcX2HId3w/hfbBff0T+iT4LjM/g8HDHZPe7
f49B+RwO/8+a1zcwwuQFHDKWZ8w98wMmL+Jw5KZ9//QPML6Ew42Tx5Vn3IPx
ZRxuxiw7dHkbjK/gkKg189SBVTC+kkNYXMkqnpkwvorDpuz8Q6WJML6aQ90k
k9cWGTC+hgPbwSgRtggYX8uhofn6rIVRML6Ow+ll0xOEXh2F8vUcpNIFDvyK
h/ENHB49jhUyTYHxDR0U/vt8KTp5BMo3cpidJH3rwT8Y39ihOM78QeszGN/E
QWn5syO1x2F8UwfX+x9Scz7A+GYOF3d8tbT0g5lv7uD7zqnP+yNM3sLBQ4Jv
6X0XmLylwxbrxuvB7w9D+VYO65WMHvWtOgTlWzu8qTY+vDkFxrdxSHflk9f7
fRDKt3VYsUJp6nb/A1C+ncO5lMep62/D1Ns7hJv0MXW/hsk7OGzaXs3zaN0+
CL/BweHLT4WYrcq7ofKODosrXE43uG+Hyjs6WF7axPz61GaovJODwavGfZ4L
NkHlnRxu25Tktghugco7O7AEHYh6O2cXVN7ZQa51Q9CLMJj5Lg7LKz8bbg2F
2e/icIZVoe201l6ovKtD6eRTd/b+gcm7Olg17ti8aDbMfDeHaVezjvSc2QGV
d3PY38I551cxVD2Du8Nr5Yas6kpoeDe4O6TxTFh9OvPQfgD6KP3T
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zwlYzekeB/A/RRlbRpukDlJOsrcp6RuRitNp0b6cztZCTHbupGNEZu6E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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10ws41PkeBvBJoq2UVEtLp2GL0kokRcVrReNSbuM2yBiXIWUrrTbdRiFF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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WlIVFEYh/HrZDJlkbbTRolL2CA5Wmam/tVGZ1wnEa0s0xnXUNMW24wG
RTRIaLGaFpgPUka2jJjaqGMuWalpYjaKiFJiaGVpGdiCVPS+BR24HH4891zO
uWeNal94gkgQBP9fz++Zh1VPcYbn7CcP/2jcu37Mq0AiZguoFCXP3zmTLcbi
iOoPrtOPyVbYNcPwo/M9eyE6aiN2KUzspRA7rhwXt7BXQDRnlkPABfZqhAao
u+cfZdtAIbWzSExi20K2+7vJuJ9tj0p3kzxawl6LZb2epaN3msmO8O2/Hth9
gy2BR5o2e/ivnaDtM12aKGavxyOJ+lVdPNsZZtbHv8XZsqW4nXhG16diu2DI
p8FprYjtipNvS4KNxkfkDTho2p1ZU8LeCDfZCXW5C9sN/rF5brpy9iaMWbe+
UF9rIrsj9+aTmttv2JvxebjkgOgr2wNfjk0dNXvH3gLLtt5C/STbE7oVzstF
rY1kL0R2qnveubC9MZC58nK2toEMvFhkXXS1lKwBDEukR64M1FP3QcqJr/LN
ErLGB4cWxCgS8x5S90WwS9JpSbSRui9U5zLOj07WUvdD+1SyjzyJux9Sz8o8
8lv4+1shbn4dV6ek9zVbkdGercSUgboM+qGmqTztA+oyhEcotPnx3P1xaXth
uns9WeOPIq/BwtiiauoB0AxWPTOfrqQeAIOi10oVTxbkKL6V1Sh15S5HxuFT
Ol3IfeoKRHlM2KSUlVFXwBC/Cm0xeuqB6MoLM7+Yfod6IIT+gm7D+lLqQdgz
J1GT1nWXehBKdJNBI7Z0HiEYOXW2lVeby6n/ZyHkvx6C6ru5I2MWvL9QJBjd
5n7cUUE9FKnO+r3nY6qoh6FMb+kQ+Zx72K/zO9/4NsldiXXSDwo7Fe0HSmRP
VN17KeP/qYQ+K6ojJ5nur16JAV1phd0nsrAN8+zTzw2nPqX1//wTAOFpjg==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0X9Q03Ucx/EBRQQoRMjx62ISGGdYgPJTx14Mxs9tjDGmEiCSoWFc4Iws
Bw1RIQi6XcwDqfAEEcZAZCowUUcqcKYpUhrVRUQFXBDgxeWBcdXt/fmj7933
vve45/e1++77XZ/ztuwNSw6Hk/Hv+d+VHY4Pmwp4tkPXzFrgP1F46aqfY+bA
eqbjXKYDsw1yiiP91I7Mjtj+9/0t407MztgWZqq6a8/sitzIodFOC2ZPWN2N
jQ2eHyRz0aM3uiruMHujRrlaaWNi9sGwLHAmqo55A/K6/zwS1MTsh+TwT5ZC
VcwbsSJsME56MvtjZLkiaHED8yuQ/NKjb5+5SQ6AV4dD13Q/cyCaO7Q9Z12Y
g5CdeyqvcPIGeTOC3VRnf3qBeQuW8gfzf3NhDkaLd8lc6R/XySGw8t+81DDK
HAr/yYq/nrrwBTkMC3tD/Xgc5nAY9HdefeabAXIEdEnuzXvHmLfCV9OjHjlg
Im9DxuCItUtWP5kHFad/xYdvJEeCI7Z7efhYL5mP21OeowreJTIwXpT82YDo
otlqYI2+yMtt4gL1KFwP7RbWy7upR6FOs+vxsLSLugDah0u9XVdYF8BZUNhp
H0zmRGO1r3pHut5APRrfnrA4fbOBzImBzP2iaFzLegwqfi75eH092wuhLU7t
GW87T10I90XHU5OGVuqxWGgVR6zzPUM9Fk3lm1ZH55upx8Ens1T8pJLt43B4
rfH7nfc7qcfjctnuSxkTLdTjkXDw3Ne3d7ZRT4CNt+DzxQfs9xOgkoY5lMQ1
Uk/EWHi15Uv5h6gnQiGby6qakvLNPQlKu6+ihQPZ1JNwIKfxnlV4CO1FODzt
wS04Xme+Xy3Cmqg97TxXLe3F2D8rihfsOkldjEAn6f4+3WnqEiiX7QqVZa3U
JViJL4zVfcd6MqwlARvzLMjqZBTvaK5tyDxGXQp5r9uZqaxKsyFFwWp6dX6w
kJ5Xit4TuXPcvINmm6RI0Lw2vvbW+/T8Kfio3ai3uVVsNlKQ9KjovGW6hvYp
SPzBEL2vt5L2KfjVfnnIUVJLexmKN6l1cy9+SnsZ5LaPg1Iqa2gvwwf9X7Z0
7CmjvQwTz0aOTbdpaZ+K2e5O7iFlOe1T4TG18HupbRXtUxEUlvC67+WjtE/F
e30enFHnEtrLUdSoyg1xqqL/L8c7c1cMaV30PtRybJ9XSbjP15ptkiMgx/Nq
fcS79P7ScPLRVd0DKw3t01CQdLTpx3tkdRqGyvhdkfoPaZ8G5XDMW/lvHqG9
AjXrFFtnxeW0V4BrkD3ttpu+v1rx//tNCtzQlGZLZ/Zd+weUIsYj
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tI01EYx/G/pSEKY5GRooO8NVNnmpbl2vxt7qLOooQoEEstC1lqvVGo
tKUYFN1eWMGmZpmWN1Iqr9PUvDQwb2maYJISYbpM1DBEl9FzCjxwOHz48pzD
cU1IjU7cwHGcdG3/OdniDxedl9h1vf6rH6GSgj73UntmDo1107FbrJlt8cjS
mW7+Zz7OcrPiiflOsgO0ve+M/mZmRwh9vL40DzK7wDj6AXO9zNtRWC7cZDQy
u8GGr3ceuMTsgRzesqgpmnkH5hODmjO1zF6QRQ2pz2iYvWFl/p5kWukg+6K7
NDF01Mjsh7Ho+FzTUWZ/VJ9QiHscmANQ+zjl15HP7eTdSO7nj9iYmQPx9uNP
z9sW5iAYsu3uXvBh83tQd1iUeXqI9b3Ij2wXiFeZg2HjMPrgTjHzPvgppFZX
eMz74ZMnFzkOt5FDEJM+2bcYwyyG85K+9b7TG/IBlHVVDBkaWJfAKW3jvdSv
zFLYJo1nhBQwh8I3uyJPs43NA7Nh9hNuInpfB0wJTyWfW26lLoNwsi1uariF
ugw1c663VBFN1OUovSkeOeZP1slhWmnbZX21mXoYyrNUdrwqsi4MvJQZwXxR
A3UFBuOWem4ojdQVGFB7uvSb2f1K7JzLUDcsNFJXwqTK7wgufkFdBf37aklO
3ivqKnQslDRqUllXQ5kwW98+WENdDYG0WFbxhMyFwzlSsJq5WEU9HPq0p/GB
tSXUI7A54/qnrG90n27NtgbDs9xa6pGInUm6Zimk/+jWmdOgu9dDW1NZT12D
kONL3henq6lHQe1+ctJy+Tn1KATwxS/Ht5ZRP4ixhy2OnZpK6uvMHVrX//s3
eCxE9Q==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgk4FXoexvFjGRSVIkUYTCGVImnjeiNr9n139sOIW2m67XNESNQdtxru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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91Hk81Psex/Gp1CFHRynp0jVXN21K1LVUeFvDdKzZt5kxZsbRZolCp+F0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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90As4lIkex/GptlY6oYs4u5XL6aZyS5Ka1i/XhFzGbQx6x5gZtCcUIarZ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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVy11I02EUx/E/RrQsapaKUyGtYWOO1eZ/2daWP53TgVAZsQoq2UYNofeI
aOWSLnqBduFqZNRmZYLQrBvNLVDT2YYjYTDWojcmRGHMbVIXpkgv9ByiBw4P
H77nlFtO7D6cw3Gc8vf8+ekJE90ndbnhkb/K1oTDg0OfVpI5iDJBmU1IFiBb
GIm5C8hCdFn3m9P55Hw4RQrhubkQcxHeuebfK6bJpVgrv5Yz8IZchp2J6par
cfJ6hCoLQsP3yWJ0eI2Jpw5yBSJt1sANM1kCfNEsu7CCLMXCvQOunrsvmWXI
LSueabOQ5UjlfT0vsZE3Y2/aGrBIyQpwyee68FKyEq1TvKkqMs5chbPJ0qYp
D5nHwUnRE+ePILMKYqdjIHqEvAXTw77rhXZyNTLOb7su8XS/Fd/7PG8HTWQ1
fDJlvK+b9jXYs2GitzI2xrwN6dRj26F+shbOZxX9/jWjzDoEX59unUuSt+PV
EkNnJ0f7NdCJ0r3RM9SBj+IHcqOeuR3wRjceCxylXovYZ79JN/KC9VqMF/d4
/B+YuTrse3jnZ8ki3dfh+KlFy8UWutejxOsqb3YMsa6HRqCaMDf5Wa+HuAub
NLM+1utRFHdL7Ktus27AZEaddbvdrBuwfJ1mlk/dYr0B9hmBTSXtYL0BV8a0
q2PzzFwjdvCj6vQjF+uNuLzQHNbm3WTd+L/b//kXMGv+tQ==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10g0s1HEcx/EbG46Fmqgl81Aq3ZSHOop8jjtHnkOap2S11pqnxWi2OsoM
zfQwOqnIw5WTyuSpEzl3mqyolVNKk7M0icSs0tP6ff/bf/+99v4//L7//98m
MWXfER0OhyP6u/870mY6XJ3qadjX9V+zXs428m3BxmQOBkSFJ6QGZAPoWw3K
5pbVzKaos9bUcqfJZnhzf4VPzyh5DdKfJ4scx8iWkE5FbvykJFtDpUo7Xt1K
tkWMS7Udv5G8AaMWj60cLpDtUVehWJ8ZQ94MTaV4uD+Q7AD3A3NxPe9VzDzI
WzIV796SHVGpjOUOlpO3I7/1WawmnuyER/6y2yVfe5mdYZS1NWEoluwCp8xw
wccssivW+i1GZemTd6A4jRttF6Fk3omahrb4z+M9zHwUdJjl72+g7obkuIor
E9+ouyMxYaSk0YT6Liy3nyvNsKC+G5NSq6uz/d3MHlg9mbFcNU32RPFQPK/2
UBfzHsjDdYVJyofMXihwXzrc5EAGCrXpyl5Xdr0EsD3tGSKe7mRdgILSmHU/
chWsC5A4YXH3SxEzxxsHzSa0qWHtrHvD3Sgv2VD7gHUfZOf8vvchh7oPcnkv
eeFlbawLoT1/Ka/9OrNEiLEHZyJ03ej+ImiadKKkumy9EhFS1a9b23vo/r4Q
y8MtE/Np/b4oMq/P1pPR/GKsdC6wH+CyeSRiLNYFGY930nx+yC1S2/H5dL0f
eMFxT08Z0fv0h8e8TtOSgJ7vj7LLM4qwgQ7W92JBOJ9T/J3WvxfXVFViez2a
LwAj0sig2OoW1gPwYqb8YU1SK+uBOKJXYf5KQT0Q19bY+vdNNbEehLR3T7zu
qJtZD8L2FAf1Ip+9T04w6s1l/IRo+j7B2JTdoXczgeYPwWS5pn99HM0XgquG
3Fuyg/T9Q3FyIX7LjbOsIxSHp7nNv37S+aFwXPXYJFPO/r/uUAQIl7XHFPS/
h0F9cczo8lFV1x9OpGf2
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zw1MzHEcx/ErIeRC4bTaikauR0f03MddkU66k5ssnWQmW+uBmra0/dcW
eUiNycM8lemqS3eHwkykUijykNqy6DR5KGXmIfO8vt/+23//vfb+/7+/798l
MXXtVkuRSBTx7/7/5Gta5/m04MnNt0Y1HNpsTPDaN2YRZhzqCT0zhW2NDr+O
SncxexquQ5zs//0u2R4Z0v09dl1sCapLNVnZbWxHxCeVXphYwnbGpem7/VS5
7LnITA/Mtk1ju6JJO+GDIY49H6VNFYUvvdlueDBLGt8/0kSWQpDkZJbWsz0w
3lAlMQpsL5Q0jPOv28H2gay5uP63lL0I5abu3IBvjWQZZo8s1hoq2YvRaB9j
cySRvQQ/lbbmrxlsX2hM9+ULatlLkbsu1ljsz16G1JaF2mGHBrIfTtspLJK3
3iH7463x2Dun8/XkAEx6Vjk36QU7EB9mDT6/ep8dhCsdtw+d0fL3wfi40+g6
tYrnh8Cx3lySfpR7KIoGN3jbHGADrwKfRtXtJQuAdr3LoiexPH85Kk7qFs7j
+cJyDFp/DjaNdTnKstSOYudb1OWYU3BuINbzBnUFvH/pTjt43KSugN65cFBR
dp16GLYUX9C9SCILYQgYQNDztmvUw2FOKRiZKKF5QjgS4k5EHGaLVkA85FMo
vlZDfQUinUK83n8yUV+JKrd7j2MTK6ivxJDMd8E9qzLqEbBV7lK+cb1IPQIz
WzaajXnV1FdhSvuVgrp0miesgiRGU5tiY6AeibDNXmWtZ+l9IRJ9T8r17RaX
qSvRFdOT+tDM85XYtP5s0yTLKuqrIZpqkZXTy/uthnBXp2y00lOPQmfcqSJ5
P+0rRMEm7/VmB0vebw2OOu3ZK2+mecIapOVbfxn3g/8vGsLx1s7aPj4/GnZ+
Cfs9pTrqKsi/fFf6hJSMGirU6Pt6A43UBRWsAi63H9hmHPVtFfIPPjrRm0n7
itTodq8O366n86BGTfafrjudvI8aGeVZMk18JX2vxgC9/xdVQ22o
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAmIQDQMC1xcX2HId3w/hfbDfHvT6ggwnjM/gYGAly/NG
EMbncJihkVvJxQ3jCzhM/rdSlIcdxhdxyGhWfcQMN0/CYd+peQE9349B+TIO
385JNxyC8xUc7v0tn3D4IYyv5LAk4+Th7ztgfBUHHafM3PBkGF/NYZr43GCn
cBhfw6Hu/t4VwfowvpbDt1htOz0bGF/HwfJgyh5feRhfz8Hqn114+dmjUL6B
w9s5nIkOq2F8QwePp2qSrXB5I4d0/tgPB4xh+o0dvNzn3j3+EyZv4uC8wDXj
ZjOMb+rQKPI5+jYXjG/m8JrBfGalCoxv7nAykltoneMRKN/CIa0ikfHWhMNQ
vqWDTezRD5cPwvhWDpFsAkah22F8a4eHs10+5znC+DYO1etid7Oqw/i2Dp5G
6iVK2jC+nYP3PNZFT0Vh9ts7nA70mH1GBMZ3cJA6lMAXwArlNzg43Pd7LrVC
F6bf0eHppfw0VadDUHlHh6WcTswXMg5C5Z0cYoWWJZ84BuU3ODlc7Rac2X0N
qp7B2aFlS0DkvGioeQ3ODssO8+UsvAYz38WB9cG8MI890PBocHFIX/L+XGPA
0f0AVb7Ltg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11HlczIkfx/HZZFV+iehQrFGuXzddtB1vTAmV6a7pmG9zIz/JtTkHORbp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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdkwtMk1cYhkvRKUwUcQoRkLvOOQgVO53cXhAFASmUAr0iFxl2WLwMEQ3R
f0gQhSiuOOJEICAiOhQrKDClFXFugs5NLVE3wYirIEHFy1A3donfWbI1+dM8
ec77fd9//nNcUtaK0/g8Hm/T388//+xn3VOzzt/ykv4tPQkU7imA37/Mg3Tv
rvawCYwn4uYa9ZUHY98SW8Nf8tT+LJ/592DiF40VDDNvB+du7qnNLcYOOC8K
9Z16krEzQmYqtvXtYuwK1wNb1vtmMXYH32yl8VAk49mwSx0VtExg/D4cMmy3
+Dy7SPwBXn6WLOB3Mv4Q/ZrCCmMMYy9Ub9XXzxjH2Bv8Re9W1O7rJBZA2ng6
al4N4/lY212ukwYx9kHFy5mtXpaMF2CHMW77gt0XiIXosB53vSWY8UdYu3DQ
OvB6B/FCPJpdpTRrYLwIOZ33Ex50nSf+GKtuR+SZmhkvhsewdL15HWNfTNtp
n7lygLEfbu1dma92YOwPz6BKq4JpjAPgsj23ZX4f6xeIh9meXjaDzANFB6JK
C/OIOeChWOOlKDCQD8KWx07pDXV68kGw2ufzU7PdWfLBGOFdLFK2tpIPRrlq
5NF3DW3kl+AML2VdkpD5JfjTqDY1aprJh2CWnV3eo6RG8iFITrbxWdJxivxS
VK163pY18Tj5pXD77e6mRZdoPW8Z7iYqrnZ00XpuGe44tM/y/qaJfCg8c2p3
P7tHzIXCbe+d0F8GT5IPg87jRtbhZmIuDPJ+ufeFMOaX4/kGnzWb+9l8y+Es
7RoyM7L+4aj49fUUYVgD+XBYplqmHXQ+RD4Ckxrdisf2HyQfAfkP2Z5pjtXk
I7FjbvXQhum15CMxrU89dfGaGvIroLB2CTMmHia/Av6Ztt72QxXko5Cb59rg
6VJGPgoZFmNPJrlVkRehRy1rGwileTgRIqqyPbg8Vj8a7zhv0IaHUH1Ew7Ff
1W3u9CWtj0ZAppWvuYLyhmj0xGuPpx+tpHwMFopsknvu1VE+BqNzfY3q12w/
YmDS2i5w//Rrysfg7D2JenMG9eOJMSNWL5l+jvUXYyDDbU6djupxYoRfmPnK
aU895cW4NrlSPmeM5WPRm6PtziimfohFt6hlxGk+Oy+xSNw2qus9T94Qi/2O
+ZralBOUl+CPg1aGYh/63pDg2FFuYN5U8pwEBebDka32VM8ggajkZdMXQ/Q+
vDgUj2///b76GOXjoDFWhaeWsP2Og77/oWDjVTZ/HI6cK/25rJTm4cXjyHPB
oMqC6iMe422qzbZaU30uHrKy9EGtgM6bIR6JJ4T+9lN0lE/AgxyRM7+eGAlI
OhW7wmM5MZeAV6m6zqR8YkMC+iz2FxyqZ/dPiq7bFq7PHM9QXgq3Azfbb7qf
prwU1/zMuwsvs/5SBIxeqdWNsvMvg6r0aa6sge2/DLYzmjNTndh9kcFUHtR0
Lp3lZXij+dEkMLL55SjrVb4Q+rHzI8ew+7rJ46+w/ZNjvag8xOsx2z85LD7B
ET9zdn4VWB2ZPFbS9RXlFbASj+wsmr6P8grIi9M0vTe0lFegLWtb5VV9CeWV
2CTUBl/W5FNeiabc+lsWHp9TXomAoNUlW1/QfTMokdKYrZ78fV7g27zqv4z/
MaeCauPRNya/Gv1f+2JfAg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2Ecx/GDtDWkwGqo2KDSEJNaXpZl29xvF3U6Ncoa9iITp4HsxZrQ
xcztQEWK1ZssM0qxlBFaSlHatEnOW14iErK9cSUFBSEaVptZVPj8i86Bw+HD
9zk8/M95NhXb9pWGcByX9vv+86QrbOr2UXXocN+y5jRVS5Uj83/NQamYaBSL
yRLsNzp9gR9DzGFAW1723AJZiqsDjs9uPzkSS+4ekWOSLMOd0ht3PT3kjZhI
jDmi8pCjcWzWcj/kCnkzdM0/ZebD5FiUH3z7vC2aHIcXi9MdunuDzPHomu6t
b+HJW9GU2TJoO02Wo+NaZ7CmhJwAx6NY06V4ciK2VcyeL4whJ8Fue/Nx7XFy
Mi48VMgP2MkK5BdOmU8mkHdgb/WeilDXAHMKvB+sIl8UeSdkSv25BpOXeRfq
Fvp1iz5yKs7EmS0JveTdeJn05J1hO72vhMUeISkCdRVq8oO6Q6+eMqshda1K
9Ur7mdNQMLJu/bMIWq/BUNknq1NN6wHtcGt7+ahn2Twgqf1mt+b2sa5FZV3K
jPWym3Utxl8XnBptfMy6Dg3+lWNfHMy8Dt1jkpyLkV2s6+HSuKI01m7W9Qh3
G2cCD2h/A5yi4OreLWw+3oCs8TxXkZjmTUdnz3epOIr9bz4dZVVfNyjd9L0z
UH222LRinpnPwJr3TbeMfjqvmQjcrG1WTDLzmZCEq66fKKFuxH/nnxeYyxJ0
gblsQReYM0Fezw+1J9N8AnM5gi4wlyvoAnN5gv7PvwBT2zmT
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzX0sFHAcx/FLnlJCSJlWHioqoouQcx/hzsPhThjRylMpjcsKWwl1jZ4s
pOgWpyutZG2GMSWq87QeVMR6mFkt/yTm6Woy1Xx/a/ltv/322vv3/f0s41JD
EzU4HI7fn/33ZMuwXynl6XU8ntcY/13YEd7G5cwcZMjMRnoNmXXRutdR3bmM
2RDXbvHabHWYTTDrmDJboMW8Cos99NVnxtvJFrCNl0o0RpnXwSnKv7B7gNkK
kxaPqg/LmW2QpVJqm51j3oC07qdGlYnMtuiyvzy2L5R5EzQ1PL11f6rIW7BG
u1f4ooXZAUodw/2qWGZHJEmSLTPcmJ0QcS/2QvHIM/I2WOX3XmrOZubiYt3m
8zV85u2Y8zPVstFidoZsSKj4MvOU7AItE5lufC7zDvRvr3Xx0mN2hbpPWDKc
zuyGjGJBhKuM2R3h/SUxOfVPyDsh5leqJyKZPWD+7sdW88E2Mg+Dt6PPKhJZ
90TZd7PBsjFmPk5xrWIlzux9oFSqev4ri+ZzgI920iQYP6buhdqquszxsIfU
vXCoM8bow3QL9V1QiEUR2cNN1HehredBdvmOBureyPzlULD7UyN1bxzaoOLG
zNVS98GKK+4JhQbV1H0w7LnVoDROSd0Xx6YSj8p21lH3xaq3J1NEB6uoC9Cc
1L7e/j7dzxEgyvS5ehHvNHUhQiTaQybJKdSFKPw4uTF61Jm6Hxq/Curc8335
890PViebdBM6jlP3x13BVGDRHjnN+6Pi/WfzQZd06gE4vcSl3jhKQT0AY2lv
6mf3y6gHonX66tqBAX/qgfhm7cBZGZBMXYSag73cavkB+l+Enxd6lg69Kp43
JwhunPQ8d81S6kEYilw+oK9XQT0Ytq9trMfDldSDscwyta/hZSX1EIzkddyY
CbpJPQRdd8rtJvIU1MUIkueqc9dcnzfECF8dKhdxT9D9BW4VQ3rMWqNdWETz
kv+NBc5Z4NZ//g1gVldH
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90Qk0lXkfB/BLaU9ZMoWpq4mhhmg1hG/FkKVs1+66uxtpbDMtTN1qyKS3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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90As41PkeBvBJOkrKtdvmcaYkInJZsjl4U6ikxt2M28ww41aUSmcVZ2Kp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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1lHtUDegehjeDErpMTTe3XdQ0gwaZombqLZXuu/u93W7fkw5HJISNpRnp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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQs01GkfB/DpokiJ0sWSJqXaUsqILuRbbgnlThhmxjCTruhO9o80K6st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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxNkwtUzdkex4/mDvKMlCtUDCnSZI70UPqmovf7/Tid06lOeTWsSTVNHHFo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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzF1Ik3EUx/GHFU1k5NRpaaltrM20WlaWs2w/554CQ1bTCwURX8qELhoK
sihmkC9YG9LLhUNC2laYMKSMZQbOsnzZBl6ZN2WymKZjY0FMEcmK/qeLDhwO
H75wpPXXDJcFHMepfu+fSyOedxiL4qc8fxXV2JNmzJkiModKrKes7yDHIax3
B/K2kcX45OhI1H+bZJZAovPej34k7wavv2R+NkXeC+XPu6EMG3kfGh8+6mlt
Jcsw0mT/bLlBlkNVIKi+0EBWwDn4XFWlIGej3mX13ZGScxBZu3l+M/aB+SB+
PBl8EQmQDyN+xGvTrJGPQFV+j0vsJ+dhxnpgzhFHPoq+7PSv/ub3zMfgfJBl
8F8hH8ehcDAsfk3Ox3ht9auaXPIJ5BbKPfunJ5hPIk1itcwKyQVQyG47vTlk
NUqjseCQhVyIutjGaLKbfApD5i8m4wr5NHwtLRLBU3IR9mz1yWZT3zGfQXNw
7HuZiKxBwy5Dd10+GehVK229RuZbAJ8g0tS20b9iPJYGuhJc1IvRORlammh8
y7oWaRFh2K8cZ12LnRXty/arY6yXoHNVXea6/ob1EpiS5Asd3aOs6xBa0Mr7
0z2s69Am3EiZX2TmeCwulVeZUodZ53HRuOzmfczcWWxPFje9nB5g/T9z5/75
F4Sj6r8=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxF0ntIk1EYBvAPJRFZtkauRRZ2YYtubn6bpuvbHp26JWZZbYOgaWKWWWwG
waSCWRTJLGxLNto/2ZgNkUGkiBgOdMtJ0I0sk6KwDZoQJnSh27rQ99aBw+HH
c24v56xpsO45lMYwjPJ3/zNSEz7z27isifBfvdc2vTK7/JlkBhHWqtmSTc5E
4NtD2ZSALIR9OpXj+3KX9zKcPDu0f+GfJQiNyEO+ODkXA4PVyZkH5Dxc2ck6
x+6T1+JMzc255inyesxlFylaAmQpPKKcmYibvAGLg8ulGQPkjfDuteze1E/e
jFNiEXfuOnkr0ms+HWkHWY7Glb0eQRpZga7uTnl8Osq7ACqhyZxwkVlYjewb
jZysxKLkcEA4GeGtwoXc4a+f28iFUN9wXrZoyUWImTwZb1nyNqxS+Qo5MbkY
L8M/XSYNuQQeY7t5tp6sRnp9ww97ZJz3dvhts8lwdIw3h6Oaez3H9pE1WMG1
quv8ZC0u2peWGFS0HuhXuD9WPeVzB/Cir/dDcYzml0I1cbrtWjd/vqMUoqDy
e4+F6i/DuroDiY4o5WVQim8/et5E++tw+JI+6IrT/jqMS+7s0kUpL8eJ5j7p
UJi3oxwteYKYt5bqrUC+5TxTbeLfx1EB5XxHqtVLeSWM73RVSyS0vhLuq5Ov
R/Ppfno4tQdTowuU69HIjdhqu+j/GlBgNEuynvDzHQasToQGO+ep/h24JXvs
lR2n+//3L1r0Bf8=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10Qk41fkeBvBDi33GxDVF9RwmmnCKtKK89rVJnHMs4WzOOVoulYm65prT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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0glIFFEcx/FpS1cFUbSiY7U08yjx6FBT136u97mzaxYVUpklrZaWByZY
a25CFlIZFpVmVrpIm2ZlXuiW10aGCJpoIl2ESuoqRlaUFf5f0MAwfPi+P2+G
eTbxKfJDAo7jwv7cf5/sMh+4kyo26WpdkH67ojApd48xM4cbAufSUDNmI+xz
KORDhczmcF9xZe/9753kpXg7k9b1bJp5BdLnMwV5emYRsvoaJtcMMa/Fy8qK
kNttzLawzs0fyT/HbAedmn8zdJDZHvKy4aSczcyOkNW3WGZ/6SBvQEOaWOec
w+wMv/lUp3VezC64mVveaCFkdkNbQODsMkU72R2dh63issrbyJswo0+zqdMw
b0ZO9btgVfNz8hYMr+qNcTNh3oopb8FS+cAzsgd0irO3RlyZPZHSK5rS7NCS
vaAaHZNVeTFvw+eTE3mwZfbGnGvZMVODVrIPfL+f8lm8pIXsi+UFloYKaTNZ
jPcaVeGu3HqyHz7ZDUrWGT0hb8f6bqFuUcojMjBRIRRFFtUuWAnMxF7QNL4i
c/4Qq80bBa9Z90dyRFmPw4HH1CU48z7xY8NRslIC7YkLx9XfWA+A8JjSPrX0
KfUAXNsfyDfq2fsEInGVuKkVZGUgEvZOV+mu1FAPQuRsRn+vCVkZhLjFnltL
AjTUg6GTeFmttqumHgy3okHjryIyF4KY0RErKV9BPQTjs29aXRMqqYfCwtii
sk+uph4Kq13qe2YqWs+FoeXHaZFh813qYeh8vTLb2prNh8PGySlZ8vQW9XD0
fDg/Vjp+lXoETO2lBjFzl6lHQLtax0UHX6Ieid2KZKOaByrqkejMi+K0Lmw+
CpnFGY6F9UXUoyCeqrDIXsl6NF7Upnf/3Mn2j0bTL4+wguhS6lL4PnZwjUss
oS7F2dhTc9eLy6nz/xs8jpzfaPbK8Q6t5+GTrvdrcKPv1fLoKG63j59k/0eG
/umji4LUD2leBkM+6VP4MrJSBr+LuoF0Bzo/WhnKput6RYPs/Mn/+TdlDW2L

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90wlUjeseBvCNJGWIBkM5Z3dNISquDE2PVJrTPGuPldJAhkNoc++1CBni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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90Ak0leseBvAv1aEUnUSjgw6iwRVFKddDaJch85BpY29b0xGJZrtBqJym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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zH8s1HEcx/Ev0TDCRCgRFpcfU6dQ4XU4P47jxLK1cU0/9Gvpaqkcc42c
brYcJlZ/VEqWVtcPoR/Ob8KiJDNWYhptfqXJbP3cvT99t+++e+z5en83pabv
OaTPcZzw7/vvyx6LocpTgSadWp3mg+0V6sARI2YOFllqY6//NsIdoZ9n6M8O
sgVOeph4WK8wr4WTwXZh6SSzLWomAqS2I8wbkJEwbZHSw+yE0WpjpKqYnWEu
GJrvSWJ2Bb9f42sfw7wZKrnUatmN2R2/vaqk56bbyVvA65VOpTcwe8JtxuXM
VhGzN96Y66lvzbeRfXBtrPiusZJ5K3qsuGLnIuZteC8PsbshYuZjUPx6U0sq
sy8ubH7a2FHDvB2DJXPDpZ7MO6A0W5obbGol++FF/zpLx0Jmf7zNXsg5/q2F
HAD38bYwfSPWd8JH2Tq7xpD1XeDzP+Wk/Gwm7wZ/bO/1psusByJuUZYkd2YO
gmajcVnuMNsHI6PcZu7eLy0Z8Ip07Oy3btRZARyYDRqwziZzAizXW1bb1byk
LoCSZ327W/8V9RC4aObGTe3YfQgmV4vy1J6050Jx76w45PAT2itCkT/cV7Fl
7QvqYbC0dCiUrSIrwpC2UhGWl9lAXYjS9DXOvUZkhRBd467vykrrqIdj/5JA
XDJTSz0cfJtl1fp4MheBI819xwdvPKYegdMfOury6zXUI9En8JMkn7hPPRKd
E8rkqbQH1KNgM+rjesyjmnoUxmKzvpb/fkhdBNOSz1I9f/Z/ER5mvJysf8b+
H42eVrOoH7W0V0Qj3LvgkdyB9lwM8guude+7Wkk9Bl+C7KYXxBepi9F1VDHS
n50QrOti+Bver/puf1BnLhbuTu+aDSpUdB8LzUCLC69dSfdxSLT6pb0zcYV6
HF6FF+/lPSukLoGsVvH8fG6RzpBAyl1SmchltJfAXzZ58/QE7Zsk+NiXWMzX
ZtJ9PFoduiSL68u0fwDa0FkI
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10glYzPseBvA5uUhuIUVSGlqkRZ20oNRLk5Qo077NWjPRsT26lkhDroN7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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzFtI02EYx/E/KahLcyOhgrKcIp7zlJa5/Dm3eZjGGnaTHWBQDndh5ulC
iT8IlUahxRQ2ImqiGS03NMWZztRKMsxDuByKFpQHpEQ6XKRZ0ftc9H/h5eXD
93mfIF2x9vw2juNkf+7fl47YZbkoE710/tNaWmDBa9zwJnMYN3rPO73I3gjS
+H7M2XrBLMaQr3Xq5xdyAKLOtHj1zpJ3Y1XiPNE6R94L8y93Vfcg+QDehvqL
Jx1kKUpPR57V15FDUBY++tmjkhwKidRdnMGTw1DjcJnc8eQIPNxe17UZRo6C
ubl9gXc8Z46BeWyf69Yjciw+zQaL/dvIcbAZ/fpSrOR4GAzzAytmcgIqDLXD
bVpyIgyDlvwmT/IhJGxI/O5vDjMn4YelqqFwB/VkbFj3vOKCyYdxtVRk631P
80ewa8qo0L0hp6DBJLu8KCUfxck1dfyKa4g5Ffz0orrFj7oMeaNFRctJ5GOQ
jKx7dCST0zARLZ+4Nkn/gRj9yP6ZcdZ54FT3TLi9nno6eowPfMR26unoc19v
1/jQPjl4RaLl6TSb5+Xor5Wt6b8Nsp6Biti4nZuOZ6xnYD3S6PzaTPsVyK4e
MXj2UFfgdsg9zfcL1JUoHp37EPpugHUlAu88lnWCmVMh4G651nSpj3UV6hdM
SlF+P+uZqNc2VqsKu1jPhLXJnNC49IT1LFypbC0/GN3Jeha2NEsDyyUdrGej
pLkgoibQxno2bNGZM4t6Zi7nf/MCc2pBF5jLFfRcLMhTV8us7aznCbrA3HHo
zqlvjvnYnb8BlWI++w==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQMC1xcX2HId3w/hfbCv8GVLW8oG4zM4zHys0f33
9zEon8Nh/fIv/0p/wvgCDkdmHp35/BWML+Lg2Cvk9OcRjC/hMIXZ78rTnTC+
jIPcq71i65fC+AoOpfxVez4tg/GVHCI+n+O8XwLjqzg8+qYdrZwK46s5fDWO
7VkbBONrOHRd6lx/kg/G13I4rZ+Y8WfbUShfx2HB/l2lDBtgfD0H75m8J/kK
YHwDB53AQ1Y/bGF8QwfmlelP5E4dgfKNHObZTSrpioPxjR0iL3lbFxjD+CYO
Uv/3GfOnwPimDh1X8vyEbWF8Mwdmr7jSwCAY39zhEE/fipD7h6F8Cwe5wN0W
4Y9gfEuH3G0t3pMfw/hWDqFVnB9+rIPxrR301jx+x+l3CMq3cQjOyow7Kg/j
2zrMecxXNC32IJRv55AXfeV15RYY397Boz/le1cCTL2Dw2eJ2QFWnVB+g4PD
7bkLdsefhMk7OhzYyvpz4z2o/Q2ODtG6e+J+iMD84+Rwni8l6Y8KNPwanBw8
vVlsYvRg8s4OF5pv/GiYBNPv7CB/9trKhAiYvIuD5rKHtXdfweRdHAwSO2uE
jsDkXVH5Da4OOcnLM1cshKVPN4dNWgmBe8pP7I87eJLrmLibw6dLvkkCESf3
AwC/me3n
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQMC1xcX2HId3w/hfbAvYn5Z85kTxmdwaKxx6Xv7
5xiUz+Gw9475dqa/ML6Ag90R1e6OfzC+iEOnQXKi4nMYX8LhRmTnpPlHYHwZ
h9uBGQ8jl8L4Cg7Xapb5p1fA+EoO2ldzF+mHwPgqDoI3hR6FOcH4ag4yMVUq
bdowvobDS6MkfgEeGF/LYb96/cqkhUehfB2Hw80/nsY6w/h6Dieipa8elobx
DRym/dNq7n90BMo3dGDdOPHmpGgY38hhyears6I3HYbyjR0e5wVvnzEZxjdx
2CqwsW6xOIxv6hBc2ro1TwbGN3N4EHehfLIQjG/u8CdRNub0xINQvoXDtdQG
hzQXGN/SoTHt9gY100NQvpXDAw1bW6somLy1Q+jk6y9TDQ5A+TYOZj4Fnf5n
YHxbh6++LkebjsPU2zl0a05k+bcPxrd32Hu9dBW/I8x8BwfGM7xmV5ug8g0O
DlcvN181NIDJOzrMmyDr/vYPTN7RITThxlRdn71QeScHntUcaUm1e6DyTg7f
VuwK7PqwCyrv7PCyvFK7bv1uqLyzg+DmC+LuO6HqGVwcPN3lHS6KwMx3cdiW
lFXwKRLmH1eHdcZ3ts0/tA0q7+ogsqR5Qt6jTVB5N4fTU0yMMxK3QuURfADu
iueR
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zntIE1AUx/ElVqtcLBgyakjZjGamzk3Tbc7fnNNVGrRRmlAxaZGgaTrR
msaIWaMsegptCEp/BJUPGOmQ2Sx1kmVDsWT5KMqiB0WtUMHMiu65cLl8+HIP
Z1NRmcEcxuFwZH/vv5cOf/xWefrqQd9/fcuwGw3BhjAyB88qagOfw8lcKP3S
lmscMh9vq6dih777mQWYT1tb1z1BFqJALpz+FCCLEJH/Iv9JK3kjbh6Yi9zc
To5GN5pNpstkMbYvqWdqreQtcNSHiv27yFvhsdoDnWvIsdA474yPDA8wx6H0
2PmTX9rJ8VAWCwfUh8iJUL//KCrRk6VofjkSVMaQkyCZEghGZ/qZZeAFYlxR
J8hy7C0U3vVO9DEno84Vd6XeRU7Bqlei23nBR8w7MJ3Yv1+iIacivemo0fz8
IXMahrWTjuVGsgKNV08NVjWTldBJLTUbLpBVkInPcBP55HR0TI/5+EEfsxr7
uF/Ltjl6mTNQ7vk5b44nA3223KChldkGWLpKxLmz1DWwOE/LIg6y+TYNZm9E
NQ7V0P6Z+H29h8cbo/+ZWKEIuXemUNdiXWGkx1RJXQtJ3eF7Z9tofhZ4zkVt
dQLb15YFcbJ/qb/yAes6JITfj/4h9LKuw+5LfukyRQ/r2Xi6Psn7brGT9WzM
LVhLPzS4Wc9B18perkrQwnoOvBW1Ep2hg3U9Fi5Opv5S0X56yM+1VR3vdfv2
2F/3HHmjR2g0r4hf8Nj3BzoSA6w=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1kws0lHkfx4fV6n5TedsWEyVJKFLk8mUI5X4d97kYI5kybVISoyQVSy61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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVzAlIk3EYx/E3jQ6LWFK5IqmGEw0Vs7VZav7mcmpuutaoKCs0W3aYGS3N
SKZpdDA1sAuNjnWsoZVlpjavmZoJlQkanYZHZUZTkAkjO/D/FL3w5+XD93me
RQkp6u1OHMfJfr8/f/p4XcZ9IS4tdeOyhZYkzHrlzCNz6Km46uvKJ0+Be43O
YP3beWj0Cqid62hmngXbCXndzQEyH5Me1iSXD5Hnw1wW+zrYQl6I9bGSo0Yj
WYAfs1PahnLIHhDesFQkZZI94V313pSTSPbCik7Twb0gL4bmFD/AV0D2wfP0
0YmG0iZmP6x9JhkrTCL744v8lqKv/jHzEth73Xzq8skBGOgv6h7eRV4K4+HU
Tc5uZBGu6ax5fp8amZdhnfbYTNVu6mJ07Pm2X3ucLIGpJ9Pc1koOxIYdBd1y
G+0vh2BqkfRnMvUVcDmE5Kcq6kFQO3emjaRbmYPRrz5yN8ezgTkE7sLa0dmV
5JVofx4y8kNLDkXH2bgwsbWeGRA2FTt0aXXj1gNv8+1ez2Ywc1K8K821OdbW
si6FR7z3vY9ZFtbD0P7uToxyDvUwGLaLFijimTkZDJoP7dkX2bxehm2tfc2l
ebS/CkGpWxyWhmrWV4Hz5y2Xuj5iPRw824XwK6Ia1sMx2TEpNDOfzXNyyJ1E
WbXX6b4cO0+3XmnZU8l6BMTmysIz2gesR2AO355l6KpgPRLqF7cO2Y33WY+E
piVX6LapnPUofNw6cTTOn1kfhQMSgd3nJPXV6C3werkkkPpqnJ+3W5YxTPej
8cSsSHwzl1kfjYwh69nBQeoKmJ5kxI+paV+B6Tpt4K7vZawrcSlAryyx3WZd
iY2bedM81phYj4Exoupz/4TLrMfgnNXVN1HM5rlYFGuqo+WFtB8LwYtjA11J
Jayr/jdUyM7+unCMz+7r//kXuedazw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10ns0lXseBvA3UYjSMCJdhJpcpk6HEpEH5Zb7Ru72hb2lhm5npUJv6XRO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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQMC1xcX2HId3w/hfbCf9v322TxRGJ/BQcQiYdZR
ERifw2GrTMdntv/HoHwBh1dNqzjrWGHyIg4v7vyXrf4Ck5dw2KATPf/FFRhf
xmHNqpftBXthfAWHtJnP3q7aBOMrObT7buPSmADjqzh0zamcIBEK46s5HK4K
kJlhCeNrOGjV7Fv2WgfG13JISO+WqzhzFMrXcfAujvhrux3G13MISG5MVkuF
8Q0crnDZh06WgfENHZYsr7nAaXoEyjdykJ/Eu0ygAMY3drifYqT55+FhKN/E
4ceZw69iC2B8U4ctO255N98/BOWbOWSUVc/8GALjmzskNQT5HLgD41s49Ozf
VrtqIYxv6ZD/OUzwhTWMb+XwKfSmTqb3QSjf2uFgJ6tUyskDUL6NQ6Kz2fEv
RvuhfFuHsjqFtCprGN/OYWnypIaDr/dC+fYOvnOaPcOe7YHyHRwebIg3On4R
ym9wcJCSXj/F8MA2qLyjw0OBLdWzWXZA5R0dXgaLt83LhvIZnBzsTp22szWH
yTs5fGVfI8JUsQ8q7+xwUcb967y7u6Dyzg7qz9vybkisgsq7wPkA3srO3Q==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwk4FHgfB/B5iYrSIZKSKdpOpUSlrO+4j5hBxLiGmWEi+6qmLF3Tqm11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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zws0lHkfB/DR0pu1Nqd0IxIiLV0oovAtIbdMGPfLjJkxI12U3sqSphNF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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0gtMVXUcB/Djc2JAoFdhqwzoAgLGQDTkceHLBeTNhct98Ji8jBYZT4WI
bnIWBmIrKyAGjC5vUUGBifFIvGLgIxFiLNQW6aAUCZKHKSZSzd+/xT3b2dln
3/Pd//c//2ManyJNWMlxXNI/979PdhmM1KSK1l86/1wP3Pc2RJ64Y8DM4WhP
VnWgDvM6SHKaHEsW+8gGeLslaGb6d2YBksoVZwZHmY0x6D8qHj/F/DJc2+rG
HQ8zmyB4yl161JvZDM7RGV7bjZmFeKYRyW2u95ItEGman/z5F8xbsTn2hiI0
itkaa34Uf110kHkbXGNfnLtiw2yLj8uN3fIGviPb4ZzkZIrRbWZ7PEz9XndV
BfN2ZFdmXOgzYXbAaNbdFdyzi+QdUOQmvFI/xrwT7/SGys1MmN/A+qWC1bP7
e8iOcFq7b0Goz7wLFoufNDQ7MTthVu1io1fD7AzjBOvX5qcvkF3g8suTpsuf
Mrvi0fsjPs35zCLsUKWr+pOZ3XC6WjUT/oOG7I646va1T/RYDnS6bawuFZJ5
oN4kw0Mg7qbcA5HHY2peHe+k3AMJ+pds04O6KBdjJHvk1+LoDsrFcHvrJcmm
D+h9zhPfqI71TVXQ+7wncqaak2PKWd8LZZ3TKseBc5R7gSsz7O3qY/N6Q4q0
6PJ6Mu+N+MrWx8L9bP7dWHIua427zubfje78JN+wtPOU+6Ds3meyWyO0H94H
6rPCrPnbtB7nixK7fZN7HrHcFzIrY0O9GZb7gV8tjpsWfku5H8YGM08Oidj3
8cf9r1pvTHzI+v7I/q0ucUsV218Alp4GPl7X0U55AGr8+Qz5R2coD0ROcZJi
o10b5YE4XF9UY2XeSnkQ8qILay3+PEF5EPRcDTQbVjRRHgwHSz/RT5vIfDBC
OkoLvrRnuQRGRXNb081ZLsFTl//3Q9DY51g0fK/xuRGCYEkT37WLzIfAKWC4
KaqdrNEyF7rcCEWuR36iXmoN9bWs0TInXW5omZdCUtg9ZLvE+lIYnF0zGztX
S/0wBDUesbv8sJ76YWj4I19WNkbmw3D1lKOgO76O+mEwv2WaN9pG5mQQe7pu
c/AhQwa3hdqdC7ZsfRmE1iZvJvZXU1+GlGtXFsuH2PxyjOceNHxhinLIkbYy
R3fPX2rqyyGoGimeV1dRX45r7aLm2H4yp8Ahs4Hjd1bRfqCAQhPz8wGe9RUQ
qDqUec4V1FfgvUxdzwNzbH0lhq2U6inTY9RXIvLdfP/X77L9K6FjuWFiyPk0
9ZUIMypQ3hc0Uz8c6tmbkJVSjnBMZu89dLGB/W/hsJxYjDKybaF+OFqMBx7w
Wez8I3BV7HtzczM7/wiEaooydexZPwJbegoH9LNYPwKVk+59Jd1kLnK5oWVe
yxotc1H/+W+0WDfC
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11Hk01Qkfx/FbRApp8YyMipA0ikakUj5IJfuSLXI3997yJClRqX6kqUST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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzWtIk1Ecx/EH9al1MaW8kUo6RFLKe2bp4346N+dmQwfZlQTNMhdplpAM
cy8SQWIFRkyUFCUx35jlZXmvec8Kaeq6UAhhxUgjrLB5qej8e+GBw+HD93/O
8c/K1+Q4cBwn/Nl/T1quMw0FwuaR/n/6Kgl6XibNcyZzWHmq3BArIoswJX0R
Ob00zOyKE+7Nv64tkt1gfMmvXHxD9oLGEH1j+jHZBztt7YPqOrIfVOmN35wq
yWLIs/mt1nxyABzMik1cBTkQ5V3W1bAi8m4Mp8ZNK93JwbD5GHiPpSHmPeC2
OLqNNZBDkLl2xdItJoeh6GdJS8naIHM40qZyjRccqUegtF7rW1xOPRJ9E0fS
ZBw5CjWaqDu3vcj70Kx+oshJJUejSvfR35sn78dqrUbMpZNj4KlM8DNZzcwH
oMkMqK+1kQ8i/keH09wxmo9F2dujjTVXyXGoMljGR17RvADfYOH19iZyPOw9
fvOHb5IlCBHpxO8S6T7w+VJFYHU163qgOEgbPtM/wHoCZrXBse2aPtYT8MFj
ouW7sZf1ROw1XJ48O0c9ETbZsMu9bf2sS9Gl856tFKhL4fwlZHToNN1Pwi2z
1l52pov1JIQ2i42DFT2syzCara09nsusl2F5VWTwTnvEuhzyFvW56rvdrMth
vx/BL2Sw97hkRDgkfRoYY/P6ZITWWzo9XTpZV6BpwWyZlHWwrsB86C5L0/gD
1lNwSuBLw3qZ9SlY5E9OFj17yLoSee6FEpWplXUl+nYUprQJzJwK52OWszb6
trGuQmtB1Xt7BvuPS8V1SW6pSWdifZ25Q+v6OnPq//4NnlQzHg==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10Qs41PkeBvCJpY7IJbpvRqHLoaV0scgbchvEmNwvM+ZCW5soD05ikFM5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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n8s1HEcx/EvU8NpOTtWOVdUSGauyK+4F84dzq+uFrP4I9OPRZlCMe2U
/sBmmVmK6wf9ILdcrOGwE/Jjd5lWizIb82NrWtShZks/1vuzNp/ts88ee77f
/32cT15QpptzHBfy5/592bEdq88Kth7U/9OSpK8h/WO3BTOH5doqj1wesyV6
dooax9cHyLaoTItXtZuYBTCUJ4mqVpi3waRd8BeOMwuxqhbcv9HBvAuriSlz
8npmF/AyLm79XMG8B4rIKXOthNkVhV72rlLTK7I7hsq+8yUaZg+8ucY/9e0q
syfcDTtahBHMXujVHa1pcGb2RnOuIeVmWz9ZjIl58b2nJcwH4D9yZvD9Qh/5
IGYc8p4sLDP7YLPiQ0JqKbMv+MNTIoGS+RCk5bMxtl96yX7QP8oZ1Wcz+6M2
lSducWEOQObZpbErRS/JgYjfVDw7YskchMFj+gnhZA/5MJJjj5QY45iDYZ0z
na2105ND4OS15pgUwixBp7fGr2KeGbiUVSfPsKZ9FZDr1OXpZsV6KIze+Ysi
cTf1UKR11ez96tNJPQx5rXm8Ol079TCUBZZYDqt11MPhMz++JV9P86pwyGza
zwfdaqMuhaPSUFW6+IK6FH0Jk2sFc63UI6BOr9y9XqilHoFsS2WR/b5m6jLo
m2ysDIvPqMvQ8XN7/rkfNM/JYcZ3iF2Ke0xdDlcLkej1iQbqkYgyK8h8d/k5
9UhUXk/hnV5ppB4FTXXi3Ypmth8Fc7/igf6aJurRmJ4ZSlb/qqUeDU5glOPT
beoKBIweNxV2sa7AHZ3MKHOrph4DjaTaTvj2AfUN5mKRoPN9aNxP/0O1wVzc
hv7fvwEyyDhx
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zw0s1HEcx/F/KVTTTkhtnSMx81DHKc5xPs7hPJXDrq2UZcwYE+uyVuzf
xjyz27UlrDI9soyu7jrJQ5LIwzTS0m6JlqadtsRCVPP79d9++++19/f7/+/n
kJQVm7KZYRj/v+ffmz6ciYazAdv7Ojf0PZCnc+Vn/jcDnwpHF5tt1OaQ3F8a
4JpQc5Bxb+pm29eXxNZYt4ydrZ6j3oMHDXvHlZ+p90Hf51GzMEhtj8LKqo8L
r6j3w+ROmTG5hvoA4t4PaEfLqZ1xMU+TUxxP7YLxnMxjE+bUrtCfTCj+aegl
dodAhPWtbrQfRGm1LNcqm3Y+Nt39bTYcT+2JW+fTlkY+vCD2wqRide66nlqA
Q9Ja98RT1N4o6GlP5vGpD0NzOTe8pbyH+AhMi4pmglKofSBqftavtKb2xeni
4BvLedRCWDxpaklKoPbDpRGD3ZAdtQiKxJXVH/LnxP7QSaSq1sVu4gCwNpaV
a8epxeCPWQ1byKgD4cxL6nBkqIECM1Oj06+ODbPA1YCSattVYiYIk4OGoXPe
naQHYSXwyiiM7aRLUJWtUJgI9aRLcGGnQfnJ/inpwZjQq5xOaNtIDwY/tXY6
pldLuhRGzrv6GAcd6VKUeIhu8z2ImRCw3UeXbLmPSQ+B4K1GzBlrJj0U8rqE
wkz5Q9JDIRQ2pg+O0O+HwVXNma+Yo/thSN2h9arK0JAuw0L+692qArovw5lv
Sqno2iPSwyGu3cIubibzbDg8XfI91Woyz0Rg10rW8lodmWcjwPbP+OrT6X4k
YpvdmDc6uh+JSt6XNMTR/0eBW1rWlRpH7sNGYV4wq+JyWkmPRqNj15Ra1ER6
NPymS+Sh4vrOPyK2ME4=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90gtIU2EUB/CbCM1kYCklYWVpU0TUzMeWzv3Vbb6mppChBGogtsAnFmXW
Lua0MKEmvgojKsssxXRrlk57+ShK7OUyS8VIodYwC5IozfA7XbhcfvzvOZzv
3Lt1f15ylg3HcSHL978nXQ7mK/nSNYN9K5qTZfPrh2X2ZA4lC1PzKf8twKKm
W2ARkB3gMZ2Y1fhjgNkJ2rTTvy59ITujwLezNq6X7IKE4ql9zbVkV9wsqjyk
qyJvw8DmXnXZXrI7FLYWx8scWYT6a+NFt+f6mT3RYWq7uMpK9oLIXj8qziF7
Y+go3zwSS/bBcX9FfK+Q7If5gu2BG7SPmXdg2Ht+vDyD7I+GUJ/Cz38eMe9E
sTlZL2kkB0DjZJfUZEMORJNYntmnfsgchMObcsMNzuRgjJ4rvWF9/oBZjJkn
2qrCY2QJ3vrsmf2qu8+8C/o4y+oEWTdzCLonr1Yb3e8yh8Lsaaio/36PWYr8
pNe6kRZyGDot1oV2A1mGCzkf+oVbepiBsoQxV4m0a8U8IG6ZSPu0lpkLh7D0
TZYwkNXz4TgxPaR9lm9keQTanIxudWMGlkdAVfCycUijZ3kkusytHm6VHSyP
hKvITvV7gHI5XpnGI32X7rBcjsJEw1KPLZ1PgeCKksndGppPgWZZ3myqgb3P
KfHifbZp0YXth1fieldUuv8B2lcUnDOFBxtKWD8+Cl78kTN+ddQ/GkkbcyfC
TlJ9NNQ14ozos50sj8FHrePTbzNsXj4G/KCuvzyb6mNxajJeJDhP88dCmJqi
lKSzfXBxkHoFtbfeYv34ZWc4GmPe0flVCKi2WpVm9v15FWrUEn3qOvpf4lEt
l/v+NJr6/gKv0y7V
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9kws4lPkex6ecOtUpuZzS3cSyUohKcslXLoVcch+MuRkzthV262y2Q1OS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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQs41Pkex/G/U1uSRKvVhYxIFzaiotB8lAmFhnHLdS5m2LabLnRllOx2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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0QtUzHkfBvARFaXVK4WESSh0pYvo8qR02y666H6ZmZoml9LKNWQUW5te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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XlI02Ecx/Fft8fyQJeRgSkyJOyydJvm9vF2h7rMtQ5MkyyNrEmZ2R82
jeiSSI0k0zJMSbpGXrPEOcuNLI/+0CgrMI9p6BQ6IMis8Pn2Rz/48ePF++H5
8jw/77SjiekLOY6L+vP+/dLj8qZaG+pgMc5rRnpJ3nF2hxOZQ1nWpw3TS8h2
6K6XcZrFZBdIE3vT1DYzszsC8ib65t6TV6LQ9+Y3dyt5Nc7MrFBmvCOvgXZh
9q0gI9kHW6TqhIqLZF/0B3y4m5xDFmBdcVJieBrZD7WvLrc+iSSvhaIx6XaT
E9kfXg+aHY/bOpnXY5ubKdOnjLwR2UL7OpuavAnxtiU1J0eeMwcgNC9/qi6X
vBk9BT7J+nLyFuyMvn1CLyUHojBJyFt+9RlzEHZa/flWFVmImNSMCWNJB7MI
wfcEeUWlZDF+CXapA6XkYIS4aWSvvMghCHlR6Cj/YWLeis7iw6bP7tRDMXxN
pP4uJktQdR7jmXdpvRTKrI9dTbFkoMX7fsqIrn3eOuBnhcX/dA8zF4Y2h5d8
Zxn1MNw5od/tWWtkPRzikdO7ctrbWA+H1aP0S10+9Qi8LfHmjQ9Rj0DN4GRr
Xy3tH4nOl9USVwP1SBzZxO01r3rKehTEs/v8XCTNrEdhOirDpfpCC+vRsGnD
c6tkT1iPRt0pzWzqvx6DL/Wq0FwRsy4GprZRvtvzetZj0Wt+tEBr/5j1WFS6
Ll3WUKhnXQZh/fXRPab7rMvQNzqZcu7QQ9bluFmwqGC4gK3XyTHWc/TgjHM1
6wqcusET7HWkroDQeeBAr5X2V2JP+tz46457rCvhM7V/IFLHzsPF4WRXnsQi
bWA9DnHdg/lrix+wHv9fj0d0TWC2RxnNT8C0IV/bX07zEzC2TlHEazSwrsJX
Gf+W5yX2v6CC3MKJEjXs/nUqXBga2z7Itc67XYXdYVcUrk7M3DbMmLOP2VUa
jL8BKdNdjA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0WtIk1Ecx/EHL5XaZcpMQynN1HCZ19TMy29TN++KlzdaqNFEHdiCatkL
2STTsMiEUGFaKplLl9fItLWms61cZmQpWGGBRKnhJbyFWuE5RQ8cHj58z59z
4DiePJ0kNGIYhvd7/fnTjzXaIA4216k3NRv6vOCEv+yvGXDj8u6JTam3YbF2
xjC/+IyYhWAvpd2F79RsrPIk1dlz1LbQs0fdjT9S2yNfa5htaaJ2wJx6orBS
Tr0fqdqU+qwb1AeQ6NutyT1L7YIpm0/q9mjqg3AeO+deyqJ2Q9rOpBLR1ADx
IbhW3TUf1FIfxrdaReMuBbUnZDJJP/c8tRcucnIM6XxqbwiElywM61piHyxp
1rSGZWpfvGhN15VpqY8g1/aUZoZD7YfaspEoD89+Yn+IjK8Mvn/TRxyA22kO
zVslGuKjaOsy7w4KoA4E++X1L4xITXwM8ZXypXwx7UGIKOjdXd71lDgY7nKW
mUivIg5ByLRjX11pD3EobkknezbWqYGv1wwZO1YebVoK7DVSWaQLu0nnYr7E
cou6iHYuRjjKdw1tj0nnYaFJvmpIIedLeRgSDhRlqmgPg3fn+FtOM50Pg1NW
SDI//yHp4ZifrLEv8+okPRz642t2N6fbSY+AoNhgu1HXSnoE/BY8nF9LyH6G
j8jUjmILNp3nw7vIJqNl+j7pArgUfmAZ82gXwE1QYaX7TOcjUauosfTjPiA9
Em451gEMj94vCj57XDycreh8FMyq9H6JIU9Ij4b6DlvPGyGWRuOVqrrPSUff
Iwam+4rWB0zIe0hj4Krc7lq/0kt6LBJahssDxun5sagUz55pn6D3i8OwSFt6
tUNJehwUY4yD9c9G0uPhNeSRaxJUEbrZ4zGidJwNXJFtmknAcoq38Id1JplP
QFP25czkPAXpif8b//wLc9hN0Q==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n1IU1EYx/HbMomU8A8DW7oydcwaunK2rbntt+mmTjMTejUKJw7LRJOK
/CO4WSRiWohagoqSgvSGWKEGvs+lVIbGsojypZxCBqKhKLZe6DxFu3C5fPjy
nHM43EBLTkqGgOM47a/395cen9E7uZoNz7r+aE6XpM+4PeNF5lCQtW5A9rev
R3Xji5Kta8k+aKkJXIxZsjP7ouqxcDHURfbDlQfXyu1fyP4wPO1NPeogb0N3
/5go7TV5O64fkKwqB8nB0Ejb5WHtZDGqHs5aRYVkCYJ2Fi+IQ8g7ILNO2qM+
9TNLUVlS3fw8nRyGHKWg9EQQWYaR1M0e97eQd6Ew+NZJebmNeTcqGlfE4YfI
ESh7m6qIryHL0TTnfXNNHjkSVQpHncWLvAfnr1bMjqT3MSvgmJn64JzsZVbi
YPJyjvc9sgq+xzummvrIe5GS1ZN5QUdWo3oxXibWkqNQpq01Brb1MGtgVjc4
tcfIWkjzzzSU+pJ1sMvHnvRtJAO68ajGJREzD+Q7Vosn7N2s69HS+k19OY6Z
1+PRJV6f4qBuQM3n2syA7E7WDVj4vmyZb6IeDUn2aKhqtYv1aGjbNZI2f2Yu
BsnzGHJO0v4xKLghbNZF0vmMiPbKLjp8mvY3wkPd6XlWSd2EN8pc048imjdB
YLDZlu10P7EoO1df9zGY3T8fiw5rkCqvlebj8O7ukVNWIfU4DIdik9lE8/EY
zJseDp+m9d3Mmd26GV9fRYheDlNPwErA0EW1i63HJyBNkbR/vIt6IvxC3rsm
ZOz/5RPhKZC69JUDrO/737ybuSS3/s8/ASWhPCw=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90GtI01EYBvA/1WBItCFKhhKbhtgQU6erXdwe3dTVJHHaWBZpi1lYpBF+
MIz9HRRSkxVuSBdE0Yp0H1aWWMOWza7YCpNEScbQPlgYSfeLdsHzeuBw+PG8
Lwceqa3ObF/FcVz2v/v/pSOe6K7Pi3kcXNZHXWuts1wtJnMwy2r6nq9YiA+C
JfmV1WQxjkeE/rKvj5jjIFG02FIXyAkY9J9WnpsmJ6EtvrrS9JosQfONy0qZ
l5yMTqcxYdJC3oQ0U03jnICcinFLs0b45iFzGm6PeY65zpBlOHrVtyg4RU7H
2fcuc6idnIFnVlFTaSk5E64eeddQBTkLvyP7xaFD5GyklO+UnpgcYZYD+37M
pHvJORhu9w7of4aYc+H0HOnt+0JWYDZ+yMi5yVtxvcnhyWghb0NgbG9nbMcD
ZiVm5w/Y3cFhZhWC/u0TyVKyGnG9VVt0tUFmDa4lGXy7I/eY8/CywZ/5WULW
IntHdbgqGmDWwSrzRy913GEGVG/dOa+UA8vmAevwhbV2HzOXj0Zton0xls3z
+WgrmekWLfSzvACHVXVLlqmbLC9ATElPtOHpIMv1GB3d8MdD//F6mBy71j3J
vctyA0ThlPG5KWbegKzNmm8KfojlhTgvdh4MmO+zvBAxe+Yduu/UVxFu1VdK
tF2sT74IFe9OKn9NU7/FWBNWjrR+YvN8MfgX6v71Nto3IrEhuPFiGe0bV/K/
hsr7Hg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90g1MzHEcx/F/mdbSnUaaPC1UjHZK7iqp+6Snq9M9sZ4W6WjzUFx5LMat
jLHEiLGWXLceRijPx3FH/ysN0y1kJo9LT5qwpfKQzPfnv/3332vv//e///e/
/0ztZk2mI8dx8tHz75Udbm1GXZhLk+Wf+qVzeF+scmXmoHKfmHHMjdkZUxqL
cj78724okn0fNI1ndocptD/4gDPzZJwN6TU8+dlIngZz2Y9bxc+YvfB8eLlR
ZWaeBUFYks9aI7M3qrV3uhxrmX2xIZ+XxFUwz0XZSu8HuUeZ58HC73khVjL7
YbawwOPSHGYR4nkfQValjeyP7TnC97vXMgfgoZLfWLyGeSGa7aL9tV95ciCy
/HbaQsG8CCOH+EvXJcxixCU2DCV/aiBL0CYqXxF0mjkInm/buQ1O98nBGJIt
lrhNvEcOQS6sfnYd82JoXLzzAk5byaEwKOwfo/yZl2C41MHQe9BCDkNbWopz
9zMzORxjw2NN6jfMUpRrRJ2t6XfJQFPB/OSXPdT1wLt9s4amHTJRj8Dryboj
Va03qUfgfkt/1dgtZG4p9mVrI4prblNfitUPG48ratl8JBwEkY7mx2R9JKqT
pc2Nv69Sj0Jaad+X2U311KMgtX8yyL+xHo0kr/XmR+MuUo9Gms782broPPUY
3LJNmKrS0v36GNgSk/nujirqsTgREHJ4/pgy6rHoOSgv1XQdpy4DJk2VRBdW
UJchYUAptigrqcdhS4bE4PXbSD0O9S0Sz/ZT7Pnx8HiSOjjQdYF6POy/BPq9
KbQPJ0fevR0zsray95fDYvMRNm0ic8sQ9j6783ZoHfVRH71WKHrK5hNwNUZ8
Y5uC7ZeArm4vaU/KZeoKuI6I3ZPWkfUKCIq8842BV6grkdfW55SQz76vEq+s
u9YNZrHnq0b/Z/25kPH0PaFCtOeB9Je9tJ9eBVnqyMl2Hb2vVYUS5/PqBdNr
aF4NZZ0mvF7F5tUY0n6tvBx7jubVKMmMTJe+YfNqdDikXOvLoX05DTyE/BmT
mAwNLE7Ciour2D4aTDjVbEjMrbP8AfIbfPg=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10gk41PkfB/BJ/vG3lfTvL9vaGh1WyVFJ0l/eJONKue8xxhhHOlA61Wxp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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10A1MzHEcx/G/p+1YcZfkhiKa52elouPTPXQVcqmJ5iE287DVpaO1G+3P
bEwSKTfXAxPaVTg9KacHD8WqU9IDGofFaCTz1GaE9f3+t//+e+39//5+v//f
c7t+3Y6hgiCE/Lv/P/mSdubFK0Y9qBlU38o2qX6CWsIWEFn4LOvECLYES4Of
O/x+15OlaC5cUmp8z3ZF/8F00+Z3bDmEcbO+mtrZk2BNF0IvXmVPQfTGW7Et
p9lTsTtgcXmnge2FQ19be5J3sqej/2yM7NNU9kwsj27M0NytI89Gv7vHyKZ8
9lzYShc4q2LZ86FP/Sbv1bAXwv6g1lzXd5+8CFcGBpJSY9mLId0i+dwhZy+B
LSB7ZnHHPbI30j0K6ho82D6I27Y116XhLnkp3I3DXsVkcffFBXlfRoqRux+U
jsfa10/vkP3R8+aGPjWRvQzOK5rtyW615OWIHz7teFtvNTkAlvNFN89mshVQ
thzuXnC7irwC0yfcmbjsE/eVMCf4lMjeswFX7/QrhS62QYvAl7w9vo72cuqB
MCT9UswZRhYD8dn+MCFILKOuRP4BW59JrKCuxOgsL+l9/0rqKlTuSPl+0Mjz
Kly/dOtEI3h9NYowZMDYXUxdjSNGQ3lVsZW6Bvu06ux9BVepa5DsNmRGUk4R
9SBEjLE6Vd8roB6EU10V/pejuGuh6C5yMteTRS107v/WL7lGPRgyy4a4vbW0
nxgMQ8kZY8x4Wk8IgVuFZJ5kBM+H4Iu7Wva9h84jhGLjO+XWRgvPh8K7IsE3
pYbPvwozfrimvY7gvgqTH1pfNgWWUl8Nz03yo7llJdRXQ/VkdoOfg//vGpij
XD5qZWRxDeT7Tb/mNvP+YXAL9jyXUG+hHoZjm1rabc58/rUwnPQQVUn0veJa
7Ooanhf28RJ1HS4kztp+tJAMHWRRcy5+sOfQ+zo4ohUmQ6J50LU6YG/ouUOd
2TQfjlbrqcy0yHiaD4f9p2jNc0qj+XCMDXik+WPOpflw9DZt1t5spfWEdXhR
4/O2aX1+zV9OGXke
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVz38s1HEcx/EjK2FS5FiX+RGTdH7c5SjyOuf8OA7dopiyhRhbjEXW2K1I
3dIPmzn9YGKuTVyI0vyI0w+lP6JRtKzQGiqjWmmjms9b67t9991jz+/n+32/
7Y5kKJL1ORyO5M/990mX2UhNpp/R4+4VzfnPjxhNHTYmc2Cbi+uOS4+YDdEW
es6x8gfZDLnhIrF21RZoL009HTlOtoLCZ7Qq8x2Zh8XvL69MjpJtoZp67rnQ
RbbHTplKmlJA3oaq1t5xnwNkJ1S/FX6eMyA7Q+6qkTfOPmR2QaL5odzXdWRX
LC/J2rIdyXw0tNmWP7EiuyOywIy7uaeP2QOdXIejXC3ZEzYD/IIINVmAHLtX
+bVyshDHGmJ/OafomHdBJuTlxTwle8F9f0fZejVZhE83WmWlfLI3eFZv3ls9
I/tgeKi+xdyVvr8bm7y1cemLvcx7YN/8YSzfjewLS91wRKUL2Q860c1CqZq8
FxOJOemDArI/chw0hlqLHmagT7qGp9B1r1gJlF7Qz0g26mJdDIG3dWGJQSfr
YiT1d5isi2HmBIAvEc0Yc9n7ygA0N93KGlg9L0GQZMlzJqmDdQn8tiwnJF+i
84FI1h0UNpyiHgg3b8fLhrXtrEvRqbLcp6xvY12Kism8hNvcu6wHwSlue+9H
VQvrQYjd2m7a3cne5wTDht/6zaLxHuvB6PtacbXuZyvrIXgwWFDo2UjnQ5Dl
61qi7W9iPRQb8nqC4seYlaHIVp/3GF+4w7oM8uKictEYzSdDKk8SeDzkPuth
EOadjNZ/wfZRhqHm4g5xURb1cJhNWKdpNGweZTgEZf3FijqaT47sHj1NbhrN
L8fIbHf8dC39PwJrBUMWonlmZQROXPtSberF9uFEYmO1SalCTPtFQu+svcPM
dDPrUQiNPjOhUbH9EPV/V/7zb8IYTag=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwk41fkex/F/DFMKKSmTdLRNUtS1TMT4jGRsyXLs2znOcc5RDWkhLZbU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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxF0wlMk2ccBvCOeSAWDwSsg00cwrCeIAi2UB8sUARKS2nLVdlQhjqPORnO
ONSPsUnMwICIYAaES0TmgXIMHUjVKcO6IQbGxINAGFOCAxS0HHNj8f9mTZrm
l+d73vf/pu+3aNOnqo9NeDxe/OT3v1/2mdNevNvLrLHhjQbX7Xvl9FRnzswD
z/B29HE+symm129tFpowz0HP1Vm6t8ZukS3xQ92cueIOZgHqU7q0T24z26Ik
+umKpjPMdrAw5Dlkcczv48wuaVJ6HPNi5PLkUe9GMzvCgV9qVerP7ITHzmbj
+95hFmKl+cLbyU9vkpdhS+fuTdpm5hXw2Htwqd9Z5lW4VrnxZWMcszM+StGm
lYiYXaCy6+YpJMyrsWOB+Xbfvp/Irvh9YEGdUsnshi8447J7WuY1CLk/KIpJ
YXaHt+hoxeDsG2QPWA6dFFRqr5PXYs20IcfeC9fIImQ11RZbhurJYnilXt47
xm8ge0Lsev+WmYTlXmi8IiiJuVtPlqCooW9rm4R5HYzB1i1Vr+vIwMm4X8Yc
xGQOsCuwGfB+wJ73xsbnLvOdj1yl3Bu3NKK0TbZk3nr4Di6501bK8vWY31Zh
IbP9kXIpbkzJPR25k8xJYfnooUK4nOU+sJk49tB/KdvfB7mesvTiYra+LwLK
xaLzc+l8nC+MZ+9nX9rBzuuHg/xzF6+b0rycH1Kcq6tPh7G+DPJYiViXy/aX
wXGla9Cff12m3B8vc2DfmllLuT9EGOu9s7GG8g3gNx93fzBM5jag9uZhL2Nt
FeUByO3Xp1mdqqY8ANJzPWbGrWReIOaNuCfWh12iPBATBpuD2V2VlAdhyqLs
K/kFtB4XhJnmqm/E0grK5UhqTf77Q9U5yuU4YtLZduAFy4Phah7+bf8hMhcM
o32fV00i21+B7VVTDeUiNr8CArupMYX8i5Qr0e0heF0WSX0oYaMPTbc6X07P
KzEt/Z71Yk3pG+uV+MPEVJW35DT1Q5BxuN9iszaf+iEI7NXPkMSeoH4Ivqqy
2BMUdoz6IdBm/mNoj82kvgpGgVQ99zfKoULCvdifU/kZ1Ffh6mis5JmCrFfB
VvG51cpDWdQPRWVSz68V3WSEYvhVh0DqlkP9UGB49MqFzwqpH4rZdzdn9yaQ
eWq8eDS9pfsxGWrkBj+R+5eSOTU6jqYMKc6UUF+N+pbmQr9EMk+DnoLbOWv3
F1Nfg+XtCVOm7iqivgYB9jXzYnwo12tQ2LrK3l7G+lq07im7/GQHGZN+psaN
AjKnhSzYva5mlM2vhdrOscagp/V4YXi+qGxhwjibPwwlvo35FifY/JP5+JYM
q076f/RhmGjnO8nfY+cPh9m21dZlzTQvwqHTdaApm+0fDmdhnt/3M9n5w9GY
MbDaM5X1I+ASsCzcNuQ76kcgPTnZSeleRv0IuKfud7kQR/dfH4Gd/PkPc4rY
+xWJfpvpwoXldL8RCesvR1x6Z7H7HokBz8OnJpbQ+6KPxCm3kZaWGez9icLJ
DS02wlFaD1GonzHSbulMORcFQVrAJ/EHWD8KH/h0BX0dz94PHbYJq2WPVtF8
0OG13LA/M4vuN/e//wVmLE3d
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2lIE2Acx/EZlTKP1JIKxQ5KREw805q2n9NtTqd20KWZzmMhWs6wFE2Y
poQQKGmKmlC5VGge83ajTC1dkgaV2V4EpdAQM9QEU6ZU+H9e6AMPDx++z/OH
51BixtmUbRwOJ/jf/n+yZTtZrwjijvRvaJ6fa/d2UmPJzEFv9HCfzp7ZAg0e
pXLBbmZbPLjv/dXBnHkPzjjEDhStD5P3wd+3UCidYnZCXnZB7Jqe+SAOzHZ9
VqmYD2O8YzVFUsB8BIndzYqum8wugN0lWZmM2RWmEve0LDtmN2R990237XlD
doc3N7N1sZDZAwXOckcrCbMn8gNqOhd+viZ7oX08cLtazeyNCZ6ms6iR2Qcq
rb8+s4XZF8niuL2tYcx+uGzDyRhMGiIfh09NSvoPd2Z/5E3La2N8mANgaVYZ
r5gYJJ9A86Lr7af7mU/ipWakLDpzgMyDecKVac+5V+RACLNXqoak/eQgGPq6
G3hVL8inEDM8m61o15H52PmhYuHCmJYMSNQek8rI3g0rgYe71j89mu2hHowE
K52DSaWhHozUzr5+rbGRugCGo+G/SpLbqAsw2MvjLzg3Uw9BoUEkyJ1poh6C
OqO2amm+nnoorG1ulZc5VlMPRf67u2ZW159RF8IlOEd87JuKuhBzpjm/9sQG
6iIgyaudp2DzRWjSZ1t8GX1CXYy5ex9F5SbWxdDIlvUTay3Uw2B9cak6tU1N
PQylcvu8/Dq6z5FAJn8cM+pG85QSXNWNOZmKn1MPx4qnMcEwyv4fDsuxtver
xWx+BPh/zqVVpBdTj8D6td93lrkF1KWbrZRCn7ljvihHzd/okZutjER+z0yl
8UYH9SgkxbfIpuI01KO2vI/e8n6LOadhHWF+nltTy/8LKjlNEQ==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90n8sFGAcx/GbM9fyh9tN3CYjXXaTbnLSOZwPd+4XWX5sZmUKFWqhdhNu
MsUfRiaxxhbOVOhitn7szqIIV1nCWDSl2RqV7NQfCv2Y79OzPXv22nvPs2d7
nj3puQmnHDgcjvzv/LeywZ9pywvfOdK/rdWIhMTc8hpnZg5EcfuuyP73HajM
OTIr3hwm85GV9SPjzTdmV5SNaVKSFpmFsNUbXaRvmXfD3/4uRdLH7I3AeO17
WyuzD9LjpF1HU5lFuOiom5LImH1RbYgMbRp7ThbDZdqt0TGR2Q88t1Srexqz
PwKKPhYlC5glmP1s0DQdYA7Aoj2/oGZmiHwQr9GcMypnDkRxWkaVSxWzFA3x
9gvGEOYgKJUKm6RikHwIwVOt456mZ+Rg6DMd8leszIcRNlM7bNl8SpbhdKLC
eMmT9RCM1E/b2gpZl0O4oLgXe471UEjXzi5vdA+QwzBfebXQ1PqEHI7469l5
pmwrWQHDh/agzrmH5AgcP780l8x/RAaSQitry8W92y4FhLnDKt68mXokOBNf
bnMX7lKPhFOMe8XlEjInCnUC7eRvWQv1KFT1NiuU4jbqShSvnSizn2H7lYjZ
f3PLY91EXQVriU/XDXkndRUCRDUZLyx0HicalolXhbxjddSjsZGuejm6VE1d
jU6N3tS91UhdjbksR17H1wbqGlSvnzQXtFdQ1yDEt0j12KODuhYDguUerje7
vxbOfkk/dxnvU9dhfN2ibvn+gLoOhqEIlb/HHep6LHG5mcLuHup6LBRMcvMH
+6jHwPVXh3n5Gr1faQxWvWK9dEHsv8Tik/mWyAn03qWxWFELpHv5ff1/ANyt
H0I=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQs41PkeBvC/6CZdbHUqbRqXLmyoqO2QeqUQYtwGgzHmwrQRqc12QlMp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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxN0QtUjHkfB/CnRNm0b7yK1NEgjUVr6LZu9ZWiu+7XaZpLc8Euhc2r7TLG
pVxKKlJIKuSWSi8VMhKxXdxy6z3LSEUbFd5Nmze9+55+zznvnDNnzud8n+/z
ff7PTBOv95NqMwxz96/v/37Zj+HTwuil39RfH1GfY/rO3KG2b1kzOLx4t+7x
saz1UPNvU0XHKNaGMPuiqPz45TZ5IoL1qppedLCejJCAP5vqH7I2Q0vmPa/1
Taw5MFe23HtwmvV0XGoQnfw1mrUFPOw33bUMZ22JcQM81/vWrGchS3+OReXw
LfJsdA19WBj1hPVc9Dzkv/Lfw/p7mBhWOf5NwJqH1lluhfXv6sjzoTNKXZf+
nvUCBPsZ14zdxtoa6n0Zx35fxNoG3guGKueE3STbYqBiZuSAL2s7FGZM3aV8
ytoebuP9BitHs/4BerW+1/s3sF4IR8vEfqa9lrwIb8ocr5jEsV6MNqtxNu0t
N8hL8KhTN3Rfspq8FHI7WWNlQQ3ZAT3tKT/G2F8lO8I5zepI6MJrZIBnFHL8
yJnKESuB9XHpyarsS5Qvg+nbioJ1qgrKlyFGv8+mwLOccidYJvk/v1pURvlf
zng2WH2MzCzHjjEHQ3/pOE/5crhyA7mFMWcod4Zze52esewU5c4w2jHF29C3
iHIXxGfP7EpZdoJyF6S0nsv2F+dQvgJZJSs/tWdupXwFVBO64rckZVC+Es15
kr9P1FhTvhJRIS2f/yz9hXJX6C+pF22+5OM4kruCa2DrKUkLHzHjhuYMfYNd
PWGUu2GxVYzN9hkCyt2x/9lyA7vZPnR/d6i7uecu5G6h3APZwYkLX9ZJqe+B
yxLukfKt8ZR7ojfmgvX850mUe0I8NK91FXcd5V6Y/6RSVKP6iXIveNXIH3m3
qyj3xmoZ/21rcxrl3tA6FTbWLGQr5auQpH0pOGu/Ez3fKjg89uNoWwRQ7gO7
tHorY624EcMHpk5jyuO/rKXrfcBPnF7HjQ0fsdoHPfxdxkW1Inp/vuAfKrZL
rp1GfV/ErbXObK0Jor4vYntPhb7U2UB9XyBn9pocg2Tq+6GX6XJpW7lrxPDD
jCPIM9mTQH0/1IbNKXTO+Zn6fkgK2u0lWLWP+v44yw0tq37G9v3hdfdMrYlW
GvX98VtXWGDjd3up7w/tn9VF46duo34AcgSFirlWm6gfAFWBliSlV0H9AOTl
buGtzN0+cj51APIFseNrZPS+mEC8/Xx28MGj/XT+QChTYpfbTkqn/yMQFa1J
nZNVGdQPxJkpc3XWZWVRPwjXc5/eT/hKRhDcHUdP3Fy8l/pB8P4oP5eamEv9
IETMz5t1VPs49YOhx9Hv4j4uoH4w6v8z+ZN2wGnqB6MnyCmDM+M89YMxrSWL
N3zhLPVDsPXKWdWsyDPUD8EJjseod8/Zfgiuih0MODuLqR8Cn3LulDUOdD0T
iuZq2XuVK9sPhfmQQKGpYPuhGPjD9MlqO8rVoWj8LE8b8mD7YXj+/znCsGW5
/27eMFkZhsnhbrJ/vCuhfhhsrS7efKtHZsJh1HtjyYEJF6gfjuqyKY2MD1kZ
jvcd9rNfmZPV4Xgo9jk5s5Pt82Fy0WDNS3Up9fnQbWyX/jmFrOSD37k5M1m/
jPp8zNjyr6T8A5QzEXC/7TTbyoXtR6BUJyv69kW2H4FTfXcC+1eT1RHIbNEx
bein+zECDGRHHrMRkCHAIxeL+k2H2L4A8ormCtPLbF+A/oc5metUdB4mEs4H
G9qt5rP7kdC4OpQHHGTPH4klWoOHhIHs+SORwtukeG3JPr8QSfbDU4uVZI4Q
RxIGfA8z7P2EcHznOS78NlkohCDmVNvXxfS8SiGyG7+0D40m5wuR0Dupo25B
Oe0JUcQr+tG+nqwRwn1FmHWeLpkRIfWAjPPRg8wRoUZu+fX3KjJEiLBEHO+b
i7Qvwus59fobvclKEdSlJfv8r5PzRZC5DT3InfdP2hdhmu9O7bcRZI0IPovm
3J+3msyIIYwbfXytHZkjxvHq00/j7pMhRrTD3JJuM7JQjA9eDsWD3WSlGC0m
1el3OZdoXwyTtpJ+iYSsFuPrgzfbTELJGjFKrx00OX+YzEjgqnvY9tNHMkeC
UamzVvUfraR9Cfosiqdv96ymfQkyO235RjeqaF8C0w/l2ZoxV2hfggCt76XN
e67SvgTRR/3atw2QNRJsNApEQzuZicLUseJv+xk17Udhr8v2HgcHMqIwM0Rl
u0vrBu1HYbNhgcmDL2RlFBbppp68eKKW9qNgw00NGxaS1VHYoW0wbukisiYK
yefmLnv2B/UZKar4TgXBk27SvhRNNQObvsshQwrjXOHpkk6yUIpug0Gpyx6y
UorXOgkpO3LqaF8KnWztbqdasloKw/rE9WPSyRopTAJ/a0y8QGZk6Dv84l2h
hsyRocbi+eChZDJkWHxsu8b98y3al6F274sNqX1kpQy5Covi6FhyvgxHHZ8Z
ynhktQzasQ9LLZbepn0Z7mz4wfxTN5mRI89rTFexhMyRQ5G18HLPGzLk4K2Y
h/g17L4c5g7GqvEFlCvleOztcs2qtp725QhosNddc5SslqNXkjDsZHCH9uVo
e1VmprAgMwp0mt/6fGzCXdpXYB7WtW0MJkMBOc/MqenKr7SvwEfuzYcvjRpo
X4Gyx16FQ1XkfAWsrH233hvfSPsK2B8oa8hIIGsUiA9Z0eHcRmZWo8lX//2H
n5od/wuAKt6o
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1znlI03EYx/FfQSWb1hJRoSU6I0VNK3U6U/fxmLojzJWy7DYmrIYZCBYd
LINCZal4JEkzNZkGM80jtcCjmQVqKVH+kamQA4nsYpYnFfs+D3z58uL9x/P4
ZF1QazdyHCf59/7/NIIPDbkxvOE+h75Lf2zoNA07kzlEuOfX1GwjO6F+vlav
Wn/JLEA6X1vQM0t2w69A3s2tQ2RPtJoswm4rWQh/U4nYvY3sjZLYV5zyFlkE
XeGDhccF5F1IPVdSkHeHvBtfT4VEWZRkf/jwjdroEHIA5L7q4aVvQ8xBOPSl
NmJohByMtpZy1ewqeS+uLszog5fI++BVMTcePkDeD55BYS+TkEOx/lla6iYi
h0GbufhGlGtlDsfxPeYjaheyGDd8T1xXRb5gjkCFZiQm9SQ5Er1FC1vSLpIl
mLzWbs7RkaMwJdEFJNnIB9BvtG33jh1kjkaV5eex1WVyDDw8/Kezm/uZYxF1
JSPNb/I5sxSyFnudJrubGVg7qBmzG1odNgDiT2pXmaiD9ThkTd09v3K6nfU4
TFfarAECZi4eY6Nz70x+T1mPh7XBbXk0iJlLwNnQvOq+pi7WEzD/xFTaG8jM
JaKwfiLbYqWeCM+iiffR2k7WZdDMataM7nSfDGIhT6hHM+tJUH90Xp3KbGQ9
CTsHqnP+bDaznoy628X8MzvaWE+Gs4dwLldB+1OQU7hetcmnh/UU/E6/dPRy
2TPW5ViM7/SqrGX7DHKEd93zHB+sZl2B1zN2fRO/nHUFFGb7dOPhDKmjKxFZ
3PE2/9F9hw1KOM23uspdLKyr8HBpJWzFr1L6F8yfH3g=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0A1MzHEcx/FT4XpYCzGMVFpx2k2XpCifq6uu6+7qwjizUnZiRmJNLLpm
5OahaYVMq/WwTl3IEpE65Yoyi43b8lAR0cJpjMnzfL9s/tt//732/n5/++/n
lZqeqLMTCARxv97fX37crBXbw5w6W//Itjx7j1YidGYLELtkdXT3XwsxsUHx
49P3DrIbmnUnD7t9ZLujJ3rhZuUYezrGnN9E1j1hz0Kb5kWPYYDtiUkmv2/h
3WxvWL0afdpa2T6wGzqRVJHO9kW+rK9gsZw9D/eHohxKhWwRVn1Zef2GM9sf
waZlc4/MYIvx1ZqUdc5sIS+EyXHDllwpOwCp9yJGJG9vkiWQOobWVm9gByLX
pdoy8qCdvAg2rWeGeBE7CLP9tziLz7aRF2Og+dubO13sYFjLinry1ewlMDz1
M7o4sEMwXp6VU9NgJoeiTuNvX3C8hbwUVc3juv32tpKXYcq6oSJFD/cwTBbL
454beD8cUcEFtaNanl+O8TB8VFZxB756Cg/NtKeuByLyUiweh7hLsTS87F3Q
Lu5SZHeG1ASimXoE3qt074+Fk/UR+Fzo5BqsuUY9EkG7CwoDrl6lHonB4Qxb
6OgV6jIYJ5zob1SQ9TLsMNo9LPzAPQothV6uJReaqEdhmipGEGjjHo3ygIbh
tEA+PxrJ3x8+6i+leUEMdt68mNkn5B6DPMk2yZxK/j85jMnt+yc2XaYux6VK
65Pda/j8WJhzf+R3VTRSj0Xic+Vr28FL1BXYGiBy9+gl6xVwbK9/Zfp0gXoc
hkMtx2bcPk89DuIs74wVunrqSvQ6bJRVuJP1SqzxUIRVZvK+Ct5H1QdEadxV
6PMXtcy31FJXQ6lr2jRYbqKuxjvZWH3JaDX1eDy99cxw7hTN6+NxP2+qE3J4
PwHr73QMVPrQPhLgW5zyaseZizSfAO1Re+ldHd2HOQGq8sb49ZF0nwINqkYS
84unkaEBsi1rRaf5vjVIddXuWyAgmzV4nJXzMvWtkfYTkXkyRD17XjHt/2f9
P/8EjNx7DQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03s01HkfB/DpeqpNWZSircmi6KKoVRJvinQxud8vM8NcuiqySsXQtmVl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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91Xs41PkeB/DpQmmzSRfX1XRZa6NMu2VJeJNR7ozGfZgLg5Jqi86ztDuO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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91XtUjfkeBvB3mTI1LqfLTKKcYkI0FRXd60mbShe7yy667r1r12aiwlIp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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10G1IU2EUB/BrH2LYi5tWmAozabZKZeXL0rT958s2ZxI5cIW1yjAxHK5M
qyUxYST7IiTUzLS01DJByw/OljpfUgkzkBVhhqTDUDSZTpchREXPufBw+fE/
59z7nD25RVl5mziOi/97/r3p4X9+akjyHXH8l1v2sChI+tKPzCHTvK9QsZ3M
g9rfLAjlyHzwS4Sjr34OM+9AgDjnSsM0ORCZre7K3xPkEDyYgrSuixyKb8JV
NddJDoOnsbRMYiHvxaVF80dLDjkcIm2wIFpDFmNtm8GqjyEfQLbW2XZmJzkC
AktV67m+IeYotG/UFLvryRKYTy35d14kH0LCPW9leRT5MMKG8EypfMscjRWl
xNhoHWSOwXSB48ZyLTkWjieZogIeOQ5lUk94e/EAsxQtd+bb1ir6mY9A6/tJ
6/jRxxyP2tjdB++eoDwBkZ1fBsfmKT+K7MIaa1MHOREzggDnWWsvcxJU+gXd
QJWD+RiGNC/4pSU9zDKsGg3vc2ftzID1fPPI2C1mE6CRXCufu97NcjmMsrHs
/PzXLJfDZ+lD91YZ9Sej2uqSrfNYvSkZczbv5Pgwq+dS4NN/9fbXHhvLU2Af
/e4/LqQ8FX6eLbEFqTQ/FXXunPaZQJqfBqVXX9EUTPPTIGvRbAQn0v8poLLL
J8JF7P4mBe4L37nidLQ/JZw3m5cNU2xfJiUen1a4dEbalwr7eb/EC8vUr4Ig
ouhyB5/2m46yXu9iSjPl6ZjNurAS6aTvq1Es0tjW02i+Gq483ebnDdSfgZBJ
ty2I6k0Z2BUmr36j72L5cVjKoyNP4pHjDwMoIuM=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XlMk3cYB/B3YIKgTJigMktEqqgV5SijWK4vLS0IpUBp65F4jE2UOhVn
iEbBvBCDJCp4IEJSB1M5PIYXonjRRlCjsilEXdCNTIdG41EXzf5YF4/4PDG+
b/LmzSff9/t7nzzvxPxVpiUegiDMf39/ePLld3d/UaLPla6PciW7/NUVdi+2
gOqBU+bR7svk4Zhywvu316/YfjiHng3Ol+wAxGnDm2297HFY1qiXB3WwZVA3
bZPHH2aHYEVvyw1FKzsUllJtUW8VexLOb60oKi9nhyG1cE1EVQR7KnzHDOve
PZ6tQHKzwfumhh2ORz/vqwkKZs/EUtXTEN1gDzkS+gLXsf1/sKPQIZvXj7fs
aDSq5gXOCuO+ElHOgu6ZRnYMlMYa/WMb+xsUT67XLZjIjsWE0s0NtrFsFZon
TG0LEHm/cRhwf7dYHcCeheujt08ZJWOrccHabi9I4X489qZ7uuJbeL4E7PO4
GnsjkJ2I1oigJ4PPu8lJ+Ds/zrc89hI5GUGZ07v9SxxkwGpt+yFtrvOjRUCT
bc1JauA8BWFzJysVrguUpyBytePpn74XKddAXBuzd52O3hc1eOluaose6qJc
i/DDgizpv3OUa7Em8F7MyVt0npCKjU2Vrf5KPj8VG+rO/F7Xw9/Xobbg6rjG
XD5fB2+V9dKzPJpX0EOepxIOBvD8elSFDJU++Iu/nwZz2v1re0rOU56G6LZr
yknBZCEdXpvq+17POUt5OjyMXcsNi05TPhvT++3BWncH5bPhPLIsYeOPpyjP
QPEtWWF1IecZ6Bv4asY9fl/IxBdHfQd3yDspz4TNJ+fXGW/4fAMqOhMr/SLP
UG7ApqwG+aoXZCELnu3T6vsW8nxZ8A7dsvL4Ac6NeHAlY8EhTzpPNKLY6+HS
7ATat5CNhhq7Rv6c9iFm4/+mnSN/+Zb3l4M7OYuV1YlkSCxK7JBYyJX0JRYl
duRCcbT+5sH7/H9NGDM8bESphQwTDlTXKirH8rwm6L4eud55lv6Xw4Q3UVtH
fZlB+xTy8E9tpP3ysXbqSyxK7JBYMMP9b3+q1ZP7ZklfYocZhrLbdWXhJ6lv
AfzKfNT5J6hvQaitJ7/z++PUtyDkyPKHJT8dor4FQ8NqNu863UJ96+fGJ78D
i0nBgQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0g1MzHEcx/F/l+yY2nGhlock1WIoXHd18TmX6q666piylYdDDCMPWxi7
Q7JlrM4mj2GFW3qQJJdS55wrTUQNM3pwu7mmaJbH8rR+31n+23//vfbe9/vb
b/tP02xTr+dxHBf55/37pUfwvCA9fLS1bkgfF61PP1Jf5UbmcCjGw8UsIPOx
OUu0sdeVLIClVGGr5ZPdUXzGq4MnJHugZO241omjyJPQk6vUqnhkb1z/kS+z
2B4w+yB99uHBcw1kXzx6Mb29/QLZD867ju2+qCEHQPxCnnZ8OTkQ5sSggBly
8ixE2UaWzZSQZ4PPlbgUi8hzkZfhqfX/bGEOwpyaCbZQJ+rBaGnr2BGURH0e
3uX3WF6ryfPRmdJSUzqWvABnNUL7F8N9ZhFSdgr0/D3kEFhPJbe9PUkWY0Xd
vH0+M8gSGLWGOCcRORQPuhLH53SZmcOQuvzTVtk6shT2k5vU5nZyOD508p69
+nyPeSGW6SPEamfyIqzZ36xffdnEDORP/mXJ660fsg74XhDiuDTAzMnQnzve
JO2gLsOJN9ck3l3UF0MWbN7eP4vt0y3GAITnVTfoPDmamiu031TU5RhxtWrl
4yt1rEdgabjHuRZxLesRMGul3d1KZm4JVokdrqFJNawvQfbHoxVFOdWsR6K4
7/ZTz7A7rEdib6O338siZi4KfL2Ty90k2h+FQsehW6tG0nw0DN3K3ie+t1mP
RvZ7PswHmDkFfKM7vmZ23mJdgY3PAhvsWVWsK+H2EFMVGrZPp4RImHyzP7OC
9RhskPhOSy2n/TEQWQ42jnG7y3oskk9rpLkhNB8L65N1fWUiI+txqOxJc21t
q2Q9Dv55W6Re+2+wrkI5r9TdrihiXYXBNzkOr75C1uOHWxcPF2NwhsnI7sMl
gGsSOrSm8iEjAXzDuwLbFPY/6RJQneZT/9PKXP+fucThxj//BgLfbLw=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtIE1AYxvEZWpIKFitGZaUMs7VsuXQupz7qvKRO03RglreYhcPWTcMK
HUYR1IeCNJTlnC4z05LMUCdplzmyi2bpvKBpWUKWt8JPJhW+pw8dOBx+/F9e
jmuGJl61jMPhyP7cvy87ztbKY/4rLW1LmgmMHZTM9zgxc7DwskF10p7ZHh12
43HblzM7Q3F1VD2x2EHmwjs5yxzxlZmHEGtrhfUz8wYYGkcKhvuZN0PRsiC8
ZmJ2w8yrVpG3lpmPqWan2C4lszs28YNd+kTMHvAJzPO7tJFZgIHqi8bzvWay
EHWTNoIaI7Mn+EZp7nwLswinLjhMSAzMOyE/+GOA58vsBX3vulWXB56TxejL
nbXoJMy7IBvcP94VzuyNKffM9uxEZh9MZsfnnHZhlmBEbm44fv0Z2RdrCs9y
Cx+wLkWBKjHH18r6bqy/XZ21RcnsB159+tsJ6VOyDGncZr5JyOyP0IXDZrXX
E3IALKXFY5qfbeRAvEu171EXPyYDeZ2zK3aMmZasBSrT+mtfTDVRD0LeqENS
yk2yNgiOSi+hreoR9WCE2qT61zQ1Ug+GSB+z+MHzIfUQxNiIukv2sh4CXcZR
ZVPVPepyOEobdXHztdTlEGsqDnWL6qmHwtD5K3nUUkc9FD11hfp8VyP1MGje
pMx9qaikHoZWS2nR1iED9XAMB3zPTbpbRj0cme3bxDllt6hH4Ij6vcO3+3eo
R6Bs7Ql+uont34Mrbh/Lg2JoXvufOZHgRSacGRNUUY+EbEj3yeOGnnoU8u3a
pm2d6T/aKMSvGC/S7GM9GrarBbo5MevReF3gfm5aVk5dgQT5ASO3vYS64l//
DRsyMRw=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XlIk3Ecx/GnpMz1R6brkNZhZUWHtcrUyvx4NDWbx5wmWBmS3bUhlSaB
D2KBrZFHRfZH2Ea6LO2wPNZgK6+hlpVBa4kloqNbJbqWWdHvW/QMHsaL9+/7
e46fd5pKkT6a47ikX9fvf/q5P9Wrg0Qt5j8aCE7ONJfZXMkcsh8tqr7sQh6H
3Lr+5/l/7Y5Uk2fzzjFkMfqnD3a/6W9mnoreTEfu2cdkCYZk2kNr9eRZ2DVb
lZyeSZ6N9B/zM0q3kudCXdKhaVpMnod5fKK4XEJegH0Ojef7ribmhVi5NNkw
0kBeDLvteLv8KNkXpw83+aQGkpfB5Fpiy3Y2MkvRGPfSjEnUl2PwoaZj9QTy
Chw4VTgtrInWr4RbfXano5nshwO9LTsceeRVuCUxe9ROIPsjzfjCN2sKOQBv
a6usptIG5kD0hPpmXLLeY14N+zmttGOAvAZfrSEBNVJavxYXTk7rfHORehA0
tpZUN9td5nWoiksRP/lIDobWL1Z9YgmtB7aXj+6L82PmAeX3oSr7oIX1EBxp
lV3LWc7m+RCUuYwUZTXQfqEQ7c4yhgZQD0V+n+jgpsPUw+A8kyKaXEw9DBWl
j9JE5+tZD4eucGdEhU8t6+GolJ8zSBNusr4e1eFqnZeGmV8Ptd6gunDsBusy
5OXoBk6+oy7D/icirTa4jvUIfGv3H7IO32I9AlmeV4cddbdZj4Q9snSy+BDd
PxILb++1RPczc1FQXvdZFGSmHgXd9pLX0jLqG5Djf9ZV7G9ifQP2tnZ+3f3q
DuvRiHQzjqnTG1mPxue3D73bOun9NyL7y7OkxDbafyMqA+fWcAa2npNDErir
x7yHnQcvhzVgbGvNTDqfGHhlOGfWf2D78THIL/KWqcbS88UiRJlv3J9M+8fi
RFdBDjeumvU4eN3fYu+TVP0xBOYFtgjMxQvmBebjwSldH3RHXWHz8Yho2Fas
UFWweQVGXRz/vb6gks0rYJ3xaXNM+TU2r4C7R9REy332PSwCcwmYk6RzccrZ
eSPh/84LbBGYU/5vCMwLbBGYSxTM//NPUAi6Mg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQk4lfkeB/CjMtKGRlEqp9HottBmiBZf66QIxzm2YznORqIsM09Sozci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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10n8s1HEcx/EvNT/yY3YUlXLnzIrzq+THcbwc5/y6ajcjM2scK1PRbPxR
re8USfrDEGVssWGErd+Ku/MjuYR1hU0bGdbmVMJaa4tqfd7f7bPvHnt+3/t+
P/t8RVn56hxzjuNkf9e/O10OMy0Fsl2vdf+1FrkUX7rVZkvmEKJr/NDPka0Q
HMBPVVmQHdBUllqTYkZ2wluTX9/s1xFmFxjHlDJvLdkVRseid+JWshC5ktq2
s+Vkdxy2u9nqeIHsAVOv9okkh+yJBoWupENMPgTrziD70k+vmL2g6p4+6D9B
lmDvd4G6toHsi+HbU05++WR/lK8J1YokcgAs+58Vj9qRjyD1zNPE3sVh5qMQ
7v85su8FORCXJqRuy+XkY7A3PRi+NT3EHASRxqTZrSUHo66pSrnRSg6BoGRy
bsaNHAqPoHHfOjFZCmlkWqj/SXIYVNis8CkcYA5H78KPYhuNnlmG7QQb5283
tMwRcOnivWLa+pgjYZhzd7bPpg7Up5yTrFuzeR4I7CjNzHCjHoXL3aFrGSvM
fBRsZUL1/XHqciy66AcqH/ezLkfPaaswkZyZi0Zu/fXJjXvs/Xw0pL/Mqw2W
9D0xGJTnTYr01GPguW3ULFjRvALtRm3jRzPqClQ4+FTOWtB8LDrfr6ZN7dGx
Hou6oeKWixJmTgnhiXBp+l2aV8JWM3e8Iu4l63HoiRAU+d15znocuqI6rujH
H7EeD7FhqaEgnT3Px2MpbF5VuIP2n4BkQW3E9jL1BGw290586aPzSMTKmGf7
52R2XnwiSrybx2uKaD4JAu78gbKtQdaTMO/v2n4tk5lTYejNqmv2Vfa/8yqM
+kys7swb1f3e6q6OfqjCulGV5XDKoPsDGfs3TQ==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVzglIk3EYx/EplccayOwkCQ2bUiI6U1um+2VtpnlMo1Arp6bSdOYKCzv3
ShclNc2otJWV2kGUx2Y6JzTTMqmgPFIqjS5Sw7LTLrvY8w964c/Lh+//ed7X
LTUnLt2Wx+PJ/5y/b/Y49ZRrgh3brlk1IpWs2PQr1oGZh3UTvyhzbZntsTdR
UO314ybZCVz3uNEP35gnIa+x4JL4X5+Gmfp454HvzC4I+nndvG2I2RUn9UZV
vIl5FrSBawIjLjG7I2lAUN1ykFkEAXc+KV3O7In2rhcGkyfzHCS87ros6b5B
9kJH/mat0MTsjV57rYf7fGYfHBTnTd3S2Er2xfFXyWNeemYxDE8c4mZfZfaD
sCC40u0d8zz4DvUmfHvL7I8gj8jcTDNzAAo7R8MNicyBeHff8uujink+vvK3
1gt7W8gS+KlFuyNDmBfAo1JQ5mVjIQfhQfZny9GdZvJClLhZVgaM1ZODEebd
pOSfriOHIDVTvtoxjlkK5b5HmilqZiBDUed7gt9gNQc0Zu1y0+qM1BdBfMRH
Yj5G97lFaNUU6nYcqqEeCr3qxRmtay31ULj7rCpt+cr6YowmFw1Xms5RX4xd
dsYfI1UV1Jfgjt6QNJhRTn0JdMKtAbYRHHUZhOOLu5LmSqTWLoNG1PdQunGD
1Tw5lgf6O6S7kDk53he3m7er02g+DNll15yeu4D2h8HuQ6Y6Wimj+aXoznFX
R+vY/FJ0RA3v6exUUQ9HiciUdWE6/Q8XjqoEk7Ht7n7aH4HSx4M1srx86hF4
UNXczPfUUF8Gm/GHnz2ekEb7l8GwfijvcoGKeiSaxAcODO3Jpx6JseZP6rR6
HX0/CqJs10d7e05Tj8KtZ6qUislnqEdDPqMvZZzdWerRaJI1VPO6yqnH/G8u
BskvL94zCiqpK/B07qljRe1kKPAm+XaHkkfmFOhfy//prL5itUWBqrPzar83
G2g+Fv2qwqK63dU0H4vUvlUpX0Lrpb8BoTVbbA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0nlMk3ccx/FHBEFgWpRtOP1jA5SC4Jwiq1z9cJVyKLSlhdAYxgwb13Ck
TIHMUSFMlIIcwwKdBYqYYGh0ZIld2GZbBBm4GBgZsMx4wHRNpgHCcDrFbeH7
y2KbNM0r736eo0/fev+INMeB47j3/n3/98levKnujyNcr19d1bywNaJQJVnP
zOHxi6UHrzszu+Dww1n3jxyYeTDL/Hdang+TPRFSt+AqtjF74cHi70OvTDJv
Q0LU+OQ+E/ObGFa2aL10zN6ojSq1DlQx+8JwYiG/o5h5B6ZrFIIgOTMf8c6J
j7sDmQOwdGu/y8wG5kD48Y49abg1RN6F2eYl49UC5t345fLbc3UL18jv4F6S
5oOmWuY9cGoImvIoZd4LvtAwmhnGHAxe+paNkppB8j6sW2MYVJxjDsGda/Xm
rf3M72J+MXu2soBZgGWnlemHM1byfmxavyvMZmUORWjQXLPgHnMYRIFCgbcn
cziGowaPzOZYyBEYKOSPtXmbyZEo4fi22FETWYhDGoutYvoKGeB0nuHuarIa
cOx80r4p7CvqUWhonev3vHGJehSixxPfsLj3UY/GlTO6ocifL1KPhi4noPFo
D+sx0Fb73+3fwHoMvqzW5Yef7KUei9722og/eAbqsXA8dKqzaayJehzcPI5X
PXPTU4+D9HKel2CqnLoI/qqM7vm4euFqFyHzdIbxYnTrqrl4CBQTZWWFjdTj
IVYJR6//QObE+EtwaWTN9xrqYviJNk/+aamknoCvfcQdj3ZUUU9A1vOflMEl
auqJUPveee3TtVnUE1FdFRTkYCyhnoTK5LbtFdl5dP1JcNC+OOGiLKKejOzh
o1lbhBW0T8aHE8vHU6ta6P4OwBm8z4t8ZLQ/gAse8u33R2tpf/Blq+3Mpdj1
FBScM5oCnjZRT8W28F/T3X77YtVIReHSzd03e7vp+6n4O7LxdPpt+j3NqdAu
u0TUaFtoL3n5+LCzWoLbGr9PclpzaS9BM1fubK2to70UPc8ipY57yJBCnOtV
rJ2j61NLYShuzM+soedllkIUrewO/Y6dXwaTUmYpVdD1QYbqcr++jd/qaC9D
bltX/UgR3Y9ZhpiaH2c6fPS0T4PANXhRtc5A+zQEjPBXng520T4NtiSxs3ng
GO3ToPrGX++wt42ejxzG0uLPJl7tXDXk8BhbDKnoaqfnJcfU1sxFtZX+32Y5
Rhse7TzrROYUcDelcON5PbRXYO39w30q/XnaK6DJOJs/0kLHNytwo8ztvK9G
R/t0rNw9uZnTn6K9ndV2Nv/vfwAUYNCj
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10AlI02EYx/FtmHk1Rp6zIDMJO2wu72Pbb1M3b2NWlpjXKu3ScGFeySgt
lDAESTEsxZkZiqJpaa15pWZhEEVGOCKK1EoNQZTKMnyfF/68fPi+/4eXd3t6
tvoEj8PhYO37v9MSvGs8L7EaNa5rQTbedcsml0/mYIWbt5RkR7ZASVjKphu2
ZAH2dOwwFVmS7aD3jc+MMiM7oUf9VOGwOsK8FeOBBUvSKbILph0LukRDZFf4
F2csm/eR3VAxnx580EDeCWHvj2Z5FdkdZVfhoU8g74YhuTZbGUTei8ZBTbTD
yDPmfdBekAufF5E9MRGSdcfpClmMUt8pV7WevB9ic8VqbzHZC/Wj23pzSsje
+Kv5IpCYkX3QuWFCae07zOyLyUzPxzMJZD+oOg2c0qUhZn8Yp2ZbtrwlB6Dr
kn26O4fOB6JhytJGFEI9CItxN7OjpeRgzHycbP9zfZBZAsEZvUyzMMAsxb2j
/rLjadRlaF2JGWvOpw5UjmxsL2zrX7cOkGcZ7ntcZubIoU3mS6ZT2XmdHNW8
r+rX5TRPgQGhW2+pB7NOgab6HMeLFnT/ENRppWrTXWbdmk8f+JxfRz0UtmK7
XT5i9n66UPwsrPCa86P3DIN2doHb0ETzw2AlkiM+g+6vxGHr90c2f+tjXYnf
jjW3bZsfsK7CmIh3SPW9k3UVli0+8c0Te1gPh8+11rwhxSPWwyEpLB9uDaAe
gXPj4ceMAV2sR0BrMTv/YpGZE4nK1m5eixX9H4kkz+F6k+Ah61GYN00vGfls
ni4KK8LgGOloN+vR4NbYl82dovnRqE1MfdK22sF6DJb7uYMvq5l1MfBOO5uQ
oqIei5NvBEM+NtRj4TxZoZG5UI9Dlqi86oOBehx+ZeY6d7xqMf4D6hA9sg==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10glUjfkfBvAbIpKSEDKKQkMJjaTFQ5EW1b3dllvduku3W2OorGGqO1MJ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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz38slHEcwPFnR2P+EDI7Rzp2lRVSqXN+5HPunMPdsRonyaTQbji/Wjct
eypzWrEVtSQmFMtYqGPkV0npkm61Sxp/hEYnpEv0SzXfT394tmfPXnvv83w/
X+cE5f5EBkVR/L/vvy8+Vm+q0/0tnnSvaj6gbuvFj5/M0BQ4OJ5vHDZFm4Nh
LGxcQaGtIFXPTAue6Se2hcmuzYkJBjQTVIXCa9xJtCOckGheaFrRbLgiinK/
VY52gfhYRrcyB82BrmS5JkWG3gISY0MJxwTtCrzI535y42PibfA2bzan4A7a
DXRF/MoP+WgPYNm7H6Xi0J4Q/V5uamGN3gkMlXXueEYf8S6YtR/gbtI+It4N
ctcH615Wo73A29IsKLoNvQeWJHbbO23Qe6Hpp3qYF/WQmAtOn5VDRzzR3jDE
lnkNStE8eMddmtPN9RL7wGvVoY4yNdoXUm+rj2uLe4j9ICZ+YjEutovYH1hZ
eiFd0kG8Dy6fnpmvsWwnDgDFZFt41tU2YoBvuZJ2Xun9VdMA1heYKVHZGtL5
cK4pZEcf6x7pfBjtrByJeNZMeiAc6J9WFdkT04HQTp3J/j3VQroA0hrMm7u1
d0kXQN3Mj+TodOxCcFPTjM4kYloIvw47cYrdyD5UEGh9KhQeN8k+dBDoZ1sH
HRbIPpQIxPmZo3or3F8E+qqKY7YTOB8MXwfqdJkt+P9gsP1iluB4Cc8XA8t7
TKRwwXkxLFwvP0VNYw+BghZ2knIJ7x8CvjWReU4n8fxQ2LBMj7yKbSI9FJ4G
NtavMGtJD4PelekMxmg96WFw8HttTM9yFekSMHAWmgUmxLQECsU2BqOgjHQp
6JyH5u1cbpAuBePi2WT1OM7LYGr9RgW7FOfXmApf09eYivjvPzdYSzc=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9lAlUzesaxnfZdZyDZM7poJlQZKo0PQ0UTZo019679m6HKHElDtuVIeKm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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQMC1xcX2HId3w/hfbAX5hKbPJEdxmdwUHrHvFrs
+zEon8NhXc23L/7fYHwBB7v+0y83PIXxRRzu3W9yizkJ40s4lE71m8O3BcaX
cfjyqpW/cgaMr+Cgaf/l9bvZML6SQ9AnRdv6ahhfxaGA4f+cU7UwvppD7qkN
738VwfgaDvddi1pKzWF8LYeOv1F2y58ehfJ1HPp/vf+s0Abj6zkcTft1am8p
jG/gUOYYzy+WCOMbOtj6VASkWsP4Rg7JN5dciYqB8Y0dVmxPMGsXgPFNHJyd
Hh1vPX8Eyjd1+Obd+ijw8WEo38xh69tghZ53ML65wzSd/ujQ5zC+hUP4ZMf6
rwEwvqUDf8cLTpkjh6B8K4cl6ewbL5nD5K0d/De4Oosnw+RtHHb9KZrOvf0g
lG/r8ODytrkHnWDydg7lymzppaowvr0D45rTLOoyMPUODh1PzP7rnDkA4Tc4
OOTyP77KUAVT7+gwf0d7SagxlN/g6OB7QEEkvRfmHieHH4+/X1CygIZHg5OD
2iHuL8vuw9KPswPT7cR4g/oT++sKp+Y/MnV2+HTJN0kg4uR+AA8kzl8=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgk81Pkfx/EpVo7k6FhUyFFtiUK7scrbVRG5GfeYi/5CrZZV0qxSjhVL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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n1Q03UcB/AlEIhRazKIh3gwEhBITEFBGG/GBBkNtjEYXPQgxo4YBHfB
edCQYdaFdgfxICDFnekgM0IBn0kGA4KwEsV46EiM5CFRFg57gI7q/H7+iN/d
7373uve9v48/99RsedoaDoez99/3vy893OHjOaHWX3c8kjGsrmnTuz02ZA7C
ZB7fj5iRrbAS5FKIxV5mLnqcLcrn5sm2OHnrbJHBSH4GQ31huTdHyc44/4NL
XeF3ZDdobBqmAlrJG8D3S7lWU0T2ADd5b+GglLwRjX3p86LtZC+sdd3y/FPr
yZuQq367aur3HmZfuH+gVuWMkF/AqNrqYGw92R9OyjLLmBryFnDLt/k1Z5Jf
xGHFZsFwRzfzVkjyprq9C8jboHt9bm2bgRyAipkidd9v5EC0FkbmjenI2/Ew
oy990JO8A9VVb8w/5kwOgp+5yvLvsS7mYDxME7ScVJN34ojJzmSa6GQOwebM
+rvNK+RQOO//5l6/G1mAia3RycJXOpjDYIgw8FPavmIGZmyt8v7iXXxkLbAU
8v70SOp5lofj8adnh2XV51gejvrh0vpGB8qFMHmXOGqmL7BciG95b7WXv8nG
40Tgp0O/DI2Osfm0EcjXddfOmV9huQiviu2kPveYtSJIfz03cLStneW7cL/8
4OJVFa1vFxyaEsQBF2n8SEhmjt3ITrnM8kgoF9ULUYu0vyg4ZO3hZAXR/FHg
jDbmjq7Ts3w3PI72Jrt9xM5HuxtRYp7aVkjnFY27qozGLC7l0djjlV+xbEF9
MYrFAl+BkFkrhk9x6LiDDeUxCFefWDL4Uh6DsOPP8UujKH8J3NL3Cj34lK8y
R7IqlyBQbmY8/DnlsThx4UGt1kh5LMqum9ZrmyiPQ2BDnCx3J+VxyL+TcSu9
hf4PKZz2Lc0/68gMKVwbYhf87Zi1Utzvr/LMWMfOTy/F/k6zrtlDl1hfhnB/
tx+Xs9l9QQadEyrTGum8ZfjjE2f+HI/6MgwZD3xxY5DuV47lDbJxyyPsPiFH
V67Zn7032f+llaPaQVrSX8Ssl+NTxeRs5Zk21o9H85Lm44IaZsRjTd8+x+Cx
06wfD41O5BZkOsX68XhQhzvDnp+xvgK1Ykm/3r2V9RWr+qusV+DnyYKWiGvM
nIT/50hAxZWXB9JdW1g/AdWTjj6LOcz6BOhWRO8EW9P6E+F/6djsk800fyJU
t63bi0XM2kSkjbvc7pQx6xMxLvDP9N54hvWV6Hrtqi2vhI0PJT40P6DzVtH8
Slyum3hi2ovtV6+Et/1pi8pTtP8klAnt03fkfcn6SdAoVs6G1Ld1FA1U2hvy
k7BwXZLKTerv+AezIgKj
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQs01HkfBvB/uiulrby1SrZXiSLXFi0eRHLLXcZtzBhDN+UWpYxSW0Tr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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzntIk1EYx/E3nTHWAuliYyXqMpFuWLqLlvmbOi8bSZpgUBkb2YWVUxDN
QTCo1AqKoiQKtbnakKIQ0mqFK7e5FaWVmZC5zIUoYXgZNCjtguf5o71wePnw
PTznidMZisrCOI5T/D3//vRFDloq0gUex4KmMmzO42EiIZnDULm0xMwj86Ef
rLMnzfUwRyK5K8Wv/EhegdV1/PJ7XrII4tujzrv3yWswLDsQbjxPjsWSJu/s
uVqyBDPfLF/36sjxCB6rXHyrkJyAyJiIN80J5ES4zuxqqBeS1+Nq/odZzQM3
80boNbH7tI/Im+Gq85/w7SQnwbRSZVklJm+Be2Ai2s0jb4Vud8uP8GoXczL2
tFYVGTeQU+DWKdqlIEsxorx0+EjQySzDWE9xbQ2PuhzB5dPKmUnqCnBrmz6Z
+8ipqGovdL/S0v00jJm/Tw9fob4NAok/7ncVeTvmWlS2cQU5HY+vDYzIAs+Z
d8DouHh99jQ5A6OJxUuHfGRgPM69qe1Q94JNwLpfwvDLUcycEjZMznf62HyT
Eq/NnRMPY2i/TAg0N/PsEuqZCLyv/hKlpX2y0Laovr+sgnoWDnYsu7A/m+Zn
Q9zX5U0toPezYQhEl5eIaD8VTjV39E55nrCuwo0Yn1rd/ZT1HERUWu+kzT9j
PQdnj0o0jVk0P/d/m3LRW3BS9cJrZz0vpIeYyw/pIebUKDI43/Y3sH1NatTw
X3626tk+nAaNmdZ3PwMO1jWIl5fKPaUdjj/hPh83
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90X8s1HEcx/Evk1200ZSVMTFuZqWj0yE/XneO82uyTIUSt5XQORZbFxVK
jLX1Y1bWxvoxSzSh2vmRcFeqv+ysmltFYVFCIbPS0nq/+2zfffbY8/t+f//4
uqm1ew5bCoIQuPr8vfnYv7mVF2Iz8OSf5sKWXeymvlqzBcQbEw03fzwji9A4
Uj81O8O2R4WxzMZpnL0BUUlpMsUIexMKq5N9dW/ZztBmHP9o6GZvgb/BYyq7
j+2O4r7q36petgcafcUhmmtsMdyOLtX057G94KOvS7cKY3tjpkWSpStkb0Wa
q0j60Intg1Rz+phM/5QsQa7zYHlQDtsXTQ7GdKWO7Yfsgu35Miv2DqDAr/Li
GrYUm3+ZjlzIMZL90RB391X4FQN5JwK6ikTi4X6yDK5j6yxKPdkBuBEcfPpS
ax85EO7atLVycy85CBZ3gopeVvWQd6FJklA1f+4xORiLoy/UMHWTQ1BjCk3t
NXeSQ+GqlBcPX31EDoNF3CeZqOIBGRj/rm8vPEMuAVyGksvUJu5yxOeodeff
t1GXo3xvYmnqeu4KaOUayUFTK3UFspImuxbs2qmHY+LA0jupjudXLTgqkm7z
vBL6xNq2jce4KzGyLLdOUd2nHoHpTKl3vYRcEoHPlhqvkwv0PSESGarAntHM
FuqRmL1uHlCkcFchOyFycP4nz6uwsG9eeSqUexRcFuu8Dg1xj0Jp5ettjvtp
nxCNBofdmsmVe9Sj0ZE3sWKb30Q9Bl/8L0+fneMegxPfPnQ02zZTj139n/ae
M7m8PxYZ5s7nKjG9L8T99x9PyB9A
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0GtIk1Ecx/EHNZWJ5AuzFaNUZM0LcyvT1NTfbHM5zbykNayQ4S2NsjKH
iTayi1p2sSKlSHHSYKUpaabZlpfsTcZAw0tKmtGCICUSU6MyOv8gHzg8fPie
C+d4aI4mZthwHBe2PP786XMZ1ueF8V6a/2o2Qp19q8bNkczBKT9T4fCvO6I1
dMhO60B2gcf8tPbjXD+zK+waNIWaRTIfsfeyd6eOkAXwba13k3WT3WGYSJ4a
NJA9UTAn7bDqyV7olVuuV1aShVhcSHiTVE4Wod2af6f/JtkHkgb35vU1ZD+U
SRsOb8wli/HhSoBAYkeWwKf2WkjE0gtmKSZLs0aPPSZvxtdRe+WmLvIWdP5c
ijntRw7AhfHyOoG6j3krBt4m5j571csciGqe3svQRQ5CXvF3fbyQ5m9Dye3U
16IK6sGwDBwZ4R/vYQ7BGJdxaf9MN3MoTKVXP6dkkrdDajPr7B38nDkMJ6us
PwobzczhSLf9VV9UZGKOgNF2umVfXBcz0Cku29CYwKwDzmYJQhdmO1mXwXfN
gWpdxlPWZZCN1fHV56hH4kx/On/QtZ31SEw9SVR6lLWxvgPqU/Pr2lStrC9b
UVwVdPkR63K4qhz2iJsesi5HeLw2aUb4gHUF7CVGkW41s06BaanASZrG5nNR
sCzFTaoiaX0UjE3Dg345zawrUbDqk8X5ELNOiYrkjvqoG/dZ3wlJe9DeArOB
9WXL895reXR+NO76pAgnzLR/NMSawPG1phbWVfA/YS39UkL7q+DSMTPUV0v3
i/nfuhXmYlf0WFz0TzedP8jei9uF7LQc96x39H4rzMWhh/fN29Gzzfwb73wy
YA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxF0A9MjHEcx/FHVq5muUkthEpaEcupKOU+5a7uzl2dVpQIzU1G0T8jf3pK
LWfopjXUOSpkUvNnioqoiGnmJukPNseKtIlCf2Zh/b55tmfPXnv/nt/veb5O
cbvDNWYcx4X8vf896RK+Lt0TYNVcP65+cfY062djU8kcfJTzGjQTFqCjZE5S
34SFOA0t3ywgz4C7wDFLN5lsj4EFm4q6ex8zO+CzcPjH+nqyI6RDZuKPZ8nO
aNOvO9h6ieyCMV8b4yUt2RWzR/bHyfLIbthrI2qa6U1eiOtHTKnJE/aAdrNl
w1cBeQnyO2R13icfMXtCde38r4tbyEsR2pZ0OXw6WYQzia+sRrqbmJdhakWV
tGUadS+oRVx5fjbZG50xCXG2z2i9DzLeqj7b55KXIyp5WFS2mLwCzgJwhueN
zL7QcdJ22ytkPxztmuPnIiavRM6kSLvE3IfM/rhuWaYx3X7AHIDX7S/y+4+S
V6Fm7gv+hB9ZDGPBm7Enh+8zAym2cnn1nbpx84DOqcRfk009ECV30t1u9taw
HgiFsWOfSX2X9SBMknnGv0tj5oPgtX19eZ4l9dUo5it+X6itZn01Yo1ah6pP
bD9OAuf21qQO0PkSjG7bYRfVTe9L4cNvfDKkpi5FqkK/tS2avi8Ycosvx6qU
1IPx3bIy8Ew89RAMmCdGpPcz8yHQmwQvj8+n+cmwL2pgw/veBtZlyNr9pjny
KjMnx6PknpRoEVvPy5Ex8PZctYbmqcCUdUGD+sZ61hX4IBe+n97JzK1Bz60D
RZnf6Pw10O0y++laSF2JQgd3X+tZ9L4SMbHDgwWL2P9wKljHexv25tSyroLW
IjOifDb1UIg8ivXmKvr/UPikcaOzHO+xHoZgnavMYGLmw6B/2pXQ2UXzV6P0
oGvJoT42b6jRZRMR3hNO69X4FF1U6SBh5z9Q49SNPsnITtp/LZSbmtNbwljH
WhQmOLUanGme//0HWTZrBw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1z31IE3Ecx/FLyZZBCi6byz8ynKnldFqtbek+btPptAesxCArg82HlJWp
YLpYZVqCkoGpGSIowmoU5APzcZoPkZWxHjDIUlMbFkJpGhFhRb/vwXG8eN99
7s7vtDFJ78JxnPTv+e9Kh+d409lI98f2//qq/OhfWix2I3OIL6mK6FgdYeah
Wi8I9fpF9kRqZeLxd4tkPk6EFi+d+UQWoOVzbknrNNkXz8ptG9fayVsxoWgK
D7KSt8Fk+VDrVU72h+GNImy7hByA2gqvyqUN5EDwZdX6uYVh5mBosu+OrZjI
O5GGgpmfAWQxKu6dl/f5k8Mw0RHWdejHELMEwqEt31qnyOE4IJLN6lfJEeBu
KcfENvIuVJ3MMby8QN6No+Nip2g/eQ+SHAdl8xKyFLJjg50+ReS9CFI488v8
yDL0bVresfz6EbMcIXWGL5Olg8wK+Np6lCId3b8PURltV3Ks9D+RGKvX2HTP
qUfB4hZse5JHVkIwWvP0soP2gO7emzd+5zGbAWe7Z3RXP70/GmWF9QK1ywDr
0Tg3m+qdJmPmVDA3Whpys+ysq9D+4JLW+L6XdTVOyV1VKnk362ooLg67GrKY
OQ1M9yWB8+mdrGtg5afwUpq7WI+BR4y7ICmE9mOw0j9d8kJI+7FIHphpnLre
w3os+teJi+KMtK+FVHp7VKXrY12L3vL1vKubmbk4ZHzPLLQn0/NxeNUy+dbH
Qfvx4GqE6c0F9H3xyLqzcFgU8JB1HRa9VzwS55jNOiQErrmW2dnGegIatOoj
2fkj9j/g5BHg
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10l1I01EYx/G1wIUkGvZiaDRtDHMpm017mXM/999mLidDyYoYkehVWVFj
TIu5BtVqtIJgmiMLJBczQg3DmdOcs62spoKsq7LEFCpX3Q0qKjzPgcPhwxcO
58CT23CmtonP4/Gk//b/k1ZGvPusMjUytqrvqgf3F2NXU8g8XEqxnhT8fsG8
DrPiWI8rSc5AfqQG4QR5I143HirP/kTOwmbniaZX78k5+KxNbj/4hCxEYH7u
cXYvOQ8CYV1AGiSLkNs6Vf/GTxbj4fhkuMtLzoflyoqitpVcgP7LsRstDeRd
UFn1ovZN5CKYM29aRrPIUrxNOxar+jLJLIPR0XEu1UMuhsyv3jZ1kbwbiYle
w9w1shwG71bOFiGXYCg+IGo7Ti6F/pbjK3eYvAdLnR/kP8+T98JtUoh91eR9
qOJJPBYpeT/u2fR5hjVkBYpPyQc7RWHmMtT9WXZ/s00wK1EaGrHy20PM5fDN
RGscBWQVOrjp0z7zODNQL9vJKR49X7UdSIsPDnHGUdYr4LzQbVO6qFcgXWgO
J2+PsK5GKFBo+bV+mHU1gj887i7TM9Y5FBrvVN9dZvfZOSzInq5Er1PXoGT4
yIyzMci6BpLZFn/OR3qfFgsvM/vK+Oy/di2aD2wweBM0nzroiyRrd7xjtutg
6juaHl2iXolpl2a+LUq9EjpR8+IWQXTsL5u78VI=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91Hk4VfkfB/DbrlQyFc1N0y0ttkTLpBq8r132fee6172uaqJpXyanUmQi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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0HtMU2cYBvCuE4KiQwLMugxmmY5ZDK1QBFHsQ8u15dKWYtkEkU4CMzGW
CipMSWdW2M1sAjEgdWKptKhTQBChbFSYsqDJghsjY0FQlpUNHHT8MYXEXcL7
ZYknOTn55Xmf9zvn8HWH1AVcDofz9r/3f092rR1t0seuGuxb1rxEekiXz3uJ
mQPBJPdsgA+zF2ZzfY32pTvktcitLUySPWH2R1Vz/slGNzMPlb31vz68x/wq
vCOfeqzvZ96AS25rt+9N5mCc5tfl5puYN0L/5y7L2HHmN2D3j7U3SJjfxFB0
e8LVjcwCNIR6uYstt8lbMGz+Zc1sEXMYdjR9YnhvA7MI6f28n0Kuf0Peij2v
VfHKK5jDcWZlzt4i1wA5AlL1xAv1jcxi3M+zC7lgjgRvYrGqu6ufvA0f6Rcv
CrXMURi679CHtN8iR2PvQrVMJGHeDs/s+N2POphjMMurq/b1Yd6B6/5NyX94
O8k7EcO/qisr6SPH4rBiZlPos6/Iu9AW2n3EOe4gSxAz/yDa5uglA2GKwKBp
Lc0bgZGhT198p5HNxyEryPR4eP9NyuNgii5z3N1/g3IpzplFPEFsJ+VSrP4y
cntgajvlMpjl3zl7drZRLsNIsDqKX9lKeTzEt2qHH9ZcojweXlMnbK/csFGe
gBUZS2M9FXbKE3Db4N3jNXWF8kSYufrDk/WXKU+EYKJ1X/sx2sdJwvq5ynHR
Kpo3JkHs6jAttLL9yYh4bPj42Lvs/GQMWgNWlx5soTwF788rRSUumjemYHgu
R9vVSe/DkaNPMDCw4GulXA5X9tEc4YqzlCvg16U/sG7mAuUK1KnKyzyKL1Ke
Cn9bvjC8he1PhbEsYPxyJO3jpMHbzbHeK2T705D2ZMvTkTx2fjomDX+7DyjY
/0lHoE5eYCqxUJ6B5GezfzV2kY0Z2Ge4WzMQx85X4uiVlLBrDjKUKF6TMV7+
iJ2nRP9oW6deTvudSti/9ju3J6KJ+ip8K+b9FjJmpr4KYROOE8LXG6ivAtf+
YCriAtmpQufx+WnPa+epr4Y0SNfba2V9NabitFHhPnXUV6Ni3WhpDZ/mnWps
axZ4yCrZ92Via/DLiZtP0TwycUdzZpPF8iH1M/G5TdziqfiC+pnIK+CdnjnI
+hosDS6uDD/ZTH0NTC6tqbaK3seowVxHanf690XU18Av+8ffzbUyyXI/Cz8Y
Nh/54LNTy0YWpG9Nt5b/fH7ZxufsfM6c3XCUSiXuwmrq/+9/AOV6xfo=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQk41Psex/H/QaW0qGihMsoRKuUiovgoS/axZ2mMWZhUqC5OudXcGyot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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQlYzfkex/E/iZmSusYUWaYaM1oIDWUp51MmFdXUqbTX6SydtIxkiNT4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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0glQlHUcxvE3hCiNM0l0UBOIEURAEgIMeGBRDjl3F5ZEkmNjiTGBmBDG
gzcVssZltTQBgzhjkAWCEIg4FhYhQTKh0BHKmIlKK+TSoJmNbPb3r4md2dn5
zPd93ndn/7slIVX4mg7HcdLH738+2cv4VkWa5+qBbq1mvPvOeCSFrGHmUHiw
fmnXv/0pyOs36E7rMBujINOk+6+H/eS1aCiOftVolNkc3BFpy3UVswUeHL9p
b1rG/DxixN/kuecxW8J+39C8RRqzNfaLzWRrnmO2wfvWwzcqjJi34qxdR4N0
NbMdRh0zVi1PXiXbw+ktw8QvepgdYNtRV+Icx+wEmdmlK1wm8w7M6zoWiKb6
yM7Yru9o5HGO+UX0jOa4ayTMOzFiZrAhuUNNdsHSu8r6ijxmV4iDblso7Jlf
gibxVNupxF6yG55RWxVfudVDdodSP+T2SBzrHjDMVTcILFnfhZ7Jaz//rlCR
X0b0uGvpo6+7yZ5w8Xtd2P89sxe22dp++LROJ9kb386tH2t9sp0MxPjbLB43
+FxrHpAempUPvdJK3Qd1rTMKCznrPhA2hixOlJM5X3gpX/juq+3N1H2R5Z0+
12vYQl0As3SHYkOTJuoCdN4VmJm6fkbdD+ceOfFtGjLvh4nEbMl1BV3P7Uax
/RFPSVIj9d2I0isNtjVWUt+DdaLagZyrZH4PIgxSjx3OYt0fNodPyBRONdT9
od5UXXTeoZZ6AGpClwur+y5TD8DURFSq1LyOeiBaQ3lNdzZdzweiRv/L+NZ9
ZdSDUG85WLFR/gn1ILQohwbvT7D9XlRWKcU7FGR+L3yHH3q1KauoByN5sHcu
M7GEejDupeX85pFRSj0E1hGChW0H2f1D8OBAkDIg/hL1UKir72zqiSmiHoob
Fyoc87kC6mHY/8P00nhwIfUwKDUzfyyfuUg9HAPGdkVxUrofwhHWtdheJrtA
14fjY0fX2SK981qrwiG1Ui+4VctpHwH5mJv5qNWbtI/AYPOI1Z86sbSPQL6J
afqgcxztI8Cd/LWy3P8Y7YUICV8XWJ2Q4q3dC9EYZpoVs/ZtrXkhDp3m/Ian
5FqrhGgy6pqND1RozYlwul1Um50gob0IR+8mTy4I0un5IvyoO+1pHXuCnv+4
VwUP+Mh4er4Y3ZqdLRdv5tP3F+PoPY1jbtV7tBdjS/vQ2ZbSD2gvxv076V1m
sez3i8Q7eibNG/3p90AkPjW9vDnlCep8JBrG05z7Q+l8VJGYE6SoBWMf0T4K
rZUesjcm6PwRhawS45PXmuj8+Sho5p+tTNKh81dFYbPzT1sPFJXTXgKXjM7q
gvVsL8HcpGGm/iz9P3kJVv3iXhuTW0n7Feai/2+sML/Cqv/8Nytu/Dc=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzX9MzHEcx/FvImk2dTGmUChFpU51OuVe0a+Lq6vZzo8ly1pZhvwoLdMl
5Tf9uH5fQ3cUYZVZx8Up4fRr+jGk8iu3JMaGC7PCen/84bt9991jz8/r87WP
2RkZO4HjOPGf9++XPZZPVbv8LB7qxvVZ9GqD+ugIx8wh/aQwwGjCbI7JmVsU
60YfkC2h6s0K6P7CPB2RLxTRre+YZ0E3tkVraGe2RWvvcJpRzWyHQVdhlDqF
eT44nwfbvscxL0R8ru+3DCGzI+b0OER6jt4nO0EwWp3kcpd5MQ7+sFGW6Zhd
0CVARUU6sxvyEk/4qPKY3ZH6Nlq2byqzB2aGvda05DeR+Xj26dfX8p/My9Dk
JbZu6Gf2hI3VzFs7vJm9cK0iX+vmyewND8Wi/hwnZgEkvKTBp4Z75OXIVtQU
2hgayT4IcZMkyW4wCzGjUX/leDXzCuwxti+e09hA9sVWfuppUwGzH4xjGZm6
vTryStRHW80zz7pDFkFvX2WqXK8lA/pK1yznqFvjlgOPi9/GmvDInD8+1lw8
3HjkJnV/9DVcqvKKI3OrEHuzY2SKGeursGSewiK5iPXVOJ/9pN//gIb6aizY
JIqyLqmlHgDlkKa96+N16gFoK8vd59RM5gLRqa+f9qylmnoglqiVrsa6y9SD
sDulTuTSr6IehOSUKke7uWQuGKn5w8O3BWepB8Ow1KLOPr6Eegj4s71tl4qK
qIfg6qhBKzNlezEKErc7S3lq6mIUVZ1rjrG9QD0UHzSp1aY57P+h6MlTGUYS
KqmvwaDYeOT4MFm+Bk2B3LWX0XQftxb11n0Dsc+V1Ndibsmj+zH7z1OXYDN/
/p2492S5BMpCs7MiPp3nwiDTTO3u4BdQD0NGj4PzpDPZ1MNRdCnKhNeZRz0c
BXGlbq9Kc6lLcXLgdOKhUyfGDSkqH5pL0ptpL5diqNzzavFB2t+V4oq3g2Np
Qg7tI7Cr7c3GwBY6jwjUxsfLJh7LpH0EBvTu7ta8NNr/Zy7yn38DIVZ3jg==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zws4lIkeBvAvLUuEsraTNEaIrUSSVC6viERyyeRuZpgZbbXFxtmKbVJ0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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxF0H8s1HEcx/GbSvmxdmQLk5whndZEXNHldY7jOJQfG9Vs2emHLlqK5YZL
q2lNhVLpB3OrjXT5mVh1fh2pSbakFUrL9cNVl61cLfoxn3d9t+++e+y51/uP
Ly8lIzbVjMPhiP+8f7/0cIfV+4SWvdo5GYNOLJZXFZqTOXDNujQjsiAvQnxF
6pOo+WQulnnFFQ3M9DDbwU2nU2gnyPZYEqeVeH0gO0G5//nFwJdkF6Qot/Im
XpBdMX046aDkn93g+Wb654FBsgdulVWfdr9A9gSv3JBQd4rMh5wv8DkeSl4F
gfJ9W/oK8mqItDaFTe5kb+jPWdkEjuuY12DQ2f5JiJLsg1b55fxd3mRfjDZ6
jZjE5LUwJUgPNo52M/shoT5me9czsj92K64ci3IkC+Bo1VrT9Zi8DpyKvVWv
c8jr4eAkX5hZRA7Alk/TGomhizkQ5p362V4ueQNOffRLW3u2k1mI3T/a4o++
62DeiAd7TvZnj5GDEJN4R/m0s50ZkE0W5oZF3p2zCpg8YF0dt/Qe6yJssVCr
O77dYV2EbGdTeZ8f9WAIvc3VzV+YVcGwnefSd1/TxroYshU55/t0dF8Mg0+a
bmUd9RAkGmu/ygdvsx4CRZWVosW3mfVQTA5f53uWMKtCYXd6SUZjcRPrEuSt
SpSOmWgvwS5jcfBV9S3Ww1D81lbWmkn7MJhdtLBdL2xhPRy8JIericPsnioc
sx7phtLvdF+K9pGM5ZattJdifuVQqE14I+sRWFBbMGWU1bEegaqJnW8c+RrW
I7F/QFMwWVbNeiSm30Unj5fWsC5DXL/gYUPPDdZlqFQmn7EQ0D4KkpLutLRm
2kfhiLM+7/Pm66xHI1Y/1S9sYPdU0agJ2PHLIeQm6zE4NCRduk1PPQa5mTrr
fNM11jfB0yMrWaOsnzM2od7/kfEVl/0f1X//BlKCWhg=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9znlI02Ecx/HfFClbhZGklIi6tbSLauaq5fbZ5rFZ0qHIMtOYpdHhapEZ
hEw8CA1ERBGbBtOyw+GBV+k8ZpqyjuWQaQn+kSn9Ia4wKsis8Pn2wMPDi/fz
PHyDdfqT5z04jov4u/+dtHxcdVcj17zsW5Fb/lWdc87NJ3NINIdmLXuTV8P+
cyxN/b/7QCou/fx8eZjZFy7thCSNo+4P73HXXeE36gHg/RhIyXSRg7CxYUo9
10gOwa+62+qxcrIQQRd2WDsNZBEWMxeUFafIoahPUXm9Xk/ejuIj87KblUPM
O2FvMnRXy8i78UbLVc/MvmDeg4ty7RA/m7wXqz4c6wmUkffhsV6/rsk8yCxG
wANdU2ABORxT2qzmjE825v0oaet9YvlIjoDvvLjSXkb3JagamU2yWqgfwNlE
R1lqNvkgFF1neEfNA8yH8NY5bZNLyFKE5hv06XzyYdR7tgmS4/uZIyHb6hAa
W6nLIEjqvyQZpy5H5jadV6mhlxkInrwW78/vWbER2NWd5xFQ08W6Au+suSfu
dXawrsDa9oq8Al/qSvg5R1qic5tZV8IS5lq6rG1lXYUEpy1Z5WhjXYVbYanT
k8P0Pgp3SjJy8xXPWI9Cu2fJcCGPmYtGVbhYI52h+aLxSLQlZLPdynoMiq57
N/oZ2X/GGIx+V365X97JeiwKB021i7X0fyxEQrf4Six1NYrERv3SxFPW1Sje
0CDtOM7m5TQQtfx+v/jQwroGpgUI5kbrWI9DunmT0mS5wXocrBWvchJO9/b9
ATwUERI=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzF1I02EUx/E/ZbFqvqQuFyjmHJLhRqXperH9NnVrWkRSjpBhE7Q2RJdd
5EUXgyhLizI1jVDLpoHiC03BELe1ys0KyhAryNICobKyItv+E3vB53jRgYeH
D9/DiSssyy1axnFc8t/376cJe3HLkr7a41zUrHKibCR2/Soyh5ejr3wNS10A
4dikqVhADoPYaBGWfhxmjsS3vTr7AZ4sxrQjdPL7DDkaTq0qR3SXvAHRif65
jkGyBK7AuhirgyxF38n3ktomcgKqvB+y7S3kjYj97TnacZW8CVHh/Kj6LDkJ
JZ9ky1sryHKI8rOrYozkzSg6l+LlMslbkFDp7R15+5B5Kz63N1xbeEZORpc/
/3GQg5yCKXvbkOEYeRu+3Bx8JNCSU1HTVF8doX/AnIb9SSV34irvMysg423d
pWHUt0Oo4VeIpdR34IZlfn58zM28Ewohpw+JJO9CQbzPrJ28x5yOXxcrjpx2
kXdDeklSe0ZOVmL0/JvqtqV94Pnxpus9J5itwIzJvKZGRPdViDfoCw8NO1hX
ITVQ99V3eIh1NRIL9nm8OmarGkEGp+J1yADrGRBEza5tcfexnoGJhRxzd3E/
65kwySICT/qZrZnQj3eGu3J7Wc9CubFH8+NgO+tZMBY02srdjaxr4JzqFAXH
VLOuwVORvH7l3AXWteBPhdb5m9m+VYuGtMv8bXcz63twRfXTJeO6lIv9P3M6
TL/LywsesCn/AA+4As0=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgk41fkex/F/IpW6RF1LGO0SWSpqUj4SdVSWc+zrOYdzUJSaUtOklBZl
ikbbLcJFxShEyghHtqGNZBnSNjVptSQaTdzu4/vzPOfxvJ7vef8+Z5p4E18i
x3Fc7bfP//+zP5WWtPBl42vKRtRttWCSosUGRWYO4i86YepKzGOhL8ycfmug
mqyCPoeO90c6mCcjtr3ynbiWWQMneAGuyqeYtdHCv1Eq2sWsh793mybVOTJP
h0fp9iPllswz8ceM9D333laRZyN9/olTyUnM+ujL6jm8jc9sgE0qfZO8eyrJ
hhhq/c694SLzfJyK1LweAmYTXM/XOu8oqyCb4kvwODX1HcxmUFLoeBI2j3kB
xMaz+Y07b5EXIvqe5Y3UZcyLUNHjrpD5ZznZHME5Cp9mfZKRLSDcmOBvqsfu
i6F3aIJL0vdl5CWo/KC+J3p/Kfl7PDQ7smdvKPNSBPV2+i6sKCZbwsB72MLL
/CZ5GfT0pa5J8UXk5WjKMrlxtrCQbAX/DpOWqsZ8MtA5e5bDhDN5I44Cqq4f
ym0fdZnu1tCL1tIeOp9Nd2uUd6ry9Puu0H0FUhKbPlepZtF9BaqN32/XVcug
uw16X2/nFUy8QHcbfJwaPqBdnkr3lVDeKee25v1/6b4SiF5rul+B9bbYoBxZ
qRqWRndbjOZv3uv6D32fs4NZ8ldJbx/r7WBYtv/xwdh0uq/C6up/4jK3sf1V
OOPQeG/ucjK3Gnu4Xc6W1axfDYmCODnkAOt5aFczyekNu0R3HpT7P1R15LHe
HmdNkrYs3sV+nz0GJonM7VpT6L4GTvO7mwzHs/fX4LLRf7TzFdn7a8GvOZUe
uvss3dciy0ftTOJ3cXRfh9fDf425oPsT3dfhhiBK8/npLXR3wCIb9fiKraFW
I3cHKCivNShNiBgx5wijuItNcsPRdHdE4UKP05MVEujuhMPJoQ6mb9JHDCfs
M5tS9lv1Bfq+E+z39Chu9EkbscwJYbwS+x/nkjlnDMdZ3/1VhQxnbNF9a3xw
SSr1zij369wqcGS9MwTzXvBed9D7HB9lz1LOyfVfop4PjSYbgc7zTOr5MFsV
72+iT3cZH3VKwhb1RLpzAhQVxPSEd2RTLwAadzrL386iXoCLpf0aAW2XqRcg
I1LvZdeOXOpd8Li4yb0yII96F/jH1L/dHUf3KBcMuXV0aZnkUO+C5GWSYZk1
610RYSvJVr1MhiuySsy7jZpZ74rt0wSFpQZkmSvul9X3bCmkPc4NRufT6xvN
2L4bjhlFu/14iBzlhrn2af+acZgsc0Pkq16bvjWsd8fW6kZdwwTWu+OdRZx4
rM9V6t0xZfM1Yekjsswd00/elUScJ3MeCOrYOMWkhwwPjHu3z4A7mE+9B/KS
Pt+xbiyg3gPykbNrX94tpN4TWQ4hg3ZHb1DvCc1RYSr7uGLqPTHYNUvrln4J
9Z5Iy9DWfaAko94LaoN5Eessy6n3gu5rxXJtl1vUe8F2gZe23imyzAtFFfmH
gh6QOW+oXzsnmcmroN4bz1uS026/qKTeGxtu9rQG1FZR7431P08b/MWgmnof
LA29dkcrmAwf/OnBbaoaX0O9D1Q0O5dvW/Q79T5Qrn9Ze+R3MueL0fHdY4xn
1lLvixdmOiWCn8lRvjDXmR8RPkyW+SL8nuKYgUQy54eJm4br/O6y3g/DfR+z
w4pZ74cu3e7wwtA66v0Qm2z2qUmDzPkjs6XYZ0UGGf64b5rPzzt9m3p/vMHx
1MRjZJk/NrzLdHu+7g71QkzjpT46OoesJ4TapM/9l9TIEEJX1Vv6qIosFKL7
2284s+0uvS+EZ+yx9OuZ90acIoT8FgdVrpksE2KZpnbBGe/7I3767b3KA61S
EZkTIUNtx+h+uXraFyHOtm1JiDkZIhz4YlAiZ0UWimBpFD9WFEuOEiF316c5
DaXkFBGcXzm4Fz0hy0QQ1zWkRU5ooH0RVhkutd1rR+bEyGlfrhLhRdYTw/LE
2OMux8kQ44eKqV/TrpKFYswb+pEX0UyOEmNI5uCm+oCcIoZmk/zJa7Vk2Tfb
9xq/es/2xfCJDmyd84LtB+Chgk6lRRrbD0BSRJ5LWjzbD4Dc+llGbhvZfgCe
ReQiwYrtB6BGf0ZDy0K2H4CfzH/J6Qhi+wGYdfTfi7LD2X4APrh2vi34ge0H
oih89dYZTWw/EIvKc5zON7D9QNgrHtm4d+YD2g/E4eAwt8EkclQgsttTRVdi
G2k/EIIEJ/ln8x/SfiA8NeJrLD3JTwMhteMXvPIlcxKsv3Blc1oMWU+C6+M+
PmrTaaJ9CaRzJD6WE8lCCVYU5R4f84q+HyVB1vTbSrdM6Z4iQYbdh5jYl2SZ
BMoaS/r78ptpX4KB9p7x+9vJnBSKrWU1M8UttC9Fg6qbbtevZEiRY/hmrtZJ
slCKGF4Gf5MfOUqKlX/lX7X+Sk759t7Y3S3v9FtpX4osz8ttXxaSn0oxdcLi
rw/OkbkgyN/0jJBO+YP2g5BXIu+ookVGEOL1bCKyxpGFQfhtcfOAuwc5KghD
H79ET99NTgnCqOe3F2+LI8uCIEx4LJig2Eb7QejdlTc+6TPduWAktGLy4CDb
D8Zcua6Qv1+z/WDEP4xQr9egXhiMYk2RkvI6clQwjHnxB5/EkFOCMdhc9Xlq
FlkWjI9xjZDby/aDobIz18nCk8yFwKtON1E9r83qfxnm62w=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zGtI02EUx/FplikYSqaWLnWGqZVmteYl3U+3ednsYmDqXkhKvlhZCuUF
E5qhlKUSZPXCyNAwBuXc3CxR55qmoSiMgn+EE4fYykTNEWUEVuw8DxwePnw5
J7yk/GypO4/HS/w3/3/2fLmuihTviRGX1sQtRVOeHr7MPITXrzYc2M28HVfG
DdUefGZfdBYtTX0NZvZHqM/QsDKKOQgLfs2PcwXMIaiU9Q3H/Rwnh6E2Z0Jk
+8wsgPX7ojB+gHkf5myB84pm5kiE5FmNb4qZo5D3yLhzPZY5Blmapl698y35
IDYFnj63HcyxkLQ1mpVTzIeRm1KyJWCWOR79XP7LbBPzEcx0x8V8+sV8FC1l
uhZtKfMxdIVd/LGyn1mIiYUCzYBhjHwcynvFsj2XmUXIuFrZccmfOQHbpjsM
DW6j5ERIJnXvz6kt5CRcqOHqBQXMyfBrs819WTaTT+C9/rfzxVYTOQWrqlvd
lpPD5FQEqqprZq0DZDEsFdKnwQ+MZKB1xaGWe+ldVgNn+Otz6WMG6mnYmI4O
LYkgq9MQORig3SXvo56O7tCy0UGNjno6Bs3Whpt/eqhLEJF2d547RVZL4KOM
sfIDtNSlUPTbH25INdSlSPUSzR4KZvsylNf1LnPC59Rl0HH+e19zXdQzIEx0
71xqb6eeAec7feHp1vvUM/Gh0LjZU6uingmpje+dlNAodvUs7HimqqviN7ms
zsJHnsgzzHKe9rOxkrs2s2i6TvvZKHazm7iEeupyjJjtdxadydTlcNROjj/R
l9N9BeydZVXXgth9BYZ009GF+VrqOXDcsHx71dsj/gtG1SIK
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVz21IE0Acx/FpYBZks7RWGugy3cRkbbnMh/bb5nQaqWgoWu3FRF0WrJWR
siYrkRGTcCLbGw2dhihIOgWfnQ9LGUSFlWmgCeHai16YlIZveqD7Ex0cx4fv
HXcXrdUXlAdyOBzp7/lnpcF933krff+C+682ZfcdomeOEDIHb6O5pkguORiL
9bqiq6FkLnbDDIOzweQwSKq9AdwAMg8beS7rjy/zzJE4tcc33P6SHIXLG9+S
PreQ+XDq5v03beQY5BskLm8xORYV6mlLfiJZgCcTs6aczefM8ajTaIPmHOQE
jI5MLqQ1khNhP8TP7hCTRdAY86yVgeQzaFqT9203eJjF+HgnYrCNR5bAsvy1
fPXdHPNZmKqKNSP7yEkoXK3oPWieZZbCFJHsq3w1w3wO2l5fxPoSORmvw/u3
SkKmmc+jlLs3KKHMzZyC2JPLMRe7p5hT8SCqtSZUTz0NPeVrn4SHyelwxnVF
hulp/wUIer5X1rZQl2FcuHNM6KEOTNseWo9HsW4GjvIUNX4BvUcO2wvXblEw
s1mOn37p04ErE6wroGru32oQ0HkFciVt1W8K6LwS91pn7ENi9l+zEo8eX+tw
ldL9GagpPGHyxo+wnoEVt1G/Y5lkXYUBg+fD3Sm6XwVfZ393H3+c9UyI8nXX
F3PHWM+Efa4pa11F/81CVapdlq4cZT0LBxwbdblHhllXI7zsxkqKc4h1NQok
7Y1xzcycbGzXXhooGaOejXrj7dNLcuo5/9v8z78A7FgMwQ==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzW1Ik1EYh/Gn1CWraKaERFG+ICI2l3PNqdP/dJvNYpCDIlgQW1r7UiMn
pU1cSYWUyzKnSS8jWy2oUEGc4lzpZmYfDEscUiSGBAmlrlnLpRWeE8wDh8OP
6745cZpTxSVrGYYR/r3/Xno44616Mfula0Wzed+0DdkdEdQMpsOWetjh1JGo
e+97y4+i5qBWN1w6sI46BpkPuzu3/h4kjsX5NLW9Yop6G1pT40u///dO+NsO
OZafUsdD11Ab5LZQJyJpWZDoNFMnQfX55pCpkjoZo9Yo7YKEOgXBwK8Llk3U
qVD7eZM1Fg8xF37PweM6MTUPFvaEU8ii3g32q0siXoubOB3Z4R+8t4zUfNhZ
wplyOXUG0jz1dsmVAWIBxtIjF72x1HtQf2z73F0TtRBD2tvBYIA6EyxzwkZl
O7UITfNVj+5L+4mzUGGoc55TvyDOhuXnji223ufEOQikRDdqDlOLcUDPPZHw
2kWci7KTR41lbNrzMD6mXLP0qZcY0F/tfFd+rWfFJmB+ShHjbuomXYIJaYZ5
pN9BugT8sywmYpTMM/lobww7Em3tIj0fzpE71YtZZJ4pQLVnRqW0OUkvgO/j
7K4b7j7SpfBdPx05yCf/maRY/yzX7esi84wMnsphdZ+Adhn25zQbVCUdpMvx
9fGPZM69NtLlqJI5RubePCG9ENNfjBqR3kZ6ISbjiw1eoZX0vav6KjMKSEQ1
Gx4020lXYDZkvyjUpiL4Q/b3YeHi5jNxzsuuP8FIHS0=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zXlI02Ecx/HlQVYksyWZV5cuG+tYeTvrs+mc85qphbHAkA7SzJGKHX/0
wy2M/iitKGMRpWVSlpbmTCtdl0fXuqxmh3mgNHMlZFnZhd+nBx4eXry/D985
6dlJG+x4PF7E3/vvZYf/okwbPrmlaVyfVki9lKPXnJh56A6Kr2qewOyEHdER
1tbRu2Q+FhvyHUT/PR3FUsOU3TZmN0yz1uzv62T2xOxZRQusFcyzURBoXGe/
hXkuAjJHfEMUzD6wqj5fXSNgFiK/XJZhHrhD9kOPq4u2/QSzCK6WJAxmMouR
fVru/DiOeRGeHpb4V927TV4CpfHj2tFgZgl0Gs1msY55KQJ6J0unZjAvw5mH
M8JapMz+2C4eMu/T3CIHwM5UtLBayByIlI1dHbcsN8lBeJbwS9yWwRyM9d76
SaV65hC49NWrfXpN5FBIXl+e4PWDOQzy3NqS43nMUnBqRdZMu2ZyOGbo6tR8
P9aXwzX02ur3etZXwNazqdvVxAw8aBwe7hSROeCxweGXnn+Dugx5vm3CL5pG
6jLsLQ7aMze3nrocXJS54orESF2Ot4tSbD5utdQj8NuQZck+UEc9Aknzkh3H
0lmPRGFl5N2BDzXUI1GNR7JC0yXqCjiVitIFq8icAhXct5gFumrqUUgzedjk
3EXqUfhtc0mN6ibzlHBPaNUmt5+jrkTHtjdTVj4/Qz0alYJ7k46ZKqhHw3L/
685d9mXUVXDO+Sjs9KV5ToUn/GFd/xj7HwOze4+q6z7NczHo8NpqbHhVTj0W
htSzD91XHacei0NH0podFKXU4+DPtXs3DZykHoe+HHuFvx+ZFw+HC55VI/PZ
/ni8q7MUmK+fp56A/J8p+8ulJdQTUPjTQz9YdpS6Gr1jB7XhuTrqanyXCUpS
i1hPREPgvn5HtyPjRiJOjE3kbuw4RvOJuC0pHnJ7earpD988VSQ=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQMC1xcX2HId3w/hfbDPuVD+dxUnjM/g8L9NbNqb
H8egfA6H5RPNH7cywOQFHB5mCTpafYXJizgk+1uVX3kB40s4SEx9fz71Lowv
45Cu25RneBHGV3DYcHu/bOdZGF/JwVk/tlNlDYyv4sDgeCjAIh3GV3N4N29u
CZMGjK/hMOPRbAM/exhfy0E/2nnzUSEYX8dB0PJ//62zR6F8PYfu49Ubbt+G
8Q0cDDMWm394C+MbOnRf26U8bx2Mb+Sgv7x08WxZmHnGDst7kltV2mDyJg61
Kh/Lt36C8U0dZpU4WDSthvHNHE4U3Ut9WgLjmzt4PRU+NS8VxrdwcHMRuH1D
GMa3dDhvumjG5NQjUL6Vww7+ndrL8mB8a4e575a8Fj10GMq3cdBKmrbWZNch
KN/W4WaBe9tfJZi8nUPqi3aV9F4Y397hLB/fg4tsMPMcHCKU7Rcs+gblNzg4
GPHFXnA4C1Pv6HCjnOdl7EYov8HRgcvi9p3sEpi8k0ODTX3KBwmYfieHOw/5
f78MgrnH2UHs4PSWG9Ng8s4O26JUp7D8hvnXxWHug7St3X0w810c2C2y1r+4
BUtfrg4XL2890253cn+HzL3pc5hcHT5d8k0SiDi5HwARMeUP
           "]], 
          
          LineBox[{{43.76793529054796, -0.198}, {44., -0.1866947420882445}, {
           45., -0.1866947420882445}, {46., -0.1866947420882445}, {
           47., -0.1866947420882445}}]}, FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1lQk0VHscx+eol6WylN5DKpJCi0yEFr6UXTEzlmFkJq3KEulotA0j2Uqh
pxQlD2UibS9rDdly6rWfXukUbe/R8ryUeqW8947ff86ZM+dzPvdz//f+7//+
xzgsmr9GhcPhpP73/f+XfbQfFG9arNF2ZZj6HC3sur/7aTHmoKK7daKFDmM1
1FraiG6pM9bGgt4nC7VGMdbFt4h2u8rRjPVQal5aGD/YSmyI3oS2xz+8ZWwE
u4tT4lJfMZ6KuPN5uypbGE9DyutvRtG7GE+Hj0oh3ziVsRmEZTcKDkoZW+Cs
LX+KOIzxLDSKSn5VFTCeg9FJX6c/UGc8FwMFXyfhTguxFVzb00zLGhhz4dI5
OGQrZjwPrXUjJ/8Yydga3GVvdgS4MbZBX1GRIlW/mXg+RJuP3izMu0psi5lW
WgsjExjbIeKydYXnGsb2KGgI96nobyJeAOcj7zojdjBeCIcLa2PDyxkvQrJb
rapWA+PFUBh8LDBey87nAFG+UOf4FcaOsDlTMUX/OmPg7WcPd2E/Xa8MMH1p
Kb62j92PE2Q/W8Zs72TeCQ5jY/ya2xrJO6PBKylrwz4leWdk3f9dv/9pDfkl
2GFyc8ONeXXkl8B7VHxUbCbzS3H55eitwpEXyS/FBc8Je62dzpF3wfhoLZ5v
41nyLsiNa+kOT2HeFVt1dWOkLlXkXZGj+XF5+fsK8m4YWZu9PfztSfJuaO35
rNnMO0XeHX+EWVeJQ8vJuyPBVG/EvdN0PMcDxZWJhxTtxeQ90OG7npvvRszx
RHqMnfSSYyl5T8zxjtF5aF1E3gve5Xr11evzyXvBycfLYWdPHnlvqH3vumtx
jVjmDQ95hvfV2uPkl6FNUfPk9LwT5Jch2Da9JGvRMfLLEbF81daSYGLZciyc
JpgZt/kIeR9EFCnzDjSy8/vg+kO7rR6TmffFF4G539C6Q8MMX3xyH6g/1ptL
x/vCP2t1kf9H6pW+uFqRkdgrX+M43POQnv237bsu2TCDhwsGz6QbN24ZZhkP
Y0T9PWLzOOp52N2hPjFnfzL1fIybfb4+Qz2Hej5mRxXM56oepJ6Pm3FNyTXP
8oZZyQevWm5snl5IvQAO0Xu+avrkUi/A6hO9wee7iWUCmEA+8LI5i3oBDCqT
Ng9FsPH9wJ17u2tVvZx6P+ziHx6K9qHrkfnh1rTu5841dD6lHwwr0oT2K4k5
/ng68Eihco+N7w+DL9uK/7RKot4fhucyZ2sXJ1Dvj9f6Hyb46wdRH4DIwXDv
+G0ymv8AVI+waz+zJYrmPwABZu6qFzMsaf4CoLc9zIrXs5ueXyDu3lHpPJ6c
Rn0gvlvKsyL1UqkPRFgp/+LtkGTqA2F6xeyVouoA9UKMke5/PyOYPX8hDE/z
9r/uZOtFiLBBbqx6J60XpRCL72QFZgrZ+glCipeiz0hK6xVBUON6nHzhTetf
FoRBkzN6AhF5ZRAEdSa1arrs/QiGrTi8u2YtvR8Ixvhx1SXcaroeWTDkQYnS
sTF0vDIYe+p+W21/IIV6ES5La/Kyq9n6EyFew6nwqAY9X5kIQ+fCRwe27aT5
F6H/yN6OIF2ab04Ieg8H7XyzLpvGD0Hs+JXdM5qJZSG4/dDRzDk/k8YPgULz
Q5cq/xfqV6Cp9qcmzg059SuwKbK+/n76dupXoKO3fptfzmHqVyBjaqeNaz3r
Q3EpbvKT3Wl0fwhFaM2pXPsB9r6HIn2n0awvWsTKUER9auE4W7BejOmPmvfd
16P9B2I0bZxZLG0po16MlFbJi+ZXxEox5Nodk1TA9jcJOjWqVcPcFcNsJEH2
weicmL+IIUFe/ueTY+qIJRJ8kWvIfDPZfi3BY23/f9qTLw3zcQnm3nJJPBVN
+71Sgr7//uA0dYi7JHguLeN2VTVc+Rd0BbRg
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zwk4lfkeB/A32rdJ1C2TQpaRFqOMaMpXtmzZl2M9x3HOQcoyKlJ6UZ00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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0gtIU1EYwPGbkUagbpVoapI6LKX5aJav3D5fm2+npqWZscwJWrYyISPy
Woagi0xNUJtL7WE18b0e5mM+s6goU1PQZIFmK7UsJTCo8DvFduFy+fHnfPdy
zrU+ciIqWY+iKP6f+++TXIzRGon3hoHOVS3wzubPaRqMiSnwDBbNK/719ZBW
zmrtMSBmQOX+k/eqvvajN0Pq82j54kdiM7CX5sptXxJbglKS41p6m3gbHLfz
WzKOJLaBuQavCh6XmAVVs9c4zkt9aDsQ6eeyTK4T74DKtKNqVxGxAwyG9xWb
84h3Qvxp1ju72l60I0Qf83HWcImdYRM3UR32uQftAkVvX2R3FhLvAveFZXnT
HWIO3J9qt9FjE7uCUfGUel9bN3o33NxeZ1ggJt4Dkx+uzM9PqtBuIEyallt7
ELuDmb2UlafoQnvA1N1f+eeGiT3h+0OeWj+kE+0FCVEFGVmidvResJi+uLyS
QuwNHW/KNRkyYi7caHZ6zWY+QfOgsWYo9oJ5GxpA0Z3EnPF+vGoa4NL7fmWe
+BF2HxBeZRaysx5g94EMRdXAyGwLdl8YfXXmVFltI3ZfSIhjVE+YoCk/GF6z
ojlf1oTdD8JHWT98B+uw+4NS7CCqWCDr/aG0I7FX9Y3MD4CNW03XWhU0Yw8A
cfrh8jorsp4PObYx7MuH6rHzYZ1hTXLqOL6PEsDsTLXKiY/zaAGMjZXGc5xk
2AOhUjGUKbWVYA+E5WG3g8zmVuxB2qaDwOKpqb3lJyX2YG3TwZCZHTMn+0J6
CKTfapkRpOB+0iHAi3WMY4jJ/oeCXDFen87pwB4KNs+2SAI55LzCQCQrqXcx
wPOndUyF63QdUxFgFOGR9FOF82gdU0Jtg45pIYxI2w5kFeH3dwlBOLBoOpGD
/wsVqW34799O3ma3
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0GtIU3EYx/GT5aU0MiuNrHlJysScU2c5c/tN3aZuOtNSE4vy9qI7WEqX
yahABgktuwhmKsVCqTDdtBm6tDSiF8vyhilSIpkvdJlvMoUK/4/gDhwOH77n
+fPw98s9l1bgwHGc9N/7/0uP++Cj8zHr3lmWZJPw5vbywjzIHAp5eXrdcnfB
9WBjwxEHsjvG9dn6LFsP82ZozgwFuo2Rt6Lph6Kv9wN5Oxpt8s6iOrIvAiQh
N6Kukv1xJ37Rq+wYOQDqvtn0ND/yLmSOhOcFm7qZA3GhoHni3kVyEHZ2WTUn
I8nBKFaunqw2v2UOQYhlT5smmxyK31fcZnQ8sgA/B4olp4xvmMOgCez/o31A
DseLom21ShE5AnmGitKHg13MQkTP5yd6f+lkjoS1IQPtnuR94E901/t0vGbe
j8+F498XnKhHwXsc+eWh1EWI/RRVxT9oYY5G75ZprlRGPoBK24IpfXcHcwxC
qk87C0PbmMW4JVCojk69YpagKkhvOJ1IHYju+cgNlLUuWQuIKzZ69Awxc1K4
XqvUWLJesi5FZn1/e7fQzHosfGZ4Lofc2XnaWOSMbLpdM8n+5+IQMZ1b83ie
zo9Dv2kuaVRE8/EQxOjeHx6m+XjMZtWtLVFSl0EzVunv20LzMhTdlOdkmGk/
OWTW4dzWDbSfHAa+Y/kzPnUFhCdKsneYjawr4DlyXGM1NrOegLCa0bbasy2s
J+DXgqN6KpL2T1xpbSJyvFZdEi/S/SXByVVQIJLS/kl280q7eTtzKruuQnG6
Srwm1cR6Mvodnkzq1rP70CYDhqCvjZepp8BZV22730T7p+Cb4m7nc/VT1tUr
rbUzl7rsvyxoSMc=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlHtMU2cYhw8wnRvDIQFFsBVlEcYQZVNgYuEH5SoF2kJLW0Qd0YWYoXYx
DFlgZYwJKwKKQlHnhavMIajxMhVpWXUOhziRMQF3q0QuQx1BMUx0LH0//2iT
pnnynOe8b5vvdFHqVukma47j1NPv/z/Zy76nepvg9R9azfQouPqEocz0kjkk
DggyF7/GeBbe8DbUfcExtof84OE2h9GrxI7I+PWBoayHsTMyZDGF642MF+CV
T6Sju1+yG3Ku+wkrbjFejLHAZws6TjB+CxPbry6famS8BNkLR/leWYw9kR3x
Il8jZOwF2zOeKtXEFWJv6AJ0YT46xj4IFfGW6lIYL4fqluTFow2MfXGj/y9t
530j8buYsNI2Xxcy/x4qr62vOz3E/Arkf9pwfvHg98QrEXWv71lGJ2M/aA2D
aTnz2PX+cKjK/ca7gfkADFxKWeNRyvh9DPlW1f4U0ka8CoKRprYP5xqIA9G3
MNrq7dJW4tVoMNns4XOXiQXTv++2VteaFuIg3LVKMipxgTgYcoNfZePm88QA
v+36lkUpx82sAfJO2RRt4DWQD0HelNM128MnyYegvLx2w9oyYi4UWf9wHo7u
zeRDkZ4uDsy8U09eiLHJXrHt4yryQtwo7kv7sfBr8mFYZuxxal93hHwY+uqX
uD8+x3w4Hqr8N5b1NpIPx3jHgfHx47QvF4Gt59pyUwRsvwgkG/nrZjiWkI+E
XdCajWN+JcFmH4mIonsfLf+23sxcFJpO2updC6rIWzAXbeEtmFtj4S2Yi4FQ
MT8tMr+afAyuqMPOiSrryItwoF+2e3iEeRHkff96/J13lHwsruUePCBtItbE
IrXDYYb/sUPk4zASnl2QFrqffBx6eaqbzmd2ko9HS5+DcsqnkHw8shPcHri4
My9GeXH3nO7+PWaGGEdasmae3lxB14uRlvlOTr1AZ2a9GIpl+an3Y8qpl+Bz
n1fHfP+opF6CC8F2Wc+t91Evgd2l1cZ6G7q/ftofu+g0z62UeilKAzrdnfls
vhQfd+fzfH/WUi+F+HZ5V0kp7a+XIph/yrRltJj6BDz1v1M6PMj6BHxgWro0
e2AX9QkwDCknlXeLqE9AtN6l6+YWOg9cIkQTrlNdS2gfJCL6uc2b4bW7qU/E
fnFNr2sJm5+ISu43+9lxGupl+CVSPbZDEWM+b5DB+6vOvLMekXQeZbhjUl4U
iivMrJehfa3Yc3vFXjqfclhP2fdvP1xNvRz2q2ZKDQ9rqZfjbDunjhrWUm/B
XBJULgnpce07aP8kpDpqbg/K9tL+SRhWmxqKv8yhPgnf5UYNzh/cR70ChUEt
U8LLh2i+Ap/5rGoOe3qQ5isQcrRnXN5Lz6degdkls56odEepVyL9hXLOnzZs
fyXijS1WO38nr1HicljANs8V9Pzrp6+faxWrlhBzKsh5FwqSdfR9oYJDoOR5
kxP9/2hU8IoXTS6aV0e9Cn4DT7RKlxrqk7HDrSnzaiabnwzfla2Nu3jEGguv
T0b/5BG3TW1s/tqX/B+bAjER
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XtIk1EYx/EhoSsNFGV2U1yO0C6WaW6Zl5/OLZe5LBOxSM1bVpq2EEsz
p5jQSiMirQizclpkTqylpUvnKikvJF6KSrBEJFbpFC+grAue54964fDy4fu+
h8Nz+AkZ+5ItOByO+M/6+6bH9v29TP9lHa2LmgjkiXUPypaTOZDZWORlLiVz
kVjk55tqQ7aFvfWJ3r1WZAco3ltW9c28Zl6Bpr1eed1G8hrMKubupHeSXWB2
XiK/0kJei8vx5qKqLrIABRpHdZ2GvA7c6aCFn/lkNyi+ccWT8eT1cGqstctO
IW+E/d2yOldPsgd8Iku5du9eMW+BKk6qWl1I9kTbl6irObHkrUg7GT9QM/eS
2QvHfqzkFbeQvaGKUYzf55O3QZTlXi15bGD2QVHfbPHwSDuzEJHetSn2Suoi
3KiNVfwyk7djs6Z/rHMD2ReOCyPGDB55B9zvFhmdb9F+fkgz3j9yiUf2R2GA
viLxITkAL4dtI8z5euZAeCTzkgz6NmYgvnvDYPnXF4tWAg0X1QPXc1tZD8LK
ueZ2oULHehCm6w9OVc8+Yz0YOqdhb+FhZmUwsgUecoHNc9bF+Pyq16Jj9Cnr
YsxY8acS+PR/CGJuhuYkPG1kPQRC/am2E+ebWJdAUBrV/mnTE9YlKLE6ZOq/
wMyRIuJoklkUWM+6FMEXw2sktZWs78RErn3dyLly1nciVdvYoJ0sYz0U2maL
uMqz7HtlKCy9Ko4f76lgXYbnhqqmcTV1GbLmVVmhJtp/F96cGT1gnVLF+i70
lH8UXjtQzXoYZMaYgkEXOl8Y3Falf3gS1sD6bgyZpmSXH9F8duPhbW+TeD8z
JxzNp/UOszIt6+HQGSu63i5h5sgx+N3g6s+l+cvRqDFURgtofnuglk+LZibp
/vagbWjMNXof9Yh/jf+sjECJ1Dllvu9Z628IfV6K
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9038s1HEcx/EvSt9My7g/jMuP1gyjiC4O3eu4w7mS3ZCi1bhGiGjzR1pU
YqXRRvkx/XULpeOf8iNyHV1OrQzD1MYqzo+wpLEV+jGfd9/ts+8ee34++3y2
zz6uydmqc+YcxwX+Hf/+9NmMaS6GWPXptvRNUp3iVjbBkzn0F3+O3bODzKPd
2ugu+D/fBidXNeofv18zC8C7jKzWmMj2cF4TNY/MkIXIqo69lfOB7ILu9eV3
rvPkvbC+I1g8MEXeh/L24pTEVrIb+IiQ3E8XyO4QOohnzUvInvBwOOGZlEb2
wqXRbdrzTuT9aFN7zeqnDcw+2My4fEXVQfaFc4PeTBRIPojHSZZW+cuvmP2g
C75+T2NO3R9nZTVLMRXUD6HRbvRnTCpZhI2ph+7GM73Mh7FZ76j2bSEHwGNa
7zNuIgciTyE+yj8li7GkTQwv4clB2LjrP1g6TA5GpmYstfxXD3MI0vmJhGd1
5COoT7jmauajZ5ZgcSVqt4PxJTPgXRUwaVp5seVCYM1WqbSTM3NS7LRoEXTm
dLEuxfEFf2nOIDMXivUirwe9tZ2sh2Iyc1DU5Ufrw5BRsDYguvmc9TCU3nYx
GT2ZORks8uPTq6/SehnSmpPj1e+ZOTnmFHXLuWLaX464aNO496421sOhu1H7
pCerlfVwCCtVp4YfUY/A6ILjTIGEuTACltqg6DIN7R+Jik1DQa6kg/VIYK6x
M6+dzq+AYd5D9iWS3WehAk3dVdLYULr/KAxk6PveNuhYj4KTfdH9GDm9DyVO
x9l9nYaRdSWybSs/moQG3fbVpjdBQ0p8HzqWbJPQr/sD6EImKg==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQMC1xcX2HId3w/hfbAvDBJ/vo0FxmdwiD8XPvct
A4zP4fCDL/PazpfHoHwBB4fdtw98vQ/jizjcznscWXoKxpdwmGF8UbtwNYwv
43CkeUZ9zgwYX8EhuvxuEEsTjK/k0PL3wpcKbxhfxeHaWmHJj+4wvppD0KKX
B10FYHwNh/rODxOcfhyF8rUcpNpPliidh/F1HNQf/68MnQTj6zms05vimOcD
4xs4JOTsfFzNBeMbOphuyGebApc3cph5of/qXksY39ihpHq6ToMujG/iwLt/
1atkXxjf1MH83N3/j4tgfDOHZzHCtRb2ML65w7wYbx1BZhjfwmFzPt+CZXOP
QPmWDn93zP8yUwUmb+Xgs/NzTOBhmLy1g77u+ZxZP2B8G4egBw1K3PIw9bYO
SR8VF/3zh8nbOZga/E257wPj2zsssXYxkSmE8R0cJB9WpLt+PgzhNzg4bBFT
b1n0+hBU3tHh54qGuuOrYfKODrpma40WnYHyGZwcJAtLnk50hsk7OaR2JLL8
54Dpd3ZIb2ZyZWSB8hucHRp+REdyWcDkXRyKr+XONOA5CJV3cdhmdypn93Yo
n8HV4eTFVSFSsPBrcHXIy93e+RQe324OnhrPtrdawOTdHO543Qt5LwFLH+4O
Tb+Fm07aHd9/S6dL1F3b3eHTJd8kgYiT+wHm4PYE
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQ1I00EYx/F/E0GGMCtNJRETSxEpV27zJdtPN+cmSmQv0NSGSyG2JM2I
apWikmJWUGihWcjAmlF7cS6l8CXLWeasLDOExMqIQcNCKJtphfd0cBwfvnfP
bdAeyS3mcRwn/rv/nbQC3hpLU/nOvhXNSaeLlu/l/zeHccG48aMv2Q+Sq/Wa
6lXkAIwKCvOFniHmQAyUHNDf+kQOwfEYr1Y0Qw5DSfispnOIHIEz7vgysZUc
CffCiPB0CzkK9sbbbWubyZsQM9ioqNWRY9Dtfq6PUJJjYU6RRUozyXHQXenY
E7j0hHkzVk/fX2x4Ro5H3kbfGxVmshBlr+0vFuLIW1FXUz4ynELeBtfhoh/S
UHICik8GjfLLHzOL4A3zLyh4MMgsxvfJxN212dQl4LW+jAoppZ4I7dGF4Jv9
j5iTcH7W71T7QXIyLq0511tkIqfAP2Rxrt6P5m2HOLeZr2uneamo5tVAc5e8
A/FjPvYuI1kKSUV7neo9zQNk1wKSnR0DK64EvNmeXYeWmLk0NL1q+ea9Qz0N
Pq5Uy8MRep8OB9f/4aeLejrORhZ+/aKmLoNreAsvJ5y6DOM7o39dTqP5cjjX
VRmWx3pZl6O1Kzdvn4mZy4A1z6mfvNDDegbkUz3znKCbdQVmbBdLgpK6WFfg
+onQ9QYNu89lYuJ38NRyNLtfmQmVf+/8MVkn60p4HJ+9Hl8b60oInqrfSAbN
rKugnjDackwW1lXgmgYCDSor61mIFVn2Vynp/yw07E0Ifidy9P0BVPgUew==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1z38s1HEcx/HjFJ1ZlJXWJWLHpFOdU9Lx8uvu/LwkIy0LNT/WhdZhqz9u
iZr1Q7Mop4yLKXfpDzo6cuXHNWyGFs1mquGPpNsso5Fqfd7f7fbdY8/3e9/3
uWfknbxgzeFw8Pf3702P44Q2X8Iz9/yXJcSqbnqTypbMQcOMzYaXNdkOS+26
vLGVAWZHJD8sHW+bIzvDWGk5K5wku8A077hXM0Lmo6uGO26uJ7uh+fSgTWA5
eR9U+Q0/FrLJnmgUQdcpJwtg9O4ck1v6mb0hNbkXcOfJPjCnf3565S7ZF5r9
hlu5J8hCmKL09udV5IOwT7BTCS+SDyFzx+jlL5N9zIfRkmpZ5POpi1Azp0je
aUf2h9Q6eshUTvNiJK77ilcjyAFQuCZt9rrWy3wEPrN9Z7Rm8lG8v/F9tDKH
HIjkSzn8Oj75GMp/mj1SW98xB2FAPZzW6Ek+DvVWXl31zFtmCSpr77U0C6kH
w2lP2+1vneQQYDDA6VwMzQMfql2UaSpmNTB9IDQkS0TzoXBPuC4akjCrQ/Fx
SvkkLZDuC0OVTCBpqqEeBuerxQZDGfVwuGpzmz2UJtbDod8erFzSvWE9ArW8
joiqktesR2CE11RYP0U9Eg5jG5q1CmZ1JLiStoWim92sS5FrJfMTpvewLkWK
7qWHSEz7Mmxe4XRUJNG+DH5uYRr/ZSPrcrTe7/9lvWxgXQ7l10InWVUn61GQ
p4RJs3rpvihItZ4vGjLY9zjRiA5yF2if0X40UvWl4RO/u1iPgUuXQ5lcSP8/
BiVbisSJz+n+WAR5x5wqXqP7Y7G4+qpaNMbmOXEQbOyKm+LRfhy4ttxM6R26
Px7KBzzDrL6D9XjsXhR0fzJSV2BbdkqB9FE76wqsP07LVgwbe/4AMBM+uQ==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBWIQDQMC1xcX2HId3w/hfbC/KzJr+TNuGJ/BwVdTLfUY
I4zP4dAiu+Wc659jUL6Ag6xN3EbJTzC+iMOZ+3EPEl/B+BIOm+XXTthyAcaX
cZiw8WHzvDUwvoKD0DansEfzYHwlh0afoMlmi2B8FYc5RyKX7Z4L46s5GAmH
zs5rh/E1HG41P3PgCIPxtRwYm4/KTPKH8XUcDsb/+Jfx+yiUr+dQenSjnc5j
GN/AwcHheEYgP0y9oUPDZNnYp3D1Rg4HOf/O5i6E8Y0dhF8svrvLHMY3cdhm
9U51KT+Mb+qQsT72dvjdI1C+mUNcCOfG8PswvrlDR//pSa+ZYOotHL7xzXs6
+ROMb+kw9VmxtP52GN/KQUH9+MeItzD91g62/tkJb9JhfBuHHIsd89fmwvi2
DlvZoiI+XTkE5ds5HFrw20phAoxv71AV7BbsVnoQyndwqHSamutfvh/Cb3Bw
mMgsIXHl1R6ovKODc+XDe9tWHoDKOzpUneepy5eA6XdyWN1idXQVI0zeyWHn
GpmLNUdg9jk7+M6Qvjnt6A6ovLPDcbemsg3RO6HyLg6VgQemZq7cDJV3cXCr
XTvp269NUHlXh+7nXQG+ldug8q4Ot246X9R4CzWPwc0hRSWt1LoEal4DkG9m
XbhMeDdU3t1hksSTs7a+MPe5Ozx7vmtHoCLM/R6o/AY0PoMnmrynw2Qj7SLe
fpj5XnB5APTSEhM=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90gs41PkeBvBZXeh2HulyUqdWKl2OUHSlvAZR7uMy7sZczJQsui/FdFNC
R5JsUUNlk1U9zNJFjDKFFB2lrSTpRFQ2ZBWxZ8/j+zvzPJ55Ps877//9/f6P
2cJwnkSDw+FU/fX3v2/20X56LmLN2Htlw/pkeej15d37RjNzIJAsqokdwawF
z0jZE9W3u2RtnPXNjLZ4zzwZda7R71KbmKdhW/um6WdeMP8DDjyvn3n1zHrw
sYmI+5LGrI8Jt5MHCuOY52Lbj/YGiu3MBsCPTxY672FegCXmm1N6BtXkRehy
/uWk5QtmQ7x+dqE9tYPZCEkylRY3lNkEu7JtBXGWzEsw5of4V08/V5CXoid6
TVZWC7MpehNrtu9oYDbDFF1x+KejzMvQx1kZ8YjDvBypKyPWdq67Q16Bw3OK
3HJGMK9EeGTdT4vHM6+CZl4LDpy4TV4Nud/jiO+/lZPNESI5WfxJl+UWsOfM
TO+OVJHXYMSqGddnjL9FXovYAvUJXdObZEskGT5ceP3jdTIg8j2WtznhxrDl
gL9p75VmrWuUW8GxT1RwpLyYciv0cBc9cZ5QRDkX/RbHXWLsCijnIka2cqqz
g5Jya/j4mhU3fma5NWZZ8GNSe8gcG0hmmWb0XrlKuQ0CB/a9sYzNp9wWK/KS
virzfqHcFl62mq8HjPIoX4eBuxHjdO1zKV8HfePSIduIi5TbQVH2tvUlj/Xt
kLrNKqPuqIJyexzMPdk11T+Lcnt0neVFt5gfpnw9/BzK77/t20r5etTs+c2n
MEpiOZxvgPXifK0jEzwo34BnbfEf4pdupdwBitnJWo0dO4ctd8ChuwnP4lcc
ptwRUn6S/M+1uyl3hMm0HeHy3CjKnXBUdOCHxDcOlDth1APnM4UdfnQ+Z4yP
iZM6Ge6mfWfEWaSl20YnU+6COH+37oRmd+q7ID3nb3Xa57Lp+a7ILSky2n0u
f9hwRXr+kKFBUC793hVltvt3KfjKYatccWSBRtGVL4XUd0NX/IU8r5nF1HeD
QWjIvewwstwNo7urPj/h3qK+G2Zlf3t1w6yU+jwU+7qO+s5JRX0elPJ0YeGC
MurzkHG9KilsL1nFA/8japdUkTnu8LEzLwj1JsMdRT11q2ZW0vPl7tBQXzWN
0aDnq9xxuiFq/c0UMscD9tHv7nDHsX0PNF8KqzjVy/oeiG1KObQjne17YOFI
j/6T+1nfE13HO6xadrK+JyJDv5aaHyfLPRE16bdelza274nnvbzlGTbl1PeC
66D/8bBVZHiBD51TVoGs74VjZ3bF/ucQ63uh9vtxlpUr2D4fqle61ioe2+fj
tPGjnAv2rM/H9FLD0OW17Px8DDWYJo7NZO/PG8171YPgsvfnjaX6lYHmm1jf
G7lhcxfq3GD73nj0woxnyGHn90HRGNvk2ins/D4Y8/zZUJMfWe4D/9SCFp9/
kVU+aDqw+dKnDtb3xeSX6931u1jfF6kBafPWKFnfFyPT8qYabWH7vqjomnFp
41rW90NndbF6fjLr+8Hyekmazuzb1PdDclBJ63jNO9T3w2WLj22nw8kcf2hO
u9BSsrSC+v4oPLf4kAlPTX1/zN0yetS722SVP6y1Ty+Y2UfmBKDn1fTbkffI
CEB9nzKxRsT6AUiNXH0gYyrrB0BpoBX2bS/rB+JE6x8v32exfiDs+OdVUi/W
D0Tu2aFuvQWsH4jTE16WTpGxfhAmzOjcxi1l5w/CmAD7X/VcWD8I0xdOWmys
xfpB0M387n78EP2eI4CxUjuyiEu5ngBWj2be515j5xGg0TTF7G4ZWSAAf7A1
YNr/348AasXEJiGfrBBgXsqSNXE72J4AGXO/3BpZTW4WwPnNg6Gcfnb+YMx2
sdosW32X9oOh0yAo3mtBRjCCnb69rZCz/WBc3rmvOPkGnV8eDPPLHzLba8mK
YOS2rduU3kZWBcMtM9CRM5/tB0NyYffBic3s/kJkbOLqFyWR9YQQj760YR2P
vU8hzqhNvHW+Z/tCbBJv1SjYwO4vRH1nTYnGdDqvQojGOU9GPjhIVgnhOavj
BW8MuVmILJPy9pv/ZvcX4UrZ0EppC3v/IgT16o8Q67P7i7BjmdGpfT+xfRFE
W8Ifxo5k+yK8y77SPbCZ3V+EpouB9T+3sv93EXL02jekjmP3F0HpZnpyfx+7
vxj5Cb9npFWyfTH+qUyb7FDC9sUoqbDO550gC8Ro3JioV95FlouR83jVuIbL
7P5iLOvMSIjrZ/cXY55m5+AUg3u0L4biT962vwvJHAkcjy3/2jC/kvYl6Pqw
1CQ0kQwJevxSE0JjqmhfgnBfTaeyidW0L4FD1diURleyQoLiyoZlEeFklQTL
FGVjj7C8WQK3tvPnjS/S8zgheLPWt+dmPOV6IXg4O3jJ9qdkhMA6wOSqQR3b
D4HdNeSl/MH2Q5A5Wbe6Nf8+7YdA/0TfxtA9ZFUI+h8/T8/LITeH4LXLFM96
rxral4J3+Hd1wAOynhS7lFvOX6snQ4reL9XPx0c9oH0pLO7bqN48J8ulGAiX
NlW4kRVSZIuyBcWmZJUUo36N4mXMITdLkWbjZhjkRebIkK6jnvH5I1lPhhqf
rf0FTx/SvgyDO2MzzWpraV8Gk4qW3HYPslwG40lZru0mZIUMjmFq5y+7qK+S
oXpUrnZsN9uXodjI2ThrBOWcjdjim7La432N5X8BbvT7XA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQtYzPkeBvCx7Iqs7brnyEpRIYpuFOJtKreS7qPrTDPNlFrXZYuWnXCO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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0G1IU1EYwPHLpmjpYKBWkloNUxHN+ZK2TPdsTqdzaq6wZmmoE6wwxUIb
WF601L4Ytt6sMFA0e1nb0nA1c1tp08I0LDWwkAmhDFQSpmlohc8p9MDl8ON/
4Jzn7sotkuUzKIoS/vn+7mSxR5uLYzZbjGua4/ecqnNc+WcKHAZdszlOxM5Q
IWjra3EgZoNBP3P/8vJbtDsM2WIl738Qb4P6dyzpNyuxF2i+lHGapoh3AqvW
FjlgI+aAT9n2reIPxL7wtXeIKdMQ+4H3Unjdqow4ABbneuy+C73oQLCcZORk
ficOAh+Xz5XDKuI94Ng/rTAUEnMh8bbTzYl04lBgN8yfLw4gDgO1jquosfWg
wyHdqUo4mEEcATVZ9LUrPOK9MBlidQkwv0FHQv6CvyL4CHEUKI6eEfEbX6P3
wVVp00imnpgHd4QDFmUz8X4wL3p0rp4zo6PhkWnSeMKN+ADYxns/C2pN6Bjg
Vx43O/sZ0bGQveLpfaO0G82HjluhvtfzDGgAS9Sy1pn9cs00QIWy8JV69wvs
AmCHBSnlLWhaALrSJ/ei5zuxC6E6osOTV6/HLoTT/kpZbZQGexx8ZC3NSi49
xh4HzKYZ8RRHi10EzDG712yGDrsIDm9yVY3ueI49HoYDI+kRC56n46GItcxV
MfA8lQCmnAn13fGn2BPgU02fRs5AU2KQm8LLkwueYRdDlQffWhTbij0RWg79
StNmPcSeCDLPdmaJHU0lwZZuN79gPc5DJ0G6odWovqDGLgFOv+5ifTaZTwJd
DWHVYne8j0oGbVdJ+YqczJcMY9MPFo41k/dLgSdKtec1kvmkUPCT65FrJf8v
Baom8lLa5vA+OgU4KnvI2cx27KnrTW8wlbahbzB1cL3hv38D9QlOxA==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90AlYzPseBvCxt1ynUJZCSQsd2lCK6m1XlmraN83SNJOLcqJku6MHKUSW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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1AlME1kcBvARJaxoVmiQVGQ9iBzpCqK4Iu3WfrRctVDbQo14JWrVuOIB
EZZjDRM1aKIQIYCAugkQoljcAh4gFqkoeKDWk0MlsUINGo0b2N0YBY+N72/i
TDKZ/PLN9968N5OZvX6HYaMLx3HJX87/r3R49FTvlLtfa/uqvxXF4X5up1zJ
HK6eWOMsHEf+ARaXM70TPnUye6BtjmLWwCjZC25p3o5p/5HFqFp0WSRykn1R
EuBof2glz0LZG5O2tpDsh5Fse41pPXkOfCQz5BYTOQDGO1VJzTJyEOw99/6Q
hJIlePpu8SPPzg7muThwv/S1KpscguSb+wZblpNDYRkUyctfXmWej9a4YJ+R
LPICjK5+2q8+TA7Dg7Ipztxn5IWo6Exz/fiQ/AsGNolbnj8nL4LP2Rv6rQXk
cBy09ku1a8iLYc7Mm7wwnhyBqcPK4Tt1V5iluD3Q1G/e3s4sQ9dfzd5+vZeZ
f0X5I39J+m6yHNLg2Irp8XT/EtQfrnTZPUS5Almp5yt9HWSgNirDoCxh5oGE
hOsz81Q2lkeiKXG8X9EwMx+JCKtyfPRoG8uV8LXW1+bMp74S6Y1DvXYxza9C
c2v3gesfKFdh1dbQruEL1I/Cx3dHROqaSyyPgsbgObZpBs0fjeiUPnuGhuaP
RkGJ2tP1FfVjIC/VHP29ipmPwUiQJGvtOspj8af5WGpJJY0fi54XTlm1lPI4
/LZgcspPjlaWx8EeGJQfNsTMqVHsnVbR1GhluRpiZ8ho790Wli9F4RuPQ2Hb
mPmlqPJSbchoPM9yDTQnuvJVqcy8Bum37mWfll9geTyUnYdGDFuaWR6Pxyt1
srGOcyxPwON/+iYO7qK+wJwWe99mtk6YyO7ntQj1Eq32N1N/GVKSa/bsj6Dn
XwZFToxpUu5FluvwpK795x+L2P5ABy+36siiAnpfOtweV3Nmcz7bf5sO5nTH
rTEprV+PeaZ95eJMNh703+e8Ht7tlW5ZtH6bHrKQY7ayDfT9GZBn+jfQ1sG+
Fxgwtrmv+JqC3pcBwXPdu++invUF5hK/NwTmBbYJzCUJ+gLzSXDv7n9vCa9j
fUHOGaE93nDqxSD1jcixrFzRc5H6RpzM/fKLqW1gfaOgv/ybPwPB1s8r
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzQks1nEcx/H/VFiiZ2VlaNIUEwrhifR8PI/ncTyHh1JZGlqXFFp0bvk/
KEe20EWGZLkzUTxypOQqrXPUultrZp3rkHTv+f5q+W2//fbae9/f13ptXMh6
PY7jZL/vn5cdwWBpvPfknos6vROpJm6Sxhoyc/Ay3m28R4/ZEHF2YYnFb7vJ
AoiOahrmPmU2RetX/+/f/toMsuH7scLnzJbIkZj3a/qYZ+NzW371jxLmOTis
zeoejWe2wcOI16EqL+Z5yHyZYjJhuItsB79VddGed5ntYeL38XhnG7MDQi2j
35SXMTshyrXpVfhB5oVQyO0rH4HZGc7a4NopvVfILtj8OHJJ12JmV5Sub4nV
v9lJXgTrW0XuLkOXyW64YYUQySdmd6xoTuPy1jB74L3RQL+t+hJZiMYa8fDo
7Q7yYmSdiPDetb+d7Ili2YJjDzLbyF7Ye8gyTj2hlbwEXM50PaFhC9kb0SIB
d8GqmbwU1gnKfY5RrItwHX0FU3NZB1IiUmdOa9LqzANz18n1d7STOR/U3tS+
/WJ/nroPOgLdzhQPnqUuBh/iHrO6tI66GJwBN/95YRV1CQ6OJfW8lNZTlyA7
IX7jDgcy54tVPu0t/PYa6r5IvhOZprJroC7FtadSCwNztl+KlT2CxgbpOeoy
pPUvc+g2Zl2GDMew8k1PKqj7IUj50fbo1ErqfjA/4B4wq/w0dX+4pp661soX
UveHxnOo6pmolHoAPCpG4nc5kfkAvFDc00/KrqYeiNB3XH3iDNrHByI11MrU
OYrNyxGnNtrSvLKIuhw/c4XJJhYnqSswsPNZQVlMHnUFqrY94eXpudSVOKT/
YVK4QTJ1JfKXy8XpZdEiXVfBLSoyO2swU2deha2tmt6Sq0eoB2FsJGdsQ34G
9aD//+PU/xvjzKth22uTaFaVrJvvGNe54HHz//wLEcBQVw==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10gtUzHkfBvC/YqnXriiFV0y7lUqbS1IZ6lEUuhhTyegyMzU3lFy2G2G0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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10AlMk3ccxvGiSFFDqUfUESgwj7RAjDIooEMeqJUKiG2pIuGYozVY8WCM
Y5vOlaMWGEgUEQ9IFRqPCEEZqwUFOi4zJkZnLDqSqTGoYVgYmxFckG3p7/8m
b9588n2fvPm/vumHlHvmcDgc1X/3/0928YcassIX3OlyaCLC+u6lQOLGzEFp
eov7rCuzKwYFWcJxLjMfRXax6OFsP3kpqtquWG++YV4BE5/nc9LG7AlP9bRJ
a2H2Qd+HU9naKuaPYdDFHXt8mHkV1MU38wQbmNdAapg1VfsxC7Fx7s9h4zxm
P+wqe7TD43kfOQBu307uXNLAvBY8rxHL8s+Z16Ei2D4tms+8HidiO+Zph3vJ
gdir7jnSlMP8CfxHvUZHwRyE1yGeJTmJzMEYmAl+XXCnhyzGLg+drfoBcwhy
/WWCmirmUFg82/cddGH7MGicLHmX6lnfgGf6GZ55PfNGNKY05Bf2dpM/RZFT
1NPPFrAejj9yzcn9Mit5E87axgzGqk5yBBa2Lda+DWAGpHV31bHdtx3WAbXx
0pT9IWROJFrnl+3o0rMeCeSd6EcH20dh+Hq7kZt6i3oUWgfFf5d6t1GXwJQW
+laYbaYugfaFJEPb/SP1zTiqWDr5TQlZtxkHVkfaRtQW6lK8Ei5aNE/fSl0K
byfnmIFCMmcLBkf+aQlyYfst8ErjTp4rZz0aqWnjuWbfdurR4A//2VJf2UFd
hvRQwbLvfdn5ZDCKgtx/ucG+vxV1M5HXHmy6Sn0rhNO9qomsRuoxuLCyJOZ3
3yvUY/DT8qgA0W8m6rHg1+zn5PSdoh4Ls6by4ZMhPfU42KziRx4/lFCPg+a0
CWsuFFHfhuDw4vbqk1kRjr4NXPuy7zprv3SYE4/Gr2t3rnDfTT0endG5/s0N
ybTfDsETw+UeeQH17ahLmuoLfBpPXY58Z3tyeb7G0SHHO01Y4OIzX9D7cng7
/zUnbt1Rx/tWOURvOpvLUgtpr0BBuSipn1vgMBS4vcq2T9Z0nM6jgPT+0JH7
mRW0V6Di/L2DLxNLaa/E2B7XxKYxI+2VuLF3+oOaV0N7JY4NHp4VHjhNeyXu
SZLMyvCLtE+Am/C4gStk+wSE1Nu5C70v0T4Blc0zPpmjmbRPwG79V1N+v6bQ
/1NhQpxRPGDU0V4FxaEkl/eFZ2ivQsbjqeyVH12mvQrvzxX5ld292PUvQkek
ZA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91ns41IkeBvDRrpSstbHVqk6TLjYhSVTI65Z7hQnDYG4MlopVu0KmwyYV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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQDQMC1xcX2HId3w/hfbDfoxG27CI3jM/g8KQp1W0+
D4zP4XBClu3yQw4YX8DBts9wxr/Px6B8EQfjU8FLFb7C+BIOvP7CF/ifwfgy
DptCNV8kHYTxFRz6kn/90NkI4ys5LG/w0+jphfFVHJhdF/0W6obx1RwE/hY1
7AuF8TUcHAPzdm+wh/G1HM5E3ZJbyAzj6zjMbl8wQWHtUShfz8Eq1Ee/ZROM
b+Ag0X7vAZssTL2hg5z4OftDtTB5I4fIe7t0/82F8Y0dCrcX79Eqh/FNHE4L
yyt2HT4C5Zs6mOose5b8HcY3cwhKnTzxYCmMb+6QIm/t9tUFpt/CIaZUU9Pb
Aca3dFA8+S7edjuMb+UQw9K3aeo/mH5rh31Zfv3ZD2B8G4faTQdmRqTB3G/r
sJJr6kyXpzC+ncOv6LnRD/xgfHsH1URnvn+JMP0ODj+zVhyZywXlNzg4+ASK
LZ5UDbPf0YGTNauqYPUJqLyjQ9jObZYn207s3/xDo/v8C0eHT5d8kwQiTu4H
AEbUuKc=
           "]], 
          
          LineBox[{{37.8727959927484, -0.198}, {38., -0.19585874023618977`}, {
           39., -0.19627649677169015`}, {40., -0.19772978415955292`}, {
           41., -0.19617597421637878`}, {41.30585360922076, -0.198}}], 
          
          LineBox[{{42.63473328538177, -0.198}, {
           43., -0.19561775042432053`}, {44., -0.19169038640600103`}, {
           45., -0.19169038640600103`}, {46., -0.1916903864060009}, {
           47., -0.1858281101584874}, {48., -0.1916903864060009}}]}, 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zwtYjPkeB/AhpXREOkVhy3VbKnTRuFTflNppEl2n29Rcm6FRrFMrR4xY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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XtIU2EYx/FjYVoKDinRVMqIDLGVl3LN22/O+1boGkFQ6WbSEKlNoaR0
nD9CoaaY5oUIE4QQgkZeN8Sc2mYSeCmX1BQRbBUrWEvLguxC71O0A4fDh+/7
vOe8nCj1RUXpJo7jUn7dv590Cea7tKnbJkb+yJ2+dOD2g7EAMofK2A+N5/3I
/ugP+1Zs+mJjFkD3wrFic5G3Y+DGeHebmxyKmcXXvm4POQILfrMBE2vk3WhS
ON+PzZD3INp0Ouizg7wXr+zugy8HyfsQrdSc6ikj78f08EpBZBg5BlsKCyXS
51bmWDgWRRv+z8hC6OQy9c6n5EOoX7gVY54nx8Gyrm2U9JHj4dOjr50MJCfg
TvHW1oZwciKmuht2tHDkw4ioyrzf3vGY+Qiq64UJTjE5Cc2JnUUhJePMItT1
NmmNf30US1fKFXeNZDHMVfrQjbkx5mT42tf78p3kFDjD5KPVGlqfCqvdYF8+
Qz0NcSVrIx6LhTkdvT/Uhsm2UWYgSN3uCS9n5oHilnvvBmqoS5C4qlK9VbN5
XgKLeFFlk9F+GagwmIKr7COsZ+Bs5/rx5WCal+JTSF3tzDDNS5EiK3xTkE3z
mRg6sTLdGkQ9E6qbHyuSVh+xngWBckE362bmszAVVWS+eo69j8vGcGCAoDKY
nZfPxii/2Sj6TufPwcPA/l1PxqnnoMzHct2lp54L11CNwhTJ/g+fC5uyNC+e
1nN56LAma+ZE9H15uHBJ2NJ10sR6/v/mvczJvLqXOTm+apvSLoebWZd79WO4
ltY8KK7uYf2ffwKRAzr4
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1Ecx/Enu5qb2krysuksERORzFvef/Myd3OCzNqLIDWVCrEwBJUu
ggkmZCqkJr3xSlltmoU6XTPd8k0KNu0mUawLkYoOitRZVnT+b3zg8PDhex4O
55zHP+9cVoETx3GJf8e/Nz3urzrOJ+yeMP3XcpLrnlxzL5/MoWwo/aA3R96F
kgDRvN3+jNkds/OBb/d+J+9DgdRD4/hC9kT2u/zcThtZiHGBNtBrmixGePe0
3k9HPgDtzlLu42VyAMqEOeKeanIgLDKbYr2YHATBz7sntsrIwSjnNS/3eZND
sGhbremzWphDwesv0nQNkw/jlKcmNCCbHAZV9/DN/AEz8xH8Xs1VTNWTw3Fa
LfQVh5AjoOtfa671I0diRlXt8u04OQpu99r2O6vJ0Yh1WnpUZB1nPooQ1cq1
hC7qMVhyq+kU6smxkPg7ZW1poPlx2HFy24XIeHI8Hsd3KRzZ5ARc6b0afebr
GHMitCLBxPtCchJ2zMkc6YujzEBdxdjzdgVzJcAXVzXNFRtZl8C3o8SoaTSw
LsEbnc8h8ywzl4wZsWj69eIw68kQpYh4Qffp+xR8eFFjN4iop0D/40Hs7fIB
1lNhNGzwe10GWU9FmzZ47KLPEOtpOBtnU2bqaP00NJpf1imrnrAuhfyGycN6
bIR1KUZbDLUVg8xcOiLi6ni3Wmh/6ZDXh/XIr9N5yJA3BUuTnJ13pQwj+pWN
Di/6H+Qw6jvXFzbY/Eo5csrCkgRR1BVYcy9csF56yroC3jGzIvsKM6eEMqvx
zkQvdSX42ydzzB4m1lVwbRe3WrypbzKXsalnIKT005wjk+5PjcnP/g9bJbQ/
NRqinaWuv4ymP/uENus=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zgtUjAkfx/EnySatQt6SrCmXlJqKCpF+ul/ofr9Mc61QNOv6ShnZnEUS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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10gk41PkfB/D561J2SmoVpYaOv7C1KlsU83aWolzjGseYwajoVtiOQYdj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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwtUDGgfBvBxF1GtcktJHBLdKBTpSbVS0l01XeZaM+VzWb4tEjtyG5FC
G6Uy7t1QCCs0JZVQn1LpQtPKpmwSlv0q6/Od/u+cM2fO7zzv8z7vzBBu9Aod
yuFwHn7//v+XfTQbzm6yHVNeNKj3dk31ajG+Y5k5aNG++OKbOvNoVGXo1tWp
MWvCwX/C+UkDZWRtmKkHCZcOZflk1C5pMMz6yvJpGLgQ9+RzL7MBgk+NyTtW
zmyInFTB05oU5lk4qSn0q/uVeTbcMyv3H/VmNoJ8tLtRzjRmY6zbrH8z7fcH
5PkIN2wN2aXGclNoeJuWXWpluTliI+Y9j8thtsDuuDNGSQ2l5AWoOFTukXWe
eSHWLVfm9kYwW6KoPcpc/Og+2Qo7QzeUtfeVkBehc1IPd+5yli/GzZaQP9V/
YfkSzJYG9VVOZbbG3Qkwrh/CbIMZ89WP195hXoqXC+N1Imey+5bhil6EaWIR
y21htyXGVvaqiLwcnUPvV8fGFpLt8FpVNbdp/B0y8Nly1IHWF7cGLQNM5O9M
S0oLKLeHZrrWAre/r1Juj416UwK+xuVTvgK8zBORcaXZlK/Ah3X2T9pGZFLu
gB8kvlVdObmUOyChntd37j2Z44gtTiZztIZfpNwRRzPfLFtzOotyJ0wMqLFe
WMz6Tlie9mjl8fMXKP8RCn9D/SwN2pP9iPyY+e0xypOUr8Qcqz8X3xl7jPKV
2J12ZiQ/N5FyZ2xQqLLKkpMod0bJQ/fsqbFplK+CLk9f58rPCsq/u/jTON6o
FMpd4F03Pmt7ezLlLvh4kVu46YOcclekNLgE9J6UUO4Kt5rC6My8vZSvxjU9
Oy0bOzovW43If4ZPtzE/QbkbtFXF49t66L0yN9xYZTRhk1UC5WsQHRKVc1q6
nfI14BsO2WNxYwPl7rDyCKnQf73RbjB3R8LsxrvatvQejgdShTtEO/z5g4YH
FM8b0/buW0f3eSChI2Oesbl0sK/0gFZPX/7qSXsGzfGE6OIF3eNRhwcNT/zr
D/0Cy9RjtOcJx287lTNjDlLfE7PNBEvfeydQ3wvFC2c8vBxLObwgSE4wk69P
or4X9jdGxx3uPEl9LxjNSTtlrk33c7zhW53z68JF0dT3xmWjWRryQLbvjcNt
ZSbdW1Ko742ikmff0m8pqO8DU+uwr6LVOdT3gdzyxj99knzq+2Bt/NU62xXX
qO8Dz5jAIzO/5VHfFxYrv7xcfuYq9X3xeKsq1ayvgPq+sE+UpHc43aK+LzQs
/nr6S+9v1F8LzWHNuurL71F/LTrfFeap8ZTUXwv3Mb9Nqxpyn/prkejV717e
UUp9P7gaj97Qv76M+n5QjslA9J0H1PdDvElTryyerPQDN6dtlpUXnef4I8TQ
LutqPeXwh8Ch93lkFOUyfzRPEMSJtMqp7490Xqm50ILMCUCRqWHDpdqH1A9A
cnN2v7P0EfUD4Kw38/S7lCfUD4DOjIq8vJhq6nNxJsLL8pPDf6jPRa5x4Svd
QrKMi4EXW6b8dIWs5CK8vWOKvJvMCcTdAPld63rWD8Rf5Y8dyo1qqB+Ieeqz
XXO3k5WBcE54JjJ7SeYEoSzgQNM2tVrqB+H6gq6+qGKyLAiLeaqR53Y8o34Q
/IOtwhvn1FE/GM65PtN4P5MRjO2HtZ3D95NlwfjQuW+WYglZGQyH6ledgUdY
PwRTNJ23O1SwfggWrOk+P9qsnvohyLMM+7Dfm6wMgfqbISU3VGQOD+fNK/8t
bSWDB93/3jD8FMf6PHQ/VtX4lLA+D3pm/UG6v7M+H3tqE9tctBsGbcBHpLr5
ZK1jZPCRMLCto6KEzOfj+tnsz8XXyTI+bAq8j05OJyv4aJnOvf32KFnJh3C9
8aqZGWQVH94X9Fxlc57TvgC3P45y9lpENhDA1sVzp14T2xdAY5J88bY2ti9A
nqe2lZy9RybAvc3DLe5J2b4Aq+4nOh0YQfcpBVj0OaHxb1+ySoCNmQfl80Rs
XwjFhKq9+jy2L4Sb2NxgYBkZQugczq2w1iXzhdDoPXh6rBtZJsR+2/mO49j/
UQhxM5t72t+G7X+/L8wqKcuS7QsRfVtfXrKV7YuQmGTbH1/D9kWY3GWdrnjG
9kVoPnRzmNNxti/C5krD8UnMMhEKZuV/qclh+yIsuvh1uO1rti/C0aASnWqT
RtoXocj/sqM9j8wRA76fn/glkA3EMM70OlJbQYYYwrKPXalDm2hfjDBxc3Xq
W8plYtS/dNn12pByhRjJvjEdzSfJSjH2qVyDdqeTVWKsap8rs75F5oSiuOt+
5vuRzbQfCo94tcmfjpERiiHjK5+8KSDzQ/HlgfhcdhdZFopYlY+z5AtZEYrp
mXYcpUkL7YeiME9PP8WLrArFLh2XCBGXzAnD0p9WJFRsJRuEweHQ2a1eFmSE
AaXh3Q+WkvlhmB4/cbfOOLIsDLfqjKpylpAVYRiw4Bo+S2P7YbBO1XZLqmX7
YTjSo5+k6GH7EpSnrAi2X/yC9iVYebVMvdWBDAkqQ/448XQvmS+BfsuVmsQM
skwCjZZ5I5JlZIUEIyf65w7rICslKBJ2X/Kzfkn7ElhF2eZvekXmSGET0XP7
y9RW2pciMsMsqnEkGVJwT31ILGin83wpHK+9GPd2M+UyKWJ9l+nOfUBWSKGx
I/tcv4GK9qX4pSi9cd0yskqKBd6SuUH3yJxw/HBlzN2BepXd/wBwx/JV
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVzWtI01EcxvF/GjmVSmg5IWVTtKS8zmum7dF5mVvqdEo6y0s3ZBkrREQj
m/ON+SJCMSgsEoNmZpiWwzYbrXIYRAjiGmlZ2dpmkAX1ooJVeH5CBw6HD18O
T/gRbdlxH47j0v7efy+dIPvg6awAm2VNq5IzPvUNJZvJHAzLW94dXe88mC6X
vf3AIwfhcGxVXfBGMh8nigQ1Qu80cwjSIyqE11zkULTLM7rFS2QRpPNWjX7d
EaifMKqa7ORIeOpfqj81knci3ny7Z1MxORrOHalOURh5N2Yr3cYLyeQYrIgj
+iudz5jjEPnjoHdUR07A1VXZMXsCORHyyeRMwaOnzGIUWy3zpXpyEpZmzBq1
iJyMzDTbmPynlTkFgfHtg8vj5FQoXsfUerrJabg0qyr0TSWnI9CVoZxaIO+F
o0Lay00/Yc6A+7M0avkX7e3Dg84bIw4T9Uxs6DpV1+hPPQsC/3CJbYj6fix0
tHC9XguzBK03/WKrv5KB2pa5K8Y285p1wPUcvsOrop4NlUavQPAU69n4frEz
3aAxsZ6DbR+39rV+YdblwFe7x3P37EPWpeiPsia6fIysS/HbOPKNb5hgPRd9
IfKVjpT7rOfC0RcdNvBijPU8JJ0MOB/VfIf1PAw0aCdNMbdYz4f6QOvqXPUQ
6/nILu1S7mpi5gpg1w8Xtb0fZr0ATr9Xj/nnRlmXQem21fDsbE8nw0y50Fwe
Ms56Id6Ituc299xjvRAVi8+rfEvov/x/6+RYVMcdUoTSvmLdfwDVMw9i
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdkAtQVGUYho+SIYXOYpCpCUKpJIHCIiLssi8IrMCu7IX77qqgAkKWuixy
KV1oRBFQIYEEM7xwMcAKRQUV1ksqmowOICCzKjpeJhEwCW/dh+9vJs7MmTPP
PN8z3/l/25jPFKvGchyX8s/775c9vM4Da4VvXWweoUFRmjIpzfAmYw4xXbtf
uP7H42HwWl+s++MCMQ83D3mbJPUztoSNQKQeMDJ+D4vHBYu4S4zfh3bZ6jG9
dYxnQFejs3epZ2yHwteXY9c0Mv4Q/kkmReN3MJ6Flj0DR18FMrZHEV+29JMP
GM/BrVjJvdl//UT8MW57PpZGFzJ2wnPbEl3bBsbzkK1SDWl2MnbGkI2c11PO
2AXTHC1W7W1izEf+5d7lS8WMXbGuet1WJz7j+Zhb5Nxu3M/YDas6JpR+aThP
vABFSrN8e2vG7jjdvMXtlIzxQpT21xSNmc7YA8vqjTcaXc8SeyKvRL79damB
WIDrL1NM1OVNxEJszurMuqJh3gsnNE1CW2/GIgS6XI6ru91MDFzsEetdZ1Gv
ByRdyo7UBw3kvXHSqetukOkJ8t5w2Xg6u2LwOHkf9OvHpQwGNJL3wfZJcx4I
HIi5RYif/jJ8/6Zj5BfB9VOLppz19eR9UdFwLyc7rY68L15cKJ8hGq4k74dp
O1v7bKZUkfeDY2tqrbPXPvL+yFD3zljTvYu8P/YmeCRWb9pGXgzricHmZ/3y
yIsRc8XUYmhFJvnFSFxwXTyzh+b1iyFY+1DyOmMz+QAExFmca2lKIx+Am/qa
Xe2OyeQD0X1VrprUlkU+EM/8g27NSc4gHwTL3qMlN3I+Jx+E7kqV2eBdPXkJ
Eocu3v5Fy3oJHqYrylpNWC9Fr/Zk80rzLeSl8LOyntmsZv0SPNFN/f7wcDz5
JThSEW67P5WdPxjjprVMjkssIB8Mj8CqqW5BdF+cDGaSDuGzM7tHGDJ8Naxx
sTPm07wMsXarBWVPaN4gwyWrsiGpQzH1clQkLP/GxrWUejk6Jyc8mMfbQ70c
1zpTZAVPvqZejmPattD7jQeoV8B94kDkbEUZ9Qq8G/X2FKGS9QrwF0xuFxQX
Uq9AuTmf6+xl51ciwXhy42NdtmikVyI3vnvt1bSdI6xXgn9tOHeTMn2EDUpI
tcd8YvvWjTAXgvWmsZYWP66g/SHQNrhbWxmyqA9BgVfP+fYLudSH4GlOq496
YR71oRibVGfuoSmk/aFoEJ93mKkpoj4UqcJW06o7JdSHQpyed/PcDprnwpB/
542++o5S6sPAe3W61D6+jPowTGjfvWFz2l7qw2A/5R2nj4rJc+FYwucf8Xr0
LfXh4NnViuxX7qM+HAqjOCW68QD14fDlbc3gTaykPgLR/VdCf9aVUx+BqRIR
nP7cRn0ELE852q7ITKY+AtITZnO36Auoj4TVF2MeyQfofxCJRy0vzO9X7qE+
Esm/JwuMSWx/JI7GZT7T6g9SH4VD1b9J3ZSHqI+CcH6Nw1PbauqjEJz+a7zz
nRrqoxB9zST4bn0t9SpoZBbipLOHqVfBsepg7fjqH6hXwdPT95R733fUj2JO
/X/GKNar4R0TH5Z7hu7HoMaAd5v0vprOw2lG9aNYP4oNGnSded4U0nBc9Dcs
XUwt
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10F1IE2AUxvGhWX5AKOjSEMuVJjrErWnm0j3OqVMvlC4SGpGzkkzbrFxR
SBlGRmVaMfu0UNGYG+XE1LSpZdkSNcKpBAUm3WjEMpOWtL7wnBcOhx//q/OG
F+p3HvAQCASyf/N/8/Ofbi5L9n01sKKvCrvmuku+li1Ad3ZVc6gX2xshbXnf
qz3Z/qgrr5gadQ2TA5FjE6dXLrGDETEiHDLPskNxIrOnZKmfvRE15+Rv5ZfZ
Iihv6nTGYvZmzE64jwzGsSOh3RVY4x5/SY5CS5DoWGkvOxpniidLD9eyxcjp
nPwmi2fHwgr37pgfL8hxaB/sbbigZUvwoWjk1rKMLcXoXXuRM5i9Fc48S9qM
c4gswyfpvGf5KDseezb5nnqzwE7AvXfzpvV/npO3IUofOZswxU5EwbW+gPak
Z+TteC8cdyocg+QkdDd9vKofZstxqK3VL7aQvQOKxrDcwoMD5GSoDcclc039
5BRUfO5Sua02sgLV0+Y1rgg2IBnxKbrf83TFlUD90fov8ron1FMxMzesvZTU
RT0VKadbfMaSO6kr4TJMmPaGPKauxGLubWmHyEo9DVfU+x2xQeTKNIjtOnGY
9SF1FZSS7PPKzkfUVRhr1Oh/v+aejp/GAMvqi2bq6dg3V2XTmEzUM3AjJlwY
7WiinoEttcsFhulW6plYbDBqx+bbqGfCy6MvX3G2g7oav7xXGTdYeqirUXZS
alvnx/+bhXy76Y6phO/PQsoDH8+FRMvAX+z5Cz8=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0HtIU2EYx/FDKx0GJjQxcV28IEunZEvn3Z9T5/22NC2xoFhJkZfS/ENd
J8FKyzAkGmTp0lz6j+Wcks65lbMMSR2IeKkkyjLJaZhKglT0vkUdOBw+fN/z
PPA6H8+TyTcxDBPx8/31pY/deGN+iM3zvt9aDPPKulAWbUvNQGUw6f3sqLnY
eWTJ9bwDtR3cBTZewq3UPGhHxBVia+od6Be3jlWuDhDzgXmNwvKBeg86mz9X
WE1Su2ByeHPZhpbaDS19i2i/S+2O1hxO8GgJtQCz634a91BqD6hfzrapQ6iF
6FkWaJ3XTMTeeNXirXKYpt6HM/zrVTN11D7Yrlwbv5dGvR/KKX5Hwfd+YhGk
OmHp/DL1AQhaJbs1Jmpf7BVP+pqXnhH74eTDDEXiVdrFmGBWtYM51P4QVUr1
c670fAAyOcXv+uufEgeCk+nsL0wwEgfB7W3tXG61gTgYWbyegBoudQhOO/Hl
C8Y+4lCUv3/yJUdCexiqpkNdChS0A8qy22aPDWIWGHZK/uTSQHs4GrJlHAVD
9rPhaCk2ylWjdJ4EK455Xd4XiVkJ2CHZfdOffREYjOySmEV60iPATdXpar7S
+ZEwONVUeEb2kh4JifpYY0x1D+lRiKgpqn0xRcxGIQiunnW25DwjBRyz080B
OtKlqOc0Hfy2Tv+PhtzR8MYU1016NALPLaTblnaRHoOMs80nCkeI2Rjwih7U
jSm1pMfiTpkgrUTeSXosbii8Dlt2dZAeB2fulvTyIXKejYPksqhQ2UTnxyPV
ctO+mEN7PFJ4KlnpRDvpCeiQXtumtNeQnoD8Cavu17mPSU8Ea+hNu3KLmE3E
KYdDazMDj0hPAt9/xb3JQnsS5Caj9dFZMo9Jho/a8DGjhO5PRlt0lf5SLLkP
JuVf4z+zf/0Dc1dUNg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgk0lXkfB/CbUmSSJqXmlRRCNZEUUvna931f4l7cRdLCvCPKuKTSTNup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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11XtUDHgfBvCJTfSG7BuyqEhprS7LlMZGT1GhYmq6X2emq0slWtpNmhNF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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQMC1xcX2HId3w/hfbD3rZ9zJZcXxmdwCJa6GcXA
AeNzOCxKqvDcAecLODw84BZ0ggXGF3FgY/o2k/vjMShfwuGzTOLztpcwvozD
J5WAC1uPw/gKDhP7pZd2roXxlRzOdzqVKUyB8VUcFn//tW5TEYyv5nDm/f2K
Vm8YX8PhjectRlURGF/L4QD3vHD/W0ehfB2HSYach6/WwPh6DvkC809Otobx
DRw2cJ1bnRcI4xs6+KU/T72cAeMbOZjO/q9qLwzjGzt0bIvaJrzjCJRv4jDD
2OSc9AEY39ThdGyMc4ATjG/moHZw1kHpWBjf3IH1RsiKqQ4wvoVD2ifbzVOO
HYbyLR30umZXSf46BOVbOXSWu31eeBDGt3YI6vybYLMNxrdxCFk21cw8Bca3
dWD9Olu86O9BKN/OYd6hJKMd6/ZD+fYO53fU95jYHYDyHRy+7nhxoPj2Pgi/
wcEhYOPeaR5lMPWODjsKIy5ODYDJOzpcK0kJnfNmL1TeyaE422s7/22oeQ1O
DutDnCfqboCZ7+xgZXw0RVoeal6Ds4Ob9a+ban9g7nVx4NnQmZjSDU0/DS4O
RlKLzFx0ju+P3BTrbnnVxeHTJd8kgYiT+wEGr9nT
           "]], 
          
          LineBox[{{43.12969105983656, -0.198}, {
           44., -0.16964347227605298`}, {45., -0.16077282480067825`}, {
           45.66714312241931, -0.198}}]}, FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90Q1MzHEcx/HDjlSmorKkuVT04KRyKT18qnPV1VV3Q2hJ8lBTK/IwVI7Y
rWRmOw2xcFt5WIr0sIu7rgdHbEe3yyKPkTpNHtOMhvX7+m+3/157/7//fX/3
523KlW2ZzOFw4v7+/t3psnmiygu11Gsn9Cl8jXtlb48tmYNq47NvsxzJFvhc
fkzob0W2QUh+Y3biZPJs2CvkouDxu8xz0DVp3+uuPrIzakZMc2LekudD2ZvW
/fw12RWF3fEldVfJbvBzKq/h7yN7QFcdKfT970XgpQkW3BaTvaDZPX+gzJbs
g8cLvrgdGe1k5qOsseLd9iqyL7IEHhmZRvJSGBaaDS0XyH6oHy5KX+tC9ocp
hcu/Z+pgDoC6tLKrfyN5GZTcqaE3BWQBTK6HghtM7cyB2AyBHz+ZvByaKvnU
eiU5CJcyrbeZSnXMwfBeZplSqyevgCBftalLRg7B6az0azOFrcyh2OVp9n8p
px6GO4HFo3sPapnD0WHFU421aZiBhM0jAXmG2xOWA1M0Q8XftzFzInAuyuLz
mGMj6xEoWDJoue5DPeuRyElUDXspa1mPxCteRs7oYB3rUWgNrt1w/hZ7Xh4F
cey0fsm8W6wLUd9TrXb9SfNCdGfqSnp33WR9JYqKZrzwzqD5ldgQNNDspmf7
cERQ5bx5EOXbwroIqyTfrR+VUY9Gs0OQusBI+0fDwUexemkavT8G2bqLx7f+
bmA9BmMRHVPaO2+wHoufBi9N+f0rrMeiwt6q76vyMutipFmnaFN/XWddjJ2P
3NfzT9J8HPx1O+557Wf/hzwO31zyz5ztoP3i8WPuU5u91+h88agZsnTSuNK8
BEbnzoZ5BpqXoErhOY2roP0TgIJ87rE89rw8AQeecAM/PaSeCL0u6769M50v
EXz9x/5KXjPrSWgqtmvrOc32QRJEB4bGzxWyLk/CuvC656LF6gm3JsFc4iFJ
dqTvL8VR5+klfSPMkOJU2CRbnpnOI0Wq4mmE3eEmNi9FjieKcu1oXob0PX0L
jfY0L0N5VbbEW0jfSwbNCXFK4Xu19g8GeH80
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtI01EYx/G/YiaZNPGCL4Q0NKTMvJvm5eembtPN2SAoTclMuoqZbVAZ
/RvZFMyW9cKsFanMTM285W2oWRbSAguloYEomZGmEphYmRU9h3AHDocPX56H
43koV5ltzXGc8M/9+7IjeFd1KmrDy95/Wojhz9htt3Vg5lBW0OI4Y89sB1eh
x5yVI7MAmk0Rurl1zM6IaH9gt/z1BdkNDq+ken6E2R2mUWFfayOzB7K8BtNV
hcxb4O3cbF13gtkLQfl8r/Io81Z8lF/aWxzK7APdQaWrsW2AvA0rrbaGI4+Y
fdF0J3thPI/ZD5nTg6LN08/J/jBnS8Nnh5kD0B0vz72vZA7EOXHWL5ta5iC0
TspGg92Yg2GaN/in3HpGDsH+1Ki5kSv95FB0eVYPGMqfksPQ5FqwWnGMeRdW
00t+ps73kcNRPZRZKT7NHIGskZ49E1rm3SjOj4xWpTBHYua6y9hKZg85CrLL
RccHxrvI0dinX/ZJ6+wgx6CwJmfxU0Y7Gbi3Yyj4Wxh1HtAKFD88Ujqpx6LE
xSf6zXQ39Vi0a/xy6h3YvBCL6eL1Zj3rQozrNLVlWiN1ER5LAhQV18i8CF8E
JZ9PHmA9DoZh78mbS/RfPg4Pr9Y5aFxoHxePD6Wmt06vW6jHQ9P9JFFibKCe
APMYoFTfpp6ABuWco8pYTl2M9j5f+cbAu9TFUM2GhIiTb1CX4Pxyvc17KzIv
QX+eKfD7lI66FE5FdVp1Wxl1KZYumKuN7mQuca15C3NJ6Kh2yygPqqSehKkJ
9U5RTS11mUWXQXG4NKnxYjN1+VrzFuaSLbqFOYVFV0BvfzYtUV1FPWWt8d+/
ASqFUBo=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz39MzHEcx/GvrJZbhWR9TYnGLeVXRD+UXndX18/rLkzTsn45kamIOJH8
HG6MND86P7p+KvmxtKsl3UWp0CIs/kB0VprmWsbym/V5z9x3++67x57f9+f9
/c5ISl+utOA4Tv7n/vuka0J3cUaAoFU/KlOg2r5eqLchc0jTZmvb7MjW2HHM
5BD/6x7zBFTnnJosHCI7IG/Z7BNbe8k8UsfkJT+9T3aCc/mUhhIjeTrOmcZq
7nWRXXGzT+ByupA8E0et+GzZcbIQSlVofsJqshukc55UrZWT3dHs/nr407cW
5jk4vTE2xDedPA9lJqHDjHHkBSjl26wanzUze2KAj0t/sJu8EOI0cXCPlLwI
mpFcjfz2XWYv5Lx83L03gPpi6FUQJiVRXwJ54Kvtx/V3mL0xPD7BuzWA7IO6
q4b6PSuamH0xsTheP+48dT/4ecf0VDSRl6JWXTbP12Bg9scND9VHG1vqAbhd
/XV4vSudtwxNd32uOeY3MAeiZR834lSnZwayJpfULZ7aOOpcQGa5febnnbWs
i+CZJ0j3T9axLsLJ8ihZe2wN62KszO70SPG/wboYkVnr3hUdu8a6BGf6dTqf
4CrWJTBMeqF5qK1gPQhdhbcarzeUsh6EzXHzP2e3lrEeDE9B44FDlZWsB4PP
SlYMWl5hXYr8jP3Vt5TUpdjlvMHR7TXNh2DTulWO7YnlrIfA0ipN3SFl5kLx
TWGZuCee9oeif7CvTiVh5sJQv6/nsp2Oehg0up9Kw2Hq4RBZqC/wLiWsh+PF
gPrLr1fMXASMzyUthd00H4Fa+y+z1Kk0H4mMTF5a8p3mI2Hixe/vr7nIugyr
LWwHA2Ooy8BHxGSsHKH/i0KorCNO0kvnR+Fg3JQa60zaL0d4TPjNnqAi1uV4
+6ZBrE3Tsq5AjunNxfW9l0YNBTqnnfzww1jA3lfAJSrHyz0hb9QGBZqrtwhE
c5m5aHgNKY88Mp5l89EoSDkg+qqi742GMeVO5NA2ts9gZm75/4aZc81sMDO3
wmzezLn//BtcEpr0
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n8s1HEcx/EjP46KE61TrcKdYpJwnM6Pl5/H+XF+a8scTW1Wo6L1h7a+
bmyltqywWi62s+TnhlCGSyL6JyMhM9ksv9oYTSalms+7rb7bd9899vx+Pp99
vp+vzdms2HP6PB4Pv+8/T7oEo9pLPqZvdNta9ptwlnwMNCPzsPOuSGPBJ/PR
29KlN7SDLMCsNmTSzoBsBfuxmMKNb33MQtQKR9RVc+SDUCcu7G3tJR9B5UxA
W34t2RYDvc3Xzf9ahGjL1nv7HpLtMaUyX6lLIh9DDYxtpi3IjuhTmoh2a3qZ
ndCZGluR7U92xtbc4zSTmdfMLjicsjS2K4F8Et8LnS7XjPQwu8JI2tI9X0V2
w9BwwzMHMdkd1aUdFhMXXjFLYLRgaN4+0M3sAcPUK+/fxVD3RGGSWMLTJ0vx
QWvt+nU/2QvxKRJ+Tjr5FJpSXT4bmJFl6BJoXCalNL831rOc37oPvmT2QVT1
unX+ceq+iOl3nD8USN0PY/LEzYo6MrCcpvhk5avbNgc8qrlZviig7g/3mhsF
gwfY+pw/Sp1Vqvkymj8ATcN3ejplzFwAZJnaFb8tGh8Ioc6Rb2dLPRAbM8v8
hgQaH4Qv8clKPTH1IOTKhgdd6uj7BuPqYnOmoTU7Hy4Ya8VFYozQeYeg8ryb
TrXJ/j8uBKfjbs2aLlGXo720Sj9YTuPliL9YKNHo0/qhyDvxc9xmqoP1UNiX
xI2riztZD4NKWWnssIfthwtDev2Pgh5xC+sKpKdjU3iNvc8pYC8Kmc6LbWQ9
HP0FQY3ZZfWsh6PkQZxJV3Ir6xG4nxE5JL3dxnoE1nJTRl/UPmc9EvJVz6Or
GU9Z/8+8KMQtSKM9ip6wHgVvlaJJHVnJuvJfc0qUu1ueyfGq0P0CQVo+Aw==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zwlYjfkeB/BzSZRxtYx0UE6deKIQLYNK31BJWk4nbaflLJ3OubZkaJmm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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVzH0sFHAcx/GjhTKSrDy0TpLslDzcCXXdhxz34Dmp0FrX8rj05KFj5rZQ
LqWUWXNCYhIyJPJQt9Djli6nmT+Yiy0PxaWpyVTz+635bb/99tr79/1ulZwJ
PaXLYDC8/95/Lz0mnyrOcte+fLasGZ72ZIX9LzNqBlrTHCyGjagNUMocMPXQ
ozbByLqIe12LvcRmcBHGWeeMU5vjMjcmJKuPejPaS0tSJ1uprbEpIX8ipYba
Bjmn536/z6S2hW9l8iFRKLUddK0WFatPUNtj5i0UhhxqFsx1EiPlbOqdeKLc
qG5nUTtCw+y6ZPSuh9gJgiRBlEErtTM6Xl3d/ZlN7QLuXZYy/EM3sSsWhoKZ
ghBqNmLD9LsnFC+IORBcVMSwmNRu0MhyCqbHlMR7MJWn4WdWPyd2h3Sw55zK
h3YPtPiyy/0FtHtCrvnYyNCn3guVNfN2gV8X8T7I436Mjld3EHOR0ZLqHeHY
SbwfScFN3UN6tPOgLi/ymimkHSgprHokqSFdBiQfvi5tO95GuhfUkfwHWwoe
k+6FqgaJG3dXE+nekGdbenxPIJZ5Q1NsM8U7Sv4zDiB/SWKX7knnD0Aujjb+
ltZMug9KcjnRqc2NpPvgdd7Pcp6wgXQ+Ngid5ysH6H4+RNsMdywN0+4L1YJW
xWmqJ90XYWJt0nanWtL9MDlu2t859pB0P4iK3ONzpXRegKnFN5HFicQyARJv
dk6khJeRLkT+QXXdeX0Z6ULcEcV/yXeVki6CebGijxWQTboIVjpR0YKMG6SL
EXNfrb2lKuMtdzGujK5yyZirXTbDf6Vl/riWp5wflNaRHgBn/oh+zhFiWQBm
n1qEp3fQHoje2UDbY9b1pAdi/YWeNWZLtAfhq41lmkMW7UGINZ4O6x8mZgSv
7PjvP4htSNM=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90Qs41HseBvBJkUqxck3syKVSSOlQJ7xSEpL7/TJjjKHaLkinx6E5ndy3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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2Ecx/EzfbEwxFWKZjNSU0wtzNTldPqb92XzNjNNGzlIUimXYgpG
HSuGWWirhGIJmYYvKt/YKqe5aV7KIk1EK8t6IdSgG5Zk2bCi5y+0Aw+HD9/z
f86B53hryrL2O3AcJ/uz/t7pEk21amVOw+Z/+hKrXLxsjXUhc3D3Q6bIkbwC
VqTOHRWQRbhSNlp/4uMQsysefljjVfOK7AF1dX7KaCdZDJf20+Koq+QNqFl9
cXKzluyDCY/WXtdlb0SfW/GmmUNkfzQJFaW8hBwAY91X+fynQeZAqAxi36lq
cjBqNaIDL+PJW1AevnRtXEAOwbGm+Y6JXQPMWzEznh/wo/sBcyiCPucdyRkg
b4MnXxQ510AOg8PYdLpqJTkc4guT8ry6fuYInPtpaFHc6mOWwMfU2SzwI2/H
pfW6ZGsoORJdJQUlYWkWZimi9avM3kJyFHLHVLpGp17maOg9X7zpretmliHI
EKzJqjAxx0DqfFPSqaEeiyzfovTyyvvMgG5tUJplmnUeuF4oKWrkuliXw03d
lj75nu3Hy1F5MNB0vp96HOTPO/aOqGg+DksC2+jiqR7W47HPZfB7QQYzHw+b
u8GyZ4TmE1BWf3K2VE09AVXZ7yLkZ+6yngj/2npbxVsj64lo9kp0NrreYT0J
pt3fMrLV91hPwtlZr2KrI+2fjEJRu76lm+aT8cSxwf1wD3ueS4HU4qQ7vo69
j0/B04WQHFvFbdYVeKZsb1pY/n4FloYLwwakdL47/jdvZy7VrtuZ22nX7cwp
UZUbHBHYxv5PXolfwse6mMwhs1F747WiX4m5caVGlPvI/Bvl1zVg
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XtIU2EYx/HTyrxmC0JMpDI3kbDyMs2ma79N3eZ0RXPO/qp5SwWpIZgR
hfMakhaRCRqYUSREIeI9L8tLalTQKYdiF8PyDyOnKZKEl4reR8oDh8OH7/vy
PrzHJ+WcPl3AcZzs9/vnS49w9J5Z5jJk/as5uaKwZiLflcwhLPhbdJ8b2Qmz
E8ufXR3JQvAz20a91waZd+K7oKHJa5HsCbFhd1GmnewNT/fA5wU8eS8ky2UZ
Ee/J+5DNhzTaJ8giJBfeXtE1kf0QYkitzly3P77uSa9fzCPvh8lY8yrUQA6A
eETJlxwiH4RIKaztWXcgIn/e/3Ti4jPmILiaVNPB+eRg3DRrE4czyCFoa7Wf
qtKTJRi5MPlm1YccCt/cYZFpaIA5DH6SoO4XpeTDqJBbAzpN5HCkbtXOqQ3k
IzDuqmrMWepnlkIjT/bgZX3METhgeCt1qOxljoRtObvb+RZ1GQQJgndVevJR
2Pihcn0xWQ6NU6gy8yntBwx11WktXqxbAPdHAc0tFdQV4OPLrnWtMVsUMJ9d
SfKQ0HxKTKqEorpyNr9FifPbawVxS3ReFBw3TeWs/mDrLVEo1k7Nh8/Q/mg8
XLA1uGdRj4aHdfOOwWm6jxiMSa+n9HyhHoM0sdjNlkD/TwV1gTFPP0vzq/Dy
ztUra+M0vxpemmJ7Yj/Nr4bvpdN3jfYu1jUo6TizpV7VzboGH4/nDHzIph4L
Fwehy8moTtZj4ZA7O9w7/oR1LS4XPdZJEztY16L0X3Nx8H8weMOU1M56HCrn
nRcas5pZj//flg3mdBv6BnPH8Hqs3dLW2Wr9BTsUOEg=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10gs0lOseBvBJN13tHe2k9k7KrakdcovkIWyhwSCXYcwMY6abJKWtYlyO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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgk41fkex/E/qUQLjTQjNUdpz1IoS/GRUAjZOdTZnKPdbbuGak6peyOp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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0GtI01EYx/G/M3GYyKRcg5o1NZnrZm5eVpv+dt96MxSjF4vZylmzcIEi
vbIJiUho9qKBLSWLIY5QEMRVXtKtelNpFkRg1KCCVc5kDAaLbngeiQ4cDh++
8Bx4JKfddU4ex3HyP/fvS0fw5u5FddbTuQ19rylYS32wZZM5tNd7e+U5ZD7u
RDo/tfHJAvTL226G88jb8bqp2R/cQRaB153oWdr0LvCUYVVu4gnzHlxqLO48
9I5cAJ/dd8s4QS6C2tIaumEjF4M/ovxcVkuWwst7Jd+rIMvgHhIeEK8/Zt4P
p9622zVFPojnM9HM6x3kUnADyZ3zteTD8AYvnMwRkMtQFHBEY5VkOUbPZatu
94WZFTD6rQnhjxBzOTJi5U2B4+QKDEY6pOJqciXmTsgmhSULzFVoKDTZKnrm
mZVYfmaIWMfIRyASvxx3Rx8xH8XWXH9m1/AsswqzK715GslDZjUUq9PWuP0B
czW6r0ZiUgu5Bl896/mS4SAzcD5Y9bNZd3/DHsDe9d61mE7zNJjkrV5b28bs
0eCMymGwXpliXQuzdnEwYGL2aPFiNHKvPcTmcTokt/iyLq/QfB00jctxc4r+
16NE1P/ti4S6HhmywrR8wwzrBvQdK61bGplm3YBkS4NgXxrtw4j4v/YYcXZ8
qNU1Qd2ElrfcwEI69f/MmeH86P/F1VM3Yyx1ypHw0v4tm/4NrW747g==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQs01Hkfx/F/sm0luzZp1W6azSZr1YZFKvURhULG/W5mmKFlUdSmlHmo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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzl1I01EcxvG5LbACldBaUyqzZZhoL86mznymbi6ji4kzMYOKSazRWmOs
EEYzBMVKL6xFNyVopuDKDceKwm2WL9RME01qXqjBfCHBIJiDdBWdH4F/OPz5
8D08nORL18pquBwOJ/vP+funL2663ZC/bdjzT6sF/tzoBVEsmQOLwuv1bSFH
w7xmD9dHkePwevtn7TCfHI+6JpVKFB5iFsCdN7ZTv0hOQudgrGlrgLwPEZ5O
/XSMvB/nA/ZeuYN8ADM93bDfIB8Ed+702ZCGfAjisuGllUpyGl52Sn+kicjp
qFnWntHtIGdA3q/21SaQj+BFvV/VIiQfxVB5X9fgyiDzMcgiu9sa35OPY9Zs
rL7FJ2chpz1YZuORxRixuFtDwXfM2bDMhS27vpFPIP9KQ1uVmCyB03/4gU1C
zoErsyHsqiDnorErfjHm11vmPDx8nJlgHCdLMW9en66Ypfv5KM+a0k2m0ntO
YlJrWtX8pF6Anjotb0VIBj5KBRO1JrZnBZyC25/mQ7Qvw5owJtXrpS7DlH6j
iXeP9guR3jrB13iYrYW4+8wj6U+k/SJ0Vj3vaL44wHoRLnMz7qeUMnOK4bqZ
Mqq/6mO9GB2OmKRHQi/rchgjypEnXz2syyEaKAnUhF+xrsDEOXf1+iizVYHk
xA+V6oU+1kuginJtuN64WS+B6cIdp9hIXQlbi+GL6rqTdSWWl74b9ow7WD+F
vc6ZYLC5l/VN5pRu6v/9G5xEHdU=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxN0XlIk3Ecx/FHI2dZIjhLcl1zHqTF1FmZ10fnfcwlKiYpakrkwXQoKoUu
TdS0SYr1h4lC80gNRWcuPCZ5Feg0RFxaWpGh3R4Yw4QKf7/ogR8PL97P73n4
/p6TiZLwZH2GYYR/1t87vUzmHma47x9X7+qHJz/z2AL3IDWD/jCVPNyU2hDL
bbV6lmbUJghx0yT3/9vPBrv/2yyjT22OxfGqjkKGmoPQyJbavF9jxCfga74t
DZ+i5sKelZq4U0HNQ+PnPRY7N6mtUa8/Kd4UUdvi8GZp15YF9SmopN+LxpSj
xPa4Y1Rh8y6L+gxSVIpsjm6EmI8B4WmPgAfUDnDmbH0KLaF2hLZwOz61mNoJ
c9lOVgmbw8QCRKhGpzOl1M5IaxDNSKOpz6JAO9vcxaU+B3VfyvpIPPV5xN61
zI9qekbsgg/Fai9pAPUFZPt+LHw0Se2KA6+HnpsKqN3AM3+btfN+iNgda187
izUlg8QeMNswLmBpnxJ7wu76hFsMr48YqBlhWduu9e5aBsijden8VWLGC1+0
SwrJm27SvbB3eb68PO4J6d7ojG6plAl6SPdG2EaDZh+b7heiRTdTWnmIdiE6
ctLrVYbkfYwPrhlkKNozafeBLMa26cqNTtJ90RAzLxFcbiPdF1pjSdLKxXbS
/bDuqixifjaT7gf5Yu/LvCTa/REVYbmcr3lMuj/0kupE/GEF6QHgWK9OLwwQ
ywKQFrkYbJfYSHogUibkGbW2xLJAGMXKNeJx8j0mCK+q446subSSHgT3VpeN
47l0vmCUuSlu3V5Xkh6MRfbm/UvdtIcgbonxdvSh84Wg4H8zodAZ5yTwhWQe
WShqWqL9qmrpfCLkcgzuvUih84kgr7bmGtrQ8wtDbBVPkN1DLAvDFNthynOw
i3Qx+utYV1lc8r8gRuHRfJ2VUkWeF8N/Zb1ZWdaj/g0uN1OZ
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zwtUDPgeB/BJa4k2hdvN0u5EoaibUhTpmzx6P0bT+zHNNI+6CUujommU
JUJsSrFsYbMiGzeJiYbaSmiVhKva8sqjUBclte7e0+9/55zOnM/5/r+/72Qk
XMMTj+JwONf/+vvfN/vo3ju21mFcbeWI3jpuCo01iB3PzMFUpC/kazOPRcpe
g9SC/7/XhaHSrnwnh3kydHIuHzbtriEbQPofrRUbOpmnoWP6Xo3oR8xcmG6y
zD73gHk6Vjx977TxLLMxHtqIXmbvZ54Jkbz6T34k82xoyvMernv1G9kMvu0F
Kc+ymOcia5Vr7Es/ZgvMeDe1bk5TNdkSIpX5eZdrVeR52FbRsP71cWYrJBY6
GDQtYbbGD48OmWQWXyPPx5Dho7qY0cw2SOh81TjZ6CrZFuq3BS+3pKvJCzDh
jjwjNuEKeSFuBi3uGbJluR0+/a3slpflZbI9WvKNLkycqyIvwpgwPq/zYDl5
MUbxo7oX3DxHdkB1tUphcew0eQnqc3WCHRTFZEc4+HMWhzayHKizb31hrSga
sRIwrM2b3R1xhnInmPT964NyiKx0goH+h5Zfw/IoXwr0NVdnmiRTvhTR1kkY
0N3gOJI745m+VammFm/ESmfE9dw+vfLr9dRfhonR6HayjKZ8GXYUd81LXZFA
/eUo9fEc35O5le4vh/3tk+aJlay/Aq+22puVjU+lfAVKbhheKrDcRflKWOg6
rbs8nEX3V2J6ivUlidfPdN8FwV/0xDa7FVPugnf1VnN2mp6h3BXTbI/EiX8+
S7kr+DpWcWkbyyl3w4nW+KB7V1SUu6GD4/PRYXQF5e5I5X7u+hFkpTverJb1
pBuy3AN/FJXVHH/Ecg+Y2lXMHxjLck8MJ/QNvXe+TLknljmoYhelsdwLGxaX
W/54iPW9kKJvJrEOZrk3nhj9VDtdn+XeOJUUVKnyYLkPVOfG2aea0334wHyX
tw//BNvzwQbTfc/nVF4ZsdoHZru/m+qmR+b4omGCe0pvERm+eNgfc1jtWUl9
XxRlpikO5bC+L1y5gbm4T/c5PDxrHBg2cGT7PIjCxvWccGX7PNTtOp2jMZr1
eSjSgfS5Hd3nrIJRMh8O9WSsgpt4yuE0azX1V6HGYs3soglk9SrM1nv17/wb
rO+HWU7r0391oxx+sBl+OupSIuv7oXdQ6+ldjavU94MqvSmgro1yDh8ZDZ8u
8tJYnw9dr+m7+aPovZKPB5cFCyO7WJ8Pt0qd5D67a9T3R8LMnEGvQTL8cepW
TXB5CVnpj4gixfZ8LbLaH+junfTqBusHoMsn5V0fe48AXLXR5V1wrqJ+ALI0
9PgVZ8jqAOTvyb5turWa+oGo0UqPyjz6G/UD8cl/zMDb4BrqB6Ls/lz/1gW1
1A9E1yXjLgvbOuoHYf+MN4sVHmQEoTNdkbS5kKwMgsfm/ifOF8jqIKgzlobG
+rJ+MJRyQ+5zL9YPRvJ6bedW6XXqByPkhp2t/xayOhi5WzLOnueROSEwNir9
9GkuGSGwu2iR2m3G+iEoluQJH8Swfggyus2HLdeyfijmtXU3Xh/L+qGIqT3w
Om9fPfVDEaJZ8sz3M1kdioOLJp7QnUbmhGF8oUks/yIZYXjZ8mBGcjbrhwEz
Uy75ZLF+GFL6qoLaK1k/HLlWEbpPm25QPxyS5VVWqkGyMhzfIGTDrPk3qR+O
koC8Up16MicCqly7xhrzW9SPgOUYrc6sXsqVEWgM+spx9SPK1RHYpfmN36Rg
MkeAHmn2nZXLGkbMFcCy/YzD/E1kCGD/+H6cqIIsEODc8ZLPzYVkpQANcW+S
dzj8PuJ8AYwfurfvOE5WC3DoaVmSdzi5Q4C2l3LfftPbtB+JNY9n8cySyNxI
GPcbxdlYkxGJxxujvn/tSxZEwt3iYnvDNrIyEvF3f9mpISbnR6L5TcQRsT1Z
HQm/kg/fZbmQO/7Kb14wKJ7A9oX4ZVpShm8V/T6uEJMf1223Nmb7QmRvCskN
jGD7QiiKUqf4ZrF9Id7Yxc4eX8j2hfiHZOuf4c6NtC/ElHYbbc1ScocQ8Xpl
aRWWTbQvwrZzOQU9NmSuCEunfm/8vpXeQwTvfcvld0ZRLhBhnSyN5yIgK0WQ
b76rvW8zOV+E4w/lQdVKslqEaQlHPOUD5A4RaguPKVx07tB+FIZi3a96eJK5
UZihbStwP0lGFLwTvWLassmCKPQaK77U+7KZ9qPwx96hBtk4cn4UxjnvcDup
T1ZH4eCBPi1TIbkjCnuaj327bQKZI0abQZ6XkJkrRtGW+BdxZmSIIV/i9VNu
NFkgRs6g/iYDHtsX4+OhZzs+HGP7YgwHTMmfdJrti3G4oMK5xOQu7Yuh3ZeQ
aKoicyRYvfK+XeV1MleCCvnu7dfiyZBg3req1hlVbF8Cj87zh8ONKFdK4NJr
/vxIP9uXYP+e1WVVHpSrJbhoWR+S28v+fwnM3bmKL/7O9qW4da9mlmMe25fC
YPLqwveaLbQvRcSXG0W1HykXSGFfkjppLZ9ypRQaJnOa2g6Q86U40W6i13eU
rJZiy+MnpxpjyR1S3J6l+7HlDJkjg7ep60nHm2SuDFn74j1OJ7J9GWpKd6c8
LyQLZCjalsmT9bN9GV6YO8lP/s72ZZh6y6Erhlktwz+/Grx6lPU7ZKhw/dr+
h3K2Hw3+AP96XE2L438BooXpwA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XlIk3Ecx/GpodYc2L3SIpeJhI3KuUrn9vGYtpq6VZpiYZdprlLBDkrr
SadYGWrZYZdLM/ICSxPTbJaWpB1Ch9KKossOyxGlhIoZ+/78owceHl68v9/f
H7/HZVPiqlhrHo+nGn3/fdnj2FWS5DuhzWiRWSHPOLtuw5h5SP3w019gz2yP
8Krn7WYrZkfEBK8vv917nzwF+m750ujvzELEpkccKnzM7IzpTZIZm8c8B7OH
HEYMRmYRIg6oP/PKmF0REXdC9SmH2Q0XdRI7mxhmd3jvmm2jm8o8HyVP5n0w
1d4jeyDyp7GmYAezGIH1qRekQuaFqOcPO/c0tJIXYfFNpwqnAubFENZuix7v
w+yJus4UQUd/C1mClH1RKR5bmL0gXNsTt+zLXbIUfUOJe/sXMi8B3/NYsn71
HfJSJBh1pc5FRvIyBCf2zt1tvk32hiwkfiRe2Ez2gdg0s2boAZuXQXtu6zmt
O+u+kG3tjsvRsX05uPUuhtMuzAoY9U4/GtfeIgPqKC9F844miznAZ9yZvqp8
Ms8PeUEdrTHpNM/54VlW2kP1g5vU/SHbLXJQ2dVR90e2ScAvy7tOPQCixuOi
gwU11ANgt6ftt6z8GvVA7NdMGW7/SOYCMZwxvk94mXUlXo9TdYmLq6krUaE2
5Zrvl1MPQgDfIO3sqaQeBOsQvnRaaSn1YHidzM2SRdI8FwxpYqzc5koJ9eVo
5zb+Eb+7TH3UthOLJM7F1FXgn1ZOnqS8Sl0Fa6FC/LInj/oKlBigLPx1kvoK
PD3QJiruKKK+Eodz5lcq3eg8biXcpTp+8qCBuhpe3ttnpKWeoa7GloE3a8z5
SdRD0Bge+U2/YCf1EMi+GgN3SjYrLD0UV48EddsmZVIPhe1111fPHyXTfhgE
TQ1hs7jt1MPgWJYluNQ9KLd0DV7IWgauZadZOjR4lFP7+Lx9Ks1r8LYm99Tk
5KMWN2tQ+OxidcJ7PZ2vRVh6fWeLYz7ta+ETb8r0fEL3y2lhdWvBcMQN+j/N
/5m3asx/AXemaJo=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90nlUzPsfx/FRXbmpxFVEmCK/ECpdSapX+6p90eo7SzN1UVmuXwhjqa7I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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90Qk41YkexvEjt0IbN84YZRxdU0hNtKd4JUwish77cXYqWw/d5044aoyl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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11Xs01HkfB/AfXahobfW0bUWTbBm6uF9qy7txKymXDLnPDDNGLiVDd01K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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQMC1xcX2HId3w/hfbDPNzKrSuCG8RkclMJXpxty
wvgcDvs33fcVYYTxBRzUqlbnzP19DMoXcdh+LPf/hBcwvoRD2vFXxptvw/gy
DscaH0nqboDxFRzUorNOsqTB+EoOh4qtuwSdYXwVB6E/2x8W8sP4ag4lxTNy
A68dhfI1HJzeFJxZORfG13LQKO4KTK2A8XUcNp3RsHjpAuPrOfwy4pq0Xh3G
N3B44S+mGQWXN3TI2RLTk3HuCJRv5KC+8vZxroMwvrFD8T8HldZVML6Jw73V
qxa4LIXxTR2+Lvj2/3U7jG/m0DZpS5Q1H4xv7iDO+mzZq/+HoXwLB3GB2W5/
2WDylg5pp0+HaNnD5K0chJTlr8ikHYLyrR1c5/RF82vD+DYOu5YZ6EjWwvi2
Dhr+NxViCw5C+XYOtk9Wlk+SgcnbO0yLEKl7Ig6zz8HhW0bjeu0+qH0NDg5l
EVeNs4tg+h0dXP4e3TWpdT9U3tHhJNukGz4ue6HyTg4hJve4Zebvg8o7OUT8
WnZ09nWYvLPDnYqW5QJXdkPlnR2MfTufLrfYth8A24HFPw==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zgs41Pkex/F/EnJUQqK2TOiy6kSEED4h11xyvxszhjnbzSpdHJ1Ghi5s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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10WtI01EYx/G1Yok2GBQYbYUb4txq4uZyq6b7zV1yiDQFKxCURvNFCS6S
SgfxByMKsYu+8EoLrAxmsJZEarVR3rIRTYoGgmbhmLXuFMsxrOg8Bw6HD99z
3pxH6myqdvF5PF7B3/3vpCV6M+guyZwO/tdX4+ty4UrLJjIPV6VphY9PzsB8
YvbopyyyCMd1S32mH1PMW+Dqbn9kek/eilcHG53fZsgS9FZkesy3yDk4Im4x
DJ8ny/ByqM2XbifnIixPXAlcJuchFg95k2fI+ej3d+SddJOVSOy8+yVbSt6F
+IYxzTsZuQCii6teQ3qSuRAq65xt1EhdjQ7x6L2Qg6yBR29ZkTeRi2DUbsNQ
IVmL3Ibs0p8C8m6o8xGTFJOLkXqYXH6cIuugEIaj/GGyHtFG2cTgEnkPAnbJ
Zvs18l6Io5M5B9rI+yCp/fihJ0Y2YF3Nr3DiBrkEbs2Cv347uRSe1LFa7W2a
lxHz8esneovIgKBOtyo8xe5zgIxrVoqXJ1g3oUuujc8+ZeZMOFR9uur3Ofq/
Mvh31L+Qhpm5MrgiugvOm/TeDN9iZE0/8oR1M9ZUgs+qSIh1C7xvL7mTjnHW
LVAMBFs7Z0ZYt2Lg+fo7gQpmzoqN6ubWVM191m0Yt+y3hxwPgpVZyobyszZ8
n6t0ig4/C/4BarDsjQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0HlIFGEYx/FRMjwqtMMVFTOpvNe7NDV/q67nrkcmmgd4BVZ4UuHdZpQY
FEnaGpYRymaaJQVG5pWalaab5BVkWkZ5JB7bIhVihe/jHw4Mw4fv87zDzJ6E
tCPHVTmOE/67/z/p0h6pSnfXfNW2pgWP2ijRuFyDzKGu1CN6TI2sjpKQ064X
17s2hPs+WhQpu5l3Iq3wepvKPFkPduer5ZJBsiGank73Z8jIxgjlj9ydLCKb
oCq3bPRqMnkvjhZLdT+4kPdjKCbxzEkPshn8+X1N1RzZAvfeOAxtNiNbgadQ
WDZ2vGTmQ5JvmH45lmyLVGmtVt1EF7MdCt/FjTVlkO3xbO69PCOP7IA/MT3D
P33Ijuj89bsm3p7shM9uERcsRzuZDyC3kBdSoU79ICaitwuOmZGdUeAWFtwh
p3kXyHsnje4LyIfQVzZ+onwL2RUzlsKI4tgOZjdcszJQGJwju8N0Rau8ZOwF
82H0ZCvzuULqHhhcrON9b29nBqSzq/OmlcwSIHI53r1Zn/YFuPFWJdbodSvr
ArSIvpYNODez7onKpa4f5lnPWfeEVVyCiUYKM+eF9rObWo2TqXtBFpk4ahBF
+96IqbI2Ds+i871RvfvKouxWC+tCOOTrRWU2s3mJEGIxf6XBjvZ90FzgGL+k
Tvs+mJrIEmybpX1fZFtK+6admSW+mJtus5nRpH0/1CQuGunF074fstN2RaZ8
oX1/5Fg73TEvZf9D4o8FVd1PvEf0fwKgkzMpas1oYj0AmeG5vTEF7DwuEPWd
FUqZfiPrgeg1DNcy2EHvF4H/pKNmWUzfJ4KJ76wir5/Nc2KY33RzkW19wLoY
fbcn05SnHrIeBPOaRI2upHrWg7AUqKal6H3MejAuKce7UxfrWA9G0rCaYqqa
eggGbLN5OqsNa0YIvtnEiT3Dqtj8BrdvMBe67r84n2In
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz11I02EUx/E/f1lGqdNKWCakmy2zspdl6ua2n1O3HBmUYMM0RSfMeTFX
FJQ3g4azCyu76SJzqTUlV10UYdaYb70IEhnCIgpCFM2WC6aWLHtjzwnaA4fD
h++5eVJrLMfqeI7jsv7M300v3tfdqFz3whvWV/V9QVqHKYbMoTWvc00glrwW
yUKxwhR6zhyPmveJL68HyZtQ+7NzZWyKLEKXoMty+gk5GYZFa+mONnIKzMVN
qskSshjO13q/W0ZOg0Z8scXDk6XYcKKyzD3zjDkd/fWL8i0ecgb49ZWz5U/J
u9Ct1Nuj28mZeGvMGYqbGGXei8tnqtv4dvI+fO7x9GY6yfsxuW3pbKCULMN8
vasySkg+AGXG9phXzhHmLEwP6lelPvJBXJiYkftHydkY75Ft/rBCzoHLe9f8
XUPOxVjo16pNRJZjts9qNzaQFTj3SH/FoSXnoXapJ0F9Y5hZiRZHSlXDHbIK
ranDxoBiiFmN1jm+fMThZQZiJXu+DaiZbcDJmIfndU0e1vNRVREqOVXBbMuH
Wzb30UD3nAZeialsWkRdg53XqlXBww9YL8DxLxsXdAv9rBcg6VLJu0/mQdYL
Me/wCm+mM9sK8eP20SMD0fS/IjT7k7Jd49SLoJ+Ke1Nf18e6FpZgQvry1Vvq
cNfCt7XfLm28Fzan+982HQS5kqjlDifrh8A/tu5uTjSwHmGuOKJHmNP/82+s
Av+s
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zXlIE2AYx/FhS5da2DEdJOVs5pZiyzNTt5/TeU2GFrGWLUVI/zBR05QM
VMgKpl0gafNINCpxHtmyQ93MI1eCWCoLDSqCRImwErSyUeHzvvDy8uH7PLzC
zLzDpxw4HE74v/v/ZcfN1pof5TxmWdeSfFprSh7ZzMzBwmKFw1FHZh4a1KJH
r7jMbrCtmk56Lr4g70CRsHLGb4pZgGWhJixwnNkTcvSWv2xh9oI9psbYcobZ
G5+3mrJSFcwi1L825LjvZN6LIidXS8H8KFmMb9N+hl9LzPuwMBvxA5eZ/dFp
8FCvFDMHwNjwddd4NrMUicPytfLfI+QD2GPRmEs3sR6Imqrq3bw41oMge3hF
l/5mmByMNIm0NsedOQS8teFKfgBzKHK12f1lXOYwqHx9HIc+DZEP4qxro80q
ZQ6Hc34Xr/vSc/IhlHukaby5g+QIzAiuZ3h5W8iRqLJdzEy7YyZHQWg1i8T2
Z2QZtjQVa9p9mOW4EL7ionZlBlShzXO5Lv3rrgCOGEPOuWwboB6N0RLlhKa2
j3o0VNsnRXx9L3UFnL5I9Q1tj6krEFzC7+h0ekI9BrUfs5d/TrEegyDTtflC
7VPqsbCaB48VT7Iei4XvrXlSHdtXwvFtaYopiv6rUKJ0YKlbMUvznDi818l6
JrSsx0Fy2zxXENlDPR7Gm7p3BSkm6vEQ/9m/Mraxi3oCCs/nnjAbuqknIIM/
d/V0Yxv1RGRFWPXHJR3UE3GD117XdstIPQkyu+DDBu4D6kmQhqVL6oLuUVfB
t+muwEHWTF2FHN2qZ2oZmZMMfbW/3b3vvuUvMfoYMg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90HtIU2EYx/Fpmpp3Gs3K5SWNKPF+abq131Gn080VYhcvScwkStKmmFlm
o7CZ/iGFpEZUpClks4hapZXX1KRCM52ZIQUOUrEmYTqmXeg8HTgcPnzP+7zn
vF7KvORsSw6HI/5z/33S5aKvPy5a09f+T9/FZvOCr8aOzEFEtdTUZ+5lbQub
kXp+wA+yC7LnOu5VL5O5uBvGm3H7SnZDiLfD/McRsju6tZwyVSvZE76fPReE
V8ne6LadlFlryD6AB495IyVvQdLrUOl5F/JWcPfkj1o+e8l6G15kP/JgtGQ/
pDQW+lkUkv1RJzuYP5NDDgQvpuxVgZAchGn96Kxmsod1MBrrYlVBDtRDUDKe
adVmoB6K9U1nhvcNksMgN3Hrx5bI4ajQ+gj9SsgRuJVVY7/Ji7wDj02KB2Zt
N2sBjn1LGy2wIEcizfjr0OCnLtZRWElvlkrKqQvB61BftjxLFqHona7G9H/+
TqjgvX94nroYdwZaf75tIQMHgjOe6HJYqwH71IaxVRO0H4PbRxVLWSXUGaxc
7I2LWupkezQS+pWLlWb2fXU0DF9Wm6r4ND8G+ipmXW0o+z3qGPTqpu+/Z6jH
QhN8cja5j3osuOKn/HBn6hIImzvTTzjS/hKcZuYjcxvo/+LgfHNjv/U49TiI
RCOJqlJaHw+nitwjykrq8aheNOalFNJ6KQznBowBfNpfCtfaC3sfWlFPwKm5
wXgrG+oJ2D7knsNM0fxEOEquTRUXUU+ELirw+ZUCWi/D5paJvA1i2l8GvWtG
udMQna8cDG9tW7igg+1yCDL9e24YWHOS4Jl6aXenkT1vdRKUyoWm4io6fwUO
53vaWWfS+SuwUnp9WSig+bvQH6D4wJN3tf8G2fRA1g==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQMC1xcX2HId3w/hfbDf+12dsZYTxmdw2HdNk1GO
DcbncMhr+LzqISuML+AwIdDvXem/Y1C+iMOhhT5qYt9hfAkHpk9bsptuw/gy
DhvO6y56dxHGV3B4FHt0B8M6GF/JgZHbhnnDWhhfxWHZ2v9XQ7bC+GoOB9I9
9F/2wvgaDh5Kt+NO2cP4Wg7v76XfsBCC8XUc5ORjPa5xw/h6Dge1X0y2OnsU
yjdwaAu11mdJhPENHSSLXvle7YLxjRzWr+zdxmgH4xs7LJ8/4/XriTC+iYMO
o2VklxuMb+pwPPN2QuHnI1C+mcP6VR2rBXNhfHOHp5NvS35ihPEtHCZL1my+
sh3Gt3SIWdvaaiwN41s5lFXYzXdPOgzlWzvMWRF9fE3LISjfxuGynM9E5nsH
oHxbB4snSZ3nymDydg5X2tOyCiNgfHuHXq/t1gfSYO51cDiWyua/zRfKb3Bw
ePggaO7HazD7HB0Sdq3p3acKk3d06KrsWh0pAnOfk0Pb/btnb5oehMo7OYju
WrHk0mSYe5wdrjxPO7x0wn6ovLPDM9ULOhMWQvkMLg6HWXXZfMpg8i4O+7am
2vKxwvS7OpR9VP76djeU34DGZ3BDk3dzOJG2wMXa/OB+ALuO7TM=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwlYjfkeB/BXlpAl5ZJldCJRjlKhTXwrlXQq2vfO6dQ5J4Ro3KkbnbJk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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzHlIE2AYx/FpGWZ/pCE2UElnzBPnUpt5bL/pvDavtNBSEBMTSuc6RUuY
kkqQpkNUyplDW+oiwTvP5VERmBWVdhgSeDSmLckgXevA9yXqhZeXD9/nfZxP
5CVmmTMYDNHv++elx3qmWRZi9Wh0SwZBdylTpLekZkDCcyx0NKO2RMYOpmn1
50Nia9SxVYo9RmpbiG7YD+qWqZnIdK2Qua5RO0DJTj69bqJ2wpzTSnHJJjUL
GlnLxns99X5Mz59MEr6hZqOB57/c30vthpR6jrpJRe0Biyn+XHM3tRfi2oPm
bwupvcEYtxV7C6h9MKWpSfazoeZiLVHnNhFKfQBSmcAl6yK1L9o3B/Trx6n9
wFQkNQQWTRL7Y9FvfJlrmCA+CPcEftqlK9Q8lJ1Kn948Qh0A3885fB6T+hA4
dS/yWxTjxIH4GpOt1CTTHoSNEnVqhxPtwVBltz616B0jDsG8lAXhOy0xH6bd
z17prB4QC1Du4s7cK6Yd8KpfKo6KG92yHBj2NF1Yuk67ELmv2UkTGmK5EJk9
fYM/Fsk8IxRpj1n6VfNh0kPhXbqt49zLEdLD4HB236yn+QDpYVB32e3KGxoi
XYT+nIUpKy/aRSjK1SjtpH2kh8NYw/k0WThIejhctH6t1d7EjAjcK1/JkjTS
HoEMx7zA9tH7pEdiT35Bnft2YnkkbO2fJKXO9pMehTbWnWMBC7RHoXF+pirc
jP6PRnzh0eLVjz2kR6O6cy7U+O0u6WKMdNhXCqRNpIuh5BV8GDujIl2CpeEu
40CmknQJNn3cxDvPV5AeA5PH7Azf8hrpMahP51aXPq8kPRYpytyqyza3SI9F
zhdDm275JulxKHH2kaa/pfvjIDeoG2oP15Iej7KK4JzOEbJPHo86i6tOHC39
n/BvRwK4brrvivxyMv9f1/71L91pXgM=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zGtI03EUxvF5o6FRy+wCWlgbK/I2Z7otm3u2/zanbxpliSaRA6M3ZWhY
RNAivJCJVC5Ju6hdVBLTUktdullrieYioaSEiK7iTKmUOXJU7PwOHA4fvnA2
mQp3FwTyeLykf/v/shG8vXVMGeoc9GtOJU75NGsVMPPwk9vnvR3GzMfyS0e5
iEBmAb7lm+2+hefkCJSMyKoD3MzrcXrdL3vjZ+Yo2ET1/IqXzNFYZptxJnQx
b0baq4RWRxmzCP2u68Kxk8xi5M9pl0wHmLciOdWeHWxk3oZFp2cqSM4cixZX
9u+iBQc5HiEvGmyJecwSHPKeGilXMicipn6L6Ir5GVmKtZa7T+4ZmJMgOTI+
rt/IvB0t3Ou4isWn5GScizRGTkwzp6BBZyhvK2aW4YRJOF8wwCyHpEsZnDU5
RFYgmF/6ZriWeQeW1vyQWTjmVFi6Da7KPcw7MdZx/t1hnY2sRPXHsZYezwA5
DZmd7pzKOCtZBVlpVubjjF4yYPI5Fy4UdfttBryjRa2OvofU1fDZ35epO9up
q8HPE6+e9LVR12B2lyL1e3wrdQ3Kv9Y5eoZvUOfwZ0i+4U74Teoc2oUxASXS
RupajIbdn1d0NFHXYiY2tL8vv5m6DjWrhozGqTPUdZgueKCp5Y6r/F0P/mBQ
r/TiZb/Netj1ueHWlVepp6Pqy4cp98RB6ulo1tSEFK6Ipm7AI9X+majxYvpv
QJjHKj2710w9AznmOvm1qtzBv4iIAW8=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJw10Vsow3EUB/A/cs1lhbB5MGFzSZjrmH33IFITU3J5kXuj5pIiZAwlKS8o
xYsnl4gk8vBf2IaisHJnpVyT+4umIf/zq9OvT9/zcE5HWKZRVdozDBP6W38/
Pd7RZL3MzcT+60W+zA6f6xzJDDSW0S1PO7ILxo9Wl2KtRs48uO+Iei++yT6Y
y5V1KG1kfzR7uhYeP5MDIRYVD+hPyEHwKu1cbJwmB8Pkx1T3NZJDkPvQlsAH
OQwxM+0yvS9ZjL1Rp4qJawPnCNydPMqzHslR4Gd77d9fkaORY+5LTbkjx6BO
6qd21pJjUbRW4x1RQo6Dk8dpQ8H0JmcJdGNVH9275Hjkr58JlPvkBBin2hcc
OsiJUH0MBhkE5CTYXiNHzPoNzsmwCERd0rd1zilYutUEiLWUS8Hb1b8f3FCe
ivu92ox+X8rTkPmV9Cl+olyGQxu/KMRKTodQklzcU079ctiWWy9nX2kewMDa
96oXOGuBoRxhSYCE9lcgvEl9OFHJ3V+rwLwu3ZynMrGqFUuL9VuBtwNlGa9w
m/0Bho695w==
           "]], 
          
          LineBox[{{36.01100930364878, -0.198}, {37., -0.1753124869758534}, {
           38., -0.1877880248501178}, {39., -0.18534176263298888`}, {
           40., -0.1262687659607356}}]}, FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zQs0VYkex/FdqWmSG0mPkRxNV4ghj4kSvyGEU97Hm30eDm6pbhkpyemh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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91HtUzHkfB/BfLCnZJSS3TKXaQoVUdHtXikj3+3WampnQVq5b0mNE6nQh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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9znlI02Ecx/Ffy6UItQVWDro2VnThNTM1bR+PzaMi8qCsxFwa2SQ1MErZ
GFL/iBhJGNYQRsbCiswjtzmaZi7TIoqV1bStlpKrbUUnKHTg8/WBh4cX7+cS
qypySnkcx8n+zf8rDeHY1crk0Ie2OX2RC3cdDxkJJnMw7ls+1MQnh0DYPKqy
zFsI34HxJQkLyGHw7Rb1F/2wM4cj+EphmcpDXol3x9pf8Z6Q16K3sqRTYiVL
YHr+3pDbSpYisX7Uo2whr8c1a1fYz1ryBvQNbyyNrCZvgnN69unEGvIW3Imq
GZ8KJ0dgrzGQpxWRoxBdHKpwm4aYo/Hta3fWahk5BrGeP4ZDrx8wy1CW7cy2
OsixiGqwn512k7fikba2+JaczsdhrMA8drOcvA3iwuui2SJyPMoPN016XtL5
BATyFp2XysiJaFTvecG13mfeDtswb1mVbJA5CeoP1ReqLg8wJ6NzMHfpKX0/
8w4YBG+8aX4bsxybzR8f33BZmIHTQfkdJo11zjpApGl2OEuYuRQMJEm0K/Qm
1lOgF9b1WPjUU/H2oN8XsLL7danwx8/sP9l4j/U0PNPVnZua6WM9Debv+TkK
KTOXDlNWhLvlSDfr6SgYidTE7LzLugKuip5f4xfZf3UKxLU5pEYv/V8J12e1
d7HIzLoSglULjeLpLtYz4GpXnWmo6WU9AyfyPl2a6GDvcZkQ/F7nvT1J72fC
HmStP8rvYT1rfv9fF30LrQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmss1XEcx/F/PCBx2MRseuBS5pbRCQfn8HG/HpTWDZFJTlqRlI3WMaut
C87mkiRmrhGT5pBTHAfFkNCSTWGqZVahNGZ0me/vif/223+vvb+/i2ncxcNn
1DiO8/m3/v/ZpzdRmSzSetW1pUWPvE/JdR90mDm0bzS7jeoza0LYNBxRYcCs
h2HDBfmDtZfk3RjaKD1xeYXZCL+Suj0FH5n3oOqo7MfAa2YT/Lym5aJoZjaD
0GQ8UlLNvBcarkqBIpfZAllLIzplicyWuBXXm/bbkdkauiXH5SfX+8i2mJ+I
+arTz2yHrG/GUeNyZnskWk9ri3jMDuicNu+feN9LPoDBfUV1LXnMfEzwiwMj
ZMwHoaqTOOiP9JAdcZNbGNRvYXaC8bL57bEUZmfszOEPKF2ZBRhcuZ5h5M3s
AnPDbCvbFBXZFU4yx6nOfGY3OFku52plMwtxI2NxvsSGWYSWQmWr+G432R0G
WTp29lZKsgcmCy497Q3rIgM5QXZh46ZkKSCqT/viJnxB3ROKdGeH03kK6p6o
r2iz0ZSQOS/86UoaSLDooO4FB176TJPLM+reeKchGbqnIEu9sT6gUjdQa6fu
gzWL5NSrBm3UfWDo1zLyvYrt94V75tL4nN1z6r4YmyqVqPPoPs4PXGSxvlUH
nSf1wyyfFx1wvpW6PxryrR6mN7Pz/aGqXRUJQjqpB+BKr79qJYHmpQF4xLMt
yPxcRz0QiaUXGg7V1FIPRHzJcE95WwP1IJxd0YxKnKV5aRA2V/OXtQWN1IOh
XSYv7Nd9Qj0YxzaPDDVVNFMPgUx32FK4n+alIbBJu/+2r/QxdTHKq6Ew29FE
XYxY+diI4hSZC8W5or65O4411EPBjxXvireppB6GN9FZsoBR9r4wzKSqdcfM
sveFQ+FZZjLJq9oytlm6zcpwCEOlS+bOjV1/ATDIXHs=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zgs41Pkex/FJ4lTsKl3YtpMKqVyKQsn6tG6JXMdlEDPMmIkWXSQRf606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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10XtI01EUB/AVBCORFpiJ6JrSy7LSuemq2b5zm7NaSc1kITldjQUlmpmu
6epHlsnyn+qvHigze4CyLSutYc1Xm1armKaJPfaHFGtEj3+kDHrQPRculw9f
7jkcToqpcrd5Po/Hy/p7/710BJPXqnIXBnz/9VVRWlgzPCUg85CmjK6wx5D5
kAx/y5EuIAvg1g85RBE/cxy0ZosxJkpOQO2uz9Nl78hJaE5SBu48I4vQe+K0
rdpDToX43mVnj5e8HGLPU63+PnklYg9VjLgukFfjnF4VW7SdvAbpLzvaQ/PI
6Wg9IjwQ7HrMvB4piU13EyzkDLg+VTcovMPMmXhRLk+smCCLsWzuy05hJzkL
jYufzEpqyBLUjcj8aSVkKfp6p39dEpOzYdX+NkRGhphzEHIayuIDZBnGr66y
hm+SNyJQWdpyXE7ehOemPba2rYPMm9HPeUPxon5mORz8JWfirviYczFpN87e
7iBvwcHD4+c9PQ+ZFQhzbyfeG/uYgS5va+2bFpZzQPBictF+wwOWKzGzr35p
exLlSkiyu0PbXlH/PGQUl9QJR5m5PDyKaPgxOspVcCSHbTPuAZaroGy7cVbX
SfOpYddYmv2n2HycGqlrnZrrVppXg/GP7oF+GdsXp4HkWCBzrpH2l4+oeYOu
SUb/87HOreY1LKL6WnwY43f8zKdci/pbwZNTP6h+AVxj7qq9R9m+uAIUlkvb
rMV+n5EnGOx+XYDvoR0mgWHU9wfO/AcR
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIU2Ecx/EHJ2mGNSVTwvKSWdksK22Vmj/dZumm09kFCyElRbBwEoUv
VM4LXWj2QrxgVJhkEWIvhErTbGNlBdkFuxlJ5sSZoGOeLmYsrfD5B50Dh8OH
73mePw9PSF6xId+NMab58/790iN/d9UY7/XYvChnwnGhzODvSWbIlWerhmRk
T1Qw55F58RG3HC9qzw0OjpNXYm5qc8mIhRyAj8o2n9gWciAc13pyc4rJwfAW
xcxGHTkUHac19iEfchjWPj07NjDbzx0Oqzhgv9RG3ggP3+b6Zj05AhsC3eta
/cgK/GT2kmDhIfcW6Lvm811h5Cgk+DWXnfEnb0ND0w/169kH3Nvxcmy0IKqO
vAM1kQdMExpyNOrVilftcnIMfM3j65R9Vu6dSBu/ogoIJyuR16+8YNGRd+Gy
R5T1SxZ5Nyan2OHPMxbuPcheM1xztJEci5japhOnQshx8JrW6U+OkONhNBa1
TcWR9+KDyd0r+tA97gTcVE86Cg33uYH03ojVBUt6Fy0ApaNWW0cDN0tEkN1m
qozo4T0RC40GY6tPF+9JGHwSJCpuU0+CfqIzK3mYm6lQ/H6VTQs+X1DBtfXX
0mWfaH81OqbXh77ZdIt3NczOUZPMu5t3Daq1gf7nS+/yrsHBpIG3z0y0fzLK
isa+Vok0PxmztSuqLqr5/2wfXI6+6ko3vp8gMdsv6RKzFBy7bi4vFPl5hRRJ
T5WsT0WkynbDkEXztfjeXZ6iKO/kXYvQ7jwZBH5eppOsl5ilYSHHbcHVQj1N
0tMl6yVmeknXo3Xm+TdH1R3eM/7vyMCcc3m7rILuQ9ItErPMf/4Nwb1yOA==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQMC1xcX2HId3w/hfbBfKDDrCyMfjM/gsLri+Z50
QRifw+H5KuVjTEIwvoDDNMl909ZywPgiDtMqarSfM8P4Eg7tWyV+pf89BuXL
ONT2LUv3uArjKzjsCRf0P30ExldyKOVIqT23CMZXcTibWCu0cCGMr+YwMf7c
JJZCGF/DYcoR9k/BATC+lkNWlLpaiA6Mr+NwZP51syOfjkL5eg5+B6yezVgI
4xs43ApN85n7FcY3dDCXf3IqdDeMb+Qg++SYNedZGN/YYd6Tu52f98D4Jg7t
K19/bRGF8U0drpQ2hDJ9PwzlmzlMzLLk4J8P45s76IU8alqkBONbOKSqrlh3
jQvGt3S4cKg/QmIVjG/l8Hz1eZP0piNQvrUDi+d669o7ML6Ng7Nc+uwtU2D2
2zr8TUtVbEyC+d/OwW1lluvmEBjf3qFvedyC4jqYegeHH+tjV9rKQvkNDg45
FaFvvzyF2e/oEDnDOZaBCWpfg6NDwlW2U7VzDkDlnRwONqzJ28R/CCrv5CDW
p1Z1pxLKZ3B2ODdfqnzSP6j6BmcHkcfhfFMXweRdHHI3lvG8zILpd3F4/GtS
asnkg1B5Vwfu62kcJsth+l0dDDweac64CvO/m8O60J3M86Ng7kPwAXA655o=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwlYzfkeBvAjy+3KUqkkg8RIOA2liUhvm1Jp39ezV7LUlUrG+MsVsqQw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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQMC1xcX2HId3w/hfbC/d8R6Po8gjM/gwMm2pEJO
CMbncAgtyDKexQLjCzgsWr911z1mGF/EYWXq32+Wf45B+RIOGXOaDJ69gfFl
HLIds3QUT8P4Cg7razm9k/bC+EoO6460382tgfFVHPKFPHYeyYLx1RzUcydz
rMyD8TUcWh/JVfi6wvhaDknxjnpugjC+jsN/Uc+i1MVHoXw9h5lqnRpKh2F8
A4eGx/dbd+XB+IYOu+vmrpj66QiUb+TwMdOurGk6jG/s0H/htJkbD4xv4jBv
h+uE+HWHoXxTh/imrdwvvx6C8s0cpOzX3H1xAMY3d3iU1za9uRfGt3BY/V9/
hvaxg1C+pQOb3GbemjIY38ph3Y/LiTLKML61w4Rfhl/dc2B8G4c6Pp3Hsz1g
5tk6eLE79Wmzw9xj57CZZ71w30eYvL1DkqaKflYBzP0ODv3p8ldOXID6v8HB
4ZLTe2PVUJi8o8NTr/rT+lUweUeHOaW3/vG3wcLLyeG0oO0S42sweSeHiCvs
623iYPY7O3hu43H5EQdNHw3ODuJXX/5+Yg3T7+Kgdm+RdpwKVH2DiwPPftlf
ws9h7nV1SJjYu2QN/wmovKvDpVkF34LToXwGN4eTIt8OthTC7EfjM7jD+adn
f7mqbuLu8OmSb5JAxMn9AEXT82Q=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQMC1xcX2HId3w/hfbBfcnrKpc1wPoNDxr09l7xZ
YHwOhx/+tnrX4PICDvwq3Ndj/h6D8kUcLmt+yVV8CeNLOGTl1YidvwLjyzhM
XTvzzInlML6CwySdz7+V82F8JYcv/kZvHmXA+CoOaqpdP+f6wPhqDoXzfXaJ
iMH4Gg6r/fME1N4ehfK1HDbknba1vQXj6zjc7rUwnHMIxtdzuLfMz0LXF8Y3
cNCfp1Wpqw/jGzr8TZYuUb9+BMo3chD9eYpL8iyMb+zwVj5uwrLzML6Jw6fk
ptRCNRjf1CGuPVgjygPGN3PQ3fVd2VMOxjd3CPr+TCnrxGEo38JhRd+6WfPj
YHxLhwcadvX102B8K4fJ8Uf36FTA+NYOv1PDxK9tPgTl2zgIymo43z15EMq3
dVDKS19WchfGt3NYqvkqTTUcpt7eQXz144fZOjDzHBwsf01+qLMbKt/g4NCf
seXtkssHoPKODgLW7hrRgruh8o4OURWsgduPbYbKOzlcOn1ioWnPaqi8k4PH
KrEEj7+roPLODiUTitckPdsClXd2yJ4stzh1ylaovIuDIYOugOJqmPkuDpW8
nz+mbIG539Vh/yyZRW4lUH6Dq4PEzJ/s/Xow97s5+B9ft98OFj4Nbg4nxX0X
d22C6Xd3qHG57ia4HeqfBneHygsqWc2KB/cDAMk47no=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zwlUDfgeB/Cb8uQ1iBYcMVdEo41KlNI3S2nRvu+3u5UsNV7JEJeohnjD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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0F1Ik1Ecx/GHCFmjUNlCl1JZohmWL03TnpY/99Jjti5qdiGFgSYVPDGH
g2AxW+VLDQwhr1ajJBjBcLmIBrvYUzo36sZBhnnjhS9MJk8NZhnqRUXnf7MD
h8OH7+Fw+Jd0Wi917+A4rvbv/nfSypt71aNTxqX/SjeV7lcXjSvIHAKe3lZv
DlmB28vqRctmjDkPt3Kc0RdJshq63SOjfQvkQqz3Du+JfSEXYyqc2amdIR/E
mOi33oyTDyHsjqcfvCOXYsZxYU2WyGX45U81Bm3kI7jqtXjsbeSjcC7mO3qS
08yVqOtM+2cT5OM4PCBufXpDroaM5Euzj1yD1LGh9aX75Fpk7IPXz1nIJ9D2
OfRjKxFl1iL4cEP1vZhch13DIf5APrkeK7Nc/3M3+STM5e3i77f0XgNGG/hn
y33kRhRcqRYLL04xn8KKc351dWOSmYcjolW2S+TTEL7tk8cUdF+HSFVQNX7v
I/MZaMNd17ZDEnMTLIm7pmhuhBkYKfeZOgaZXUCNNTi/cJl6M/iigPzoNfVm
lPADZiFF7+mR8NXfiZV9YF2PCcdP2+ZTZs4A15rmhqmfugEeTq8Rh+h/RlRs
u4XHrWw+LiNUFRPyXp7mZYLS9oR3F1DPMnc2q2eZE7K6AE3G8L7DS/Nqgfg1
0C3ZmV0tyA2dD3iNk9IfZY79Zg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1z38s1HEcx/FvTPKraZ1+yK38KsOM6C4/vrxw7nDHiqVoslk/rkPRH9Yv
vzZKqbAWlfweu81yJN1s7HJRmzZtuqas6Yex0OZHiThU6/P+bt9999jz/fnx
dUw9H3fKhOO4wL/vvy89tsONmbzlK91/zYYot85Ud9iQObT4BEw6mZE3QdKb
3RdjRbZFVl3BTxtTsgBjJZpW74WXzDsQ96tOujRPdoB4PaZUu0reA/HH2I5z
H8hOMPDp8bpusgvEk47Li2Xkvai4UKA3ysluaE06YZz53s/sDsPK4+S0SrIn
WsrtA6KzyV6o4JuHTM+QvcGf1qisfck+uHe8dGGwp495PyZ3qY8NF5N9Ya/0
dV1tJvthujXn5MDMC+YDsLNeCR2eIouQVSh8VD1GFkPkfnTn2hfyQVR+Gy2Z
q6f9/KGzy8t1yCAHQHrtUFGSDc0Hoknf9Wl9Qs8cBPW0/+chLzKPhMLX6Vna
XuZgLIrP/rh6gxyCyrW6u0duP2cGKkYudyp3s54PfG3IKU1Iox4K5yVV7Kyx
m/VQFI271Kaoe1gPg6ZGELZs3sV6GAyb9WZ3Qpi5cAjL3IWcWMt6OILURpHF
YCfrEvAeJhfbr3SwLsG2eWVG12FmLgKuzrJEvSX1CKRM1KveVFOX4npDcrBf
4xPWpQjvl1nse8/MyTDWXy4cSH3Kugzls4XjcxI6PxJuQfddMmyZ8yMxNLXh
Jq9l81wUTFTmmaqN1KMwIvhtMZpLPRqetdIaURP1aHhsWXhwqYX9LyeH1dvB
h1XLz1iXw1Bm15anofUK3CpOVMCe1iuQ8q7YOz6Y7heDxqrtbVOj7bo/aGQw
YA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9z3tIk1EcxvF3aTotm+GC2SpW5D1EnTV1bns2L9PFQq0wwQwNofrHuVSw
Ald0syWUBJKVMayIwpARXbTcXDOT1MxYA62olozWZTbMLhpUdH4dOBw+fM97
zntWV9WUVC/gOE72Z/5daUS6Ow2K8EHbP02roiSXZudDyByCW+WtdWFkPjzP
KqckQeRImIUTNRWBh8xCPJ10vVNPkEXYN9xjCnWSV2CMV3/i9VmyBJpHzf1v
68hrkCzorojbSV6LEWXX8icqciyiz99sP5xIjkfQHldbmHuAORG1jvCYV07y
Osyq44OFN8jJyC0eEUeAnAJN9bRluJGcCu6OJ1O3iJyGhPGDtmItWQpfcaWx
N4TuTwePax3N8lBfj/29hp/HW8gbwC8r9WVLyTK833v947WAkzkDtV3lmw0x
5Ex8U5/W24LIWai3pxx1zTxglkPIq/LHesnZeC4Wfd0y7WBWYJlo1QfDXbIS
A40Jpcf0ZBWmfkwmSK12ZuDT0JdTQwtZNwHVMrd7VxHtV+MqL71p+z0b62o4
REX++hH6XgPOokzSSvpZ12BMflIQdY56DuSCz3orRz0HgUNN343tzFwudCWh
F/Q+6rlY+cIbEZJIPQ9XdoR7rGLqeUjT3n4ji6aeD+vl1O5tfHafKR+bmpoH
zQ3sfzkttmYMzpz537UQPB5NPaLoY70AL8vn2ryW+6wXIPnAxaH5sl7WCyGW
+2vmOuj9hUiyR7aYO6nrsDvul7/Pzs4z6dCweKJ0KZnbCKPGOb7kVo/tNzq8
E4k=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwtUjfkaBvCvqEFJiU5MlDkJpShKF9VTpLvu99uuvXftmk4XUdLIZo4w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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zwtYzOkeB/DRZaVsYrvY1T5GkojMRiUZfbtpJU336TpNl5nJ9ZRLS0kj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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0H8s1HEcx/Ev1ropP3ZU52ahH5ecQw6F8PLznHOiqFHWaLlrFdUf/sjU
/VNamU3Nkq2RX6PC3UVZSZxISTgtVDclrT9Yrq0f1LRqPu8199k+++yx52ef
7fP2yM7bfdia47jov/vfSctxrOZEmO2TR0syR5T+FHybtidz8H85d7TdgcyD
2N0lrdOG7Ijot/ULUYt9zM7Q8TTvaj6SBRAXtrQvfCC7QphRNssbJLujwkFk
4PWQN8DsdLrIp4G8CftPDmQl68kixBXxM89Vkj3hVDqZbVCTveAljTUGrid7
wziZOrcw1cvsA1vJl8Ej02Q/ZKn3jg+Nkrcht3BWq7pA9scv2bD1oWayFF2X
xeEZY4+ZA/DMvVr11Y56IDrWynNdC6gH4dRkzcTWkh7m7TAfHK4aSTMw78Bq
Qb8q52Y3czDy9Tc+XUmiHoKn0tH3fSbqoZCclVcok6nvhG9lrVbhRg6D/dCg
9Tif7odjQn3e73NWF3ME1r26rlrlQwaM2t620ImOJWsAUYT+/oGBe6xHImXK
KJMU32U9EvNnODtBTivrUXiuGpC6KdtYj0LMVJDLigpmLhphIXUlOXnUo7HI
1aaLZ/Ssx2Be1vEiU3aH9RgEKIUG10s61mOxL+nhxhQl9Vik1po9+Tot63EQ
dpebFxW3WY+DQlKwck1LI+syjF+D2sqZWSPDD35xk0DUwHo8mku3vN480sR6
PMq0bnX99ew9Tg59sK/3LfcW1uUwmY4Ze62YuQQkvgkPtZqhnoD0/Llpboz+
p8D3qgA/m1ZmjQIXyz2CqvPo/UQc7xRey6+j+SaiUSc0cVdpfkqLrsQe+3ZF
z+8HrCctt8bC3C6LbmEueblhYc1//wFxxFOU
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XtIU2EYx/HTRdSUmjrI2rrnkq6zbE7n3M9tOqeTofaP0R/hpTALR1ZI
EB1hGsEsTE2rKZgGSmniPTSXzi5aiCmVpi2ZICFWC7PCwC74PoEdOBw+fF/e
9+G8W1KyEtOXcxyn+PP+/dIjeFNlUq56aluUSxXhIfGXeZE5rL1md8/xJXtg
NDdsLMiDLECtwq+kcPYJsxCOz9frxa/J/ohP2GSsaSCL4XnG27OxgLwZy4Y3
XKw1kbfCHnCipD2ZvB3PLx/ruSkiS+DrSkueXEEOxI1+aaN27jHzTig2OqaM
xeTdyKk2lwnk5L042vFj/p2QLEXiN+WXRik5CDP6PPnHGPJ+tF91jp5NJR+A
26mF+YLhXuZgnHMOjYS77MwHkatf81BlIcugO/LMNaElh8Bn9a2vSmsPsxyv
rKct3QnkUKhXNnn1DXUzhyFEkFU+l0FWQC1JEfDfHzGHw1A62JL/gayEwVZo
ECbS+ggc7qzMWH/XxqyC+tMee/F4FzMwWPS294IXMw+YLr2wDBR1sh4JLuf4
y0p3tj8fidm2rnLxezpPDVtqQrl3JnU1fiU5nUka6hr4+RgHMqepa1BfJ4z8
WUtdi9ARyz7RNjYfr0UAJyqVZ7exHgV5mlbiVsfm4aMQnMdn6mQ0XzTma0wz
2XjAejSSuPMT9/NaWNfBPC21VXc3sK6DSqo3TC10sB6DqjFRhmCymfUY7Drp
MNv76X71uHdoR/LEOnb/vB7tZfni9B76v7HoM475V9xpYj0WuVdaA0Ost1mP
W2o+DsHN6tTWcatqsRuWmv/PXPw//wYLiCdq
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxF0WtIU3EYx/GzqLlSYbSgCdHKW6Hb8rLpVjp/u7iplZRSUi4hIUEL89Uq
ijhZEElq2ZY6VhmDYVhoBTGzWuZmGYK+SqQhOIV0k7Cyy/JFF/w/9YfDnw/f
A+fhPFurT5YdW8VxnOrP8/emI55wN+Sve+1b0WJB042z93JiyRzCj27p3EKy
CHOT5oA/Oswshqu41umbJm9AhnPKuS9AliJWUfZA6yZvwu2WSLiXJ2/Bhb2X
3rvM5ESo7OeCj0XkZGweuZ4SlZBTkSo5mGgeDTBvR01cZ6PARU5DqThYpZKT
5Wh2yPQxb/3MSij9ovlv3eQM1Hrjr37sI2di7Mh+dWg1OQveznL+e88QczZm
lpW6U01kFQTubQ9DMrIakv5De6revGLOwbWe5X5BJTkXJ6zxv0xSsgZths9z
s5GXzFqkBWyt+RbyTtz3akYXEnzMu/AurqPEayfnQT5+ca0++Jw5H2OOFrX1
3/s6zMp+lCTcJBcge7Ii76iFDET4FHsm92LFPMBLK6y5jmes61HdeKVD7GHm
9chemFrsuzPAugHt64fPZDVQN0A7IZh2KGgeI5a+lkcNQupGhG1G4eUY6ia0
b1xKHz/A5uFNqHdWDsR30XyFmDn8M+Cpo16IT7K29KHSQdbNkIRDih3z7H/y
ZsiUvcc9d2kfFpw/3cz5hGyfvAW7v9Tp6rtp/iKoWj+sSR95ynoRBjVd6icu
+n4xkpJsycKaPtb/+zeHQwDE
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQk41ekeB/B/SkxpUZEWZUsbKW206Etpke3IdqzH2dUkIZpJdUYyXXSp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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBWIQDQMC1xcX2HId3w/hfbB3FthtUAbnMzgw/z4gn84G
43M4pB0rTDRjhfEFHByE3tbJvDoG5Ys4XDv/JWfFdRhfwmGnyrPgz5tgfBkH
/Wu3l2lug/EVHBbE5P2Ia4PxlRxKJ7GXV7jB+CoOullJqb9lYXw1h2WFV4wr
fx2F8jUcDmvkZsv8gPG1HGqYprzlYIap13HgCd3aFroAJq/nIPlNN/xiGIxv
4OA1e8fzqYYwvqGDd9zt+rubj0D5Rg4rDx55aMgB4xs7MK95uzkxH8Y3cWj1
+tEw985hKN/UoWfzxyOno2B8M4ewkGtV2htgfHMHpQ8Hp1QxwvgWDnJiRzf1
TYfxLR0S6qvuzbt0CMq3cjig90QmvvAglG/tUPP3MnN5zQEo38bhcEe6VWEQ
jG/rwOi39a+d834o387BXFF71QKTvVC+vYNVPMsDk1f7oHwHh8z5tvcuHIDy
GxwcSjbXsS2/tQcq7+igUmxd0bURJu/osOReelR8LkzeyeF6//kzWe9h8k4O
fvv32xbxwdzj7DAjs+t1QAvUPQ3ODo1v0vRYV2+Hyrs4vPmVsWOrwi6ovItD
oMCa3ozTMPe7OrT7Xpt+/AnU/w2uDg23DM/dPQAz383hmEPuqd07ofwGN4dF
F/cWvXWBhZ87Kr/B3WFF+H9b8zhYeHqg8hvQ+AyeaPJofAYvOB8ASf0RGA==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91ns41PkeB/CJnmyiEk6d2FwOXV3KNRLvKIwt9zvDmDEzypIudLE0yMlB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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0A9MlHUcx/HnUi+kcMcwY3ZNBIYuOYfAHXgc3Yc7/nhw4HHn3RzMcgit
UMMbl5xS9EgigksxS5rVDkLsbIn/mEswwfi7i8VmDhkKOWALiAZkKE3Cany/
K7jtdnvt/fs8z+23NivPnPOMIAgZ/3z//eWP7G7NvljvjqZ5TWp7urM33X6e
LUCec/SObSnbC7ucVVKbhC1D/Wxy1PmZdvJK+Dda9TvH2P7I3P7zGdtDthzf
iOYPQzzsAGSkNIwcPMcOxIqEjNVKFzsYT+uNSpeDHYJfcuaOTESw1+PNMsuL
umD2K9iTe2b1lf42cijUEZEazSX2RmS9cUkRdoAdhqETTfbvvNmbsGTI3Tq5
v5UcjsumYkV5EDsC45KAtcNSdiSqXyocP17dQlZC7Zk5flZkq7Db7nfI186O
Qk2KpDNpGTsaX7/eljvTfYu8GY7I9XPlUrYa90Zi+h781kyOQZHfJ0+Xe3HX
IPavZ31lTu6xUJzq2nuyhPur8M5sL7hVwNbiUZhQekLOBoaK+64M3Gyatwh4
/RmYr+okC3Hw19yQxIXcpB4HSXRH6fCDBuo6jLV4WntmG6nrYK33VE3c5a5H
qWHssSWA93r4mJeuurOCzgvxmLa8du8DO+/jkV+03yfJcoN6AtQZlvvG5fQ8
MQGH1vWran+8Tj0RvxfVauakvE/EaF9+trqOn58EV7GfRDFK58UkVOwc1ivf
+5b6FkyV5fULJrK4BdLB6InpRP7/BnSmpZlu2/j9Bvz0Vut9nf816slA84ap
rlk39WSY/m8hBcr3684Ozu2jnoLcggsHBnzf0c53I0pcVxWmsJPUjRB/KAkq
ET6jfepCi6mQhl/V6karqKchSpeXtyaILKbhj5elD7MSuW+Fu3eH02P/kvpW
SHrbqmUdn1M3Ye/g9QT9r3QeJqgCK6M2NlXTeRNs4+8qCzsq591sgs90z3MH
L3xB+3QYKgsqH685R/t0OAZHIhu1FbRPh7ffDrnzWA3t01H0pGLY/fbHtDdj
z0B36pGLZJgR7PDxGnlSRnszTu/qWiWXfUR786L7sWAydPz0+YZPaW9BdmoO
etsLaW/BC1/VPVqyLp/2FmwwhMZnxhyj/TY4D5/aPTXrov02tKh8l20up/sR
F7l5kQXrQsMKY9zho9bLfH9WfO92hzuCamm/yIJtofGf/waCssGm
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAmIQDQMC1xcX2HId3w/hfbD/+dnixyoOGJ/BYc/rizdE
eGF8DofZkXW3HnHC+AIOZQXaToI/j0H5Ig4i3yQfVN+H8SUcTjnKfLJ6AOPL
OLg/FBAueAjjKzjc+D2V4c4pGF/J4aNkc8uaezC+ikPHt+ZPq8/D+GoOkXvO
2slsgPE1HBqWfb6zZBWMr+UwV+vcquB2GF/HQT5vTfFKORhfzyHUgGv54WdH
oXwDB6vXf6tVnsP4hg4S/lt3Lv8B4xs5hAfMvt8ZC+MbO2y8tzaNnQXGN3FY
dn662sL+I1C+qcOWaRMXczPA5M0cnnfdubAyDsY3d1jcs0+pfDdMvYXDlxW/
CiZWwviWDvvO7w/oXg3jWznM3af2d2vPYSjf2mFhVBTnBO9DUL6Nw5+O01I2
+2B8W4dzCmZaWpww9XYOn/b7y/Uaw+TtHbJUj23JZIXJOzj800p/8O79AQi/
wcGh4s69/wfPQPkMjg6BshI9MU67ofKODmeaVjk1eu6Ayjs5ZLyauqb5/3ao
vJPDMcf2gnvW26Dyzg5dL+Us9S5shco7O2zrmLVQ/ckWqLyLQ16/TH7VjJ1Q
eQQfAE0R3Ok=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zQlYzfkex/GjUlRMhUSGtKjJkqlEGtOnDZn2fe90lk4LKUtTWfpbLkUa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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgtYzPkex/F/Nm2bLlbqZN0aJaJINyH1IemmUqkp09TcJ+tSWFmEwYot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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1kglQU0cch4PWCoqYKmUURcBaKlRbIBxy5oeGABKBhAQCiSeiTENQFKEC
QuQswtQA1apQoVAZpFYBD0AUYlFRGWs5qqLGA6xWAYtFvEqnF/99M2/efPPt
t++93bVet0kSPYHD4ST+e//3ZBf3RuVmryntreM0zG+xcIqUGTHmwMj1YMLE
iYwNYXO3wqd/+CIxF38ZyQf8BhibIslhsJL/kPEsXJvxpOX5ZcZzEXRm/hVB
A2MrXClTHbcvZjwfRzqdP9KqGS/ABrGjMMWdsQ1S68amdz++QLwQzjtKVZ+e
YmyHhqSasZJ0xotQzLs1ciCA8SeYM7drMdeTsT3MsvX2qp7zxA4w231v6/5C
xo7wai+fyVMw5uHF+fjJb8faiJ3AE/rFxqoZOyOxa2N55eCPxC7wfrflQuol
xq7oLU75PG70HPESNF0cC8wQ6YjdsOfm0DXzplZid0x1SrHIcmLsgbvudS9v
o4XYE0eLLm2+UXuW2AtV8lMzlsQ2E3tD+p7a41Y0Yz7OrrovsnI5QwxI9bdH
D78i1gDKWwMyaT4b74Ph2lfRT3g0v8YHMYZ7k+1mML8U6uZn8pZs1i+Fv4dP
mdvHzC9DQ48ia1dUE/llONQ5MTp5OjFHAJlxc5LE8yR5AYT7tqe85NaT98We
HRmaoNV15H0xzcHSJCqthrwQ4klJi9aZfU9eCHXYIE7Iasn7oeB2ybIe22Pk
/dBhrt774skh8v643uazetivirw/DLLej+PafkM+AAmua9fpp5SRD8AfJbGT
TobReM5ypNe6dvS50Hya5ZjpcNZaYcDmD0SNy92nx6ez+QORGZGmk+qZF2Gk
xNNBYsp6EVSCeSnJP31HfgU2bDqjL3VjfgU2NfrwuduYD8L6pupR8z9pPTRB
yApPN/1yC1ufYMS/cJktmFZCPhhdMQvM2yrLyYfA2OV+48Le3HFGCFqL+FYm
ydtpfAiqNtTn9dyJ4//PuhB8m/Ome6g0ZZw5YtTbvY0WDa0aZ4jxVOuksvFd
S70YFXXqvRe8d46zToxeZ5G3+xwNvV8Cqzse2ptRxJCgthFNAomWegnmc+bx
q48Q6yR487jw8IhXPvWhcDTgbjsxtYj6UCjLus12T91DfShyzuVv7O/7mvpQ
WFW0Stc82k+9FBYVsroik1Lqpej6QZV1oJ72XyPFlPsFa1/P3Ue9FCaLh6r9
ucQcGcoPbLyaXV1AvQwztanBvzllUi/DVUse79HLGOpluPJhZ9Vpy3Tqw7Cl
5qahKmAr9WHQ+lr2+balUR8Gt7H2bOEs1och89r6hp+r46kPh9G2VIX1sTjq
wyEKPZJvMJxHfThODnxWvl1C66MLx6tf+dzT18lz5Ki2HTS8p8mmXo7MTKtf
Hhxn+y9H4euvbJ/PTqReDsVR/UCaI30vJwJ9xhNcu03Z/kXALsbd4qoznQ9N
BHLt1+jNbNj+R8B68TnnvzsS6PxEYjD3smncZAmdn0gIZlkc7B2Opz4ScY3n
Dza3Z9P5i8Tu/tYsz/4c6hUIfua+9E7ULuoV+GJeYNujpFzqFQgZ1LpVStKo
V+CdDPOGNx8kUq/Ewzlvj41maKhXQpexZdFIfib1Sjj6rs57bBxKvRLCjl0G
h35X0v+vxOUTnQ/yxAn0/ysxaatBY7hnAf8fL3hPuw==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03sslWEcB/Azl2ZkLpMklpDpZCa3UI6v+zk4mEs7TVulpExkORpaXpXM
SXRzW2uKUcPcOkc3OeegE2lpxk6WptpM1B8Wss6yLuv5aevd3r377Pu87/s8
v9/zbE3NTkjT4/F4ob/vP0+6zLWNJwONnyv/aiHolvqJw9CaeTAVp0ydMSMb
QXfZxaRBj2wOVUZFdOachtkK8mx+Quck2QbymZVISQ/ZDov89KLDfWQHlPLz
p6UtZEcMlh0UFjaRnXEvcVg5ICO7IFfkYqJKIbuioOPTuStmZD487siHelTP
mN3gyktydFCT3TGbH5HILyB7IM998mdCGHknJBalUdVnyZ6Y+rip86qA7IWb
tttF9aZkb9RZTLSH9Qwy+2C5NlnPajPZFwrsKMqVknchwXV5dSGJ7AfH1x7e
Bmvj/ZGk8J0a8SIHYMW4ysVJQt6NYfPjWmXzAPMeXLM0aO2QkgNhm7Qgcz7a
zyxAoda/0rdYzRyEqm+Cr+fVKmbA8f33tpwjzBxgUuodUrxRyfJgKOdleeIH
fSwPRnnT6CmraMpD4Bwwxx0oZ+ZC0JiZm37IppfloehtGLmtn/6Y5aHYoj0h
/ZLCvscLQ422VjFnz+bHhUGzbtUivo3mGw7DRGs0F7D1ceHI6t6wYlVI641A
03hOyCNDVh8uAroL6yN42VSvSHywf3mjZZLySJS5SgRO1dQ/IXTysSDVZ8qF
mIi7P7ZNQ++LIKhP6511Y/uLE+GNqqv+UivttyjoZHuv29VRHoXp/pbk5FTK
ozFeub9zuYvyaLTPiiosxiiPwahQwbcUsvPExaDmYsZiyRLlYnS/0Pgar/1f
jPHTb/3s1s5PLOSycr/5JapPLPa9KjGqekf1i4P+MUHGXWvWD+4/8+Ihai6c
eZjF+oF4/JB6BvhIn7Lx//wLuCxUKg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0F1I01EYx/H/puWMpVMzXS9k00LyhW3ZdLm536abKxRqllQwooWTxJps
OJKV/LWLRNpFXhleDDKQ1N5g3hSyN9NCA+ltaRoRS7DSaoXQC1jheW46cDh8
+PIcOGenzWFpEHIcp/y7/520JNH+Fu2GicCavuhCkmuH7WIyh44U6+LbZLII
8u3R8wdTyRJIPVZ/aDN5ExKnlrZMCsnZGHeHNz6OjzNvw2+f8vbUNDkHaceL
RrQhsgzuNyvDIR85D+9z8u6mO8m74b1c4u6ykPOhv9F23Sgj74Gzwe+PJZEL
MZh5T76oJBdjIacp68Ovh8xyeFrnteU9ZAVcos8Fqy6yEjfPBh2DJ8l7sTC9
I2wVkEuge/C9ubiVvA+a9d/S2uJjzCp01dQaAnZyKZyHmlK9MnIZ2m1Pio4N
kNV4fkk6c1pE3o8M9by+UxVhLsd9oXNXfQ91DV6es5eeUZG1gLoxfvFTmLkC
jT79gRozzeuQle93GT+GmIGJYfuLKynBNfPAkbnsR5puZk6P6M8lhTSTuh7v
pD8EtWPUDehVzUaTPOw+3oDRhLI6gYjur0QdP9NS4AuwXokTV7daTJOjrFfh
gi13IDnGzFcho+9UuiKX5o3gEoY6myPsPbwR4pGO+sJX1E2omJOudL+mbkKw
f90tR4x69X+9Gk/lz45GY/QfZngTl1f77jDzZnxtn13uFUcCfwCxj/Xm
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90n8s1HEcx/E7PzrDrQtLxYaiJBnlR9fFvfy687u5Da21ws1GEZOsJF2a
+oNm0qqFxcJahy4TwnXOj7CGapNaKJXLMLFJaKjm/em7fffdY8/PH5/P9/2x
i0+VJehxOBzh3/fflz2C4Ydp3sY9mg3NiYe+dCw+4jNzIOhKHBwxYTZCzgiP
x93FLEBp5bmUdFtmCxib8buP/fc2jOXGSdbWX5KtMVt1PK9tktkWUsk+Xng1
806oDGTXnHKZ7TFfYmX63pV5N+wTMiccxrrJjkgLNv2JHGYnZNg1v+JGMjtj
T99Cw0c5swvKBuVDLb1dZFe4zGe765TMbkiVnZ45k898AOIIF8cpEfNBSNfe
PQ9q6SS746ylXPT2GbMHFmtNfdT1zJ7oWe6afWDcQfbCxW9Tt1KztORD0FV+
SN6e0U4WYkd6cYpNsYZ8GF9n7izkX2FdhNykaHPnTuYjOMU9elJWyNZ7o6B0
nDutUpN94Jndvnq9/gVZjOma0TiPz21kwGb15icz39YNK4CkLUqhw2QzdV/8
Goo2b0pupO4Lh74KcVhFA3U/WKVn1oVeeErdD7rJmKvtRU+o+0M7W25jnUlW
+OP23hOK8v5a6gG4y9eLkhhUUQ/AeF7j/tdlNdQDYWkralUaPqYeiKr4GIvf
1UrqEpgs39say1NRlyA6ka/zGmD7k+J+/qao3sgm6lJs1nGErdbsfEHQXtYY
XcoiK4KwpHZTrdxg/ysYDWGxo3MRNC9FMPQDDc+HZ7P5haB/QF2tb0/zUIRA
PrFU2FvE5hOK4e/SN/xwug+KUNTZlaz/KGD3IQyK2BUTvkCr+QNBkyAz
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0HtIU3EUwPGLtbSoNDMQDWrhI0fp0vmYuTzb1NT5KixNimS6WmFp/ZGG
VNNSQy3xgTM0C9/ZDHWUziTTsmimCaEmoY4o57TXQnyAWkbnEHrhx+XD99wf
v/tjSxMPy0wYhhEtr79veiyGKpMEG153/NNPX33q7WKNJZkBm3L79yWbyWYg
cjvW3sWQLaDuMrctevEV2gp4Jk97XWbI1rAk19kPj5G3g/XZR8KRt+SdULU3
RRehIe8C/69RW23yyXbQNfddFSkmO0CuzzXVAou8G/JGRsreaLvRHMgQ3PXU
j5H3gPzGpR+9A2RnkGhlBYIEMhfUibJ5vy3kfTDcJK2ezHyJdgX7ILep5Hcv
0G6gM62Q66yp84A/vS05u5+6OxSu4aanfiR7QPanwS+dU11oT1Bm9Tg5epC9
QMd3ci+VkvnQ83AxLsyO7A3nJm0H6yY60fvB8eKo9mYu2QcM7Fvj3r860AKY
qalPz58gH4B5Tn1ee+YztC984yqLzDY9RwPkiC9cadNjVwDEF51q4q6lLoSY
wmJOyyz+j0II/bJpPSuN7l8EFUPK8obz1EUwqy6PztDT+cRgfmjUwOFpsIth
SdjAqhpuxe4HnbzPVw3qJ9j9QJlQ6XDUtAW7PwinasdtXakvO3fHneZu+j4A
OOyeoZIYtCIAvFRGo2U4zjMHIWcw7jQ/APdTHIR15hWlfVa0fyDYOCwItZGP
sQeCy0bXvGYDmgmCrPlGh8YBNfYgWDjBNpyRq7AHQ0FBe9ussQ57MKQp7qeI
p2uwSyC+yqvPeZS6BFqN669Lo2uxh0CU8EP/bwnOK0LAVhEbW1qG80woVLNO
ps8lPcAeCveOHO/WZKCZsJVWrDITvqqvMhOx0vDffwCCQV4b
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1znlI02Ecx/GfliSrlUwTQ4VV3oTosjzm9LOf95ZppphDal5gWbiM7CDn
QXlEapRGKFPQP6xw2ULJzXLmUWJiZIKF2TGP9o9YhpgQXfh8f/Dw48X7+T7P
szu7MCXPluO40H/r/58+h+l2jUzw0ryhb5H8sO6jaRuZw5vh654/t5LtsbNI
FVTEkR0w3TFSuf7jBbMThGWdOWtrZBdc3GE5LLGS3aAqLLdODpHFULca7xeb
yHuQ6fhOqjCSPTD4KnLvCR3ZC+dredEmDdkHmXWlFnsXsh/Kkq3F31dHmPeh
xDV33O4D2R9n6mYdndvIAZioXK8VLQ0zB2KRl/vaSMkSdJh1krS+Ieb9cC9R
HO08Rg6CYdXuU4gP+QBuve+eel1KPgjPMN8KQQo5GOcWEvXO5eQQCGxzU79+
HmQORVBIQxevIYdBKdeK/VcGmKVIvn1tTi0ihyNneX7GfYYsg7Z1RevWQo7A
5lG/PFMGORJtynRrluApM1Cz3JNRHd634TLgpAMXrJ9l5uSYlz0OMC72sC7H
ku5y0p9JZo6Hart0y2gXdR6ZGk7S0d3LehS8+3Y9v3nKyHoUGvKPTDV+Yeai
IXUVXU0cN7EeDYF+zu60G90fAw/hhfbQBXpfDGouNabXg86PheuN33eeddN8
LBRN3mFe/fS+OCzX24ryE5+wHodfS3erepvp/Hg8mHNKa4kwsB6P6tQCcVXg
Q9YTYBmLP/t2gHoCpptlSeb5R6wrkFEptumv6GRdgR4fobbgHs0rYc5Osxxf
pXklmq4U5Bmy2H7uECbG9KoYtcH8F+VzHSg=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n9MzHEcx/GvMKUfYsnVmlASHYviiNPr6vpdrjuGGPl1ozarNRTb3Y6N
TbL82E5qZPMjpxv94JSoS0UYGio/dtWF8iNklC3pMO93f/hu33332PP7/nw+
++47dVOaSm0nCELCn/vvky/X1rPp0rF3a/6pN9TWMMrsM2wBOdrjLQZ7tj0U
IU/UQXZsVxQO5E7M+HWH7Ia8FfcWjP/BFqFlsMjR2ML2gke2obbYxJ4Crw2i
IbOBPQ2OWVslxfvZvig7pnEpTGX7obqjb7vIge2P57M1FQFNDeRZGL07v3b7
K7YYlgGv0FcG9hyY1FP7Tu1hB6JZr4t2XcWeix6jxH7oXT15Hhq/f/RUa9lB
+JSz6eUuF3YwXl+4std0vY48H9myDuWz+ewFePQhTK9pu02WIFu5NiE/mL0Q
8m32G1dOYi9Cr/hE+EO3WnIIvIr0kgxP9mKkDQ01X51mJi9B+5h+S1IUWwrF
x0xrl0cNeSlmlhR4xw6/HwqP1VmPJ5urycCW3BcpT0/f+mcdUP5GlpPszF0G
731CU8CiKuoyPBeHPnZ+XUk9DEc0tg12n25QD4P12ea+9DZaTwiH9Fdw4c5U
ng/HA+PdgdJesiCH0b0k1TWT9tPJYVvb6dNg5B6Bnmhn6RYnno/A2ZWFUssX
2k+IxMX3Bm2pls6ji0SP1cFt6eXr1KMgXDnX6tB6lXoUMt1fvB2RxT0aCu9c
P9tIsi4a1X2So13dJuox8B+x3pJ37Sb1GIjXHzrj18/zsXDslhoedPP6sTBl
BrdPaLtGPQ5f3CtHxu+j9XRxqDwS2D1HX0E9HrIZnSbFKO7xUMV1Ws17S6gn
ID/F39tz6yXqCegf1Nf79hipL0NSdfE4x9G8/zJEDi5uzkkpp66AKWOdSF5V
Rl0BbVFQY345WUhEnGbwcNJXMhJx8qD2Z42a5nWJiGrOu79DRN2ciIKaJsvC
DJ5XYo08uTEwgN6HEq0ltkdOKj6PEqa694dCzPQ9zEqkJ+sKyk7x91XBZXLE
gcYl9L9Ahc++4m9PzpfSvAruIQ03p1vP0fx/FpYP+zfk4ZOr
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zws0lekeBvBNiBjklqRs6khTI5cuQ8kj5X7JLZdc9t7svVVHElJNmV2n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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0H9M1HUcx/EvtogRCFzokF1DTX5OnEAHKT/uBQcHcgfcj47LyWgdGXKi
CKklP27fpVCIx4YN0ShOOIRDvZQTilTg/AEGmpgVZCYSxIyIhmMUps5qvj9/
eLd9d3vsudfn+9l3ha5AtXkRx3HZ/z3//7Of54h5R6zrld6nmhVvKpC4zLsz
c/hw3Fp+143ZBf3FrqYSZ2ZPiD1umCZn+sneWF+01v/OLWYfoNPwcf4UsxCG
mtpq43Xm5XDRGtukPzGvxDu33LL/6WFeha8KnAXhXcwByKgQ7Wj9gDkIV0UT
yoNS5hBsqdVv5QTMq1G6pMrv9GwfeQ20fMW9wlWsr4UxRi//bYj1MLRMB3R9
Gc0cDvPfVtkvNy+TIzBuLHt0uZH5VcQJ6mJ9a5hFGO274DUsYI7EaET98EUd
cxSUD6u+f37+Evk1KNpFL3iOMK+DYdZQ7eXLvB6f3rZ6ndFeJEejWpz3++Dk
BXIM4kzZ11L2M8fCtaQjIMyfOQ67X660Hj7ILAa/f090/mpmoHTi5kuViWQe
eHMgK0/0yE49HgvFDW2uh8h8PBr1zvGRzd3UE3C/8m7xmKKHegLe6KyckoLt
JahrOCXb18e6BJLAzQ1ZcWQuEXkJS1qHAs9TT8RY+IFTW8bY+Umw/ejub/ms
i3oSWryDyhe910ldCsODxwcKY8i8FEWWTU7DPjbqyTDuzRUO7j5NPRlzkUHz
Lk5nqKdge3CuoPc4mU/B4NdVsbPbPqe+AW+leEt2ZbdT34A9LxadfbuHzuNS
0akrrq272ko9FQp3/ZQlrYW6DF3tsnM95kbqMhSJPIJyRk3U5TgZ/Jzfu2Vm
6nJ06A2hEhudx6VBcaNqTU4YncenoSI9zOS7tZl6OoqO/CrXSdn70+Gz8M21
ueGj1DNQc2LnFS83eh+fAbfvqnUlj9leAUtdSNuxQLofFFjalLb8XAS7jwKL
w08kNd0++dR2Bcqbe6//dZ46p4RyYZvBJqDzocTGfPO0QthEeyUsy/qH/uj+
hPZKZNW/b/3ozyO0V6EldUoXYqP7QoWBucV3TDXUeRX8hE0JM9xh2qvwRaH3
yvF1bK/GWbWyIG+eOtTIkT58ENV/iPZqFEqWbRc+qae9GpLkn7/tjmLf5/Vn
DQfzDrY7mNMgRr5335MV7Ptp8EPjpDw3mL4vr4HnyMLMrgmyXYPQewNLy5KP
0z4TifrmS2KnDto7mHewPROvZHqETpeSOe2zhhbGtI07Nfc7e/8FVKnfOQ==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdy2lIE3AYx/EVzVRKlwnZNJyxDVsparrNlvqb7vAgo0IoBkK6WqWkOeyF
WiwtoXzhEb5IO8RtLuwwNgeK4ZXbUkiCRK2wA7HUMgRrgXTj8xfygYeHD1+e
iLyiwyfWczgc2d/9d9nwJszFSf6evhUtpoirr8luBzBzUJigVkQFM/siwDdo
WbBqHgZCMyvdPszBWFjwH1/84iaHwGIcC6idZA5Dqejq5PxTZgG2nlVx+e3M
OzGhOKh/W84sRLRb3vBJxyzGOUHOR4+UORIVc1XG1lBmCcrChi/nzrrIe5D/
3d5hW2KOhsUpDGpPZY5BoFVUqu4bIseiuYpf4REwx8Fc9uK1PYd5L7JPSs4c
284cj+cx0aFLrifkBLQ0NXe+f8YsRc2I6p1NwiyDO3z4wI1cZjlu1jnC6wXM
iZjdPSPbVT1I3gevT+CpDVEDZAUqOyJ/HlIz70eXberHJU8fOQk9Sp5oWd9P
ToZOah8XW3vJKbjoVe44z39MBiSaI/MRD3tWbAKy1xUrsr51UVdCUqeLzzva
TV0Jw6A+xKUnc1Lh9npGr485qaeiftMtuXTGQT0NvVu+aqdekk1pCJsblY8f
f0RdBavfRt50o5W6Ct1+rU2/Wtqoq3HPxs1uuMO6GkXbpocSGy3UNTit4X5w
DtylroHxQe0Fp5f9a+F6FVRe4LhPXQttconuTb+NejoWOgvnY82V1NNR8tmw
WVhwJWWlZ/xvUwZGDL/zLTVx9J+5pq8xJ2vVfwAdsw2G
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zX8s1HEcx/GvUiGGdn/YsolFl+Icd4cuvq87d9ypy0QzmzY7lazJj/rD
jw1/RItMLbusMBtWOktKMnXn6MiPxho6rTWjLLb+ULqzSfqxPu8+22efPfb8
vPf21+edPLuN47jIP/fvS8fL1pof4/Zq4J9W+W+u8qEoFzIHffbKteSdZBfM
3Uk1h26OMHvh6srpCMEyWYBAnTbjoY3sA3/fqlzXGbIv0sTO1ioTeR/U2um4
6sfkAGxfd/36sZG8H1Me42/MbeQgdMyvS+xXyELMfz++e+IiORjXHfbFSiX5
MHIU50f8LcPMoXCo5lQzzeQw/Dix2VCeThbjUEFHGP/TyhwOW/zSVL6EegRC
dO4FzWVkCaI7dXsrRWQpNiKs0bJCsgwHU1s2FqXkSJwq3hV804kcBcfacH94
DO2Lxlt1cXqLmHwExrY9daMlL5nl6O5aba/0GWI+ihtCfWBZAjkGmszpyeQD
5Fic8eTvJiUNMvOoDpFnGA1k4IK+rzRFwFwBaJw/p/XIB1hXoNVPZn3SZ2Fd
gYXbNWPlIppXgm8YdxP+70rk3VoTG9Q0H4cFd8fYqJ25Ig6lAZFO3hL2n1PB
Q3iusbaEugriolW/UoOZdTUyLQJvT9ML1tXY2tE1a3F6zno8trpiL7/v6WU9
HnXLTfacFOoJ6M26x32ZfcZ6An5NSi8tFfazrkFB0cS7HmM36xqIp0Wm2jlm
TosPnVJZvcbIuhZNjwat/AMD64nwyjV3hDW0sJ6Iqez6gE+vs1g/hqD7tqdj
NRX8bxBbF2I=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0X801Xccx/HvDFnDCJesMdVpQkslRN37qvymwnV/+HVbNNR+EOO2km6l
aDezNSt0tzpIYpaJ06WS9INOWZ11nUa1htVRzqJRWoW14/35w/eec889j/P6
Pr+f7/leh7jk8I/1OI7LfP39/5d9zG6Vpiyb2npuQoOiRRaDDqnTmDl07Xgo
VZgzG2Eo4rO1rm8zm0Ev/piw3IDZElv9sNTzxWWyDY4+aBCUPGGegcjioCHx
feb3obV2vr+2i3kmOtMSmh5dYp4Ns9aBHrcY5jk4GTowOG7P7AhV2qDj6ieX
yE6QLK1798+bzC440n05tfM684fQ3Ygf0y9ndsX07Ksub25mXoBhw5G5K6XM
C2HsaR5s/CnzItRFJw1vHLpIdkP2oM7hQQvzYlzU5YQWVjO7Y/iLz33q85k9
8CtnwK3byOwJR4+5red8mJcgJMtzINeK2Qsv70hvP8pj9kag7ooufh17nqVo
PfxBigXHvAwHjztaRP5xgSzEJkMbq/jeFrIIIwVDn2x/j+2AuLBQNltDVgHz
BHNvzu89T/ty7PxnvKtmGvWq5QjMq49wTmT7ClSsc6/UKptoX4F73s/niZ0b
aV+JMvUh2ZdasmolbJ/51BuIztLuA+XTu95tDmdo90F8vMvjRMlp2n0h6MsW
CjUNtPtinplJ/zk3MueH8E73vtp8tvthR8C4rqNSS7s/9NVbbr8VzXZ/7Fns
V5KSzPYA6Lt+1aS8QeepAmA5o7ojPZeehwvE9gSPyrTn7PkDsXWnbPREKjs/
CEl/z1E4bayhPQi+Lk6jljhCezBsFWUi96ubaOeZC+HtPHOreDvP3GrezjO3
hrfzzIVONkKxr1+/8OHmLLqetzfzzIXx+jA8thOq9Yx3iyb6MCw8cXt6XI1m
ws08c+GTrwfPqnD01u+obf0ph/pw7FZcTzjTv496MV4VXDNV1X1DvRht5o3K
W69yqee5WYyX3Qni36apqY9A2SxJXZGG9RF42prn1XWRrIrABcOqgWejGdRH
oGeN5f3Rrdupl6Cs3dMw4fQu6iX4dkpD6ciudOolsLdr8LK32Ua9BPI4gUCZ
TffjpLjbd8+utiKLeikyEtvlFRs2UC/FcctY+9lWqdRLgawU7X63RHr/MnSU
aa6pL6RRL0NOllD9lwV7fzIoitMN0fcd9TKIal/mnxIU0vlyKNv83PRsi6mX
450XJmGmtYeol+ONqBxdbNd+6uUwHT9refwwvR8uEqo7ayuLE9j7i4TJL1pZ
1V36v1SR8CqelWEYROc1R8JoprH1R9UHqI9C0cH0KGHP99RHITPJa0pyCT2P
KgryxTFbzJ79QH0UlixUCy5bl1EfjfWuLWOZoceoj0Z3cr7R2YIS6qNh4Z1k
esW6iPpo+I+1f31AXUF9DO4s2mRiO05GDHp9zwg6BVXUx2Cs7UduqJTu3xzD
62MxtTFo78+aeupjsTzFKvVouZb6WGgOrgpe4NhI/evrz4eYJB1uol4x2VBg
/r/zu/wa6HqVAsXK9Sl7fz9FvQInc4OV23pqRP8BbR9VUw==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tIU2Ecx/GDeMtLGFleK5WyMjVnedm87KfOTd3UyuwOUi5XGbZQEsp0
ppFvzCyVIGWiEs1Wm5d5wzatNDHQRDF7IUYIFWSmKJqUXfD/9KIDh8OH78Ph
+XmeuXTorBnHceF/3r9f9ji8rVdG2Lwyremb0PNcs+HqP3NoVtty96yZreEu
uDwpt2B2QLI4nZe20k92hDB9/rPfL2Zn2KV3hN56x+wO9d2b/o/GmD3QeKSi
RGlk9kJ28qhwsJR5O3qsBR9+FDF7o9xytX5EyrwL4Y8zE3M5Zh+MaQu9Zjv6
yL7g3T4dWZ7H7A/+xiGv937MAbjjFyxs2MnMw7SNR8qAgjkQVTnKmft2zPsQ
ViywP+HEvB9NeyQW0REvyUFoT+HnWNkwByNrrP+jpfMLcgh61flfvpt6yaHI
Ew06Pt1hJPORm68tnBvqIgvwzORh7qrpJofB3kUnF7j1kMPhYnlAVudvIkfg
hj7A3KqmkxyJAX2tKNC3jSxEwOuW7C6BgQxUbhlfvihvWrMKUJgV85XXmqlH
YVOdRlpY0Uo9CkutGc9Lrdj/orFaFTevXE/nVdFIbZvSZZrTeS4G2zIedK00
dFCPwamwoWONIWyPCJtVNV+XU2mvSoSVvmFupIDtj8UGl588y4J26rE4qDBW
czIyJ8byycksnyS6j0qMzhn+wpulFuoSTLgqxFMFbJ8EmuGiBZ0TmYtDVsj5
3XNprMdBMr/V082b7Y+HTNXfM2vQU4/HOq18trpMSz0B3g6jelH3Q+oJmL4e
X2Lcq6Eu/a9LcXguqWzxSg11GWyPf4rtG6ilLsMT1/oLi+Z11BNRNt4yoXNV
U09EUFOj4WhSpek3+90oDA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0WtIU3EYBvBlKypaczhx4pCuFqWSlnenj3edOqOLiSHFsjRzaZkaQnmc
N8wim6IWYubAQC1CSUMcpplCWDlLtIshObNkW94+uK20ovN+6MDh8OP5Py//
l7NNnnH4jBWHw5H8ef9+6bEeU2dKNg32/NNcoKafGy/kkzlQ/rR1FgjJGzC+
4sgxCcjWiNtd15XAIwtRb/BQlFsGWItge3o1Y+odWYx08YfYjl7yVjSlKoZ4
7eTteMm/Od9dRd4Jy0L29c11ZCdMi9x/8DPJezB3bIesIZS8F5I3i8P2DmRn
6PX1A7njL1i7Qj6RryhLIe9HDtectnEX2Q2fa2R2Gl0/a3cUpYg8CizkA/hk
lgyaren8QXzU+sQcr6HcA8rKTu8EFdkTi98bX1dcJHuhtKq4qXCC7I3b8tG7
FtA8H2zxeyZw7n/O2hcX2vRcpoPO+yHxcus1XRad90eqMmm6gEf7SmDvWu/V
bkMOQOvyypLxLDkQQc1euaon9L+AUvX5x/MTrBnAZd9oMreR8iD4Ns4MuJnZ
PhOEspJLvKttNC8YDYXiEaOO+sHIYg49mLxPeQjWPBR+dXzK3p8JgTkpfSEl
nu4fitmjhhLZespDUR62HOwipv3DcOJKsenV2z42D4Np7I7L+2LWnHCYDLlK
rYzycPjbGNoCOymPgDR1uNrhG+URcFgSCfhDlEfiiGORLlFOeSRaPEfuDSb3
snkUNLdGaht+sWaiMNusyutqor4UZrucSakV9aXIE92onhmifjS0J3UV+hrq
RyN/7bmePFfqx6BbvZAtT2P3ZWJgPDXl1BdHeez/ZmJR2brOFLBK82VYbfkS
Z3zU2/MboFZFgw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zglczPkfx/Gf/hXRtlrW2q3sOEJKOgiN9Nah0jkdU03XXM1U5ChXrh1F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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zHlI03EYx/FfWVmOcoHIAsXbwtpaHssj8zPnMae2WOofqSTi6I9It4yF
LkUpNUkijKVYKDXJSsIyZ0mtNY/y3hIiK/xDkA6dR2QLU+jA79MXHh5evB++
fvlFKvVGjuMi/86/TY//zqiJdXttWddSnPPIfJDJlczh54Iy3MudvBVvhBl1
M//v+Sh1pgvmXMgesJwoTbu58opZgA7NvKr+K9kL/C77WGAf2RcK3niVuI3s
D4WFr3etIgcicjUouLiSHIzx5p2OkWvkPbA153sXFZBDMNRgeNagJO+DQudT
NvN5gFmEkLEvc9GXyWLUXqn9OHmefACzooJOuyc5FH7me2lNEnIYJtovzXaG
ksNxPGche4uOHIGVqTxTwHA/swS5Ur3d/RT5IObk3lmLanIk7leU1PXUkqOg
3eZyo3I7ORol8+XVyz/6mGOwWXLWPOBJ/RAmjxqzDFLqsXAIW4PDA8iHoYmx
qh9ae5nj8F61yeiTa2UGWgft7rO3Xq67AnCJeNuycpe6FDpBjVBtoC7F6tp0
PE/8gvV4lPtPnem+yFwRD8eIb5htzcy6DJkXphyjGc9Zl8Hj9LfKRhv7j0vA
/l9x9h2Z1BNQXNzbJvzew3oiZLuGtS3XqSdCu9t36Opt6kloKnT7XZj+iPUk
LJpyeIM5zFwy7oxFDR3z7GQ9GfoON1sNv4t1OfZaP3w6J3rMuhwCWV75oIaZ
S8Goub6Bp6SeguWOvqUHZU9ZVyAle4O4n+tmXYHGk86giSgT66kwt0+LFkKf
sJ6KOkOb0VrdY/kDUwQgfw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQs41PkeBvBpF4ndUshWe5mSaoUKsUK9iBQx7rfBzJgZ1LYuS7XpMqHa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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9z39M1HUcx/Fv3LCyBEbSLHGd7o4fYZxg4uFx3uv45clxcD+I3R+YhVFm
LbTZEGjulARBmaR4sskORCcsiskEOwzvjusOWuzatQw2WppimT/mEdJhN4ps
93733b777rHn5/P9vD+ryyuNFRGCIOgfv/99+YmZPLtbuXTMGdaMatQrDdqX
sQW4ox1zrSL2U2gvmXpT/v/6GETvUH4gnR8lL4dsuLu6O8BeAXVflKzlZ3Y8
NJGpDxROthg9++oWX/Ky1+Bdm7dy5QBbAveaU9aJYXYCpGO9cdca2EnwP4yM
2w/2y7ifXLMvP5u9Fm/NO+KFUnYqPnthQ1RcJHsd/LX/VK4IeclpCDw598Uq
Kzsdu+5J/vDf9ZDX47XFufTUJvareNgaq9mznb0BqoWpj+VNX5MzcDtxbPWR
o+yN8Mz7zm3TsuWYlSo1ZWp2JkQjZcctzW7yJgycHjme+AZbgfcMD4ayro2Q
s+A+tNMWGmcr8b6uzTabzN4MT+X8NwtiF1mFX/3f+UpvOMmArdp7p/FvR9gW
4K94RdB0/gp1NXJafEdfCXBXo2hwXHFnmCxkQyUpTtOlc8/GeP3Bbx+ZL1PP
QWD6YkHHYTv1HIzu/91zdvYS9Vz0KWVFBY8GqedCVXH3RDDjS+p5uK4uEU8l
8f48TI86Fqa2cc/HL10ZNZdcdJ4lH0nW5oB5yVfUt2DxmeRJ3QmebwturLrp
tO/l+TX48Fm5cFDMXYMUyeGWXXW8fyv6mqPetqeQLVvhkkX4Fmv5fgVYqw1t
r1IMUX/s1z/pjHme76fFoXZR6/oKskULUdMPx6aX8vyFmGk7t/nAFbKlEKdi
PzJliem+gg5nZO6EKlE/dR36bw3crxU+p16EUkdwWWqOjXoRzHWNN5dcrade
jMH+5mOavT2qcC+GtPx7+0TjybAFPda19d5ujOgMG3ok1nQmbHy6gdbrIYnt
ffE3S33YLj0mrc6ZsjPn6f8GeHrvLSzv7gobBuw4YpZ2RPfQPAZUX0XI3Efz
uwzYk/ZOodzH8xtxy1Ga1+Gn+8OIP1WqugPPnaT9RmR+GtTtbrhI5xsRGi8L
tGoHaX4Tqkqif7x+4QLNb8LQE5tWmtupW0yYyOzfia4h2m9CrvWn0ynll1X/
AsHnmug=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1y2tI03EUxvE/plEipTi0OzmczBGuNs28zD3TORUbjGFFN6nhSBjdtFea
KGIXyYqikIhgXlJXZqWb2yKd03SbhZZikbKh5osKKQuzRTkqPL8Dh8OHLydG
d1qrD+I4TvJv/1824e+azshCXY4VLciNU5GvA1HMHMZ67L/rNzKvQcXa+cLa
SOZwhFlrRHnhzDxMLF3T1XLMG7B/tdJbvDxE3gKTYrZC/YZ5OwY0+8buNDPz
caj06zFjCXMsKufH17l1zHHw8d3dM3JmIfx7qzYNbmMWIV0WdXQ2nnkHFsWe
T/VPBskJEBvOfYgsZ96JGpmZH5LCvAueyo8e1+gLsgTnDzQOG1qZpRBfnGyf
sjEnItF/2NhpGSAnwRSaYVPwmXdj2igoaL7VT06GWhm8eTqGeQ++l59cht9J
TkF0QCctUfeRU5FXJ71als6cBq19IeztUA85HdKfxS0H43vJMrjaGqJFX1jP
QOGfz6p71udkOXhBRyYuaZmB623Vkoizz1ZcBay6a5kUHSdzCngSLv8qEtip
K/CyY7EgeMZKPRON42VcdaqNeiaKTt0sXZrrpp6FaFH+w0Ad+89Cc93oq7mR
LupKBBsFaW51B3Ul2hsGI24LyVw2fLxv+hFhE/VsaJJbhB0/TNRV6HMaQpwj
D6ir4HD1F7/veUQ9Bxqz+LE39in1HNy4r49rvdBJPRdd3vWVW69YqOciyes7
MdxrdvwFkKwBXg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQMC1xcX2HId3w/hfbDPfxTuNJkHxmdwqLymLfiF
A8bncGD5ImBz5N8xKF/AQfGRctMSZpi8iMM/tQi7ld9h8hIOzGIWv9++gPFl
HFKjdvIGnofxFRwelUy6UjEdxldyuHrZJuRhD4yv4uD7ar3vLz8YX82h5lU6
2wQuGF/DYWXOFbPjx49C+VoOUolXP/6OgvF1HC5eSOWSToLx9RxUip7U5WrC
+AYOUkeYr0UwwviGDi/V65N/asD4Rg65ZyPS1zPA+MYO7Ld1WTefPwLlmzgE
GTPfqLkD45s6vL6wUPxzLIxv5jBXoeZMpx6Mb+7QYau6xPDeYSjfwiEuMPxr
VTSMb+mgLT11mcIkGN/K4bHfagULIZh+a4fMbXun5MLNs3E4tyZeRlgMxrd1
0LM9HvvXCabfzoHRdXOZszSMb+9gESQy+6sBjO/gcMuWP3b1rUMQfoODQ3DA
uSuzvaF8BkeHvJySjbdqDkLlHR26LnHWbLKFyTs55Pr92ZETAzWvwclhap4E
n0UhzHxnh1f8C37kcMLknR1sIxas2BgHC08XB+7i6dr3pkP5DS4O36ZqpL9e
C4tfV4fntx4+7YPFR4Orw/VGQePnPjDz3Rw2zVy/Tq4S5n43hw8PFl6UtYTJ
uzss9wiTkZtzYD8AOM3ovA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tI01EYx/E/LmLVqAklM0xa6VYmVtNNMy+/uS1zrpFjOiK6IJkZyvam
NSrZP/VFl4EUYVNBhQ0NlULT7s7lpgZCJEZFZZcXXXxhhKZC0azoPET/A4fD
h+/DA0deareURXEcl/n7/nnpSJ/7HNnLRwf/6muubcobOL2CzEGU0LD5RxRZ
jK1XFv2jHFmKKvPHM5YPI8yrMWgVhz1PyTLEl12ekd4gx+F+S5Mt7CGvR6Mh
fvKWg7wBSeKr3wKV5ATsndmYf0JJVqDauoyPjgwzb0LA7exPbycn4fgnl3jW
Sk5GbPT3z4cvkFPwvkI9l1hF3oa3NS6fTUfeDrG9qU25iqxCTNG0Tz8ZZk6F
ydR1J+MaOQ3jj0pSVnpCzGoUSxYPXFSSNWjeJzLwOeR07OmeM7yqHWLOwJTX
0WpeSt4B7Tp5dKeG5jPxJXWo9I2fvBNe8/y8Yprms6Aw1px8Z37InI3Xzru1
PbYgcw4mVK0iiXWAORfNLq7kWHmAGUgO3n4RGWHzPNAXCi2oedqnRbts7FLx
GmZei4JZzSHJE9qfB89arq0oi+3n81BfzleGH9B+HXC0d2xBf491Hbb8TKyz
2G+yrsf5yNm0Z/u7WddDNV79su5IL+uG/80LzO0SdIG5fEEXmNst6AJzBYIu
MGeE4VR9pzzA/sMb0dcYu+TguR7WC9Ey4YxrEHewXgh/jGzAHfSzboL7cX9F
1/B11v/5F2lTJkg=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tI01EYx/G/FjOdlNmoGdFMcoappVlqc+6nM53OOTazWDASwQi7OGGY
SMY0mUnDJAikApHhNGcXlpV20cxb4VhaqGi9SSWhxHyhZiTd8Dy9+B84HD58
n3Pg7Mov0hd4cxwn+7v/nbQCxu0mud9g95oWFG6RucXpT+ZwMlNcofQmb4Cs
655P7P/5AIgdnZEdAWQRtM+KdY6VAWYxOl+bZI1vyTvgWhe6/nsDORinF7M1
qxXkEAg2+rr9teTdeCccdpniyFLkbbeP1EnIezCmm7i8tNLPHI6JGC/J0DI5
ArU7F1/o3eQobB2tDZ+ykvcjVehJC28jR8NZ8LR4m50cg2ztnLoninwAys3X
61MjybFwWQxSiamP+SCCKiWl/UG9zIdwPNF3SeNDjsP9et9C8cdXzPEYKd9b
UzhNToAhvbTV00g+jB/WMJHxVw+zDH2TDVtqjeRECCtvXnD20bwcU4Pzy2V5
1JMgf589ViQlKyBVNzY8jHrJDJi/XRF6+T1fswU4paxX3T76hPVkfMLA0Juc
DtaToQ0zVAiS2llPQb6PRm9zuFhPQfDF3EshvY9YV+LBrZL2mcBm1pU4c8wT
EW92sJ4KVVuyseraHdZ55o7wOs9cGq/zzKUjZPKnzTrfyno6r6t491U4sa/k
63Au9Qxs0uREV8W3sZ4BW4Kn5OyNFtYzIZHOffmtoP9lItAsEK+UM3NqhNY9
7hr9wOYtaqyGVTfNdDhZz4Lu8/jV2THqWciYPVfdVEbvazB9tyby/EJz9x+L
RCF5
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0HlI02Ecx/FfdtnWbJTKBCMboiYqat55fJzOOZcmoZUpEZoHNlCEILVg
mZFuuiw00yQxkZZHztJ5geadon+kVqtIRgRZYll20CEd+HwLfODh4cX7eX6/
h2d3ctbBVDOO4wL/zL8rDeGT+uwg3lj/qpZC5qs+2uWakznkKRf6nv2zOYrl
idL29WQhcrdPLbStjDJbIvG47OnMMlmEGkftFYsXZFu8tpyXtI6Q7VDer+0x
lpDF8LY12I+lk+3hYB2TkisnO6A3WhvkbhphdkLGzvxtF2fIzjh5yDM7uJbs
gjtNc8cyrMluuF4e7Hzv/TCzOzpuu3HWl8geePBdzNcMkD3Rk955TtdK3gvl
0eLSMiXZC9OLvp/vGsnecHZp3NF2k+yDjkynM5OT9H9fdJnJHiW9pO4H/UTm
geRKsj9GVarz03G0PwDzmgK+OIH6PhQ9dJHwUoaYA6F4s9zgsYschFieOuKx
mBwMG9dU46n6QeYQfI370FwqIwMVr+K35nsOrFoF+HUVFuZtoh4K++fjdt1L
zKpQtAl9KqxK6PsSiATXfomSmFUShGCQrzHS+TD4VdusnPh2n/UwvCubCTAp
+lgPx0DxRIrrjx7Ww3HZy7+ld5GZk8IjZjbWwpW6FAWCrFnNz07WI9B9On6O
q2xnPQLSPVb69HV61mW4MKrcOOLbxLoM1eOxPIOukfVIOOrHrer4zaxH4kjO
J/UG0S3W5XC6Gi8sOqtjXQ5h65jP9OYG1qNgSps63BVYy3oUWoa/CIYS2H5O
AWON4UZdeAfrCrzVpc0VbKH774fakKNWmej915iLXtP/+zdK9DDG
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90AtYjPkeB/AXGwptnHWJaEo6lUpLlwnVN0o33SfdVHOf1q1lW+x2MLlE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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0H8s1HEcx/Fv1KYoWtlMsuJqhc75WVd3eZ07d+gXR1K35Gpq3ZhajWTW
/SFxTExz6LdSW03rF6n8TLRpZSwrjeRoE+I6lSz9XJ93W9/bvvvusef3/X1/
P7d0d7I6wYrjuKjf1587/RxeXjognfOk4a/MQW8KFCsNs8kcRMZae99/3Qbb
5DvGTbPIDjhxK01gnmplXoj+1NLyHUNkJ4y1Ztbc7iC7IOXy59zCu+Ql0Eqs
hzMryG5YNrdMI8kmC9CTn60N05GXw+Xmzxv5R8kr4CW8/mjlHrIHKsXnhSVi
shcE0y0ZFg+yEM12dV09tmQRpPMnizwKWph9YCXKyyrPJfvCtUg3ctqP7IfS
V0612giyP/wTvd39xeQAqKK/dg99fMwciKlUn8G19tRXY9ewo1QlIK+Bdbuy
eqsbPS/GN5/XR2bbk9fC9MI5druIvA7HLFePCE+SJTh4Ns9G7ESWYlA6MXDO
QF4Pv3BFtfFOM3MQyivfzVXVkAHX/TKTwZlZD0Se8i7ufUvzMvTVy2I6NI2s
yxBQIZu5cH4T68HQdN042nmcejC8Fo+OfJcyc3IMJ6W6uFxpYF2OsWT9jCZp
PesKLDI+NmySPmBdgbrBoLLOtvushyBEO9695Af1EJzZWfHDPMbMKWHbImkz
F9exroSpJNdb087MqeDvdT9OacX26VVw07lW6jjaHwq5e6y9SEbzoTCmqC8u
cKT5MFwwloQffk49DHlXnubOm6hlPRyV6UlV1onM+nCkJWpKJR8esr4BfWHz
lP26e6z/do77F7/0atY3Il8e0/vMjuY3IsEwHZ9jofNtQvZoeqenns7PM7cZ
A+o22WAwfR/P3BZe34Ks9xnNn/bR+SPQGZddb6liHRGQjzcVpozT90T8P9/I
Mxf5v8GzPhLCmKYKUwZ7XyOvc2r4Tpy/JFjFOtS4lvXT82IHzauxyClI3BhI
+9Wwtd17oFxH/38Ubz/P+ig4TiMmZy/NRyHyukV7KJn2RyPePKmYc4bmedZH
/3vfL7rhsOQ=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtI02EUx/F/QhmaqWEkaGoSIqblvZm6/bzMu8IcwXRvSpvDgasUNE1z
CKkloWLeQtR5w7CU8pZu6XJloGRGL1IsKcuQEMwr5o0Kz+OLPXA4fPi+OM+Z
pOvxMiOO4/j/5v9mz+JT841Ak7fD+/otmNpY0fGOMXO4LEoT3z7wUcSHyt7V
HdgCEyXyvLjtUbIVEixGdpN+MVtjseXOcMd3ZluM27RvdfczO2AjYHZ6rInZ
EQ6KyZ0Ht5jP4jC/urVcyuyETI1a4cNjdsaTUTNl9dobsgu6Jb7Lfg3MrtDf
f2He2ct8HjZSO5GpmNkdM9eKnSSZzB6IMna0TJQze8LVef2QRSWzF7I0c7mF
xcze0CRvRenymX1gt1gpWPBg9kXs2KlxWdtr8kVIJ/xdSk8y86Dfnc/PNdaT
/TB6QhwfkzJCvgStd+92YROzP7wV3criZOYAbCpluerSV+RAWLrZfxFl6ch8
tK9dledMDpEFuOm+d+XZjJYM+K7UzzbIX+5bBVQp7/ZfKCVzQZBXWC91vh+k
HgS1X8fcw6dkLhjm5+4NlploqAcj+kNaqH51gHoItPOrbbr0Xuoh0GSkK76Z
9VEPhXjdNrsmp5N6KE5PGRkfSX5MXYjl7bmCkqOt1IUYShBahQlqqYfhufBz
YLr+EfUw/HTr8Snaa6QejoCm2tSO403Uw9FVKc3bHVBTj0Bijs7zY3YD9QjY
1vyZFtezHglJqlV5lZKsisROQWP+QkUd9Sgsq2z6+Hl0TxWFlc3mH7xE+g8X
jaWMxZYEWRn1aHTNiFK/qiuoxyDFS1Kk17ZRNzAXa9ANzMUZ9DiU2ptKGp17
hv8Cnt8/2A==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10X8s1HEcx/GjkR+xij8Yq04xWcqPIzp8X37/prEsKzOXVNgQRX5cl2XV
tE7IVFKcZC6V4/yomzs6PyazOaQiayu12rpjt1Z0I+0+n+/22XePPd+fz+eP
D5uXk3DakMViMZvr/59+2+dEuf5mo3K9lhmubdI5k23ULIh6CvNbjKhNcFyC
scK1EeLtGPUZnVlSU1uDKTJ62qeltkFzAZD1kdoejHhXT9sY9R6s1o+vZExR
O0A3YsBLUlDvQ3lm4UvOJWonLGQnhtyJoHbG9N/W/WULw8QuCDNPsSzTUh/A
qqtd0f2r1Adhcf2rMECtJHbDMTmvXSegdkc1Lt7s8qT2gJ+0Ula3k9oTubXI
82ZTc5DhtmLR8Oc1sRf6DWxOtdjT7o2UBs54XTPth5Gc8mHi7gtqHzAJkrl5
LrUv5AFpW9N9h4iPIKNKdGvyLTUXqU7eP9bjqf0gztFkuWwZJPZHR+d5VR+f
OgC+79byzWypGZTOKJsmrRTEgFY9pxOYyvUWAFKVxr/Ems4Hoo2nctzgknlB
ILKPBivHSsg8Kwgx/KX5yAK6PwjF5icunHUfID0YQ3HdDtFDMtKDMXj7yZTz
bC/pIRg2Ufza+1tCegjEiiDrnL5O0kNRr7HL4+mekx6KRf9MRzdpO+lh8Ly3
PJJa+oz0MPBtjYWhfHIeKxzrwzZLWqGU9HCM734wK/zZTXoEmq7dMP92kt4f
AQ/7R98du+j+SFz2Smuv4IpJj8RAa5Zc+6qJ9Cjs2HwSGfsh6VEQGX7pYHs0
kh4NTi3DqlPXkx6Nqn7DxfTEGtJjEO5XbdVoSc4TxODNmUrXQ8YdpMdCUpHa
8NmyjfRYfCou1pTz6xh9j4MqLF9mKq/RWxCH98oridPrjaTHY2OiN1lb85j5
B/8HQwQ=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQMC1xcX2HId3w/hfbDfvr1WYDkfjM/g4PCB6eRS
QRifwyFdkzHPSwDGF3B4lpil5iMG44s4LPrSL87HBuNLOFyQ2fH149NjUL6M
wzLteHnxBzC+gkPT16MujadhfCUH3qgD084thvFVHO66Lfn4ogLGV3NY3fT7
gHQQjK/hsED6+csTujC+loOW14nf03cfhfJ1HJLyvbyNYmB8PYejqctmZC2C
8Q0cfLsfBH3XhPENHX73zbn6RxvGN3J4Ntk5quHHESjf2GFuTnGsoDRM3sQh
Z8klWdE2mLypQ92Hl1IhHDB5M4fpQQ9jkxlgfHOHiz9TVVNrYHwLh40ROv9t
zsL0WzpslPvpE7IaJm/lwBuY8dewC8a3djAPYnZxqIX518ah7X+QwLTTMHlb
h3pZ76drBWF8OwfOc70rbyfB+PYOwVfuP3L4DrPPweGdhc8nHj6ofIODg/wX
zbf3FsPkHR3qpltFsGjB5B0d3kvuDWzihpnn5GB3mVMoPxbqngYnh/P82Su4
WmHuc3a4I6G6eoc21LwGZwej9XPrk+7B9Ls4tPDM/NbVATPfxWGqaRH3vqcw
eVeHgJmR9cp6MP2uDk8tmbWN4mDybg5Z72RP7JaG2e/msLD/is2lbJi8u4PL
qdBNCj9g5qPxGTwc/Ddx/m+PgZmPxmfwhPMB0A3+qA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQDQMC1xcX2HId3w/hfbDP60g/qcED4zM4mD9M+X9E
CMbncGh+P+1mMweML+AgeaGQU/3bMShfxOGqpvyuE09hfAkH+39FrAlnYHwZ
h975wcezJ8P4Cg7ODjLqwbNhfCWH7vcKcquaYHwVB1e79V4PfGF8NYcG/uqf
/QowvoZDBcc5xV8vjkL5Wg69Kc8S/N/C+DoOdxdoSjLfh/H1HKpbvyUcWQfj
GzgUp+01veoI4xs6JKWc+zLv0xEo38hB9tWxS6FXYXxjh78flqUwe8L4Jg4J
IepLirJgfFMHqaeOd9vUYXwzh51zOefoCcD45g5eW73f/uOB8S0clLb7py1t
h/EtHZjXrg5TWwLjWzkcfsNaUp4A41s7KMjM6TjHAOPbOLh1Zlae7z8M5ds6
3GC2+aIoA+PbOdTE37N7zAbj2ztc9mUtceA7BOU7OMxaNofD0xjKb3Bw0HN+
KZJ3/CBU3tFh8xz7NMekvVB5RweH0Ji98wS2QuWdHB6rJLrtYoHGR4OTQ265
KT+P9vH9n+KXvvoy28nh0yXfJIGIk/sB3/LAaw==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90g1MzHEYB/C/zssp0tRZCOUqb9FJRHX17f2qi7szJqY2ujU7doSYNh2Z
d1MpL1M0kbC7XlZeUruOvByS8zKv85LkPXkpsbzO8/hv//332fd59v89z34e
C/QarZ0gCPF/3r9ffpzuFi+V218y/1N76JagqwOLxGwBcsG3aa+ILUZjnm5+
Ux+2E/RfEvuX92C7IDE56ER0x0WyKz6PrZUO+283bHsZ1bvNxnZHVqujqLWM
PRItzv4S1Qq2JzbOc3jslsT2hsQ5Od0Szx4NU1uJxwVv9lgs3WO/McV4geyD
7dpn+rVL2BPQtNfaONSPLYNk8HKxbVcDeSLMc+a0PAlk++Hlt/FTMgvOkydB
vkoak+rB9kcPxeGuu1L2ZOiVHec7UthTMLlmt6E7iR2Aksb0VMkz9lR8zxR/
8l3Mngad1Fx6LYcdiBMBmjF5b8+Rg1CRuftScxHnwdC6OIy4/sJClqPUGPrK
JuH6EFjuB8f4iLg+FH7Ztqs+b7kesHTnnno6jmwA8itbB2Q51lMehjDZPcsG
Yx3lYdBNXJS/7Ewt5eHIiNT2lCw+Q3k4hIcGcVbzacojENyQIfLNPkV5BFpl
P6+sFE5SHomIUtU1RXAl5ZHY0TShxjvXSHkUOvvuelD4tZzyKHTMysgLsR6j
PBqXW7RVXtVkQzTsnj/Sa94cpzwGDfVdXkdN3B+DHNe+SdnrzlKuQF2CrbpO
zfMpoLIWz5W48XyxkG11r/GU0X0xxMJl0wpXo5T3F4fOcf453Td5/jjcWZhu
DXtupjwe+uZFtevvHKU8HqKCNT1NDnx+JYIcFQ4DrHw+JaTKxOubA2gfQgIO
7f/xpCKP8wS0t6+N8lpNFqajpHCQ+6tinn86DoxSbpGL6X/CDOxMFpw+xdE+
DTOw7ZY619uP96vC+3c6SWUv6ocKsz8O6vcgtYTqVRDNrKtZcJZcr8Kymxmv
e+WbqF+NNLu0c8Z9ZdSvxsF7bcW3G/m8avxK+nAwZB65Xo2y18MP6NZTvaDB
kBT7QNOqCurXoM0oypp1g++DBkf0RWndvavMvwHD2nwW
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10AdUVGceBfAnLsYS7KAB1MFFQQ+4ItKkXaTJUMShI+VNH3vBEuLqvgQw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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11HtUzHkfB/DZomKLrCUqyi2lFG1FlN660UX3qelqqmlmFLltmZQascqm
enThSDwpXWQ39kmFFhOlnUjUqsQyPCjSYNfWI2ttz/H5zjlz5rzO+/v+vn8z
f8ycqM1+MSocDkc+9v7/J3tp95RtsZ/YeuWz3jhYfFGcG6zJzEGA+WzdunHM
GohwejtLosqsDXnYsJdoPPPXeHgwM7T3/XXyDCSd6k4x+MSsj4A2Vauud8yG
6K83zgntZZ4LEff3ja4dzPMR7xLWatHAbASfti5Ppx+YjbFVtHP/VSnzIjz5
mJxQG89sBqOQs282hDCbI/RscO20My3kJSiV950f8WZeir8j9gjvljWTLTHa
qj2UPpX5G2R27t++S5vZCv+rzgkZ3nyNbI2/VTpUelWZbSCuTeRfVlwlL4PH
X8+/9xpsIi+H6uurH4rKmG2xdrN8mcJDRl6BPSahdT1WjeSVY793b3rR6fNk
O2yPsRHqHKkn26OJ7z/+wLgG8ipYbZn4Q/G358gOsE96N2LJqyUDpSu/KL3U
fuazpYD8TJGdovI05auhs0/lWrflScpXYwjV6hVZFZQ7QrlulqO35ATljjAt
4oXNWXKccicY1ZXpVR4toNwJDrkzh5SjRyh3xpY7875a/jaRcmfs+zZ0Xc73
mQ6fcxc0LLabPj0m+7OlLrC/keynczOLclcowxapuM9Jo9wV8+Xnl/Zq7qF8
DeYtKb5v5raf8jWwzl5UEGKfQfla2E7S/ZD37zzK18Jj4dBrdZciyt2wP6iy
MTulmnI3nLPYqIxf0EC5Oy49PbJLI6+OcnfcGTzyrCX1AuUe8DxmUq5dcpFy
D+xyvadbVdtIuSeMdUsajhRfotwT1vmJIfYtP1O+DsrVOxb5pZKl65A1YWux
5XF2vxfyEu9V9ASw+73wdNv4pWvL2P3eyI27m77vFZ2XeuM/rxt8Oi6y3AfF
VTv1zYJpHz4oV1+g48lnez5402nCy00hy3xg56LK65fSeY4vZieqWH7Yyvq+
0BId9i91Zt/HF/UWnbEaqZep7wv30jRbWw0Z9f0wuPzkGWNrMvzwWF5coAgl
S/1wyPV9cWElWeaHj5n9Rp23Wd8fOi9S8yX3Wd8fBZJTcqtHrO+PD7NtOM9H
WN8fvArTfT0JrB+AQcOD83xzWD8AWwx0Vu/pZv0AQGeyTmIf6wdAffK0+3d/
ZX0u7ud213fFNVGfi10RqSUecrKUC4t47zBLq6vU50IvccHsxhlkTiBS0upU
R+LICEQFZ2a7RPsa9QMBu2J9t2Vk2dj5poTE22pkThB2H6/JOMgjIwguPmZt
L/ayfhDah0/kzj3E+kHwzhjSXvmE9XmYcKCvK216M/V5qDG1vvF0OVnKQ6Rs
/If8cWQZD0aKvun5c8mcYDx79in/GDOCUbFCre2wJusHg6s95UT4bNYPRvHa
nklDhawfAseNA9X9LawfAvmtgpOL+1qoHwLX9I82/XFkWQhc0kT8nSfInFBc
eKCVMOHkdeqH4icr/f+e022lfigOXehVd3Uky0JR8/zlpYWryJwwTDy5ff6t
K79QP2zs/2biRJmmnPphyPMz6UpOJcvCMKA0EZnrtlE/HPMOD84LaqYc4Uh6
VpH1rybKpeEIGxhRqj0iy8IRm59kJA24Qf0IzBiIG7rygnJEQD321aafSiiX
RiDB2e39gTqyLAIPSpdUFmew/nqULjjVopfF+usxOvKV+KA766+HSUMV/885
rL8eX4bHaRQo2fPz0fpH4pqc8ZQb8uER77h9qsFNuo+P/qTRc5XnyXw+nnB/
KZy0uJ3u52OGLGvp2d3kEj4UfRYruW5kGR+FSqXp+e/ICj72OvG13glu0X4k
bg8a6r8dJhtG4vGdW8bzUztoPxI1A26FjYLbtB8Jl9ykWcpnZGkk0rpHzF9W
kUsi8WPV710ux8iySBg72+zyarpD+2P3ebrea5/USftR2K688Z1GB9kwCh28
SWLrnC7aj4KRhtbC+Fm/0n4UpmxLXpAZTpZG4UR1dXaKyl3aj0LMpq9VnGLJ
sigUVXr9JUklK6IQWzm6unNhN+1HozmzxvRdINkwGl8m2iY3V5ERjdKhTHFh
P5kfDaFXrla4cw/tR2NnYvbMuhRySTS4WfVTt6r10n40qhy8JDsEZEU09lo1
R6c0kDkCcCsqzMpt79G+AIqn79Pc08kQYMWjhTXWHWS+AHqBvJacLrJUgO5v
+IcFL8klAlS3lVpqHSPLBJA0qnms1+yjfQGOlnkdTZtC5sSgXNha555ANoyB
mf5RvfqDZIzl15p3NK65T/sxePi4f5WWhHJpDHQMXD9dlZFLYlDrOVnea0bn
ZTG4EajI/u1vsiIG5rMuR/+49AHtC5E0RdLH0SQbCpFxeqP6IjsyhIhtHUgf
5vxG+0I4uRm9GnEgS4VQG71sdSqNXCLEhubNT4M1HtK+EMdMXm9zCiQrhMBu
v/zJdmSOCNMy59T90UA2FGG43IA3oZYMESK9fctGW8l8EXzrnizRyydLRQj4
cyq3rJJcIoLNipBlvafYvgj8iMUP3grYvggGGXkF27ayfTFuTc4tTw1l+2Jk
mmtLzrqwfTGe675UU7Ln5YthLBm4bNzM9sX4tD/n8M99bF+MHZHh899GPKJ9
MW4OPzTVeUxWiHGu8rruxU1kzgZ4Jb9oP1D9yOEf8hrlOA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxF0H8s1HEcx/Hb1SZFCKUiNM6Pi4mS6Hg5F3d+3ZWsxBSy4jLSzGrRDWv5
9YdWKllEpJ/yo0mS32dxS1k/rpRKND+qFTVJrJr3R9/tu+8ee76/n30+H/PI
+O3RXA6HI/r7/vuyR/dFaYJgcWfTnL56ePfxuaNLmDl4O+nEk2kzL0LS60PZ
F+a7Lvgd9dEGS5kNsHMyuDNjft4I/R+GG6YWMBtjdNCqIfe3kmyGHO0nqhNq
5rW4Gtu9l3uZ2QIxxeKHjueYeRA9f2+qzGC2RuajrDh+ErMthPy4vv0S5nXQ
KF+l4vd3kO1hHPMld+gnswPs/GbD008yr8e7iO9vutyZHSFPU1rKU9rJTjDt
zR4JHWsjb0Da0yaeOoR5I34flYVU3WR2Ruayswdscpg3ISglXMO2h9kFZyMT
zx+rbiVvhnXYiyg9TWZXtKh3v3R2aCG7wVQYriH3bCZvwcIme0NeZSNZgFf5
s9+8De6R3REs517fPsTsgbtHBpaKJ++TATf3NzV2m+rmrABWqrakdpVVU/dE
UUfw4+LBGuqesDl45uLPAdaFOCxSO0U+uEVdCPMVhvnS0CrqXjgYP5neLSAr
vJC4uiIsb+Y2dRGUoYLb0pib1EUo0Go07ZWz9bciK3u6z9Gf5hVbcWq1/nRh
xDXq3mg/3pYzvvwGdW9I6scmii1Y98FEwpSOntcV6j4IiDIsqB2voC7GL82q
FF3jcupi6JekWmbtu05dgtagH/xxdSl1CdpbKkLMkmk9ji8K9DdarzS5Q90X
w84muxKNaqn74bTK+EN2Frs/P3i6SItKeZXU/dEjSNDWukT7Vfjj8zbhp1IX
ug9OAKzNO2N7y1gPwMQa1xIzXhn1QBTaCZ7pfCQrAtFTm+mmp83+l+JZX12U
bw07nxTK6Jn7Dsl0Ho4Mqoy8xJDqkjlDhugwqz0j3AKal6FueMfjdf75c27+
7z8TsVap
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91Hs41PkeB/CpU8g61UmbLqpJkSSsQ0nFOzQUyf0ybjMMRh1SUtJtFq2S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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdkQdQE1Ych1NrqxarFhUXRapeRFQUERQE+SFDiOwVIEDCEqWKWIFYoRAZ
Yg8ktIogsikIFClhFEFlRVGrgBYi50At5wDX4QQFte3l/9o7c5fLffe97/3f
e/nGf4dz0DgOh5P0z/ffX/aZ1lsUZvLFuWYlDZmGZr425/3HHAgGBjRnqTCe
iKdjDfe5kxhPQ12OfbRopJ14BnJ6c2+ef814NsTcOk1uD2N1FIhq5/m1MtbE
PZszcj0Z4wUY6B1+lbOb8SIc5t40sY5izEVwbMxzfQ/GWqh+baPYZsJYGysG
QjpVFzNehu6a7dB/dZZYBzGX35y13Mt4JayelsnvGzPWBV6EXQncc4Z4FQru
vZje7sZYDwN7Hlj1+MuJVyNWpqgznc1YH6qTLY9e9GVsgD7enYXqF9qI1yA8
PSXKKYHxWtxO75d+K2NsiFUT2i0r/Rgb4R3/otWQrJV4HbIKrYMzucwbo+nC
X17yBuZNcOJadZeGFuP1cKkuKgtyYWyKsqqXmTHJjIGqgcr6+ndNSpYAq28c
su7Ycpq8GQpsZT3Cww3kzRCvx9VOvEzM2QC7GT3ZvpdPkN8A3pQDt8V2zJtj
zW/rV8rGnyJvjpK3acNODTSPY4Ejuy51fyKmeRILPJNeu1KpwXpL3P3Qb2zI
Y/tbYpHaiUSLXbXkrfB4KHKfXFFD3gqftoc0fG9WTX4jHj3WUbPRIpZsRFDq
9cfNmsxb48HOW/xtrZXkrTGl8qqF3oYq8jZIP6lufkdI8yQ2KJZkFGvfZD0P
yTfUhjqPlZPnoftup+a5shLym9Ay63joxjf55DehZPmImnxnLnlb+B16UReQ
fIi8LdrqIwWj+Unk7dDU2xHmPvwTeTsIH+Y9s3feRd4eSyXRXUu2x5O3R1fN
gqh13P3kHaAwmylMyUgl74AmFc3nBhkR5B2R1ZQ3sW95sJLhCB5f30hDlkjr
HfFn0JzhoNQ4Jbc4otzmpFTSl029EyIr43Zv16X7wQmy5Ofb9lw6Sr0T4mSl
ARcasqh3gukuRf98T9Y7Q2iZuNUovIB6Z3gdfyIZ4edR74y+iLFf1S2KqHdG
QIbircoIMccF5SE/tKZYZVLvgjFvsa5Ok5R6F+yrai3cMSGKehdUVEik8x44
mSp7V8Tv9u/IVqQqGa6IfejzLsftRyVLXDE698v7YVPjlNziis/0zhjuXSKh
3g1d0jFn8eRw6t1Qd+1Sa5JZIPVucGgySXvov5nmu2FQNCla66Annd8dipm6
tYOGfnR+dyzZIlTR6Qmn87sjR877fURB3OKOD0nu+9e0BdB8Pmx9K975CyJo
Ph87RgMH6lKjaD4f78Ov12ROE9P5+ejO81yv2EL34Xhgbv3XsyvEdB94YPMH
9UkTEhOo94DA0n3xwqF91Hsgy3l5t4GBP/WeGM61a6sVhFLviZA7FS6jZWnU
e+JWoK2bfugB6j1xqbEz51FQPPVeMAlujJF30Xnghbhf2hqnDtP/IfGCoqCh
O7z9CPVeKBZyQ+sjaX+OAHPUDPJymw9TL0BcdJu88RitlwgwTlRw8X1COvUC
FDkYX416Rus53mgOnPp5zP6D1HsjIa5N2i4mL/FGx9SQoSHtAuq9Ybjz7Vbp
9ErqffBdydHi2J8LqfeBeMradfcHs6n3wauVESl5FfnU+6BrqXlp4Thiji/6
jYRPRl7mUu+L5ek16qlb86j3hVbCYF9HNHGLL9piZhlasPUcIc5bj0+bL86h
XohTC8pP35tIXiKEwVnV91ZhbL4QqhpflfRcp/04Ioz0+PWvWEbvoynCHynz
astKifERi0SwL7050jXK3leEZUWma2fx6H3yP+KW//lvYNS5aA==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1kAk41fkeh4+2SUWmLKno6Da0TMhSaeGjCIXIWlkOznGOq9KE9jhOWjyu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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10Ak4lfkeB/C3CSktaFE6t3FbKYzSuEL55qBQx37snM05pzKSm0LRuWWk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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91As0FPgeB/BZtW2plrX02ISK8tjNq6KEr5S3IjLMhHmZmZJIT3rNJUI3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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10X8s1HEcx/GvH3+UqU6LWT+2I4lYO5TCHa87DufcqZtjy8qy+REpGRkx
hh2rxB/arPmx1v3hx8ro/OrcIXfq5A/lD0Vb1CLKFJakUc3n/d2+++6x596f
z+f7/bokXVclW3McJ/53/3/SxZt8lCWyezGwo+8hM23VR5T2ZA4ua5alBRvy
LqRL89o1myPMPHTx45ezP5EPoGjZquDqB7IzbP+sJU+9JB/G7ukZid5E5mNf
ZVPLxadkVxzSNMSZK8huGMmTCzwvk92Rs1LCy9owM3ugeq7PdslIPoG0euOV
njKyNwQVN4yaUvJJuNZP5w+LyQIIpCKeKo3sA4d8m6LQg2RfTEWlp8wPmZj9
UC5WjpkfDjOfAs/S5qT1J5/Gilfgk7FYsj/0GRn8uvHnzGfwtTA1sPAm+SxM
kw6y0beDzAGY82spn68lB0Ke6SXqfE8OglqymifIMzILsRA0UqpeNzCLELlu
0N5NJAdj/JLdvJf6GXMIRlMW3WZbycDRaov3N6u+HZcAP8o7FHt0vayLsRnj
mF5V08O6GJ4KXU7WdjfrEtQtfXl83pm6BEm5xRk6juZDcSFzPanGg3oohF6V
ZR1CZi4MhldDK9bHqIch5sEtH3MfdSlU9X7OahWdT4qI2+0NAZHMXDh+b8bv
dZygHg6ZVtQfkED7R2DGkPpL48DetyQC+jX7lrAmmo9E65vcWNMdmo/E1s+P
PZrX1GW4Vly2XduoZ12GOX/j56Dmftaj4Fbr6Tt4j33vkiiEuzTPGodpXg4u
bkucuNXFuhxWsxud9vk61qMRUshX64po/2g4Se9PlO2n/6tAd/CUoCN6gHUF
ChctqyEW2l8JnjQ8oVFL6ytR9U621NtL68dA6l5dqvehHgOJnfJ4dgEzdw5C
1v8CxxVO/A==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxFzntIk1EYx/FXTbYW5IUpSkWbWpmomWab5uXnbTq3ypQwcq0QbwiRVGaF
yFjmTGikuEJLxVWIiWmaoZg4rXS2PzIlJaREwzSaZV6IlOxC56EXDi8fvuc8
54jTzyRn2nIcF/Zn/f3T5zh+Ny9cMNj7TwuREW9yu+02kTlkVcZ9D+XIfGTw
W05Uzg0wO0K7yM+3myILMbea4VM9QXbDuwjZ/IVh8lZYXb+NT5rIIqik5o8d
dWQPCJwGjMZCshe8Lb1BXVryTlwOPmb1SyV7o2DkR6z7LrIPNgp1QwJXsi/O
LaxtGNO/YPZH1WR7kY2IHABxh+Hm0iHyXkhXxbxrE8+ZA3HYYdqlRE8OQnmS
d5OdJ3kfPMUhn1rrnzEHQ32yusewRt4PcwqvpdaN9ksQcH69wUFClkKo8jvt
uYUcAr59WbKljRyKQafPj5ZN5AOY87COCZrJYSguVg03TdN94dCs8K7f0vYz
R8D90mBq4qs+5kgohrbVTc+SgS/bVdZQep8GMOkc17ILaH4UHiRtblXbsHma
KCRnmXJqJL2sRyPFcrz/yvJT1qPxYWxU5Hv0CesxSC+T5Lsf6WA9Bl3Ftq5F
SmYuFr61Xrqpl49Zj8VoRdqUizMzF4fFvqyu+5J21uMgbe6s/GWmLoP6NRcc
WMHu08iwqkhLWZ+l+fGwl5fqe3h0Ph7Z2oyHjVwb6wk4ZRiZ3uPfzHoCyhFp
6VYbWZfjp1/h2x2d9azLUauuyi3NvM16ImbM81e/5tWwnog+8b2R93JmToHO
JFGFXtnIugJNhqV8YaaOdSWcjSU5K+U3WFdiZXeD7GwIM3cQF2c0ZcbcO6z/
92+slS/y
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0V1I01EYx/F/26hpIyySnI3UrNHGWi2zzGb+NjdXREq6iwqMGsxRQQ61
EoYxFJeFehHuYisHrmwmhq1VG0pNs1ZdOIqEZZBGr0ZaJrMXvSij83TRgcPh
w/d5rk6GqaLEzOM4Lmv+/nnpJMUuWfMSH4b/airfuDu97vtiMgedX+2L8chC
hK5U8WOzEeYknFb5Vi2dIi+H8eXnziXPyClY2zx9ZlGELEHIkRyf9JPTwbcc
2eBsIK9G83AtxvaT1yAzYbbILCNL8aj0QI4r/oB5HSQjnxqCIbIc7SOdM+5y
sgJp5euDT1aQldhrn+zRCMgbYXyXkVvx6z6zCrWDRxttEfImBL4tVMYyyVkY
fX+x8cdT8maIpHOn9pwYZM5G6vBZcXEqeQtcUUE4XnOPeSviDnWDvXWAOQfJ
IlOTppu8Ddecda88QnIu1CVdVquU9rcjUibvvtpMViMgS7R4Wmg+D0rb6OOB
nn7mHRj66frS7yHnY0LTcUMuCjMDb2SxbHELsx3QH+T5otE7rGtQdayGJzzX
x7oGXJ/87swHZk4LxUfvc+9X6lpU15u9bxN6WS8Axl+kHfaHWC+AZtwwzV8W
ZF2H435H71jZLdZ1MCkETTdtAdb1UK2sb3Pzr7Ouh3Gf9tDY6y7WCxFNCc8Z
Bcz2wvn/Ka4UV3awbkDRhQGHZOgy6wa0OSdEpQvaWd+J2+ctJ1ur3az/Z27X
P/8GcEICcw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90H1IU1EYx/GxBmol+RbZknxlasVSm9maut90Tp3OqBUJvqVpvhAqgs1E
4jaK3B+ioBNEZFaSYYWZ0sJ0UyuLRpElqaO0FCQUJaIapmmFz+nA5fDheznn
udc/r+xEAZ/H48n+Pv92ttwmbpbHbH1u3dRXeWjzksyynZmHSWnEedN/O6Oy
1VTkcGJ2Q4NWqqpdGSV7Qd/V8dJ1itkb7lWlVW02Zh94zcrsBQPMfhjPmsse
KmIOQIrPt6UKMAdhfmXWZXr1GVmE0bNrtzM/ModgInujP7+OeR9em1XGNjnz
AQjeS0oy3j4li7GeJXLbNcYcBu/dArVdzhwO1aXHhSUJzBFYMBlr5uxPyIfw
M1Q33e7CLEFX77WSdR1zJJznbdcHrcyHcXpA0dGtGyFHQWMpqNl2jPkIIms7
PMLvMktxcHl+r3FxmHwU6U1zeQEqZhlif5+zdUmGyNEI7DT8cAQxx6BJmLbB
T2WOhdTo4d4XbSHLUTH5S1ZfyDoQVhcsdNVbN80BXLwyR28g8xQQ81cye97R
/ZwCLY0tUW9sbN44iBSDOUkqOo+Lg3vwfXPrngHq8SifsvvNCOl/cPHwvVin
FY6w71Ei5IxvgLaana9EVqkyWtRnpp6A7sZPC7HqR9QTEKfzk+8wPKCugmeP
l0Pj309dhVPVDp1VTOYlYrRf37DzM73PJWJYW19+YfUh9SSkdXJjevMt6kng
Ly/ekxS3Uk/G2oeMxJPfm6knw+NGpDg59w51NYpFpvwyjsypsUWTe/nql27q
KajMEEwFjfdRT4GT/ytLYHov9VTMzhiMk55s/lRwjWMvXCIGqWuwv0lwPPzK
sPUPt6gmXg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1kws01Hkfh0chFKbohCSWIumColXxqdxyi0Fug2GMmaJ0kcqlHaXeLmhb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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQMC1xcX2HId3w/hfbBv7Y9p1WaH8RkcItj0hXNY
YXwOhydm+QlhjDC+gIPU438y6f+OQfkiDl+fq08tfwDjSzgUhCrLyt+E8WUc
rJ9/VBI4CeMrOKQy5Kh+3QjjKzkIme97cn8WjK/i0G6/cFZLGYyv5vCj6viD
Cb4wvoYDY+nV7w1qML6Wg81h5XcCmjC+jsN6ts5VZVePQvl6DtcCjy4SK4Hx
DRy8tf9cf1MH4xs6rH70xHtRD4xv5MC3yvuXQzGMb+ygtFVohWM1jG/icHSG
u2NLK4xv6vD82aw3D5xgfDOHRTPX61dtOQLlmzt8dn6uqGEG41s4TD09ke/J
wsNQvqXD8c+v9vq0wvhWDo/9Z1YeU4HxrR0eKN16+tHhEJRv4/C0MJnd8PFB
KN/W4RfDke69DDB5O4ep4ZG7Ov/D5O0dWOa6B/+vg8k7OChpZ26zKIPyGxwc
6jJmGN/tPgCVd3TY7e+pw6kI1d/g6KCz7HvpUnWYeU4Or77HnRScBJN3cuCz
iu0TiYWZ7+yg5L/pQdNNmLyzQ+mqe13KM2Hx4+JQ3n/Q8xYHND01uDgkdf86
lbMcJu/q4PVLmHOVBzS8GtD4DG4O56WW+57UhOlH8AFdDuga
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10QtUzHkfBvC/tkJ4CRsWmULIvNJ2p8tTEamY7veamWoml3RxWdGbiVZW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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAmIQDQMC1xcX2HId3w/hfbBf8vpS3hJeGJ/BIV1lxoY+
HhifwyE6NsF1BiuML+CgeTLyZi4TjC/isNFW4KDNt2NQvoSDxe49pW43YHwZ
B/bz1yamb4PxFRzOt/hf65wA4ys5OEdP3y+dB+OrOJRFqfDMUYDx1RwMRCfa
MgvC+BoOBa+mcWzjhfG1HL732nZfYITxdRw+T/f7mbP7KJSv5/D2hu38vQ0w
voFD56rDj7nDYHxDhy07+dl+icP4Rg6qf13SNnnA+MYOufMy82SjYHwTh1Xv
/esU/8H4pg4H5nyuu/QfxjdzyDr10CMhEMY3B8pzT2+YegTKt3Co7QqNXdN8
GMq3dMheIHJc/8QhKN/K4aJvqEC2KUze2oGxd4Xk5hcweRsHV4lbPZsiYXxb
h76ybx7bfh+E8u0c9B7PO79gN4xv76Apu0TMwRLGd3B4uyfx0OfZUP0NDg49
N7ViTGRg5jk6MNjxJN15CpN3dLhecIy74h7MPU4OBgUMeUu/w+SdHM797No6
Sx9mvrNDQaqydI7RTqi8s8MiiZMO1m+hfAYXB32Hd+/KHsPkEXwAZGrSUw==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90HlIk3Ecx/GH0jk8SObAAyNTMVtlqx3Zsfnx1iGVEeXyD1mHFVGWI1sa
9gRCaGl00IUngzITpfKY6XRrTiudQYh2sNSlYlayEvqjogt/3x54eHjxfp7P
w/Ms35u348AijuOUf89/Vzr8R43HVd79PQtyx4Xr35we8iNzKE82nDMLyEIE
+XI3PL72MfvDkRW6TOImi5GZNDPg/YkchP6oFdsCn5JDUfRL93NXKzkM1rlT
JxuM5HBUHrpwN6KaHIkMc2dFfA45CnOW4pLyCHI0RAp58cPPdmYJ2sRSodcE
eTVEDyzB7+3kGKyJ7NIfbiBLsSfUMSk6S16H3Cuzx5qDyevh15C1e3ssWYaR
6MYiTUsvsxzcB/XgxFGyApV8r75Eb2NWotvoFOkWkzdAoux47nn1CXMsrPom
q2cfeSP4AN3w+LCVeROGJN+86sOob4brh+rZxXzqW1C602Bc+cXCrMLH5stj
50vMzGr4akdr9mm6mOPQNCjIuz9tYgZu3k6ZzX3VtmAekAb8nulqbGc9HqVC
d+21kVbW43HnnsBTcamF9QQURBlkHja2xycgZCxwqWGM9hMx75C5q3Rsj0+E
j8wU1/6aehJqROMZR+rp+SSszXeIBS86WE+GrG9rx0DtY9aTEWKxy+vkzFwK
VtVVn6n+zr6PT8GUWvlOup/2U9GbnSZ9O93Jeiomq6Zybv3/P2mYt2nzKhT0
/jQoM5fYC8vY/Vw6tM0JhamubtbT4YwpyDYdZOY0ULtOPJJMsz1eA58yp/r6
S1PPH6mwEic=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zQtYzPkex/FxOUWFog0dbIiDVuiGqD50ldL9qsvcJ0WkInariU0iqtPR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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10QlYzPkfB/BBEp5aD61iHZGj5CpH6dC7lO5rmu7DNGc5CrFbSibnWiTs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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdkQlM02cYhwsbKCACDgeeqMjhNBxyeFDKT67KpdCTtqgRFV1QYWRSB3VW
mVcUxCDIIZcynETZJrC5atYqdEUX8WTWrpuATAK4iBuoIxs7wvuZjCZN8+T5
nv/7/d/OT80QbLHkcDi7/v3+98s+jg/PZobaGrTjNBT23FRyYMMb5mCvLq1k
F4fxZLz0qtptOfwdsSNOLZjm6/mUsTP+suKuva9l7AqzfsXLzS2MZ2NbTrDG
soDxPKTXjqQ9zWS8ADW2XQO5GxkvRG6zvLWYy9gTd2t7BuDC2BtXlQ0RN9r1
xO/B4vbxXxxPM14C1/b585wDGPvg3IChxv4txn4IVY3e3mpoI/ZHcOe+J6rt
jJdiafeM7n4LxgGoUwwpHzsyDoTVHpWKX9hKHASXyEn1G29eJw6Gw+mywcoF
jJfh7sEoi2NzrxEvh03P1LZv9DriFSgI4ZrLn2uJV2JO4ymxnYL5ELgtuxQc
s5ExFw2xZ0KyNex5oeAvP9qXXs+Yh+mxLtF8HTsfBkO7RraonD0fMFQt1bg9
pvNqIO7w48ILyaxfhTvefkuuCuj+6lUIlBrHagaYD4dFyinTYeG35MNRKdCk
5u/XkI+AWX4moOp6M/kIeDS19Gv7W8hHovp10Y5mKfORuPbCu2NJeRP5KNxq
+/lJ29eXyEfhwZCq1PXdL8lHI/X9LzysHxCro9GbJXPIPs88Hxm8zsCi7s/J
8xG6bmjE+rNG8qvRcWen27mBc+RXw3P68N2c8/XkY2C9w9o9+VUN+Rh8pfu+
5GpnFflY1FrFHFGVMh8L7k+L96dwy8jHod2muj0uv5p8HDD3hIdvVxH5eMz+
OMtl5gjr48GXFLXOaioln4Cbet/cENtC8gnYMDlqMM8vi/waRG0pT8k2isPG
/RoUXHm9yzlNRn4tbnkLMniX+OTX4n6h9t5FvYB8Il6P3HPSL946zkjEZdsO
/yqfD+l8Ihza84R9FXnjrEvEToc1tVNWEnOS0HDZ1NaccGickYSBoBkSn1Ji
dRIeNilt9tqnUJ8E97QVsfEmCfUCTGv9U7PQP4d6Adq6zE4H7Oi8WgDNoCLt
5ii9v06A3bbHw4O92H6EeObs61orKqH7C6F5VD8aMOUI7UuIRjfZI29vLvVC
XD/UF3ZjbBPNF0GrLI7r+GA3zReBZzPL+DaP3V8Ee8HvvCbVNrq/CGOuPib3
XgXNF+NKpXx40oxMmi+GafVtravXJzRfjNMIXN8VWUDzxVj/g3KfVr+PegmC
zJXXJJo91Eswvzf0Iw/PXOolODnKlypE9H/rJMg1FhyUPqXnc6QIPyhMn2o4
QL0UGdOMWceUx6mX4kyDWZxvpn3opJj5W6nhjyd51CfjhUSdqEk4TH0y/t5+
VBG1aTP1yZC7lMhyegvp/ZOhqb9wlheST/uTIWt7Raxd9UnanwyZzzJMOaoT
tD8ZWh6kZn7qpaZehgab6T3FC8uol2NR3bCyzFhLvRzvONUFzlHVUS/Hr9YR
xaIfz1I/gTmK/zMmsFoBrgPvYnQV6yd4TsqEPgWvghyM+asqqJ/gdROYs+4N
/wMBn0RO
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91Xk0lfseBvB9VUeUBkdp3VREoVSX0iDyhExFxm3a7JmtOuFQhkq7kG7C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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90mtIk1Ecx/EHJVCpXBlMmYlaVKx5KV1t6ubP6dy8NhcWM5hO84VUKKNw
KOlo4As1Jexq1ChfVGgGXlpB6nTN8P5CLXHQCsLAZVh5aQZ2ofP3gcPDh+9z
Dodznojicm2pD8dx0r/j35se3ru2ClnAm4H/Wk7OV1+LGvMnc5ja/cLq3Op+
4If03o78PczMgyWk07S+Rt6DZvckf9RDDkb3Xdug3xw5FKYbS3n1E+RwSMef
z+e3kyPRWtKVUtVI3g/fMu5S0HnyAXhNeV/TzpAPoVrkjfqlJAsxp+uoLX7r
ZBbBeWqq8HM1ORoXPyUqd6y8Zo7FYUvPpN1GPoKmoetFml7yUdx0aJ9c0ZLj
8Kgh1CiMJMcjV7g4UtLiYBbjY7k118eXfAw/ZvwqI6aHmI9DPHAr7Nlj6hJk
xChOLixRl8KiXg5r5MgJsG3TtRZaB5kTsf20osIYS07Ct7qqhEB/sgwNM5sx
4g6yHIrvMr0oi9ZLxqu6sQ/JK9SBzqaInTwvsxl4Kl9zhbVRT4HOUNaTo6Ke
gmaJx3lVQl2BOMtGnEBBXYH6osvLpvt21lOxYNw42x9EPRXvLa7FUcMA62nQ
yZ3B40nU07D+s68gPoe6EgGdJ/YJ5vtZV8JwZ2Lv1CYzlw7zsBkGyUvW01Eg
FIY7uD7WVbhn1ZcVLtJ8FS54NNNdXpqvxi7Xw02HgO3XrIY8aGQ1+wHtPwNc
9GzNQTv1DLToJ1dlW/ebCb7aNHuunZ2vORM1pdUqp57OOwsaHlfp/sK+N2dB
5+oOdNfS/5i95T+9rSKz
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10wlUjPsfBvARRcjflpJiypYsiRA1eqJFpb1pX6aZaaaOU+lKJMvcZJSr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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tI01EYx/E/c0IqlJJ5YRomljnNnKbldPOnbl6mZmyklFgk2UUor2QS
shW9WBkWTBR8odQw5iYTEZHUnLcZZVhooNBNLSUwVvRuU+hCz9OLDhwOH76c
83D2VVRrK0WCIKT+3n9OXv5L5hqF7zPHX33PCHSMuUt92AJGnV+rSgT2Dph8
03KuumfJ/piL2q5td7EDUeO1/651iR2C5pUNg+YFOwwXjyv0omF2BHxE06bR
QXYk1LfuSOc62VHwPP6SnFLPPoDDJz54r5SxD8IaYBSfzWRL0dZabh5adZLj
0NinrQraZMej/n1ReO0COwH9OrNgucKWQbZLoouQsxMhn0qSfHszQ06Czph/
o8XNPoLuLp3fmpOdjNONdUqZgu+n4MLMpQ7LAPej+BxU6ba+myYfw2b4KVXv
TnYqhPOD/TGVbDlEWbNboa1T5DT0bEycafBMktMxp956MGnkroAroKjNsc5W
4v6irGa3lJ2Bh6GFnkOp/D4wEBcbnFBO7xmAVUOV3rt+gnom3vaMmOtekw2Z
EKdL9sSbnlLPQsX25fYn10epZ2Gko6ksMpEsZKNpbT5mQTNMPRvj2nPaeOkY
dRW6hHBXUuk4dRWCf1r9X0bzfTXEyoYJPznNM6hxrzpt5uPzEeo56LdcG/ON
5Z6DveZi80k9/zcXLSs3JXHr9F9DLnqHLAnT0TRPyIO+o9M4r3JQz4NTXOyx
FQxRz8cnu13kZeujno+CZXtvt22QugZhi4GukmE7dQ3cLWE/cm2PqBfg1W3l
bMhyM/X/LBT+8y/KWhxa
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBWIQDQMC1xcX2HId3w/hfbDfq89VwM4D4zM4/Ijb+xTB
53BQecp0RYkbxhdwkOu5N+crK4wv4nDO8rqaGx+ML+EwdQPL7edweRkHIX3L
0g8Pj0H5Cg5FXM8fGN+C8ZUcmLTy0ladhfFVHIoyFC0T9sL4ag6dPvP6Detg
fA2HgOKf068Uw/haDktsa5avFoLxdRwyzyt8DJh/FMrXc7hdnMxZ0gXjGzh8
qDvX2lgI4xs6tDG/6N7pAuMbObybdOjI9R1HoHxjh8NNGVUsVTC+icOkY+s8
ZG8fhvJNHQTWrJr28yCMb+ZwuXDX5fd5ML65w2PjT69easL4Fg4LZP5emBt1
CMq3dHCfPHtf852DUL6Vw4T6SteFHjC+tcPX8mbjwOUwvo3DkdSyygtpMP22
DvsypvvmJcD4dg4PnrbUG6fA7LN32Htv8c+MzTB5BwdHe8V9zf5Q+QYHh1TX
SsVVZTD/OzrsPbhn37okaHg2ODqo39Barc0Gi08nhwNh3w+lboeqb3ByuFF0
8OA7SVj4OzsUleZvjLsFk3d2uN5QL2tXBrPfxSFqn/6XyrZdUHkXh+97254f
mQcLX1dUfgMan8HNYV5LxJHmGzB5N4fIf61Fbf9h/nV3mN+hx5pvAvOfu0OY
6dEDki9h8h4OTCLra4+sgcl7OHxe9NHFTxgWvp4OUdP3z+Y/B+U3oPEZvOB8
AOdsF4M=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90mtIU3EYx/GZlFLhJTUiReYVMSdWXudlP928bM5JJgqKvVA0JqXTlKgX
tb2wtMwVpZlFkgqKonidlsxpTQVNGyjLAkmdIaK5wDTsZob/pwOHw4fv/zk8
HI5bdmFK7gEOhxO1d/970mX3vlEReXhct6+vAq6l5Fa5DZmD1JIdmed/W2NC
ke8j3RljtoNgzt715ibZEReqMxUzc+QT+GnjZV4YJrvgnMjhWUIVmYsDfF6d
sIbsDknBdGvuFbInzjdrt1eTyN7IqVSEjDuSfaA2ts5K1kaZfWEOmqwqMpL9
wGs+WZVlIPtj0rk/WnObHACTpWpCX08+jcfz8kxuKPkMiqZjxmptyGfR02lt
XfdBzxyI0abAlIoWchAqV0pKV9LIwTgWhgLj3GvmEJh9L997EPCGORSuZpWt
1pocBqHVssfCJzrPx3NZrpJvSw7HUPHHbZV4hDkCg0eCdpO55EgsBY205UjJ
UeBHzG8Uu9O8AI/KE37lKagDmcu1bqeGdftWAg93f0/FZmhZj4Yx2bD2LeIV
69EY+mPvfye9j/UYXHcuc1pZ72c9Bl8Omdrlhew8R4hg9Vvb+tIB1oVAzNaN
AouXrIvw+SqvMbGL3i/CgMZSKPIeZD0WosmKVK9Fdl4Zi26PIvUUh72PEwe5
R5v/JRPbRxmHg0uuLnKBhvV4WAlqV7UbvazH49oPQ4NLGu2fgE1eb/dUA80n
wNxoPO41S10Mi/BVv3XQ/mJ0NTlFynuoS+Bek3W3VEXzEnw3mMr0atovEQ59
4vh8CdtHmYisnqeB6Tqal+Lok/a8wRf0/aQwzVRUp+mpJ+39PFt+O5pu1pOw
+E4f1jLfyboMYqvsjkW0sy7Dcofz/YyLfbq//WM9Pg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90AlYjfkeB/A3gynMKMqSLUrWiFSWjr4tskT7vr5n7RRKlmJMOpZp0pUs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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzWtI01EYx/G/i6iMyihFypauspDwkjbL3PzN69QZNVNW+kK2yspCoaxe
tLnChEZYvlhRJplRIaVOp45l89K0QUWFWclaIYGMtZyztEJMKjwP0Q4cDh++
POcJU5bKD/A4jkv8c/++dALe3S4T+dt65uRNev9CcMK5mMzBqjY0OBeRF8Iz
EWjs8CMHYMlndczrySfMK5EUOXvhhp0cDMvp+wa+mRwC2Y/JcNtVciiEg4bs
XWVkARbw+xUFKvJ6qM4/DXaEkcNRMpshLvYMMG/CyymevaWeHIGPNs2rt4Xk
zcjLlVfs3UCOhE7oup7/qZ85Glmmbv/lGnIMzuT0jLWsI29B9EFFo7nKyhwL
mWOsnJdPjoP++0hviesx81ZUjDhCupRkIaQWXlPfUB9zPIIiKt+IH5G3weMq
qqwOoP+2Q7pGZz18hOYT8Oyht15S3cu8A+5Wb1SVmJwIQfuKazY9WQTzfpXp
io4sRo1EPSGb7mFOQqbHPR2v6WIGjtUWG0tKTXPWAmXateUwd7AugUXeeanp
C7NWgq/DCmfBuJH1ZEx13j0Vf5l6Mhp+BkWHudtZT0F3Ht85EcWsTUHtaGDC
6HGaT8XNk37j6oFW1lOxU380X5nLzKUhtPeb+2KNgfU0LL03JJ+/p4n1dIj8
9LsFG6mnY16gqbA7jpnLwIxStepsbDPrGag4JPLoBqlLsU907lbbcBvrUp+e
+b+1PuayfHoWVtuLmqcb2T4uG8ssvOe/8ID1bHwon6kT5dxhXeYz72Mux6f/
829c7jzz
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11Hk01HsfB/C5WpRSWiSVTIu4ikfh6nbDu2SiLGPLIMxiLCEt6LHViJS1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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90X1I00EYB/A1VzMJnGDiKprKihgx3c81NWf77kW3ckRI5bAgF0ml0sb8
I2gSv0WGE8H2R1k2iJIE8w+X4QtBTG2mxhZK5CxaVFBEG6ShVM5e6Z4OjuPD
9+547p7c446qOqFAIOD+zL8rDUm021mWNhn8pwVdV8w70ZJBFsDRaqnTrCOn
ojd5N2/y12NmCQ5dWbO0f5mciYzrW92Jd+Rs3Hwm7j8fI2/BtN8tejpFzsFw
Z8HCuRlyHqrmE7rxIFmOVXGo03eLvB1ySaWbqyXvQH0kyekOkBWo8D9JL91G
3olLQnlz8ecJZiUO5wXXprSTCyBTBRDOIavQpL46fee/OfSZTixK08iF8Ng4
SWdHiFmNysAPs/HhI+ZdsCxLbS+qyRoMZxaeft04zlwEe8qIUnF5jLkYDd71
dm1ilLkEjqyi5669lO+G8IhVlB+hvBSrA0mVexPdp8WFbO9K7jfKyxAODBlr
YuQ9eB9e7KrWk3VYco74uE9BZmDf1Ed/VMzMA0pFb8vRetqvR9tX69uDAVYP
r8fQ5mg8y0z1GTAbmr0t/cL28wbMN3tO/nxDuRH2jgEUi+i8EeqLpc6ZJqrf
hFcR0YpNwcybEJfFJKPdVF858tvO1jT2sP/kyzGX7tko01A/KvD9gSuaqmL9
5itwjPtwr7+E+m/Gy8Haa6caWL94M86MtfpcPfQ+CxLWOe2GyCDLLShvvxE3
mO4HfwOS9PuJ
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10QlIk2Ecx/FlhlJIRobzQKaImZrHPDOnP53nnDrywkAyS4u8Rck0TSlK
KqN5FnlAWqjpzGveV1MHKpaZCM2iRCpIY2CilkWG/+eFh5cP3+f/vPC8pvFp
ZxI0OByO7+76/2aP7mJ9uuCgcmRPaq8I7qbjvA4zBzPtHqLiw8zaMBAnqGYN
mXXROcdvrOUy6yGLo/87xpiZC64JX8tRl9kYGNnQlGgy81DSlWd5dWmSbIaK
Ox6BTS3M5tDr/5C8Ws9sgWcCH+uma8yWWGszeVeVx2wF7fyws7FSZhtktjhN
z59ntkXygvJi3y1me1zO9f9sLGR2QMbbp9qFRsx8SM0FU4pzzI7waQ6r4KUz
OyHvk/f6TOME2Rkx6XMLcU+YXeD5M0J5N4XZFRtqnYrWonGyG8YeSZXLsQry
KZTLpL3C16/I7uB1Gfdw68bIp2Hgl9S83jBK9tj9/k51ZOIQWYAr5TZWvRPM
nmjZemi0GDtM9sKE+0Anz4gZSBu1UFdnD+65EKhImYp0ru+n7g23nZsSyXQf
dW90GP4YCP3VTd0H8i+TZZUmcuo+cJIHdbt5tlMX4kD2xEm9bzLqQtyL6Ygv
tqX9HF9UWp9QfQ1n876Iuh2eGmzEzvfD0WNJqUN8cqEfauwW3zQqeqj74/2F
xeu8fjbvD5OFoSm5soN6AMYvKUrrzNl8AMx4puArWA/EqmoscZb/knogDG28
yloyyZwgyEqsPD4Wd1IPglq2BNXxNuoi2EtFf6KjnlMXoaCglhO50kg9GBqr
apVa0UQ9GPqHHq+Ixhuoi5GaI8jhxtVSF2PNjueQ8P0F9RDMb8qWs450UQ+B
1Xhg9HYNu79QmLuoXUXOrIeiqKpfOyaf3U8YbsT5dwk3yIVhmBmULLhp9VKX
oHRbvDW2nzokyP3rN5wkYv9bggwzw3jxvpE9j0pQ1nq/w/qBfOQf6/FYqg==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVzWtI03EUxvERVqvUbZYwdNiamaUWlqazsj3771oiuJKiiBGRdBHLYFKr
oUs0UXHLoHdmic5LghE6F242Q1MrimCaBS6JaohN0CgrK1bR+REdOBw+fF+c
dcfO7itYwuPx0n/vn8tGONFcnL1yxPtXc4o8k+OMUsDMw5WB3BiZkJmPcz0f
J/MjmYXgW15ci4hgXoOc509FnlXMYpTc5D+rmB4mS9AlmbnE+ZilsNgMaQst
zDK4iz+F11Qxr4ev8frqRhXzBnybMV3+LGDeiN6TkTHVCw/JSZAvG+ObXzOn
QNMUWFtoYN6Cmfu9bx8nMafC4jbbw2aHyFvxxSrmh5zM2zD41W8bO86chuRJ
cUu9kjkd2qlm08HZQfJ29LypLhuxM2cg4BAJlgYfkDNRGO7miZczyxHc/6E1
GMOcBUlbfnmia4C8A1LReGLcIvNO+GyOrHt+L3kXOMPeC8lT/eRsZJxIuc2V
95F3g5/geVla4CEr8H1F97jU7iYDP0vqwp74yVZAcORH/lEv60rIfAqP/nA3
dSVcqXUNZefvUufgip92DXZ0UOcQb2yyqyPaqaugdYpOHaokW1WQjhpjjeYG
6mq0e+4M51RVUFcjrrZ8gjd6lboGp/tDOmlnJXUNKued0e9f1VLXYi7IbY6K
qqeuReziAaDPRl2HtqFHRZtyrdR1yAvVTN+KNlPX44Y+MN/Vyf7rIS9KyHx3
sZT6nv9t/edfXMIC5Q==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zgs01HkfBvB/9TZJrdhcusl9FJVbVmzliSj3cic0xgyTkGoPr7Jvo8vb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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzXtI01EYxvGfQ828wMBJkpFlmRVTS9OV12dep27/TJSceFeYrZgXlAqE
kYvsIqmRoqJSCytFbZbkvE1dLS1DzOhCBiq0YlpaQhhEVvgegg68HD58D+fd
nauWF/A4jgv7M39vdvivdUXhjk+Mm1qN1KqShxq2MnPIFt6a0wmYHXCm/vhU
qTMzHzHryvVVe2YB1K5LVQ5WM9kdV4Rp3xVPmXfgxLfaNbtW5l0wLfAWzeeY
vWBJVxxISWXei4zkT/INEfM+uDTrQrSOzPvxatrVX/TiMfkg4u5OPJfOMAvh
sPiLv1HF7IfGsWfXlQHMh5AZZy7TxjAfhkH5tbyYYw6AX1NHRf61R+RAqDrX
3tX3MR+Be6Wi2niDOQhmN/H7kjfMweA3dazcO88sgkj/sriqhPkojOLarj4h
8zHE+/pP6VtN5BAU2czPnGpnDoXE07M8Wj9ODsPNlJ0jZSVj5HDkNMvUfi2j
5AgsyRfaLk4ayZFosTa8nfkxTAYuGEQepVWGTWsAn+WgpIqrZE6MCYtphec9
SF0MWUjo2fLOAepRGBVYbZXj/dSj4PuhcH51iMxF4/KeLz/TraxHo27St9cl
9yH1GPB4NpdSvR5Qj4FzxmyW9X4v9Vhs4U8Xbuvqph4Ln8a1As/uTupxsBdY
CrQROupx2FguVqtq7lCPx4ioJo0L7KIej88+GhUvp4e6BN7udrZ54nbqEgQb
ejI3Bm9TT4BbY2N1rYXeaxJwcjirn1dB/3GJ0MzlOcq20z5NIlpOZzt9HGT7
k5DnrSjR1XVQT8KsU75pxqOGuhQebeF6aa+WuvS/LkPlgtxGMtBM/Z9/A+Ry
LN8=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwlUjAsfx/G5CSHkUm8n5U4kbus1hRbp10rpat9T00wzU4lsRbKMCve9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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zws0FPgeB/CxlR50k1M2PacHShLrtRS+kiQ9GG+GGYOZKaVo5abUKFRL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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0V1Ik1Ecx/FnVjNDlmWxgVMqV5pLcdlM52y/6ZzaLEO9MHu5SIf5njhI
EN3TC4kgaUMpU3pb2crIUQMRZk2bOjDoopVCILGLwnmzq2oE64XOn+B54PDw
4XvO4XDO7nNtFeYojuM0f8bfP31xy/YL+VsWX/9TSOcxyj0928kc2oL1FTej
yZuxX3s2VvdrgTkOL3v6ArFB8g5cfXc9rPxIlmFMGzqzyUOWI3uv9U74CXkX
mlT+htHL5D24djqSfLeZrEDLV2m5xUzeh+/r5RlrEnIqnFv7B6RKchraRpai
nWLyAeReGpdIXswzZ0B5/ET1rU/kTEQmVAGvlaxC7bC72LZCPoh439v65FVy
FhxJ1Z/XKsmHkHbx/XnNNy+zGjXmmtWdEXI2TDnzy45Emn8Y8vDUhyg3OQeP
vizFTEvJueBmM7smrbReA6ljKqT9+YY5D0mBEunzDdS1sC88bLbHkPPR3iRz
ccdovyOoqioL19XSfejAt57c+NRCBhQiQ6LPwN6XB0StosWBJHpvPWTdea7o
bT7W9VhPzbLceEb7F2C0x7nWcI+ZL4BqvEVf2THHeiGG9KUJvZ3s/HwhOrO8
3SkmOq8BtnF+pGuQzecNaFT77TO2WdaLMFiX0uj6wcwXIX6lV5494WHdCFO6
K9g352bdCPFkv0LdQb0YCaceXLnvn2G9GEMp7Qm3h1+xXoKx9DTx4+A06wJz
pYIuMHdU0AXmTIIuMFcm6P/9G3g6Gm8=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzwtIU2EYxvGDdNXyOm2FSGrYUklbudJt+nh0NqcWmlmKGBkSiZDWogsa
R0oxCVGTSiaSSVpWYtmiFTpTMzMFW+kgZgSVhcwymVIt7ELfK9iBw+HH/3u/
l+ObfTglx4HjOPmf9++XHldzY77S8anxn6aiFF/2ugwsJ3MwD1/gJ371MS/D
XE3a7iuzZFeUpFhVJjtZhGfjydbPH8hiZGTd7dhgJXuj9uEIJnvIayG16fGi
ieyH8fvFGS2l5HW47mw7KckjB6DZbpQYdpIl6HNRzbyUkQMhHFkxY5GSgzF4
qLF6jeUJ80aIc9/kGo+TQ+Gcd0JVwpM3IX9Y9q4qmCxFuqPe414ReTOaeLsy
QEnegrEdlf4fZ3uZw5ATpH5uqyfL0D36qsXQQN4Kz6WlTmZf8jZor2rLHH72
MIcjdSK2oGj+vgh0r3YPyOZonxxdd9wsib3UFTja8rZt1pOshE5RkaZupfsi
ocWxkPM3yFHoDGzbk5zdzQwM779UbQplFoD1XzV+A6LHrEcjoYLvqpg2sh4N
L8P79BB7F+s8PIRd9T5e7LzAo8otrNwpiuZjUD1ya0nkaXZeiMHU6zmd6SzN
x6LBP7lWnEQ9FtPfXUTqc2wfp0I/bzuYOU77VRiTVrVXlnawHofC1sz21CHq
cbh4atGBmn6a346SBf0/c2r86N9385ud3Seo0axbOSpa1cl6PGImZ8xaOc3H
o+Ca4sGgO81r0FGsKA8Po//XoLDuctaIgXoCfILmhnzLHrGeAJNe88m4uJ31
xIUWEuHdG3FmWn6b9aT5/htbPjWG
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zntIk1EYx/E3xZAskiG6tGRaTvFSs8vU5fSn03mLZauJjArLnJmYlVLT
/nCtZrdF848QXKyWF5BK/1LZtL15S4MiVCJFEIskrxVGiiFZ0Xk88HL48OV5
zht0ulRd4MZxnPTv9++m4/2h/oJ80wD/X98T3ReVlmUvMgeTW0SeyIPsCb7H
abjkTvYG97Rcrl6f94Fx9U2Mdd1C9GX7+OvnXzFvR9az1rf2YbIIW7JVtqOD
5GA4D5+L9Kwm78K97PH58UyyGEk11oAqKTkMXue1+Uuh5HDsidY1zjT0M0di
6XJEo0NJ3o0dJ+aipn3IEtQt3RA2C8jR4EcbBtqv9zHvRX9OVKhQSd6HhbEF
fmKkl3k/0ucm34lzyQeQYPFt6zCTpZCf2ZoxOt3DHIOh4Q03Z0TUYyG7ErRc
2E09DsWatkPVyWQZgiqrHkzJupkPwmQL/xL36SVzPLZNxhZ4FFKXw8/he7ci
n5yAqauvKywSciL6BPplwUMyEP+rpL3IwvYZgK+DZ0tWORfrSXBKOrOkwS9Y
T4Kq6ZHt/WPqyZg8plc0H+9kPRniI7ka/j51BXb+HCkztvCsK2DXaC+O1VFP
wWxRjkvWS/tTsKLqWlEHd7GeipNhTTXKWmZDKiQtsxMrQ9SV+BwoKXRU0PtK
xG106YwhbB+XhjWptrLtm4P1NNzxC1D733Kyno7NH21mawGzIR0/7Iumklaa
z8DtcpU5xIvmM+DKHebyapi5TJQ9Ly7VrdH/Z+LJ72uB9ac6+D+f1hBY
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0HsslXEcx/GnlExqrs2aCsmQ5J6S43Mc93NOjkupZYhs0drpQmmJJ9OU
iSmxZpHIfbqR0EG51JhbmeuaS3PatCX9obSyar6/P5xne/bstfe+e777mkTJ
g2LWchwn/vf+/7JHe6TkrJvm29YVfXO/8zyi//JmZg63pAt7yzSYNRAxskOt
5U8XWRszU3NZqQvM+pBP9x4//J3ZEJEPRyds3zMbYeNE94XHY8zG0ByXfpco
mE0xNHTMQHqd2Qz2RqO9oWJmc6TiU0aOJbMFjrs6/Lyo7CRboVoeohE3y2yN
dVX5U0FpzDZwrU0ZHpIx28K8vKPaYQ2zHfIXT74wju8g20N/wF5x3o/ZAcuF
AXd1OGZHCDUibbmWdrITdNtydl27zewMk89qusk2zPswYa0XLtjK7ILY3A07
+xRvyPthsZxiFaVkPoCqKou+mPzXZFeMd7pYWAazfhB7C0zrLWtZd0P2vUJx
jy+zAEr3vNzpwVayO5oTsqZDOlvIQOJ+5ZLaUcWKeUC5TfOjZfAr6kJU/M7a
LXRqpi5E6UBhWfZyE3UPxOgdqY9OeUndA/3hl74Y5dVTFyFtJlP5eLmOuggB
c0Oz1RFPqHti0utrgmNPJXVPaO3ubhCEFVP3womQrkT1mDLqXqhp2SKer2Td
G1rtYyO4X0rdG71aCtc9CSXUfSDsCZ4XJZN5H/wx1NMZS3xE3RfvNiVdhUcF
dV/YlcfJJNU11P3QXhD2LF3C9vPDcJvS2XF9LXV/TIiCTZwc2X7+EHTJP9iH
PqAuho1ziqLfjP7Hi2GwdPP0QEkhdQmK6ooGdLvonrwEIufybMUg3ZOTqnQp
GtUXS5JOsf0O4UpxU0hsA92DVzEXAD153aRkKZO6ijnZakPFvAzx688t/hhM
WnGbDPz2vqfaar8EK/OBqw0V84FIuHGmfDZNSPMqnQtSmVcxH4Sk6D5ZRmN6
61/ymXw6
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zwk41fkex/H/Q1OGFGWquTQpslZ2KcrHEjklWY6sOYezadqLkdQcobRd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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tI01EYx/E/y4ma0VLDRhvZqilmaaY5zctv87JNXYlkUaRCoRFJmmgI
qf1JBI0UihWCiak4rHyhaeQtt7XlQAysUVmuyzDN7KIgCZKtC52nFx44HD58
n/Pi2XqiMDNPwHFc9J/796UjetlWFOdlM/7TQgKcla0v1pI5NPv7HRN4kz0g
seiqFQKyCNdaLPcOLY4w+2HXL0On4783QbbMf/N1kCXw9S4JjTSRAzBvd+mO
GsgytEfm12mayNvhujjyOaKSLIeneGPxqJIcBP5duVu8mByMS1VlmbOfHjOH
4HVMjvRjBXk3dmreCgfyyGF4GJyt8Aoh70FJ75zjmQc5HE1nNy+FjVqZ96K2
YqF0wkCOQGD2kCVMbmGOxPJKaoHn5UfM+7DGd9wuBTkKz2ePy2dKyQrUrrPe
Cc0jR2MwUWozyckxyPzxSjImJu9HlbBhsviNmTkW5Y19Y1f8qcehu804fH+a
ejxstql5Wz31BIgD3Z8oLlAHFqeKO76cZ+aBsnbr7cmvw6wrUfFBcGtx3MS6
Eg+GcoSnh6irYM7SOxt30H8Vqg/eGLAHsXkuEfHqcZFPPZvnE1Fo5xp03dST
oDK7BG4r1JNwXVKj55v7WU9G1wH94ZGWPtaTkasreV89TT0F1gzZROvdDtZT
sMHMFbVfvcm6GlnfDT51P7tYV8M9bclzXjjAugba/m3pBeE9rGtwiss1Hjkz
yLoWNdrYnvVPmXkttsz58VFBnaynIkBa6+zto/1XmUtb1VeZS8dM/klTxjmr
8TcThiKZ
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz38s1HEcx/GvmjItmcqPopATTocckV+vO3d+3HFkNCskS/mRZaixUqda
adnuj9uKWcaaspJrwkU5IaQZq5Q1u+X8YTUmSjc0Vq3P2x8+22efPfbcZ5/3
xynjXELmBo7jRH/3v5OW5dj9/BDzga7/mgv7oHpX3LRmDp68oJxCU7IZnpe4
N0T97me2hKRB1MxbJe/AbO8Ps51Gsi3KxJ+7y/Rke6i9/D4VjJIdwVOqDaIp
sjPcx08+MOklu0DhZVpr3UZ2xbhVidNQOdkNglrJ4/ZAsgdqzG9leTf1MXui
9vrImEkVWQBjh0I1fJnsDavj2xv5pWQf+LR7S4aKyAdh/XZ0PkRP9kW8sj4/
K4cshKGVdynYnOyHu2kTQQf6XzP7o65C05hrSf0QUrSTgisOvcwBGPFqsPU9
3cMciNSI7DOShm7mw9iVGeAUJCUHoaAv++u1p6+Yg5Habrdn7gk5BAMVR5dK
ZORQ8MUWySk/dcxhcLILdchOpA4Y1AlxGx2YlQDfVXOzYxt1Eabfd+pvV3ey
LkJJdZlHqY6ZE0OrXjXmSbtYFyN/JmNsIpWZC4fcoD7fo2HvK8PxqzBz6k3y
S9YlGOdPyFQb6L4E4ZW6wMR5mlcK7ZGzF4OHaD4phmOW9VUrNF8Ebhiv2jhn
UI9An7x+MH0z9UiYTstmKuK1rEciWFi3hb/czHoUbDY5aoulLaxHQfdl7Jhd
zTPWo9FSuPtjUV4r69G417H3wqk06jIIUkwkCos21mV4NLsiky28YF0OeZJw
SjhJ/5dDc0JzZyG3nfUYfPew71n8RvfXmYvF/qQZ1WIt9Vj4u6QPPiynrkCi
YtptazL1debiUDm4JN4H9p4ybl2PX/MfdIBGVA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10A001PkeBvDpKkRKrYpCSJFevFNhPSoqEgZhDGaYMdxyo9LtZdVEa6O0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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzw1MzHEcx/E/ajsPx6m2kIckxM7tkjiP97mup0t1D5inIZK1xbI41DHX
SE7KVCy5SZTqcK3oysquUE0sy1NpI5OrWLOjOVM07L6/Gf/tv/9ee/+//9//
O3NHoiZuJMdxEb/vP092Cdqv7l05ptnqlF1quZln2jKamYNBZ4txcWHmYfN4
0Ws/HrMAX6UZyWWDTWQPCEyfCwYGmCdBNELmYvzAPBWJ7Yf9a5qYvfHJXeGW
VsHsA4Pks+ua3cy+cBzzehgSyzwH+1puv3bbwOyH5lG20GAe83yctrjPzn3e
SBaibvHJ0rZXzCJ4agu7xOeYxdhjciTWXmf2R2+2m7yulHkh4kVZhoJTzAHI
DLSppnszL8LQh5Qjj7Y9IAfivdfkoMwf98iLoRYdv3E1jnkJiqzHo3JEzBJk
l3yr1ImZl6LPYta2vKsnLwO3UWfkhzMvx+bsHsuwq5W8AvNF4GmEd8kr4T9G
2Tqp6Q55FU6oLVWyLzVkKTzF6XGlc1kHShdY2ov6LU7rgc6ctOLIdbepy5B+
pf6xQEvWy7DK9XwMb0Il9SDonjQrkuaxHoQZxbVB5WY2L8e6gTOW2EP0vl6O
OmGSQ7HpFvVgXAmVJQxsZz0Y4/qnCFO1FdRDIBf32H35JuohaGjolfClbD4U
+qWtVoMX+/9QiDJ684ckVdTDcN+RPeytNFMPg3/Z2UBjQzH1cMTbcscuOlBI
PRxP7V88D/fTeZwCs18MBcR0XqOuQJbOYdp1sYR6BJr3V+QWvDRSj8Ajza2o
PiV9j1uN1OpTrSmDBqmzr8bEWRWpZk2+01wkyj6Wx1t9yfpI+HgHNnU7LlCP
QnLb+nHFR43Uo9A3re9twFg2H43YRrs8I7eAejTWBBzieZQXUlfC93r69I61
OdSVqBam35PoT1NXwS/p+1aPiINOQ4W2Gn1W1+UQ2keFnx72Ln7lTqfrVQjr
vlFYoj1G+6lhS8jreHypiObVSOAfqH7zzkznqfEszSvtu4D2qf/PnOZf469/
ARPecxw=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz3lI02Ecx/FfLTt0oiuzwECdOeeRV0vTpvs65+Yx77JaHmiZ1iytSAun
bMk8qqFYTnOtQkUF09Aopnjm1Z+NsCTDAypQ0ZbMP1JZB34fwh54eHjx5vnj
45iRm5C5naKo0D/370uO9cfGvCDz8YFNGXgppgtDy1bEFGRxZqfuWxLvhors
CCPbgtga1rV85vT3MbQNKLd1TPyYJD4Il42JM4XDxIfA1mvPgfw6YgeYYxYH
nKsmZsJMSWfVCxXxYbiuz2hnSYhZ0KFVF9/zI2bDYpLPDpmQ2A3il/iBe3cS
e8C+eg8ns+5RtCewFbrc2EJib2BESdvsCoh9QDhmXjuUQ+wL79P8VCvexEch
1Zemrm0bQXNAU2JgRxqH0cdA8e4n01VB7AeVpTl6fzGxPwQ6F4VzUoiPg7TB
ftVn1xt0ABjKE/s61wfRgWD5pe/sfPsA+gScliWlrRp60Vxo3pg2pkleo4NA
l9ysPt/SjQ4GmcNgSF8WMQ/OzERrVXHEAJzPtEKTAC0HEHM0edJ8HfYQ0Cg1
lFPpS+whYN9jMfuB9Rw7HwqsMqWLOS3Y+XA1XbN8s+AJ9lBYp2u2l518hj0U
+gdfjW7crsYuAN7ayrJYdRe7AKy66XdoPQ+wh0FL069WccJj7GGgKHKflDEf
YReCQz/DNN1bj10Iq9y6i/GnSBfBxNdc/ZVk0kVwq43RpaNrsIdDerbjjSCh
Fns4VLrX00xHyP8IMJW52tuInmKPALe6hIGsVNxDRUJNfKLSfKQZeyTMMSRc
F10N9iiomFpYcPIk+6MgQz56iStXYxdDk5utnbO+FbsYrpVzhV6f0FQ0jAWX
l9C7GrFHQ97bnm+SgAbsMSBgzT+sMlNhjwHWuEhiuYR7qNitlseCer/LmodQ
ydvscVsN/1n+z78B+KtFvA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zwtYzHsex/FxRK3bSRw5yE43l6SkQraaT6VGQvfrdJlpmhpWkVDrqP7a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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zws41PkeBvDJPhWFSrroqih0VopKKXlDKPch4xYzY4ypRDLbXY1qsYej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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0nlQjHEcx/GHMI5ktQ1Fg81dtm1XKmz6bNd27VWEyh+ayZRjq0njHLPk
yrQzljQmWiUTWRWFNjK7VkWbwlSKcfvDEONqZDTO8f05emaeeeY179/3+zx/
PILk9NiUwRzHqX/ev57s4nWVZgSOvG75rXdBJRun3s8fwczB4e3e4s+OzMPR
21Sy03s0Mw9TL0nf9H5tIrvAcWVGhfYLsyvWd3w8b7nD7I7ljUPsNhvzFLj4
yJorzcweeHFNL15XwDwNgelFJtEG5hmoHFvGt2iZZ0FYpZEekTF7IkL/yJDq
zDwHuSZBgLG0keyNHa7fxElaZh9kFzaJGjKYxUis6tun+d5AlmDumlfyjlbm
uUDikvfKR8y+cEjzutC8nXkeLNEtJlMqsx/2SZRO/J5rZH80Gd1rVxcyB6Dc
XRlUNMFGng9Dd2Pu7Zyr5AXIe2yvjJxoJS9Ei8KzfsooC1mKvHuP7TMO1ZMD
0SJcUbbfbiYvwo62mNrn02vJQWj17qvmOzIDm8uz/V5vqPttHZDfl7Qxcyeb
l+Gops8oSabzOhmK+23x9TfOUw+GX9KDe7ynF6kHo7DXHOAaQeZCcGtrwUmJ
0xnqIXhyoXOwsuI09VAsFRn8VZll1EPh1OP2bHzVCephmOmvyenmH6ceBmnI
sVShUwn1cGSd6nd4cLiYejhm+wekPxxjpC6H1uLBy+PRPp0cVzzjShXT2f4I
TP7+sj38A53XRcBk/LT4rPkA9Uh0pXof9NDT+3SReJpbd9fswuajMEa1qrP/
OPv+KOSo5EVnIlmPhqFgqPZmq4l6NHwFL9qqfclcDAoThi6vqaymHoOUBGH/
RDGZU8ArId7dVnOOugLP3Syz52STOeX/1inh8e95TgX5iPR253bWVch5JQv+
kMD2q3F56bkDMxVkqPFGM1nR/WefGoLd/GWD9NStaohrx/mJ0ti8Blkd8+3D
pGdpXgODW1lWlIT9LxqIRfk9jXXUrQPMxWJLZrvAeVINzcf+33UDbI2FfpNw
2562CpqPw9pdBwOz0sppPm7A/ABb//oHPaKWgw==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0A1M1HUcx/G/ThIiUwaJ6xyHgk9HAYGkIMd9eDhOOeAeFSiPp+jEaBMO
jYAcNy8eahg+1OTOMxiH6F24LhESBD2RBwUsy+JyDlkTI2vOhjhwElTj+3PL
//bff6+9f9/f////rcreo3x3Icdxaf/e/z3ZtcxpyRe+2H9pXn+JjHm1xQ+W
MnNIa/d7a7knsyusnxSr556tX4aQh/7efRyzF+QXcTjiaR95BWJcRq8VTjKv
hJv1ZnjJGLMvOhuuuUYuYPOrUfij2+O5Z/bHqfa/Y698z9avxfRYWM5n3czr
caQz0plbzSzASnvLO+K9zK8hKinu/g+bmQMxaatImXjcSw6G7cmMPtjA/AZO
NPpopWHMITgWmD6505M5FAk57w3MVvSQN6JNWeWWXsAcBn1Ffs2Xa5jfhEiz
+GqJN/MmhKQ9kMqMzJthfnm4aiiOORy1q/ZldtzqJkegofaWz/UFV8hbYPvQ
vmK5lvVIaM5bAn9tuEwWItW239NwjDkK6XOz8gmdgyzCn+Od1XcyLpKBIrH7
R6Zxsh6IsAcfmGnvoh6N3uoPNtXHkvXRmB5cKws60UE9BmpPo+bj2+epx6Cy
puWFM/fIXCzKh4eyFGPfUo9FyGij8WF0G/U4DOboDPv3kPVx+Jk/ZDVxrIth
Vlbys0Ssi2E7orqwc0kr9XiU+QUctVwm6+Ph6yEY4glYlyA71LrkgPUcdQnM
zc2L715tob4VXdqm3S9NfU19K4LSnySPa1jfBj5X2u2ygc1vQ905r/4dKWep
J6Bn6oY2TWalnoBf1h02JGeepi5Fn8IZ4H2arJdil2TkeH5xE/VElApHhDdW
N1BPhK6VxxsYIXNJcBYk/pa/hfUkbDg0PZDrcpJ6MvaW+efek9ZTT8bt8Mx2
P/Nx6jJ4LOKXi2saqctgfNv0tDWPzctRai7UxUvo+yDHXa1IcKnqFK2Xw+tg
AX/dhGXeDjncBX/8vsaXzCmgnm3amJpK/wMF9kVlhWYsIusV2P16nsR/lvZ3
KDBw8NVHlTfZ+Sjhfb+uzG3pVzSvhOU710M/5ZD1SijP9JvLA2g/hxLyXdlB
vC4bzavg0JRccJ8mQ4XxroWvyKbYeauQku3iZxHS/zhU6B0MulPkZO9Xo+fz
ozwvE50H1PjG4FM/3FFH82rYbdG6L2CieTXe9+h99OmMgea3/994zvrn7NiO
5oxRTYXKLpqf34HoyKLrbWcrRf8AbTPF7Q==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10n8s1GEcB/Dv3ZoRrpMfHes2xM1UJqEc8ubLcUe1MUvLlSwlkptZY8uc
fmij1bVamKVWbE2Nzcmdc0fFYdWiDI2kVpGWTSSnf1TzfJ7t2bPX3s9n++x5
Pj7Zhak5Qo7jIv7t/yct8fgDTfTGgZ51LcTkWyNOqMVkDsOvgps/bCDbw2Vz
3mC6kCzG4qeM2VVbP7MbMnWZ/vXzZAkKtYbwqgXyVjga5D23JsneKC75aHDr
JPvCUjm9/5ee7AefhlL/1gayDFOypfSLRnIAlqX33szXkgPxIqyyG2nkHbi5
6JEhcyAHYWfeOWdTv5U5GI5NTbeLysm7MMaLPS5872MOwedh9Hp1kndjZfiy
PPE9ORQLTdsrlIfJYZjIOH1dcK2XORzWvOWixqnnzHug8VwT2609Y96LuZI2
UXUNOQJOtrptFY1kOQr4WXVAHNVHQn9lTDieT3kUlhXeNvcnT5mjcUbXl9Uy
QN4Hq8uKLTKE7sdA/fpOFT9hYQZ8u0466lWd69YCzhNHjYdGTCyPhbhjJrXA
bGZ5LB6KHm0ZDWLm4nDg7uM/m7K6WB6Hd1/cx5NzO1jOY9S9ViT5zazlEXUw
/Ky518jyeHgaNWVvm6k+HpOFstFpPwPLEyAJFMxJXVm/2gTk3Bisrmxn/XIK
GE0zS5d8u1muQHaoaMjelfpLxMvzUj0vpfpEWFrbTFKe/icJYVe/nlJr2P9p
k8AJ7Gp+GmkelEBuh8JpiHIlvMyG6ONCmicVRurKSo/pmLUqlGR+c0hZpXlI
RvukQHlEQnkyFAVp8h/F9L4psHDl93N0LT1/ARAJINQ=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10ns0lPkfB/BB0RaRpXa3toaSStpKK4q86UKKzDC5hBkzg5GULmJ1e/rV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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgtUTYkex/FNk9xkajASIuGYqCgqM0k/vZPS+/04PU5PeruYik1NZBqZ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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQMC1xcX2HId3w/hfbDP+FS1SwvOZ3A4xZWtUc0D
43M4JIXzRE9igPEFHCYyRi3We3sMyhdxCJi93pfzMYwv4WDBkVQj/QjGl3HY
ee9KXPFeGF/B4Vqrf9q8dhhfyaH0ieC5w/kwvoqDZuuDj22BML6aQ0h8f2Vj
BYyv4bD779983TwYX8thXpcEe2UojK/jIKp63/lNJYyv59A665XljiwY38Dh
lJzIGWs7GN/Qodf9tSPP76NQvpHD68rYY/P+wvjGDhwLF7x75ABTb+LwR71n
X3E4jG/qUCjKGyhwHabezGHNmq2z7R7A+OYOU6fx8ReshPEtHByupDUXvYfx
LR3udivVdaXAzLNyENm+xOttISy8rR1C5EWnvJwK49s4CKcfrqjmOwHl2zrc
O33wEP8tmLydw+TOk3Kq8PCxd7Dd7j5R7RSM7+Cwe9bcXuXLUH6Dg8OTA+VL
T7rB9Ds61E40mmn8Aeq+BkcHoxd3vlxaCdPv5DCnUdPLNAwm7+TwzjQvZZky
TL+zg7bivGCZxVB+g7NDxKrKrc/MYPpdHI563KzY3Aqz38XBU6Lm3sd7MHlX
h2ehZ199nA/1X4Orw70VM6qO6J6Eyrs5hNxxc8gKPbF/w7ECPtEcN4dPl3yT
BCJO7gcAoNTr2w==
           "]], 
          
          LineBox[{{47.161484213966745`, -0.198}, {
           48., -0.19113935881509686`}, {49., -0.19113935881509686`}, {
           50., -0.1902009305791062}, {50.39001218627666, -0.198}}]}, 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwk4lfkeB/BjKV3XRFkqU4ZSo8iTjER0vvaTlN2xO85quteE1FRKJ5Sb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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQDQMC1xcX2HId3w/hfbD/eb3/IwM7jM/gsPOKvJch
E4zP4ZDLtjRI/scxKF/AIXfPK2fnlzC+iMOh2WLyu7/B+BIOduUdDEd/w/gy
Du4rup8wvYHxFRy2ejyuYbgN4ys5POj98Il7LYyv4pA5rU3nfgaMr+bAcymN
YWIwjK/hIBHHfeqCOIyv5RAqL7164/ujUL6Owy1Jbl+GPTC+ngPzx5T/xWkw
voGD7KXYp6ddYHxDh6NP2E+7HTsC5Rs5nN1zPE9kHoxv7BB6XDno4woY38Rh
/493OzvzYXxTh8jsPbGGAjC+mUPgib+HehIOQ/nmDv+cd7nX8cHkLRw2354r
UNgF41s6fL30df4zZZh7rBy6y9blKq6DyVs72LjITwx/DuPbOEhOmXZU/SHM
fFsHdb+QjRc6YPJ2DqqXuPTq+GHm2Tsk31d6rH8UJu/gcKYm5NPvbVB+g4MD
01LeHIe+Q1B5R4fE/sAV58/vg8o7OthPSljN0LofKu/kcKk/MHVp5EGovJND
lMYDs71P90LlnR0SZZRWPn6yZD8Ak5bFEw==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zwlUjXkfB/BHRkzzIssIY7kjWSqVUSTSt7QvtHe7bXfpLrxjX0op99XL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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zn8s1HEcx/EvWy0lpGvdUrhSyUyIkx/H6xyOO9bNmsbQVFdLW35kV4u2
W35X2oQUYudH3YhxIeXKocRctUjyY4qlWRZaW/2RUc3n/dnee++x5x/vj+BE
UqTSlOM4n3/zf9OzGq1JFm181bWmpYB1JbzH7aZkDpnnzlpe5cgbUHC7aVfK
nz5mK4ROG4MjZsg8qJVRfvoPZD6WvFslFgbyTog0tfyYMrI9bj3Il17IIe/G
NqRFDcSSHaBNTZpztibvw9fIts+WJmRHOPMEvDujL5mdcPTTGaHDBNkZXUc6
On5mkF2gaNicZWNLdkWxU2eDnf4Fsxs0pcntBdFkd+T2dJrpZeRDSFDsUL8e
72X2gEqVwV+sJ3vim8g2XS8lCxHiGmThtdDD7IW8li9e2ibyYUyfnr2i9CB7
Y2uqSjg8QPZBgn/225lksi+6B9e/ye7pZvZD3Hf7eP9LZBGGlhWFCe8MzP7Q
LRhHFovIAYhPlEMpIAMfzW36ouefr1kNDC7zL2/XPmNdjHLZeV1axVPWxeid
6l/qe8jMBaK239gqXqEeiMLJ1cBMOXUJyktLcoL5etYlMET0npyopB6Emlix
q2qc3VMHwf1RY+Ts9SesB6OqXlfpWdzKejAmD6SfUsmZuRDYzVTfdBnSsR4C
RdLwfJGmhXUpstoMjk7NWtal8HtfmzI1WMd6KFb2xpTFHLvPeij2Z1ZVCPKZ
uTDU7TGzTDOpZj0MONg8P66uZF2GOIlmrqaMWS3Djax7I40/7rIuR+Km47Z5
+nLW5bD+NecmvEg9HN6+v81zr7H/qMMxZpwd27La2PUXj24pFw==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10As0FPgeB/BpFLUlkUpSDZUkvRBF+FIij/JmPGeGGaPHIbQq5Q65Kjer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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQDQMC1xcX2HId3w/hfbAPXnTjawovjM/gsGgtf+te
Dhifw0E7f0PCXSYYX8Dh0PSVui1/j0H5Ig5/VRc4MzyF8SUcHufOj0u6CuPL
OPD/6AtdfxTGV3CYKpVlsOkEjK/ksPBUiBHTJhhfxeEM39qDPMthfDUHHn3j
FfcWwPgaDkuuhJ07lQvjazl4GzssmeQN4+s4iCdtPlETDuPrOUTWyHyTCIDx
DRzKPx94P40bxjd02DXjeUjf46NQvpHDbN7TzplKMHljh5R72TZLNWB8E4fX
P+6t+fAUpt7UYYLrwfPcVjB5MwfOTUulRZfB5M0dfB9XHrVIhvEtHM7Ick8r
WwHjWzqUCeh/as6H8a0cmmcV5NRMPgLlWzuY3V3J5JcFk7dxEJ7zsLerGmaf
rUPJsehfEw/D+HYOKlcUXyiehfHtHWZ63dFevwwWfw4Omnc+qPitg8o3ODh4
nOcrW9EEM9/RYc6lNdvzgmHyjg4VpStlV86B6XdyUONV2uPscxIq7+SgsSHF
8Xbj8f3/b1y2kvnl5PDpkm+SQMTJ/QA+Cceg
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwtMU1ccx/ELQ4T5oEyljeKGMIEhBRR5KJT+aHlUCva1aJTEB9uQIAoS
fAyJq3ObElKdzAcxRGBV0U2ETphILVQR7MjQxccwokSMDhUcRAwE53Ph/7/J
zc0n3/M/59w5Gbn6r5wFQdC+f///8iPqMufJPrzSMq4h+TFT4dtNIrYAjxkF
VtFMthtW6To0TWK2CBk7RM3hk9nTob7pdPvhBLYErX9b3e//0072xqi7n1v4
dbYPnpZYinWNbF94R49+3VPG/hTJ6tm1U/ax/SEqNKsHE9mBGPJJD3aZyA7C
xtCy0lv/tpGDUR5nc/34D3YIohcUX713hx2GgA921z+6xJ4P2S70ZtjYCzD1
I3VTYBY7HMfPyKI9Oy6TF0I7mNn26g47Ajeiwk6M7GFH4nG+s3hafys5Cqu7
4+fmrGNHQ33s0UCD9BJ5ETQ1HnPl1ovkxbjW2eg/224nx0CeH3O2Z6iZHAu5
I6K97raNLMPzN/aHO2vYccB+i6p2sJEsx9Yf0n9WZbKBa0V3n0k0ZCPQG2zy
z3Zqoh6Pp96+n9eLrdTj0fqsq/pULllQYPPKwmWVi85TV2Den8PtOz/heSV+
6vqv9MGvZKMSsjlmpVfV79QTYEzPuarc1kA9AZaCaWNuN+qpJ2JFb7yypu0s
9UR4Xsx7m+pK64Uk+I+c83xRSOuNSQjf0dN3YC33ZMQ6oqQd+bx/Ml5kLl//
mw+fr0K36mCOi4Tvr0LSLssU22GysAQOIbs6QcLzS5Amvq6XzqL7CCnYerno
5RepfH4Khua79+eu565GmM/GL5eHWqirkbGwvPNB6BnqqTg5r6X/seg09VSY
AiaWubz+hXoa/GYoKiQD3NNQPPrjAcWqU9SXwq8oSbi55QT1pbCO5eTVreGu
QdaFSUemV9N+Rg3M25x1MTYzdS1Ufd1BvnWl44YWxRVPtjvl7af1WlQ2bFnR
7VU+brsWFcj2GOkx0bwO574Vv/7rSRXN6xBwxOH6TSDfRwfl6coN331G59l1
iFXqlQGelTSvR1DzUY+9w8dpXo+DRzd5W1bz/+qREDbV8H0n7WfXwxRyS+F1
v5rmDSjZXjsgXXOS5g1YF3dPMqavoXkDZmocryZF1tG8AYdqpeZIJ0vLO9mi
kDI=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zG1Ik1EYxvGnwJAZNCgjxMpZ2Ja2Ultt6eal85ljw7L6EPUhzBiENlwv
ZiWKUytqCa0XMz8M25xOTancEKJt5UuTpWEFi6CCZAZR5KalloEVnfvA4fDj
f99HVFK+z7CU47iMv/ffS0f4xmFSCgL+/4rkfH84NhKII3PIHm3rSo0lx2LJ
rO147/wzZiGalIV7OufIq1DpNiULpslrEDaL4o0T5EQk9ewvs4fISbiY4PtQ
84icjPQpY8eYi7wRKSGV09ZNTkFM8dCA0EIW405nx8r1FeTNWJR/3N1qJqdB
532ukp4kS2E3iF+kHiFvwwl3ZuyTGHI6hufOVxX1DTNnIDioP9BrIGdCL2he
9FnJ2yEMR0KzM2QZqis606Yy6L8deCCLOl1C8k7Ue05p3m8gy5H1KVj3+yrt
K9DYsKIn+GuIeRe2NGytdV2ingWLW1yq6CJnoyr6cp2Zp3klJIIbcWdFZBVe
+fqb2v0DzDmwdkd+KtYOMgOOvdZl6tWs1wL8QuBo6hnqueCdE9638U9Zz0XC
fGm164eP9Tyc1kaOSTyPWc+DxHTrW9HBftbVsJeFiuUyD+tqbFI6bnsP3Wc9
H1cKw0Gupo/1fCReuCcv119nnUedrl4UNV5jncfo1xT1yPKbrGswmS23VDa3
sK7BTOO4Sn23lfUC2A43frlcYmO9AJ8tgelJHTOnhVT77vW5cSfrWjjLWiYX
+Db/H7QqAlY=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11ns41PkeB/BpI1G7Ks6h6DTFdiKdo5uK4q3ognGfkesMxhi5lM0qqjXZ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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91nk8lfkeB/CnTA6VRiGSXLqmNEqlyWjjE4pEWY+dg3MsTTXdEjNlOVFZ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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw903lUUwcaBfAHbuAoomjrTCFEqEuVRYoGRZYruyBbwg7BJJAEWRQcrVDA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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz38s1HEcx/HbNaGZKJvadeZXRkx+FHKOlzvknLrrblNXaYukVcpibenX
1bgrzkZNvw5Fv1SrSIvmR8eJtdXVwqSstUTRKdNOSqWa98cfvtt33z32fH8+
38/HLWWvIo3L4XAk/97/X/Y49FzOFM7reDSt0ajimobv3rbMHNQ5/h7O5DLb
QOqmmur+3k52QM6x66WWCWYnKHcnZ5j7mBchP0DhH2FkXoK23/rJjzeZXeF1
fYGvvIjZHa26Pc6/TjB74lrNPdVAMLMXbP7sX3plEbM3tFuychS2zMuQpHrn
e/zzY7IfnCv0vId1zP5o8lNtt6tlDoAu2ali9EMbORAvJCofqx7mIIxmnR0J
LWcOBq+gcENZv5G8Asow85Q0mHklUke1I8rOVnIISpTN3NPxzKEouZR6s6mp
hRyGwGrXgFM/mVch0mOjYcyFORyddwq1w7nMAgh43za9KWWOgOTgXLeBLgNZ
CPu+fstrI+uRMGWaMgYnWI/CkQjj9iczHVjiqYmak0ddDfy4ra3jOrP5aIgm
k8Jasx9Rj4Y1x2ro53AjdRHatY4TCT711EVwsIx7bRm8T10MM9f8skZJVovR
2X/g6Pyae9Rj0JYmsu5oqaYeA209v1lQdpt6LNaLOoaSDl2jHouShhzZVp9K
6nFI548Vd6WUUY9Db0BsdkhzEfXVeOoiXN4uO0N9NWwydgiTZCXU4/HqTf5i
Q1U+9XhEhY+0iCNzqUtg5WG8aJrcTV2CMzv3uTfkiqgn4IK62/65XTT1BHwN
vGXRvM+jLoVJoKm119F51FKMJ3wTSkwF1BPR1JJeMMRn/0/Era/nqvVfzlNf
g7zSnf6n1Hrqa+Ba9anDk8fuvxaby7ZNnjxK8+q1qNQ19vEn2P1kKOq1ffDL
hq2X4arUx+7trlLqchyaIy6ymOi8kMO7J+TBs+jDNC+HJutus7Qnc9oGOYIW
3hhsLD9L69ehVlictktD+2GW1bNsmGWOYsZ/Aee+efg=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwdQlAcaxvEPEBEURUXJCacrcqixoEQQlfLQkSa9LG37omBBMZxovN0g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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zws41PkeBvBZ3aRNKt1UJ6TYQimFiBeD7rnLZZgZc7Nt6Jwk21QjxcZ2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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91Hs01Akfx/EfXXSRRrbLQ1tTSci2KLZIPoSSyv0+GGaG2U1ESW3K2FKb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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90QlQk+kdBvAPitJBQe6l4BHFsoDoigVFIeZBBUFRjsglVxIICZ5FQUXq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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdk2lQk1cUhlMRZFBQWUShtSYwxaIgorggIW9UEFlDFiAQ68LgMrYCisEi
xVBRqRWqYV+KYRMQF+oCqKCRta0iM13YLNoyOlBtFZGCQoW2k3N/1Mx8k3nm
ue93zr33fNxtkeKIKRwOZ/+/z3//7DersziKb9R6S0eDAq5ArcywZMyB34WF
PUusGRti/bI1/veNGc9CTJXy4u0pjM1xbM8Tw3n6jOfi4vHNvK7RFuJ3UTd9
5NnDfsYLEK8een2+mTEPMyVGfPtcxrbotLnb5xXF+ANUD+oFNDkxXojwLYZb
hVaM7dGx4Kw0/F4z8WIkhg4t7jzL2BEqjm+09W7GTlht1H7svV+biJdi0X2j
vO8KGDujQzj9I7dHjcTLkGL5fLI4k/FytJecqIyxYuwC9Z2PO6eVNhCvQGPS
tjceWxivxPjLsarmI4xXwZ3bkDNsfpt4NXacm5362JixK25YvN/8Ql9LvAbc
6MpI74nrxG5YsUfvYIfiKjEfeZ5un0WuvUbsDtuSst9Nxq4QCxAZ/2dgdkIl
MXB59FTLnldlOlYBmoTur/u6SsgLUV+uHNpvXUBeCA03eRfPppD8WqS8kJeO
g9ar1iItfa/fi1e0nrMOg9ay+qtRzK+DqrrKvnaymPx6fOLkb/Z9QB759ZhR
VtdxOCyDvAeMhUs0B+ZkkvfAnfkNVi2H08l7IjrB7GBjBuvPEzdEiq5b57PJ
b0B/votkx3FWfwPEXs63fV+y/r1w8744zqhaQ94Ll46YaBZJT5PfCOEv0+u1
TcxvxKjyTs1wdxZ5b3xhai2qamHeG3EWiS5lbmz/PkiOOKD8IfwUeR+EbTof
f+YblvfFzIHxAvnPVE/li8nlKcPKD1neDw/FvFUDf+eQ98P2wWSHMst88v5o
585KfyPMJe+PfZE9ntx86ocTgIGsvtquk+x8AhBcp3Hdepp5EZx/uhDlWUPn
AREarKpbRWFsPyJEXH1QMS+/SMdaEVxEDtEoYPMRCB+zvWbn/Ok+EYinHUe7
k3vLKR8It2uf9sx/fYbygTC7Uqx0taB544jRlV8hS0ui9RDjt6aYEqkHzadK
jMvalB9DnhNrxXhaGZb0zgSbXwna+LYB+59UUF6CpN5hvr0py0twd7L/evJT
lpfA7g/FTv+cs5SX4lHs6OjjZbQfSFHjkN3YHE7noZIiURUXG3mLWCtFvJMd
R67Pzk+GYvXK+Dk1NJ+QYQvPoHJaCbtvGTKOxCbutqP51sqgGui9UHiTzWcQ
0BmzI86B7gdBsL55aqj6NZ2nKgju7h0u/Ch6vzYIpnXbHu3inaR8MLK3y+5N
sfCjfDByfNVNDmPeAl0+GC1l6voHO7N0rA1GkF+hW/ZfaTrmhKA8PFU5VT9F
xwhBwM5anuXJw5QPgV3GyLgjbx/lQ1BkaWBgYBNLeTkc701MjB36kurLsWSG
a/9Xngepfzku8Z03t63bR/3LYV5QkXkpIY7yof9nhEJzHend356g+qFwmOqY
5jueTPVD0fe52GxidhztPwyqK+1ttnPVVP8tVoWh/KWeILWUvh/tW56jQI+k
zdW89RDlFTCprxkP3B1N9RWY+oyXP1qbTvUVmFtUKMhS5FL/mzCytHipVUuR
4B8lJVbJ
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgk41fkex/FDmy3ZWtyZEKoRiUSJ8iF7yHbsy9mpsUWbNPW/Tbljpqgp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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIk1Ecx/HHIC8VNVtiUISOvDBsZbZla/P5Pbs4pZlSYGAXKyjJcI1A
odBYNaisGIuoDMHyUpi3XlRINee8NNCl2ZIkViMcoxchG8rEvFDR+fuiA4fD
h+85HA4n+eS5A6dWcByX9Wf+XWmIPjeZ1avczn8K8Ve2NAcNq8kcqo/VFxRH
k2NRPC/12JYtgn1/1YtvgXfMG9DT6HsijJM34l5H51LNM/JmaF6VNbpvkZOw
yeSGu4IsgWjOdfB9HnkrzF7j2l8qciq67AInCg8yp+NOYVJw5gNZin2fzo/O
TJAzIB5OSDEGyDLox2M8D6+Sd8DeHxUfqiVnYvp0r/ryOvJODN6eavD7Bpiz
MBauqNTeIO9CtWk28aKSLEd8pvV6ZSxZgUCg6+vTIvJufJEcOXMztZ85G8H7
gcjA3T7mPejm1KqPDS5mJUYVl+I85eS9SCyXeX6KySpMrTcuhvy9zGooJ51n
ZdHkHLxs91kfRHqYeYjbNN5ZJXVgaWXdtDWZ2QK4utMO51gcrAuIqi8be/zG
yboAmSTj+aGj1DVwOEvmm9KpaxCZWMPxddS1kArbYzoK2P0WLSYXiuakYeo6
2EZsw6JSZosOtSnemhbaz+mxYB6Cv5XO69HJlzziS9l9XC4S5NkXWhbfsp4L
/fEfhX3f6X0GmNxyxVAanTfg2usqx4k46nnIl7SObNOx/7H8Zy5/2b8BQ1oF
1g==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90HlI02Ecx/GRpWssm2V0IJG1UtTyTk3XPpvOeZbNUhIUrBQxlzGPKNTS
IFuIpJZWqDnNDo+klkfNe6VQ4oF5oX9UpGFiW1lgYSc+3x748fDi/TwPX37W
x5IVcSs4HI7o7/dvpyUYqzot4vV2LMsoru1PSgkTkDnYKWs+OsMlc+Ea/W0q
7XcPswCnMlWD3LdkS4wJY57aDZI34Uf2+NYnTWQr+Iw/KKxUk7fhy0T0ydlw
8naYmQRyLinIQrQJkgd4vuRdSL/+q6HclGwLdWSGPNWcbIfOfIfDrQ5kBxSP
6Kcjhl8w70G4+Ov89yyyEzQN/Y7TzmRn/Cxz33he8ZzZBdf0LVWKd3pmV6zi
OYquvu9mdgOX3xhmsKbuDnv3szfM7KnvRXuakzC0qovZA1F5u/nOk2RPeGgP
LSUskr1gazE1W51I9/ehbotSWSsje6NGYRm3+JLO+6BRcXtY+Yq6COrL2fGZ
CeT92KBosbp5gs6L0RwptHAZJQNyz6GZXl7nsi8Akz1nPsrWtLIuwUhR3hHo
n7EuwUUJ/251fDvrUph2TF4ZlupYl2KpzW0hyryRdV9o1E2bPw08Zt0XYY9i
c3PP1bPuhxrHLDVX+JB1PzT1pSbnWFSxLsP6jG4bg66MdRk0UjejrriAdX8Y
rcK1Lgu3WPeHd8paZUWShnU5BO39Nt19JazLIaqP+TCfTu8HwFDwWaqJv8d6
ADTe2lFhRax4uQeidaymNDsrn/VAIMrDzFNfyO4HYfUb1dAEn81zIQhOKlVD
T90d1oNhmLufOJdUznowJH46kx1ami8Er+vyjgeXVLIegoiV0/YBB2m+UBjX
lRYWOdP8oeiK88rR9dH/O/DffwCRuTOj
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVzglI02EYx/EhhiY2J60wGagrUtPs8J6ZP4853SyY0MQy00pDRRNk0CUM
EV3UZJqa0IHaQWRWnqmp05oKGSK0LDsWkUnlgVSSgWKFz1P0wp+XD9/nefl7
HD6emGEjEAhkv78/Nx/Ri2v54Q5DphXNRYgNroIxZ7YAktLl0dNr2PYwzGpr
3ERsEcr2qPSSv12M+qwUo+3iINkFGcahV9YptgQFbUrvpUG2OwKHghUpZrYU
Sw3zk9susTeh6djJfL2GvRlJPguahzK2F+xmLpu7pwfIWyC0hGpthNx9kfZl
3xl9OXc/aG+o06rV7O3Irpc33LOayTtQl3m1wLuQvRPDobarJq6z/SG+o86J
z2AHIFEhVPaHsAPhVHZ7NCqYHQS/5LXeWROPycHY6Nsx0V3MDoHZ9DonW/uI
HIrxzwkl84Z+sgzT+4PcZor6yGEYtbYN17qwdyHatmqviyM7HBaL+KnYxN4N
Y65DrrSmlxyB9OZPk/LFHjLg+qyytf9894p1wM2KyCtT/l3UI5ETUGxqDKN5
XSR+evYGHXKieUEUShq23ioce0A9CrpzlpK1y+3Uo+Fhv97O5NhBPRojreVe
9u7cY5AZkCV939NGPQbFT+ZSTnmRBXIMv6s84GPtpC7HkTeGplJn3o+F5qO6
wpPndbE46lHtm9fF/6/A16IFqSaQ9xWo2nDR8H3pPvU46E/MteStbqYeh0yh
RP58toV6PA6qkz5cWNdIPR6Oys6YgfRW6kq0pxpTU/voPZ0S46qykbMy3ldB
mCuq/TZwl7oKRW9/vEzOq6Oe8L91//wLo+Ak7Q==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxFzHtMk1ccxvF3KEScQ4xmaJ3OIoKAItOieKk8lFuRcnnbSUDNIKIkYFoQ
ppCoCShSwbXz0oSUlcmlCHYFFSqryK0ibDMbblwmRMHosm6M/UFUnIqiW/o7
8yRvTj75nucV7s2S73fiOC7+3++/mx33uzXZ4rnfdTo0GeJkE1+w/28OVfoa
o9qFeQ6K01bHfvOql+yOL+xNNusk8yKsD07c5GxnXozCgbKTu/5g/ghjiRlK
yW3mFfgtdclAiYbZE2X5fXEdh5i9kPT4V1V4DrM3lq81f9oVyrwaqY+L81xe
95D9MKV/eTCxinkN5vguNbTvYg5AZePve0v9mQOR+Wddt3gP8yd4WZ8dY/Jg
Xo8jD37gCwtukTdAqhp52r2YWQRn0eBXqiTmIBj8OoemFMwb4bpTUjehZd6E
R4LhEX4dczB81XrN6Z5u8ma4NnqWeWiZt0DR5Faa0n6TvBVFs83Cz3uYt8Ga
euVM+CVmMSpVz7xknI28HXc6Faa8ROYQBFrEvjjBDKxM/SfdPanL4QIg+eaQ
ce4FMhcKhPpVq2d1Ug/FCU177/GHZE6CCt3VX/YZO6hL8GjWfRfbeBv1MLS8
ap/40HKdehjG7Zf9Wy5ZqYdDJ68Jqqi6QT0cG+v0IuFDC/UI9IoyVTpFM/UI
zL+nzHmy+Qr1SMxLMb5viG+gHonxPdMdmlNm6lFYMBg97bOMXBCFbKVZ6nyg
nroU0f35Oj63jroUbWlfjv74hPVo9AUKI88trKUeDe3Pac2u0mrqO+DW/N7H
XmNfU9+B4QybWuJRQT0GORum+iYUNdRjoBRGrhoJM1KX4VhATrJWeJG6DD/l
33Wq92L/j0Vb+p3B2QvzqMfCVNIXMFWZSz0O8895N2c914Y4ehzGsktMKYvI
XDxWRvjqB/ly6vE42zvaOnDUQD0Bl0NW1B5+Ue0wEvD3t2aBbMZE7xPwgZO6
/E2c0eGuBPTfE/mYxuppz2Pys+nT+0YbaM9DIE5/cbDoKu15fL97/zXDKgvt
ecy4FcqMWWRODs/zdks/T+8hR2vg0pnbyVbay6EsHBGsCyZ3ybHkrMbH1dpK
ewV2twh0hw+00V6BeX8VVXjqrtP+nd8CAUCLxQ==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQMC1xcX2HId3w/hfbC/9XrZ2kPsMD6DAwcfs8HR
f8egfA4Hc37uRKX/ML6Ag98LFwazrzC+iIPHvHOc6a9gfAkHbXFmsS0XYXwZ
hw8/Il692wXjKzicN6mdfr0RxldyMLZ4NvdsLIyv4pC45ObWh3YwvprD3vdm
KzPeHIXyNRzK02+EvoXztRzyt1X43TgN4+s47Hvad0+2BsbXczgrOaemSQjG
N3CYrRcVslAJxjd0eBTzxZP/+xEo38hhd/5bYTY1mLyxg/K6Fzv+88P4Jg4B
ZtFTWtJhfFMHb2v+9TtTYXwzB/sTvSzbXGF8cwdepzONr47CzLdwmF/y8nL2
JBjf0mFLw33XG04wvpWDc5SCVP+xw1C+tcOfgp2ztathfBuHki/rrG/Ngqm3
dUizN55QBOfbOdikSvRaWsL49g5L7j6beL4Jpt/BIfJlU5G7/iEIv8HBYXXv
NvXp0Qeg8o4Oj84JLcv4fBAq7+jA1HBTt/kTVD2Dk8ONa9xmqveg5jc4Odxs
+MNuO+cEVN7ZQbV0poK6A5Tf4OzAWHf5UNMLWPpycfC8bOQZ/ATKb3BxmMzM
FzJLHqbf1WHj5JWRCwOh8d/g6nDVeObfE97H98fzpMrbPnd1+HTJN0kg4uR+
APne5wE=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxFzWlIE2Acx/GldukqTVdCavMgp6h4lzrdb+7yiNRUNsmwIkdFoKIZkdmC
5kHlsRAto1BXqSwoKy2Hd5pkLyIjHc2jw15kSZiiYWaF/4ceeHj48H3+z+N6
JGt/pgWHwwn/u/+dbNmONGRHWj/vWtV3UXt21Zx5EzMHNTM5eXBg3gCtfDip
jMtsCx9J20Xl3ADZAY1eN9/xPjA7QpQqcPplYnaC+2HDV+5jZj4WuaV5syXM
btiqHRFM5TB74La9XV16IvMupCi37DgpZRZg6uqoc/haZm9MWDQJvEz9ZB/0
9bnqfzcx+yFj2T/h1llmf1Tb2/px7jIHQKq/9HLNeuZAZJUcyJCnPiMHoZwv
birexhyM+ntJ5UWGPnIIhqpkRs9K5lD42iR/PNHOvBvCKPfNQcnMe6A0TytU
pl5yGCRqX2FpIXM4Hnk1f3P70kOOwGKjMf+hFetCvFLOLqkGWI9EeK3Cc0HW
TY5CYZc4RG3uJIvwIreGNz7YQQYCz0+2nDlE1gD8TwVHPeZZF+Mzd9yhu+Ip
dTHKUk85dg4ZqUfjTmKr7sbSE+rRCEjZ2WM2sP8kiKpP4RdFsHkJKkuNzcuW
dJ8jBc9mhXuwt426FA26aecJp2rqMpi0wRvLc+uoy8CzE04Vdempy3E93S5M
YmihLsc6y1r9z0EddQW0wsk0a5fj1BUYmwlVPejPpx6DzIKFfTVjZE0MdH7F
8z86KqjHIrTDskGVQO9pYqGee629YqqkHoc0s2xs+/A16nFIX3nfo/Nm8/FQ
H3N5c9/qHPV4BJ2Oa31rf1m02vdieFTiMbNyYdWa//4Dvh4f/g==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdkntQjXkYxw/JJFrEKi07omiTSBeF6lviHJ1u55wup3O60VREupCQtZWm
k460iMRkOyXTJLuhu0p0ESXKlm3DFqKbScimwV7mPL8/dt+Zd975zOf5vO/z
vvPqbg0XBk3mcDgH/jn/vbJj1qPcCGv12zeU9MY2OFs9JmImYw4+fU6XZOsw
VsPzmkN/dmgxnoUbqn9o+481Es/F/C9HvPm/MtbG3cYl20YrGS+AimQ85lUy
40XIn9R873AE48Vwbp69oMGWsR6cY+vnDeozXoqNgcOvfbsaiA0Qtrr1uwgZ
Y0NseXXkRHQEYyPsSdb0CghkbIz3KwpMGlQZr4JFkoFW3dN6YhN05PcUz21g
vBrnVTRVQ6SMTaGrG/RQxmdshrz6VL0dQ3XE5tjaI1Ob2cbYArdWuHz16MUt
4jXIWDNDVpXD2BIZF7VqNj29SWyFkpPLLcrGa4nXwqYofP+7LsbrkNCnESl8
W0O8Ht4eXMnCAsbWsNao296XU0Vsg4/XW+y6ihnbQi1l16BYweYBkzNppwbT
q5UcB/BmFvS2n2PzdjD7mJds2V1K3g5zEt2TeDxijj06tUqiehrLyNvDXMqZ
PTB6lfwGPLn2W8XP1SXkN2C5bOq2A3bEHAfMGnuovrKjiLwDys55Tmtxu0x+
Ix7zE+0PLGJ+Ix483PfGLPcS+U1olTZblV4ljtsEvktxUJp6BnkuOvTHpbq6
Z8hzMW2dn+H03mPkeUipKdW+P+8HW6XnQTCjau7nYAH5zRAaxvOnF50mvxkC
K8srB23OKZnjiJhrpubLPuWQdwRX0R9/VEHM4SNmeGDo+yQFeT7ufBzvPTF0
irwTbkVe0lwjDiPvhDttAxVnW2LJO8Nf0Gq56F4IeWeE6oScehnrSN4Fnnoj
3cYhlvR+LpiTGRQ8MWpN3hVlgeU2fopo6l3xTLuqvqJpL3k3JPtNyo8c/V7J
cENQenKhY1ACzbshSoWn83x+nJJr3RDgNbE7kyejXgDZzaY3CxMjlM+HAJ9G
TA2y5VLaR4CYlfn7Qsv3KrlWAOe6scZtw3L6vkJkxX6tllcQS70QPfpRorfN
h6kXQv5uwYMAozTqhUjtNM/WOJ9IvQi83bCODAul/UUYr5sSYMT1of1FUP9r
12O9vMO0vwjVvuFTPgzJaX93XO+X13ybRYz/cZw73qZ3rO+PJK51R6DrzjbB
nGPUe6Dz9Uv9LxGp1HugfqAvTCg+Qb0H8rSSVv5UdZx6D2DqhuGuoqPUeyJw
p/GF6IB06j2hv9bM4BvNLOo9YVZ4NqViK/1/tZ4YtE7Y8oFL9+d4obxd+Lq/
iTy8sGJJV8w+A9Z74YnMKdN+jLjWC1km7Tt+dM2lXoyCgw23rVMvUi/GnpPT
3USGBdSLUWlmWB715DL1YmR0N0xNdPqFem9cuet4KD+cPLyRW3dDPlnBem+o
Hq13vo2r1Hvj8/6238cyS6mXoNvdn1ejQh4SlEi8RMOiK9RLsLMyf+TeOHGt
BFbVfr1WXJrnSOF/snVZbzt5SLE0Li2lL4f1Uix+Yccx7mS9FMflhc+M4tn+
PjgUrLGK71hIvQ9OT8jvT1QWUe+DhJem7xOXs94HDgsnh17QIub4wkKhfXO7
A3u+L+IF0ft1Smm/OF+EFrU0KdyuUe8L3Q8uS63G2P5+//Xww4jdSMHjtGLb
vwHd8F2k
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11HtYzPkeB/BfHZRQeRJtKlMI5SRJqJV3NZWU7vdpprk0Ta6tFkeLY6Sj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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10QlUU2ceBfCHW0FQqFZcyiioRWYsiKK4ROCyr7IvIQGykISgolWL6Fg0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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10AlQjGEcx/EXRZok4yhsyork2Oxqi1r165au3c2VBoPkGtQwNM6dipjR
DGVQzooKUXLEhnbZSqgxTeMY6SCFjChLcoTp/39n3nnnM9/nP8/zPmOXb1Sv
7CsIQvi/9/+XH6tn2bGzzCtKe/XZ6/Xp72/jBrIFxJ7d9KC8P9sMNcnjtj/8
XU62wv5HZtI9Xexh+PF9REJbI9sG0Qfqf155yBYhNrto/NpCtj1mipITh6aw
xWiv7FGIlWwHDIjKtraRsSdglaVz1KDWMvJEHHhfZC7Zy56EbfnVFltN2VOw
4cvUhFoTtgSf2pr8uo4byNNQOTJvcVYJWwrzrc+vt+ewZUjtsHH1jGRPh8LG
9Vwz2C64mmY55NfH+2Q5tBeVke2T2a5o+d3Py8yN7YYTVj2DlXH3yDNQ+rQm
s6xMT54JW8m3rykZbHcU6E+MjC5ge8BBpJ9icYOtwN6FH5wOtbFnwfi4tsE5
lO0JWeuSgc1RbC8sSbxdU57E+wO7N7vbLjpK1gCrDVmdhhhe7w1f3WYLuVZH
3Rt/jBX2+atLqfvghfS8/frW29R98OOwU+gEkzvUfZH6+WVLmkhL3RcHU+Jd
DuuLqfuh20Q+Xx18i7ofGu3E3Z0ooe6P48Zl4WlnrlL3R47p0mJjchH1AGS8
c4zbZyRrAlCU15bckELrhUCkOVbd3GDG84E4efnWN0t/7rOhubdAuyWxkPps
dF6/1uTdkkc9CIOnvYmMeULWBCFguPPOi/PPU5+DxieSBdES7nMgmlhSNWYH
zwdD3Jq3tvbuJerBmJs03q7dOod6CEasCxtjtYJ7CEaVuB2prz5HPRTW8elJ
b59lUw/FK9uMXUu/XqAehpCeQHfVqSzqYZBaFM6bfpfPF46QApeDqyzzqYdD
0KWuqU/nrkTmoxsyvWdur6GEt6+DfKWOrFHCdIhrk1PfzF7rlPDrM67OMZos
qNDQrM2qcKDzQYXufZ9iZDnpNK/CWDuFdFsCz6tQJZNbdyjofwU1gjYFuD2u
pvuCGjtXdI/OreP7UMPjV12uT8cVmlej33uxofo5WYiAcviLmqeVZESgy2mo
eNRCsiYCHvHuBu2x4tK/hIKXlw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zQs4lAsex/FJOqEsUkekmopyW+pEcv+RGtfCMO7MjMtMF8dRW6fLSVMn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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQMC1xcX2HId3w/hfbDv6Z3b/YEXxmdwWMo5JUeD
E8bncKg5d75Qmh/GF3DQVmtOdueB8UUcPI59qpv5+RiUL+Gw/KfLc+NHML6M
w6f4Bjb/YzC+gsOjN24VkodgfCUH66dxi2TgfBUHjsgZHjXbYXw1hw2PYncU
z4XxNRxq7suw3XwK42s5sL0ov71iF4yv46DQ7rzerRHG13OQzTn1Zo0PjG/g
MKOhKs7JDcY3dJimfUl77f6jUL6Rw4HWjzEfjWB8Ywd5a57bC88egfJNHFgy
PfetWw/jmzq0XOBmXtgB45s5aAjOaNpYA+ObOyR9F5vz4OVhKN/C4bMm2+o3
m2B8SwfdysWXj0bD+FYOF9x6NZnXHYLyrR2Yn67jUYiB8W0c0vJiRauXwPi2
Dudq37/mDIfx7RzWSQhtbu84COXbO7zi+nrNvfYAlO/gIM6+h6txA5Tf4OCQ
sXPOnOf8MPWODu9vF630KoGa1+Do8Mtvze/XITD3OTn8Nd9m98oLym9wcvh6
+R/L3gkw+50dGBjKDTcfhul3djgVWlLAvxQWHi4OtZMmHTCLgfIbXBxU/hUX
PeCHme/qsNK8y/sYC0ze1UGNbemyLV0weTeHVBuOY9c1Yea7OVwzap0jeQpm
v7uDdUTisQeGMHl3h9mfftb5voH5z8MhcfmzKc0OMP+j8Rk84XwAkMsEaw==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11Ak0lQkfx/GnRXuoFM2orlZTSuUlsv2QIvvuuribe68alUaJhDsp9GZC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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9z3tIU2EYx/GxVtlQp2RDw8S8oSPmJTNz2n7qnG7TLLNISyHT1GzNSoXA
2KRForHClTKjKag0jDAlDbKhbpqBFd4oK69YkSQiIjSwPzJ8nw4cDh++7+U5
+/M0GQVcDocTt/n++9Lj9qmlNI4/3LelVelyY4qW40rm4Jtjgd/wvzshNTt0
RM8lu6G8tzFL9/MNswf0+ZLmmmGyJ/hfPFeCe8neeL/3YQdvkOwLZ8uNBQ8b
2Q8ha5eq52bJAfDNCtJEtJOD4NPLuy83koOx6CTnd1aRRQgxC3fxNOQDKMq6
Vj24nSzGpPquxLY8xByGOenNqXsz5HC4ZqoNG03kCEQJLKEf1IPMBzGWUzax
FEaOxGdZ3qn8SPIh9IsEWmkdOQrT4uXbkV7kw1j0twoDVORo5LZNKOxLduYj
MAvstxwSG3MMTAmVMnd/sgTW5/4DFcYB5lg42QXrNenkOLRtFEfbztL6oyhN
71pZ76YuRaeH1fyspo8ZmBArqjev37IOmClKtOxrp/3xODPVllnIZft18cgO
zwtz+UPnJeDqSKuRV8XW6xIwu6h1VzTQ/yRi9HiJyexNPRGXfUJ/v+PR+TLk
nKt0ybXS+TL8aJKOJ1+hnoQnOo6oWEn7kwD72k5FNd0vx6yPRhZ73sq6HM09
BddF31+ynozXJkd95sUXrCcj4G0Mdz6KmZMCR91Y1a/CbtZTEDg6lCG90Mm6
ApavXv0flR2sKyDcsXTaLb6ddSUcaerawJpW1pUQVhgeuTy2sK5CuWRN32Lq
YV2F8TJx16QzzZ+Kp7nz07UPXrGeijt+O+eSV2n+NKi2rVoCdrN5dGkoMWgN
rup+1o/h5Al9/Z4mo/QvMvMt3A==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9lAs0lHkfx6doowsqnUa17ZQUNkVKIfkiueVOro0xM2YmuYSo7bIGpZDb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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQMC1xcX2HId3w/hfbCfezShJJsNxmdweGDjMYXn
/zEon8PB6eTBxQKfYXwBh6oM6/jY+zC+iINTT1Tz+z0wvoTDZmObq73LYHwZ
B6EA6/XrO2F8BYcZ59TPamXB+EoOgleke3rtYXwVBxvXXWIHrx2F8tUcrBTz
uPvXw/gaDqk+auv4KmB8LYdzddJW+Yowvo7DhbnbpY5rwfh6Dl6mjw7tf3wE
yjdwcDx+NzusAcY3dNhtLjdvYz2Mb+TAJZplEZ0J4xs7GLg8f1L56DCUb+LQ
dFQ1xXMBjG/qIGH1f+v5HhjfzKHBNCfBRRvGN3e4/cX6vXAQjG/h8LxIatGt
aYegfEuHW6tmyStYwPhWDo0Cc9LXOcP41g7PVbvfPiiE6bdxMFhxMU/yLIxv
62DXMNuiRhLGt3OYvc9p48aHMP32DtEGM1IXusL4Dg4XbQKZV2+Eqm9wcAj9
lrdN/jtMv6PDe2Y7yWctUP83ODo8+5Hh97QQFh5ODqli9gn9n2DyTg7Nk53/
qQjCwtvZoSPvmZNiATQ+G5wdeC8IpEe+hMWvi8P3N4/S5mtC01uDi8PS7OrN
z41g6c/VYX6xn0izK0ze1YHj+7GjvM4weTeHbq5D2vcrTkDl3RzYCu9p3laA
8hncHZ6GzE++rHxi/yGFoF1+we4Ony75JglEnNwPAEKi8J0=
           "]], 
          
          LineBox[{{47.12279528216141, -0.198}, {
           48., -0.16194994101517493`}, {49., -0.15975059182536694`}, {
           50., -0.14242583740614026`}, {51., -0.11364612536726557`}, {
           52., -0.08350695296774431}, {53., -0.08350695296774431}}]}, 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0V1IU3EYx/GDWTSdtd5fXOpeyJkxdXNNt3S/vdvsIrIShV7ISjLQskWU
JVMkI4lRFxIkzkwrkmgpg1XTpqmtm3IhBmFiGdRKY14IGeYq+j9deOBw+PD9
P5zncESHK3YfjeI4Tv3n/vukS/D29smcmBfP/imsC0x1lvP4ZA4ST9EFexR5
Ke6ctdl2/RhkFkDdurysf5K8GvxFV93735HXY84i/fWxmyyENZ7TFt8lJ+HA
yITuWytZjFWWB9/9Z8hSPH2YMzeVT96MTSUi8/zEALMMa2+UFK/4QN4CT2lH
uLydvBUibehIQi1ZjohLsYc7SE4HhyLJVxU5A6WFVaYRZz+zAgPOkNudTFbi
5rHTl1XTz5kzcby5qy/LT1YhWqgfWuMib0Nwtr5qVknzaiTW1Yo8MnIWHGrx
+8VjdD4bwevSdqGErEGBu+yQs7OPWQvxeKMx3U7ejtGXG2wRVy9zDgzZl+zn
Ksm5mDbH1TQ0kHV40hHt1f/0MwNvlGWpTRdZdwDR/HChN0Ln9RhP5ctD8ex9
Dj1mTNWNKbXUDdBUx8609VI3IM16b+/cfdrPiKaYmrqNXdSNeK2wD+cm0rwJ
gQLvo2Yv28dhQs9neb3P4GPdjIAgYd+nlT2sm3HeN7/kGo/2t+CxWnNlWSbN
WxDOSEluHqZuxeCrdV943dStMDvTjLFh6nk4JXW6h2T0/XnIbZsM7jxB++9A
ZbtGM9ZC+y8wZ1vQbYi7VZE0KqP/l/+//wYMThGb
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90gs41PkeBvBJbUdny8qKdEWbSCp0I8zr0hZKLmmGBnMfukmny9J2mi5K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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zglczPkfx/FZhQ6Rvyj+xbhyppw5Uu9uKt33OTM108UquhbZqdWWqyJ/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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90wk01XkfBvB/exlDE3p5q8klulQKbag8pXClZL+2u9/rZrTRpma4NRel
7S2VerUQTQuFEaIyNxKSFo2WUdLytkqW5q2GNL2n7+91zj3O5zz/5/f8f/ec
y5Mt81P25Tiu9svnf//Z39A7Wctn6lX/9lXtrkW898H3TZg59K9zTG6zZB4M
fmm9rvH/zw/FlWh+Vk3vZbIxbKZNKNz/ktkU+NDyTlrLPBLxsROdhlczm2Ma
F21xLJ3ZAv4q2zSzdcxj0P358EWvOczWyDt95YO2HzMfIfv1njheryLbYk+U
10q9E8zjYZr6vjUujtkORs2S14tEzJNw1fS7hpVJzPYw3RC92+w/l8gO6DBZ
mdl4kdkRdaWB3Tt1zJMhsl1ftXY78xQEC7ryx5xinopb/Kz+vyUyT0O7V/lC
555K8nRsufBf79t9mJ2gKxf+tGJ1BdkZm1PLTQuFLHfB2djNxkefMM+AwdFV
+Ue+ZZ6J082rW2ybWX8WjNxlz9fXM7siIz7NIrn0IhkoO/Q8YNc63VdrgIRu
n9mVG8ncbJj77/0jpeQC5bPxZqP7Nc/k85TPQfbBLY3H01g+Bx/7nqjw3cVy
NyRNbTfuO4SscQM3KvWAVUAx5XMxeoPoUdHVIsrn4sW3vSv6zWD5PBQkjG3f
E1VC+Tz48koG3ZjLcncsG1TseSUnn3J33P9583m7u7mUeyDXI3dYZ91Jyj0w
J/qb9e/+PEa5J3ZKZzQ08VIp9wQvtyk8L47MCVBUNutBZluM69dcgMkZBhe2
Pdd8NeeFmavlJYesyBovqGVb1E6vNlI+HwnTotYZZ8ZRPh9305IdchpiKfdG
kE3swQ5ndr43/lpq+3HWlKG0vwDxpmtS9DcqKF+AfvZ8nnOykvoLUah6XGhU
5U7vvxCizH/5iOKiKPdB2ij7lgV7VZT74OaAv4IWZ6yhfBFCbPLTJhbR+2IR
LC0VYyuDkmhvERway0dPT0/8at0iPF6W+ipkId2H88XEwCg7TrSY+r5Y3BFU
5chbTX1fxHQkTCg4yPq+0PP445hf0y7q++HHU1NNFeID1PdD/bBs6/gnJ6jv
B3PrD8ohO36hvh/u9w1fq3A6RX1/XB0omCHSFlDfH0b88b3pDkXU90euUZlk
VFMx9f2h99D+QkHrWeoHYLjysIw3ooT6ASjmjlRM92X9ADwbG286n19K/QAE
VA+4a9lQRv1AlHnW6g27SjkCYVWzbuTRRjpPE4ghCuvTPnnnqR+INt6+zc6z
L1A/CBEl2kl2reXUD4LJL7mjnYU66gehK7j2yajjZF0QHl3KLrBPv0j9YCx5
dr5KW01GMN5OVBxNmlhB/WDcMzkkSHlE1gUj3XD95wpBJfWFcEoSn7T0uER9
IQ72L2yvklGuEWKc1QbLXCnrC7HldZkks53MhSBx2wMLl5/oeYRg5us30+yD
6DxNCCJszJauFldRPwR/2la/TXQjc6GoEbk9z40nIxSnK/7Z6dnnMvVD8cxw
nNuP5dXUDwUvyhqpz8lcGF48KDHbEURGGGI8kioL7GqoH4bcHZWzUnaTdWE4
Uv7Z4M4aMheONC5/7/poMsJhNUDbJfmV9cPR9GyK89jNrB+OAbuumUzYxPYj
0Lt9a0H1QLYfAQOLETL5VLImAgXn1sw985Huo4uAw6cog+xPrC+CdlyyyVsv
ti9C8zfZp2qNa6kvgt3TxwUnF7J9ERJzbqQbGrP3F2OOTn9bThqdDzF8XOre
8eRsX4yzg/WiuOXs+xPjxdMIQXYPPc9JYJjYyS8XU24uQVNvvF33ZXYfCcRq
U/VNJVkiwXdnHxzIPsPOl8DFZlNNsgm9b8aXPj9l+b0Ysk4CmSCnPcaR3CJB
8QEbl1WTyJwUOw7udvXuIZtLYaa/Xf9+4xXal+LlobVBYeo62peitWvr2VvC
q7Qvhbv3k+sq1NO+FH26VplNfkzWSeHySCQ4Yn2N9qUY1mubNC72Ou3LkM/P
95zVRrm5DPPr40LuJVIOGVRhdce3VZAlMvz8cD+f732D9mVIc/80bvQmcoYM
nddjEq+LyToZsvQyThRKyC0yTGp0G/3uONuXw2/ymn+vGEa5uRzJL0326TWw
fTlm8M7kX9ajXCKH9fDbh32t2b4cDsJS19Lv2b4csVqBbCCP7cvxzObcFbED
25dj6YTMZoM8MqfAyPopl0L8b9K+AvauB/IMnMhQfPn9bjFSKsgSBZZmBYYX
upI1Cvi8ctv/UEnOUEA6r8O96yZZp4BVQ2lEz+AG2lfgjrhmbWQCmVNC/M75
VuEesrkSD4dubE1uIEOJl/r9phddJkuU8FwumBllcYv2lXDx6G77IYWcoYS7
/vvyBRvIOiXuxdW05Rr9TvtKqItdJTs/U86psL9O+KbBkXJzFcY7/povE5Kh
wsUd1m+rF5MlKgw5ZGyt0pI1KhjmhU1Z9Ts5Q4UP0V2TlpaSdSpoblj29Oax
fRU+vVj2ykhO5iKxdd4AufAw24+EdWiOdlAC24/EPzr3ffJ2ZvuRCHt4YxO3
nd0/EttGjmnWuLL9SCw/p6pdm872I6Fr7Tf9Yyjbj8SefeuCfc+w+6uxbKqk
YwOf7auhCXNyDjNk+2pkfZ8YaX6anpeo0amffPxpM7u/GhU/aFte5zTSvhrd
C4Ri7WOyTo35wiU1I0Jv074aH4uW9JxPJnOLsbeixrf/l/xvf6fkLw==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91nlUzQkfx/Hf3KZHkrRYuogboUlaaNEiHy1SSfui9S7dtglTdjVcRlGi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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQMC1xcX2HId3w/hfbCXMjyj85UDxmdwCPtxcXMQ
XJ7DYfKr3c9KWWB8AQd5ZR6f7p/HoHwRhze/0tu/foDxJRxcI6yCp16E8WUc
jm+LE9t4EMZXcFj/PFVlwUIYX8mhZmnr/pWTYHwVh11qWc7KPTC+moOG4pGq
rlIYX8NB2f14vkY4jK/lIJ7Bp6SjDOPrOOx7psJy8sZRKF/PweFqY0rzZhjf
wMHq6FTt6+EwvqFDwy3hhgMTYXwjh4gj5fEn4mF8Y4fXVpNLWGxgfBMHTdl5
j763HYHyTR3Ep5zZNqX+MJRv5lDZ8PWJsDiMb+6gV28d+bf5EJRv4bD8wqXn
4scOQvmWDvfPdB6+thYmb+Xg8GKv+iIhGN/a4bbg9T1Ty2DqbRw85MWmzllz
AMq3dTi492Lk6kP7oHw7h+vWv/hmxuyG8u0drurqHZPduxPKBxo/yfTVlpy9
EH6Dg4NhsrtSugVMv6PDFP6wdMknUH6Do8NPqa6NO3qh6hmcHGxrhEIOL9wP
lXdy8Dl2VKTUB+YeZ4clNcUvJu6CurfB2eFy8CE7wTsw810cnknX7JXcBDPf
xUGUXWsxty3MfFcHM49W5Q2/oOY1uDqY3D665Bg8PN0ctGSvCR61hMZHg5vD
HRelNSX5MPvdHYoFD386smg7VB7BBwBKf/KC
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz3tMU3cYxvET3GIVRRdBLkFSiRd0E2bHGIjYh0Kh3HslyCVkBIjZglSj
EholZ0zWqJha/IPMaRaVCAJGYApkSGiVDi8d2/DC4qjBCWFbAqLGoFyMGt7X
zDZpmk++fX6/c1YXlGqLPARByH7zffvLn+WDZ40xi/t65jUpLysM7qh6ZwHd
41mReyVsCVrMAaYKD/ZyLLh7o7b65S9kb5jC9mXWT7P90B79T1Xwf+xAKGZG
5kJcbCmCpobTch+wg/Hr7d4jq0fYa1AoeutDnex1CPIddfj9zA7BHw9NC6NO
sDdif0r1hZAC9idY9qT3xOgmdih+m9HZ933I/hTBptKFh4cc5M2wGg7cXeVk
yzBdOrRyZxH7Mxw0xSHcwA5HY+XAzbUa9ucYXzHQFVbDjsC9qlP+K77i+75A
8t/3VaFHuUciqyUp1fCilxyFJd3bfep3cN8Cx9RE/nAJOxofSXzCLdJr5K2o
q2vbdNXC+xhoo45nKo5y34Yli2qvaPuvkuWw5m/cmV3ABv70uV7WUkIWgV3G
umlLNp8XC3ulbHdJEp0nxuJ5SUSo2sh7BQZ9R41nTtqpKyDeeezvu40sxKE8
TyaT5duox2HXXr3TMEkW4tHqrQ9QOLjHQ/F14MvKOe5K2DqL1p119VBXwrlF
PjScQBYSYKu6MXb4FO8T4Pi/hUQE/RV5bu19fr5EuCKax6dPclfBPOuasqh5
r0L55d2qQQ33JPR5jX6p3M89CW0DTQsOnub7kyGxPP79ppyfLxkVHvlB63O7
qafg1R6rKyaHLKZAmhyeg2+7qKfiu6UZDaqhTuqpUBdEZR2a7KCe9r5FNwvp
bt3NQoZbz0DObNiy/qLL1NVY6hXfd6Tjp3lDDf3MrcDG0630fzWOtQ40l99p
m7dNje/LrNu3/kAWNEj3j7+0WXqR9m4WNTgWnVeYeID3GpgujY3M6S7QXouP
q+2xjWreazH3KKRB2Upd1KL9Ye2P3zw5R3stAqTFlrynZEGH9GsfRIQVN9Be
h7EuL+MGK1nUIfdKZ1mN53na65C1eMzsmKinvR5m5+wD5T3e61Fv6UlRPKPz
RTfb3rh55b8TNXSeYMDtCnPA8+om2hsg77fsMNn5+Q3w7EJ7o18L7Q1olhR7
PvLl989838h8d99rM4TRmg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0wtMTXEcB/Cz6LHkWZs2WhG6PVG6cuu63x63q65u3Xsj08pExdClZa4x
O54LlZVZ3ZrKY1GZJFHdntySRxfNREgjXI88YsaS1/x/rM52dvbZ9/z+v/3P
/3emJWhUiWYcx6l+33+edE3oOrFRbH216a8+SITB3JdT/8zh7DFBtWwU2Qr3
r0U4Jg+2MU/AoSnla5KekO1Qhxjnnk6yPR5vG7g7q408FffsVmmEjWQnZATE
HvQ5RZ6O87dLkvK15BkoPfzerXA+eRaqzGqXGS3IAlSWiz56F7Qyu+HZePX6
Kk+yBzzeZX37CbIX9h3dcHPsCwPzHLwVzxSosshzUXE/e6BLRPaG5E6Rc0H3
FWYfKNIaij7nkOehOF37NeMV2RcXLwl7bz27zCxEmZm0t+J1C/N8+HsP1WZr
yX6Ine065kkMeQGkT8vMrDLIIkjSqlp5BdkftX59q0v7mpkDYHrokJ3gQBbD
6key75sjjcwL0b9PJg670sAsgfm674nXKykHXGVR8s4P+r/mAeVeB123eT3L
A9Hl2DBQkcfq+UAEGDryb6TSekFoamx/Ff28luVBGIqzlI4OrWF5MCS9vdu1
LhdZHgzrgUMtBxTsfS4E2VvTRS6FlIfAnQuxad90geVSTD6udIo3MvNSzOlz
MprGUB6K40vzKuttq1keiocn138tsqBchk/nFrRbP6b1ZUjpN1qOi2fmFsFr
p31Kacclli9CZkDcpwdSth4Xhs26ZJPwbR3Lw5B62kbfKab9hUOTNj5XZ0X1
4ch9tDe6P4/q5SheaD+oMVF/Ofx7YnJK/p3XYjxwfON7uofyxXjepTY5r6N5
ihhuPgL9OndVhwXNs2K4eQVSxPobdwvofCKRa6McdOlm/fhIbC7MdHeeS/9z
FF4oYzUVW9i8IwpuLQU76qey+eVHuHmEOeVwQ4k9WkF94mo2r7wSBoX/Ga/9
zM1KBA4ZBEtW0v5V8Cz20yVMYoYKwp6a3fp46q+C7dpE+UtzqlehzXy2fpWc
/gf1cGOEeTWSW5cn3MtoYvVqWE4TrdiRSv2jsQt58XET2ffHf/8CDXOnSw==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQMC1xcX2HId3w/hfbDf/utRlhQHjM/gsKbmqvGh
P8egfA4HA+29lqLfYHwBhzLRn5aHvsL4Ig5pK8x/672D8SUcmC4Uuf59DuPL
OJxeMKP9724YX8HBOmZJ8YypML6Sg9zBLxbZbTC+ioPJhJDr+a0wvprDz3kS
tybrwfgaDnoqh5M+ScL4Wg4mx2YJl2nC+DoOn3OLc47ePArl6zmYsi1NML0H
4xs4zFMobWvNhPENHdoWL7/KUwXjGzncb9f1YpKG8Y0d2Obui2hhhvFNHNz2
373FaXQEyjd1OOM6OWjf2cNQvplDrowhd1UijG/uIJITsNClHca3cDh7aNfX
P9YwvqXD2ljF28syYeZZOVQvqrC28YTxrR0EmJ1kHBphfBuHqdfsCpKPwfTb
OiixKYrZS8Pk7RyEuwqMPu05BOXbO8z/8fJ8j9lBKN/BQUdDU9raFSrf4OCQ
5blQ6UYpTN7Rwbdkx8JWGSi/wdFhl/fToLN6MPucHI5e2XBHeSJM3snhtuSd
VQJ3YPqdHRpffHHjvg0z39lB6fv6uLJjsPBzcfgV9KCxwQHq3gYXB07zkyfk
HsLc7+qw7uvuq2wyUPUNrg4SfwtvLHgEk3dzqFO4FlIUCNOPxmdwR1Xf4O6w
uPxnw/0KmPs9HPSLt23dsRDmPgQfAPBp/ac=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgk41fkeBvB/hdCQyqiEpFXXRJR15JXl2OMc+3o4i6XNbe6oppo5qTQ1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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91HdUlGcaBfCP2LAAirgqaBwMQaREjYLAUC7EoUhn6G0KM8OAsrBZpcRF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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0F9Ik2EUx/G31WA1Rm8R2p9VbiypEbOyOW3pfs5Nc7W1RpCWFYmT0gtN
yAyVvAm2CGqLihFDTDQyArMZsdX+Za9QJmSWkLGBLZAuzKQLb2oVPqeLHXg4
fPg+V0dR2+RwijiO0/59/zYNP9XbXLxqNLKkeYPnyM3hmJjMYQFpf5uELIES
h9o+pgVmHv6trSvFIurrUJjlR8836usRO/rpwskpshztc7W9mjA5BxUTgUHL
LbISzsqo4YGbrELqmSoiOk7Ohfqge7ldTd6OZZbfCqWOrEZyZrH/tJS8ExfT
fU8m46+YNTCE9W9z6si7ELJuscfU5N3YJiR6vggjzHtwPjZ371yAnI9NzofT
Xh95L7T+D7k1g2QtbHk2u7KDXIAxJIayEy+ZdTBez5ZLneRCVPV3z0tex5mL
wM8es8qsMeZ90AidY+6fZD18bxrzvQ7yfvAR9cS7u1HmYly5ccrFd1IvwcCv
1OrqErIBa2Wq2wGe/gNFG2Tu5I7wkruAMw3fa9DAzJXiR+iEvNn1gvVSmBfy
/It1zJwRHaaC4Ohm6kbcbxFaR6aDrJdBEWx0eK+GWC/DGs+1WWV7hHUTWr6u
GK6XsXt1mfBIJ0112+geZph8ly81JZ+zbsad8Y2erPhT1sshHtK7xqsfs16O
qPj94fTnPtYrUD9QNTljPMt6hrkDGT3DXGVGzzBn+e8/yCcIKg==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0Q1M1HUcx/EzQZjE8SAQmoAyHoyacDwIQhefQ0B58LznQ1QYiGTRAkFA
YMVRwEF6LiLRgoCC8OFQ4kEBTTg4FMylFALVCEeyZgZ0BLGmWdnu+1uT2263
196/z3//229jcrrkwDMcDmf/k+9/v+xjPd6QwV892GuUIVRrG5tsac3MwQ0X
b0G4DbM5ekzCh22tmK1xIcjgrl24TraDv9WV18qHmB3R3H3x7uUW5vXwqvrL
m/cJ8wZMeNnAJovZFd1DQSYm3sxu4C5EvOH76zWyB/ZoFzcbmpk3wWd8Q37x
EWYvTGUf5h10Z34JCYWSYPHsAHkzVvWu52aMMPsgT9dorzJh53mwmDbEVney
7ou+1sfiKBmzH2TOfvwMLrM/vq27tC9JrCcHoDh1482H+n7yFrgcrN9jzWUO
RIAPT6D+vY8cBHvtxB1ZIPNWxATeO1er15GDYV8mjG6w6yGH4I5LkrNHBfPL
qPxY+IGZJTMfIRKNp9unveRXwL12r2WFL3Mo2kpTAvz9mIEHM70jnMO0VwGa
pjmnLk/2PgL89my0fncfvY9KAL6yectA61XqYQgTnqhcE0ZWhcEs2SLHtLOb
+jZkLf2TrBZeor4NUxPZdgXmXdTDYX7LJc3xehv1cLxfI+LdbTxLPQL5rpEY
eFNLPQIJ+oRfhD+dox6JsQFFw1ZDE/VIxBu6rE7z66lvx6Qy4/yZvFrq29H0
XYzJjxV11HdA/cWS5d6KGuo7kPa909H+Sdaj0FdyrA2zn1GPQsX0N/Etz7Hn
R6NAwe0Y9WD7aOxbME3M96+kHoMzX83LTyZUUI9B4uD8+PDCKeqxOPb5+eCh
+OPUY3FoURArf6SivhPTIsPt9CxZqLHvRGadmbvF5DtGc4TQVr1YIk0/RF34
5AJn48zjyJxdEA7V/xypzaS+C6ldcte52hzqInxZc3LV/lfLjYYIDp05BXvr
8+m8CGUvDGo6hKVG60ToN22eWbm7hPZiDJ0dNZvLzaa9GCN/1z5sef4o7cVY
/XXdW2vc2F6MdSuXCh/4q2kvwR+zfKdS3du0lyDpQEZo3RidV0mwznNAPTyT
R3sJHGS96e1pR2gvxYqqopubTtN5SCFUlo7ekBbTXor2FHPXVkcN7aVwllV7
Tz2i/8uR4aIuM1HwA52HDHEW8sdux9+lvQyXCx1yeW22xvvQyXB/KpCTO5pC
9yPHmFLavrax1GjIcT/R6kLclffoPuWw8+ip7unR0F6ONpMi649e/5D2Cmiu
Xv9TkEAdimV7Bco6HOf1t8tpr4BDVuWJU95q2isBzmLR2tQoen8lvEJuuQeX
0P9VKZ9+nm6ZOXFPG8us+t//Aicv4ME=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQMC1xcX2HId3w/hfbC/4NnCOosXxmdwCNk4a6oK
P4zP4dB+cz23PCeML+Cw+F9QCdf/Y1C+iMM5k/AvDL9gfAmH2Tqfq2+9gPFl
HDzm6Ux79RzGV3DQySvXNToK4ys52GRPaStvgvFVHB4nX1lwwx3GV3M4YLpG
cC03jK/hEHviYv2xFUehfC2HLWzKxScbYXwdh4XRSwUdY2B8PYd3/FuzJdlh
fAOHmi/5xiXnj0D5hg7Osqn3r/6F8Y0cHtkF8r6Ayxs72By8utwzCqbfxEGk
48FHgWoY39TB60bcjK0TYHwzh6pDXcct8mF8cweDNRf2bl0A41s45CxWFPu+
Dsa3dLhd+8FQUwXGt3LYt7KOZXoRzH5rh6anRqpCgTC+jYO1W4nY7SoY39bh
sOrnrhVeML6dg1O946J/yjC+vUMy7929NqWHoXwHh0XKN42F/x2E8BscHHwd
Lc9OmXsAKu/owMtkeWPvVii/wdFhwf6rxjfvQdUzODk8bFW78zLwEFTeyUF9
KaOG5Skon8HZYVnN77VJdTB5Zweunfdt+5Vg8i4OtoXLve2PweRdHLgD2VbO
jYK5z9VBosFp45nZUPc3uDrsrd4w7bsQzD9uDhsFW8vOGMLk3RxUn2Y4az6B
6Xd3CDm/K1qlEspvcHc4IDRpX44nzH4PVH4DGp/BE84HAO09AAc=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQMC1xcX2HId3w/hfbCfr7xS8g87jM/gEFWUsz2e
FcbncDD8/G8Hw+9jUL6Ag/Viv+UP78P4Ig7iv07fmX0dxpdwOKqiLW+/F8aX
cXC6fvHs6V4YX8GheZLWSbs6GF/JwVXm3/0dKTC+ioP7qbhN99xgfDUH10Nm
Ctt1YXwNB0nF86eL3h2F8rUcPt3ZIDxhGYyv43BugqCKQAyMr+fwiqON+7o9
jG/gYHzEQEapCcY3dGg2yqyXyYbxjRx2NGw9emvbESjf2EFk4o+NexJhfBOH
EoeZ2ozxh6F8U4dpk77N+FgO45s5XKou2La05RCUb+7gvEP0Zcnhg1C+hUNy
wHH++U9hfEuHPq6oyAWXYHwrB5+u9cc3vTgA5Vs7TN0i1jB/F4xv47BEb3fc
Y7i8rcP5C9432kNgfDuHALkztWxFML69g+PjCJu122DmOzjkyLg0/Z4A5Tc4
OLxu19LQmwZzr6ODg1/OOi4fmLyjg/ePRz9VLsLknRxEj19XEP0PDY8GJ4e9
2tfZEgRg4ePsENhp9mie5H6oPBqfwcVhSrtKlOXyjVB5ND6DK5o8gg8AHBHc
vQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz3tIU2EYx/GDQXRbTHA2sNW0GVG2Mi9pte23m0ut1ipYEmFUMxBbOiRq
gZwySAcGjVHMGrE0w/ojZsu0cmot90dzdIHGgv4YFi1HFCYlQXah9wk6B14O
H77wvO+Te/DYLlsGx3Hlv8+fP33ieFejakFk+K8+a4Kxqv5sEZnD22L3e0U2
eR48Pn/tlUyyGPdtRVp1BjkL3nSgc//0GLMUmtZCxfcJ8lLcq+3IPxUhy3H+
4i1DopecB7V0zsMdzWQF3O1zEyN7yCsx2jTTt8xOXgXRG85SZyGvhoZPZu10
kgug7HZapVayEnFXn9n97QnzeshunvbefUUuhOfC3upoK3kDBgaSoZdWchHu
dLe463LJxegQ+cOH88glsH951v7RH2YuxcLXzsAnH3kjavSNa3OmHzOX4UhJ
wfI2I7kcD4ItJ6cM5E3QBeWp4Dh5M9JKGX/gKnkLGn42jbpekFWIB9ddipnJ
akyp8xMNzx8xazBUb7aFlNQB2eQKwxkfMw8EUofkM/toHy1c4/1fU3ZmXouu
3cPK6DXqOmhKey/3nGP78TpkTuQ89Tpovh6xMUcyZGf383q4o7ZJ8ZoR1g3w
3z4xu8jEzBsQP6r60fOO3mvEknilwZKm9xlxfDA8OF9C8ysgCXVe/0D78xW4
cXZxssxO801oG5I4IttHWTdB7alprp8Nsb71f/MCc5WCLjBXJegCc9WCLjC3
7Z9/AYSeJ8c=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9jglM02cYh//osuCcyFXGJiGg4AbjENyAitifgkApLaUtZWYXYDmlzEjY
IDsoxyxy41EWNwsIWyGTgbNyyWidYJ0wr0TMmJmT6JZMHQgiqyyyLX2//ZMv
/zx53uf9Pu+M92SZKziOe/ff89+ffY432vdGPWcx2WhWoN9cb324hjGHFb1v
bkh3ZGyPme5f7gmdGDtCFrRKFmjP2BXDdauajDPnid1R9kzDMd00Yw+M8eyM
n/3K2AtZ4w91u4YYr4f6jxvCO0cY+6Cgr9v1xRzGG6Hy80h/EM74FQz+UNpo
mh4j9kd5bnClWy3jAIx4JC1ZcxkH4VrslGQpnfEmiH3XNRfwGIdg8vHicNbI
KHEobm0J2PrXUcabEfVSvqnkAePXEH6zblJtYfw6opsLQ/Z/zjgMlk8qynY/
Okccjuv9YecjWhhHwHosXll09XtiPvLsrzqo/uct6PWolH/pwuYjMf+sO2aH
md+KDyY6j27KZhyF45/K9/SNMt6GSxPiNsgZC6Bc36BqLGDvAybMNa4tKeQ1
wH13v7sSf+a3w2K4op7KY347BIHrktwzzeR3IKxyOKH7sYn8Dhw+e9ftto75
aIxUBTx51Zv5aHjGGGo2Ln1HPgYa3XSTv88A+RgUe168MFBJzO2E/qc72qWQ
M+R34grWLnxYNUg+Fp3O2rftYmifJhZut2U80yWa5+JwebI8bVTF+jj4RhlX
FqcxH482+x7DUC67Px7B0ftk5qB+8kJ48XdJQ1bTfRohfNtE3nljfeQT8LQ6
T5KmMZJPgFuh3QlrySnyIhi2pWm//phYI4Ldt7eCx9+neS4Rbo4HHHT72P5E
lIouNP8oGiIvxhv8IXlZFLFGjNAzDoY+BXufBAdr2u3FFrZfAhfVsrZq5iT5
JJwsnFVz/F7ySWjwORfzlcsJ8lK8dcB0ccir28aQwlQd+Pu1LAPNS3GkuKR9
T1mHjc1SOAsD+MGCduqT4fWNkYt37qQ+GVn3KyRTGV3UJ2OkdVCfs9BDfTKE
c4n15V2sl8E57uezWfV11MvghdLWHpGaehmgmM7mxcZTL4NTnqfMjhcrsPVy
XLcKQvNV+dTLkTMdJi4Keod6OUSX9Y+yn1Tb5s1ydEdI619eq6VegQaOtzhj
2G9jKFCy3B83vlxpY40CrdL8hcy95M0KCHmnd3eUZ1KfgtP8Q0WNixXUp0Ax
N1bBOdRSnwKHOa3T2OrD1Kfgi/li7vgGPfVK1K4xpgacIoYSoX0FAyOH2qhX
Qs37++ZTXQf1StyLzPmz9vlW6lMxnzvxgtSvhfpU/GZtiuxKb6c+FdKgppUf
ZbQJ/gFc2dhK
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11gswlI0ex/Fn8jarUi9vpzjzpuiNUknlUgr7yy2X5LIu6xLL3kjviS6n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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zws0FPgeB/BhT8/toVXZbI8RF0W1SvLI+iZveY2IvMbMMBPaUltqhYlI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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10AtUzGkfB/C/e7SICKmVbHTalNtS0vqmmqSLbjNNus21ppK0rFhkurxt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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzWtI01EYx/F/ySpHkz80SMqRKxGJMZpuLc3Lb7rNDWqybCMss5xdFsWi
QsplzigkyRH1oo3CUUnOC7kXQTZL0zW7IFQTWlJiiESkM/FFcxhR0XkIPHA4
fPjyPEda7dh1aDnHcco/9+9Lh4/eO1kgfDHwT3NFIWO52JRC5mCZWN2gE5FX
wblSpZhOJvMIR++bBL+GmcVofeB+HR8jp6LHsWCRjJDTIK/s3JvdRk7Hsg1n
yiN3yBuxYl3/aJ2PnIFIq29h3kvOxL7o2cm+ZnIWDq61BqQe8mbE3c7j/FGy
DFfnS+uGFGQ5Cm/WvvnyKsy8BU3KXJG4hayArN5i948/Z86GXaA1DXjJOfjc
VjM+1UFWIpTpeJxhJatQkaw5JwyQtyJtT+xG1yJZDalyzZNwCf23DXz7+q5b
u6nnIiev0mDvJOehvbd+6MRD8nbY+q5JJEFyPuZSFl2eBLkAj7w/mrJ4ciEi
7mOOxAVyEZxjU3LR6BAzMPyyxu/rYHYB+jJj1eKRQdY1uP0+9WljLbNLg8nY
hwbhCM0Xw3Nxp//yINvvKkbjlU/qMluI9RIo5idOX3r3jPUS7Iglqr6bab8W
Lekz/OxX2q+F/sD5bz8F/azr4Olu3iSvoHkdqmVms2GGmdMjKZgfUU8HWdfj
rsHqSlL1sl4KZ/es+PrhHtaXmDPg4ylbfP/bAOtLzBmXzP/3b0GqCr0=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0Q0s1HEcx/HrSZLqNBNxdTUhqXm4Syg+ymMcR3mekYoe2OlJj3QeSnWl
XBSGPGx6uEJ01bp05CFijZXVepCcVdSqFbOe9LC+v7X5b7/999r7991++/3m
xUgCN47ncDg+f9bfP/u4j8sTV+jcU//TJxe09dsKtJk5GFW2Gkd+bSFrQydg
uLrqJzMXN7XWdFZ8ZtbHL62BIcceZkOkFFyQN6qZTbBJ3RE1U8nMh1WmbPpM
BfN8xCpiCkRnmU2xLyOpLTCT2Qy8kYlGr3OYLRBuLk42imC2hNnudoNCZ2Yr
HAs27m3mMy9B8R7/itFHzWRrJHU+lx5PZ7bBaN4ThO5ltoW5vFfTZsFsh5ea
+bpLJzMLIBBsFwTzmYXY9ralfjijibwUzpvM4jqmMNtjQ6Z7zLL+RvIyTIKv
gFfA7IBvjof1KmXMjthV1Ji1Jfwu2Qn6wtp+OznzckQWlqoEkcwrUMHvMy1z
YHaG4aG5PcnnG8guEFdveBc9wAwET+MMuSwmSwFJwt063UE1dVdUOfAexhve
pu6KuDecQf1LKuor8bj1U1pxNFm6EjNcBpr8ZLeor0K5OM6/S3ad+ip8cP2q
F1F3jbobdpeemnO+t5a6G0RfUu1rzGuouyNLdVTeMHKRujuaVHz38KAq6h54
qogVDieUU/fAg6MLWqxHc6l7YqrarSy55Cx1T2xukCz/bpBP3Qvxg0brNBPO
UPeCU5DmVXc37ed4wyDUlauIyKHuDe7pXJPZ009SX40QrQPtylQ59dVI2Zq3
TqabTd0HTlnvt+S9PULdBxNfSIpmZSRS98Xi/GfCEOcd1H0xdFlPHpKdRl0E
yazghlabaOoiRD099iVUHEPdD6bj9uQndZ2j7odJa/dXFi4so+6PxLC1N2JF
7P780dddOLk6vYK6GE80YXfSK6/8M8SIjVpv3WdFlorx0HTkxOxheo96Me4v
tJXs5F6l+QCoFgmVvHsKmg/Aoxeec0yMSmg+AJY6HzVBB+k89WPMCUSd7o8z
N0OUND/G0v/+DYXkecI=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwk0VfseB/Cd3mnwCqGlQdItRHmklCF8SSUazPNwznEmrzTdcl+p2+nh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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdznsslXEcx/HntM5ImJTELKmEU+tCQh2djzvHpdFQuRStXEMXFWoOG1OU
Rpgykk0tVqrFye0cJbpZJrK1DCOx1nHL5NJRzffnj57t2bPX3s/v9/0ahcb6
nFjGcZzo7/vvyx6t7rI4W7VW2aLGRMmXQ/RGNJk5WMwnBwwutJBV4VZ8pbPq
J7MWNGYd1loPM68B/0yggPeFeR0ssw4nKNqZDdAXZjapLWXegGcFNaYpp5k3
omms83uEL/NmTI6LRblWzFtg9KFTwNdnNkVmSloXb+gVWYDZvODymULmbUht
Sw8PTWfeDsfa3raJJOadGG0LL/rd00zeBavQaOF0ELM5ctRHNIzHXpItMGfT
nGZSxbwb77x12/2WbAnVqZzs8CzmPVC9EXNIlvKCbIVohfu4sbSJbA250mre
Ll9OtkEf/7WKZEpG3otLCrVik2zmfbimFmV7RJtZCNch3QaOx2yLmiwTN/3r
DeT9OMvvLWs2qCeLMBDGnw2oaiQDotRV3y5G0nwJILXsVkwwc3aQf9U5Zv+A
dTtMeRoOt75h8+wx81m9cliL5knsETj10SvRrpa6A34sNOo+Vqmm7oCWinLF
DpmUuiNSJc7KSQH9L3HETH+CmdzlKXUnFGr4TV/1fELdCdOVWquf99yl7gyd
Cxn+vkf9RYvdGS6/OoR987cWzbmgHUl14vs3qbtALzjm4PHzOdRdUcI7t9B1
Kp+6K3zMl0uUubnU3bCeEyoebmXdDXmqZWH3HhVSF2P0bXWjpocx7SfGygF5
SWZsPO3njopEUZ0sLoLOu6PjdmBWqV4BnfdATwg/TYWj+yQeiPd2NIzqon05
TwTVzw2eLA2i+z3xfsUms/47GdS9oPzkFBk5V0Tn/zN3YMl/AHpvPoE=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQMC1xcX2HId3w/hfbBnrX/7qZwdxmdw8F/yKq2c
BcbncDi3+aKxEwOML+AQsCRsze8vx6B8EQeuP4KrJF7C+BIOUU1HOs0OwPgy
DtphqUb6a2B8BQcTHyG+p50wvpIDR0JVq2EhjK/iECq6d9sSNxhfzSH2wY31
2wRgfA0H22dGXBfnHYXytRyM418/YEqF8XUc5gmzLY6Vh/H1HG416P68fP4I
lG/gwFWbOPlhKIxv6PBa6kHmh/mHoXwjhweZR3YesYLxjR0mnEuXu+ML45s4
yD/ZfeL04UNQvqnDBe+8k32XYXwzB+1zPi/qrhyE8s0dNi1g9BHYAeNbOLw+
oLj4WhFMvaXDauPgzR7iML6Vw/SDrX9+34bxrR0csmcE62XD9Ns4xKlpz9ta
DePbOhilWHOwNMH4dg7K/FZN4nIwvr3DwbvLxQpkYHwHBwu9mwrqjVB+g4OD
m+Syjm1rD0DlHR0+t2rX3nWG8hscHQ7ZpzBbGO+Dyjs58GWcdn9qvhcq7+Rw
JOPYNkttmH5nhy5Js8/SpTDznR2CCg9My2+Fybs4LHOtl+johZnv4rBAWEFX
1xYm74rKb0DjM7ihySP4AGIS2ng=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11HlcTXkfB/Ajy5Al1JNlhrkViWRKWmjoo0K79ttyq9O93bqNbCEz1jtS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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90Ak01XkfBvArNSGkbWihW0pDSSWUFk/Zk33vhntdLqUJU+PWO8qdpJBl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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJw10EsowwEcB/CRV0I7sEzk2Tya18zMsH3nJrSiPA6KyaMY8lxGyZCDgyEi
RA7aYUVqDmKL2XKTzJLyyCMnY0MLCfn/fvXr16ff4/CLVbaXNXizWKyE3/yr
FGzHWkdBoM30r2dZ+OrNjsOPzAI3znDZ9G1lHIAww2b8jYfMhtHVdj79Sg5F
hiXEnPhADkf60qDk+YwcCV505tOelRwDk2Cyon+BHIfmjZrqog5yAgo1Jf4T
bWQexJzUifM+chL23PpAroKcgrt6XXElh8yHuc7POvx5yDgNySunUvMiOQMz
+oc0sZqcibeRi94pL7IAFc6X0nKXhXEWWnp2db4x1BeiCl2ieSk5G1fSxmSB
hiyC4+v92hZEzoFV4bB7OumeGCLv8a+GCHIu7tWeR87AAWMJVMasq/XRfcZ5
sOxojrROcj5q554MqlaaL4BMOyzhLZOlGCvii085dF+GsG317UIU/QeYdR/r
jKmMhwCF0Mej/aB9Oa4nP7RbrTaTXdntDpbL4TopVbKrjkw/FKS6cQ==
           "]], 
          
          LineBox[{{36.175377376914966`, -0.198}, {
           37., -0.15355310498460578`}, {38., -0.18391316786582093`}, {
           39., -0.18492165787189482`}, {40., -0.1725735375044583}, {
           41., -0.17845318060299292`}, {42., -0.18203501874644898`}, {
           43., -0.18203501874644898`}}]}, FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10G1Ik1EUB/DH/OCaIxdJRCptMkzzpZm66abz795084VYQRlSaFZa2ETD
Mgsf7EPih8hKy4JkLTMN06WVaHPZNBE1sTcDNQkCM0hDQSmVXvCeC5fLj/+5
nMOR5lgtxzZwHKf6d/+/dMTj9sIE4YBrXT8TH2bUDYb7kDn0as9N5W8iC9DS
+MeyKCKL4e07KxX9es3sC+ORi7Lp7+RtyOnr2L0wRPaHu3dS8bmJLMHStbPN
7lJyIMwxLcXlB8kylC0OVwXryEGIixJ0F5nIwTBEZod8We5n3gUu6HHJ6S5y
GJaMN04oZ8kRMEcp9ymHyXJsrtoam3efHIlVZ8jY0F7yHvAGffYnJTkKVpPn
6IiEHI3tqmSFy97HHIPD6e4L4x5kBa6Xcp7WCjezEvGzy+k7M18xx8LhXd9e
E0qOQ4HbfmA08CWzCgWKN6Gr1T3MamjkXNewmhwPY6Wxf8nazZyAq8d/rHXm
djJrMONVd7t1gJyIk5lT6rnpp8yApkkoO2RpXzcP/A6bcO2fY+aSoJXUR18R
sHo+CSsld8W2Msq1aEpa8J2XP2G5Fuf9Wu4ZminXIaJ4YzycHSzXQV+VUFJd
yeo5PczlHu/tbdRfj6JiZ5bTi9VzBjhq5N/OyJ6x3IA2s4+gte45y41467au
3Jmk+YywzOuknCftJxm1tdkfF+XMfDI+BKQ/EBlesDwF705V50tG2H74FKw0
++fKdnSx3ITCBrUw+jL9N8ERMeS0PaJ9m5GRNxYgbmT1vBlf17Y4jjZQ/1SI
NRPhqpusH58Kf6lo4VI9zZ+GwqzMmIoe6p8Gm3Dw1oxfp+sv8bEedg==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zglYDHgfB/BppTe1dkstsWFSVEzlWEqob6VQuqb7NEdT07FRitcRsx3u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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgs41Pkex/GhjY5UGyqdVKMtlWKTIhEfXcgl13EZ1xnMjEvC1qZjt7P/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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgk4lYkex/H3aiGtl0qkuUeplBpdKZcsPyGlkn09eM9OUZMmhSln0jZZ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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zVtIE3AUx/GRRrWwVljIMJhD5gWTLDdb6fbb3DTCLjOwSCoaGCsHTZi9
bOV8icJkA4skgi4zY9pkM43NoaazTUkwaLRoc0WIEDOURQpudsP/6cDh8OH7
cHK0V2sbNnA4nJK/++/S8MJ2QwU3OLquJfmy8/EZ11YyB6Yx6d1EBnkzLh6f
Sdo2knmImbvnTYsB5kzkm/gBVZicBf1ujSfaS86G/axgYZuNLIB/ot/RYyAL
Ue/LaEqoybnI9SyXnUsni+DuemFribxhzoev7n3ap0lyIR4NZDqeDJKL8KDW
3DtymlwMa4r70r42wbwPBdOLkbfz5BL8MM4suBzk/Yj/zt67YiYfQE8692iH
hlyKX1PjqVmnn1mME8rGuuFnZAl4PolCV04uwz3jLc9TAfkgHFi70y0jSyGs
aXHEdOPMhxBs0runO8aYD2MPP5yKfiSXQ2/e3qUzkitwe0s4+WEHWYacG0Or
32VkOYpnCu+3pV4zA64CbfuFzyPrtgCiL21ZSeMw6wrkWcWtS1PMFgXS3DX8
ThF1JR52RkMDwSHWlVixHpubiw+yXolTuniecPYV65W4aY081yU8rKtQv8sW
+hrwsq7CpL/9kiFGXY1v8pOrRedHWVejb+fPRquAehWueb394svMlipciWrf
CVrZP041pMJmToPEzXo1SpudIc2m66wf+e8/xeoCpg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0Q1M1HUcx/H/oY4MCdIgEoZhRBFqGGBCAR/gDrgn7u7PHWYEhHQSKHdg
CTEi/ozKyZPrkEIe2hVgJEhoYDxtnIAwcLOgtRs0DSpgPSyOSRZFWM3vzxZs
jL325vP73nZeh4y83o7juJR/fv/9y36crY3ZofeODtyRLfycebGj1pGZg+sX
TrzMifke+F5TN123Z3ZGltrUWnTXD2BMEG0x/jFCdkPv0uTKjUlmD7TbmQtf
G2R+GG/l1ZzuOc+8E5e98lJvZTN7w/nqvMQ3mdkHhw9k2EtUzI/D4eXMUZdH
mZ/AanRIjmwT8y5MZNa8ODhyhbwHEem5Y/d/yOwPl5WjwTYP5r2wpkhbgyaG
yU/h7YpCx9xM5gC01HTkLywNkQMR0HLd5J3EHITOykd27j41SN4HQ7jLyrez
l8lPY/ekT/PGm8z7kZGcpkz4yUIORkDhef6XMuYQFF8wxIoUzM/gvbR09z1H
mZ/FQZmh9btZ5lAY66e7KjKYw7BaVmtqTBkgh8O2f3xximcG9D/W+ctj6P8F
oMg7scrpGPt8EVBHy1fSNrIeAYtbnMXDgb0fiRcurZkXluk9IRKml6YMom2s
R+Gm3nxb82A/9SjUzfEzJU591MUQHd7el3qjl7oYfRMX3Z9s6qEugT7/Ym3K
993UJRjP7k7UDbIejc1zulztz5eoRyOsStkgruyiHoNfnxc/JFpm+xg0f6LW
vP8D3eNi8ZXJXxFqpfeEWBTkiPwOln9GXQr3Pr634BBZkOKWS4tX0i66x8ng
1y8N29tD9wQZ1iQlWZ6GDupyFG3Ne+O3kAvU5fj0r2VX4bF26grMv+nfvVja
Sl0BW+IrjmekzdSViIlPNkbWnaWuhBvGm9ZWW6jHwT5Mk93mc456HMolnTu+
VrH7KvRXDytt7uy+Cqpie1fJ3ftqbD/+531ds3Qfaqg950+26eh9QY3C4cot
DvKmO7aokX5kOI177l3aa+Btva0/FdVAew08NllT8/1qaK+B9dVtc9OKKtpr
cPbE652BZ07TnsfoPlNp8jt1tOehNS0n8A7UBR7ighavNq6M9jxKZvoDBrfS
+1w8LLKG0cRGeh/xuNKu89gQbKJ9PIJHr+YoPq+mfTx8jSP1J+roHqfFWMax
pIodH9Bei29M9h9bsuppr4Xd9MmPZgPp+7Boke0/tFAxY6a9DkuexTZ5EPv8
OmzuGar9/Uvqgg7Xpqo3HOk4Tvt15hL+bySgNL88zziQQ/t13bLO3IF1+3UW
/vPfWbbkKw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11Hs0lYkexvG3mzOV0sxQOTXHJZWc1FBStsuTqCT3+23btmtoddGklM4r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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91ns01Akfx/FfbUpJtU8ulS6jlU2FJLkVn6gouY9xGcPczKDLFrs50a7Z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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzg1I00EcxvGlpiMrWuRQyVgiTTNSm5mmbs+m812rmZQJgZKl0otOzQpZ
/xB8m1ChGOgMcQgypm5m+YbNbJqWLUsiWWavSuWSlC2kkl7wjsiD4/jwPe5+
2zPOyTLtWCyW8M/+e9K16YU6N3zdA8OKvorc18tmQ5yoWZixuklL7anZSGrt
XxpfHibehMU4xqhcpN4CxRDjIrNQu+Lw1LMp8TvqrQhUPywLHKPmQc7lGnXX
qT0hGjAv59dRe+G054UJcyX1DnT7jTQ7nqH2RlptnqabQ70TAt+DRZzHQ8S7
oOxsWXsim3o3alVOJUIHan8Ykub9clqNxAGQ9E3P9ouo90CSb6jWraEWoN50
QModvE8cCL5SX76QQr0XZUc8LNb5QeIg5DZcvfH5OfU+2Ion/Xo2UwfDOTMg
f9zlHnEIrE4dqY/i7xLvhz440XL8Qz9xKOaSLiaHqfuIwyAsbRJnTfUQh8Mn
QHXWlX+HWIi58xUpDdIOYhGK5ZOaowvUAOdmjWJCrl8xAzQPn8q2ZNEuRlq9
NrnpJTEjhkYeJGji3SJdAq0Dk5Nu1pEuwZMBoU3Nv016BBZ9Ilv6nLtJj8Cv
Q+mpnz7S+SKxcZvK2/ctmZ+JhKK3sdra3kW6FCfN9q/GTOQ+I8WoW9+VnyWd
pEdBycvispXETBRsVSEd3/3p/9FQsQvFvaO0R4PTVqi3E9H5Y2AqLv8WMd9O
egy88kam69ga0mOReSxVaLvUSHosamQZQx4FdaTHYUkocLxcWUR6HHjGGf57
UwXp8YD2i06xgdxn4vE6veup4UcV6QkoVV7T5hbQ9xMQ+qbQ6ujeRnri/2ZW
mZW0qv/zb/70Pd4=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0nkwlHEcx/Fn8oeNkt2hQ0zR2nS4KnQ4Pq4NWZbSVFodbNHUoKaYVtOO
jommf5KjSKwkIZGUarPoQM3aDpUyXXaMrllFjUy6pu+vZjwzzzzzmvfv93yf
eeZnuzExUj6G47jQ3/efJ7vMn5QkeZncafyrfp9zNqo7Xf/MgXvSJ44bx8xD
j9bpu8e322Rz5MrKTrp+ZrbACV2nt5OBeTLMDHf10Y+YrdFx5p1RYRvzdNgp
xo4Y1TDbQacd8jc9yizERZ6lp/YAswjzW5O3l61mdoDR8kWrqvyZZ+O5XjNm
0tAt8lzEV/S2Jtmz7gRbmWAd95R1F+je5BnSSpldwU9oF8ljmOchZKGf2teU
eT5mCYtrrf55AZx5+sGgOcxu8Iyu8olyYHZHhGEgdZf6JtkDLcMWNnZ85oXg
qbYaPu5gXoS9F+81tDgyL0bP2jZv8ckW8hKsM1suD0xl9oRs6qd4K8tmshfs
+CKBVt1E9sbm7sNpHQXMPnDb2fXT2VtDBninXuUmS8hKoN+Y61lx/zp1XzTU
lkarflyl7guL/BvvHfbUUPfDPFX721exddT9kGxcsCq9gnV/zJasMeuIyaPu
jy8Tmi4XDZdQD0Dm4oTzsamnqQdAnn0kvvrtCeqB6LQ8vkCXlU09EA0xionp
aTnUxdiQ2N4orM6lLkZhyspD1h6F1JdivSwxoXF9JvXfnnE9qa+P5nFBOKZ/
MbnU5hT1IBQeLJtiG3CBejA0mY+dU/ZUUQ9GicRDeNzxHPUQKGbyt20yraQe
gq5pDxzE42k9twwZ0d16fR/ryyBT3HzW2kb/iwvFU9ml8kF9PfVQVPZvz+O2
sPkSHGrOjouVkpUSxHltE0xoKKYeBqtPqt4frvnUw5AT5oZ8Pvu+cCheGxqz
9rP94ei1r8sXV9VSl0L9fomjtonmQ4oP++Q2flFXaL0UCe4zuRAdWSPFWd3L
3crya7Q/Ag8Hi3KujtD5wygrIyAwGa53iSJrIjBQbX3j4FZ2HiMBc6/+SXX0
PkQiQ1Tf+VWqpv2juua/fwG+oYWv
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1z3lI03EYx/EfZmDmdGLWskSzDE1ZpTnzmp/pvKY2EbZS8h/LCBM1CvII
GmZkHmFEEUpMTZd5RC5T8JpHrf5TqFxaWd4dEOHCylIqep4vfPny4s2Xh2dH
Zl5qlo0gCLK/99/LR2y5kx9h/9T0X18jS1Jbt3SK2ALGixzVWRK2HWRVDgWJ
TmwxbjuZ4PHDTN6EtPPrirXLbAneewykl4+xt2PMe7FnrYntiU+KvFZ9JdsL
NjWnfhsq2LsgtYp/FWWzd2MxeO/EpB/bB7UTmpaPAnsPhqrbel2nn5D9sfHn
l5Z8I1sK53Sfec/r7H24aTnc+eISez+q1b6yJkd2APSSnNnx1cfkQFi1Jxsy
ptkHsLA604ASdhD85hzK5UsjZBncTryRf7vMDobLTF1Ax8ow+SBqx5wCrU3s
EBRq5JnJInYodvaGejamDJHDkDiYrh+pGySHQ1naplDPsSPQ6H/r3vQxE1kO
lzLd6FZtHzkSXWtJWqN/Lxm4YtYU9xup64Cea6Ve4s/cFXhpHZgSjndTV8Cu
ItCa526kHgX3G6P9lvAO6lHQv7LUXO0gC9HwNSd9yE1qox6N03V9jnPNZEGJ
9sqcoyEKA3Ulgrq2xdk/vEs9BgbN5ndZrxuox0BiK30+u76ReiyEZ99VbhP1
1GNx0bmk/2wK9zhMGVzV3ZP8Pw5eZbkrRc00T4iH9/CRc4fmaZ4uHuNvDRsy
ltupJ+BM9kLYvJT3S0BKmntVYcF96ipIzEMPlMk0T6fCBWml7ZLokekPidkR
0Q==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0AsslXEYx/GXXEIaW2fFUi6t0k4SjiPh/Nwd0TlHrZJqdHbUQpqJuRTm
MmYSSSi3WjfSxVwKdRyEZqvFWsumUghbdhZLqyHN82/j3d69++z7Ps/e/2tx
MjpIoclxnP/i/e/JLqP3t8656vcol6QWdQ2I+PW6zBxSrp85YKLNvBrjC2Xf
3+gwGyFss1JRqse8Dl/1s4/NGzJvQFHhfKT1TDd5IwrzDdSHhpjNEdxiyB9q
ZbZE7mDMkE0V8xYUlHsmV5Yxb8XO2eIRYTzzdhiaCbn6g8w7sCM8r6Q3gpkP
64Kf3oIEZhuovIv64uTMtpgcDCtQOzHvxvW1d9zybZntsCp93r5YzGyP6aqH
3QtJzA6Q9wSLJNrMAvCzLjWEaDE7wuNEFC/Y8yVZiGcO69XGr7rITlD0T8Ta
tzHvQcSoovqdA7MzLqgb6lUhneS9uBDZonJP7yC74Om4WSXfREV2XZwvf2uV
3U52Q8CktMMtn1mEghQz045wJRmwsz7asUZIPRX4nZxv6vuKve+Oqxe1e344
PqfujuM1OSaZzq3UPeBaPHZbovWCugdOzx3ZGcex/Z7IfVA3nilpo+4Jl29T
XvcusvN4Qd4cX5xpRedJ9cKClsYcr5n2cd6Q18k/adTRvlRv8PtkoV/yGqj7
YKyx01b3eAl1HxSNpPlET2ZS90Xcny7Jm/N51H0xc/Zu4odTsdT9YO77KFCj
P5S6H/Tv21wbVq6nLsZA4+uSPl6AaKmLMTV3M8OiIXbJnD98/JofJGXE0Lw/
Jgw2Zc3WKKjvQ++vDek2iVk0vw+fm24lzPNyqQfA9GnO6uc3DtP8CnOBEGha
XDFWplEPhEOTqlbM3aS+H9t2hadNTz2hvh8VCXrpYkEtdclyp64wJ0WU8EXE
aBEZUpQPKxc+8tn/XOF26Yp5GUq9NDur4x7TvAwK65EzFcJHNC+D5SlhrE41
fV+7DJd1RgXj5fQ+F7TcCPq//y80lnGo
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU2EYBvBjmUzLXJliEulizQveK295eXROncvUkVAzKg1RwpyWGUnF
RJAgMGMVaGleIi8YFtrQLm7TY0oUapqa1cJLCmqiZlKZUdF5/3AHPg4/nu99
eb/vHEGKUp66jmGYmL/r35se/lB1VrBFl/a/5kOXBLUT283IDDrZ8w/4JmQe
nifn9ZgtvODMR/+p/DnpD/I2NI82ssmfyXbQH16Zdn5J3oGHme5B1WqyI97K
fEvKCsm7sJKXUGrIJAuhk+ef1gSSRZgbbP2osSY7Y6D42X3mfSdnV2zJPZNV
0k12g9QpSaNUkz0g+Gra5MAne2GoqmBySkD2xrjSKnF8keXsA8Vso8jfhfI9
KK4d9WUl5L1wEZv1NgaQ92E5ybD7rojsixmZ/lMNS/38YLuVTVePkP3R7P64
UxhCDkAYay1IyyIHwvOpMP6mgbwfdzQjrTVN5CD8HhRP3t5IDkas/Xx2w4YO
ziGwyynPFk7rOYfCpmWd5RHLds7ASf8TSzqyCmj/LipSV1EehrNjFZpSsioM
gW0t9h4fqF84FBNf0kfitFwejjRTR/NhuY7LxXC+etzPheX2q8Tg8Ro39dRT
HoHrQtHEm0XKI4C6nU7RYdRfgqKBY6Mt0dx+lQRjr1WbFXE0XyS0w9VX5gOo
PhJzq576X+5UHwWLgbF+nzrKo5DxpOKaoY/qo3F5pDvn0ivKoxH0TeL2qJ5y
Ke7xog5NL3P3qZJioYV30SGD+segyavL0nWqjctjILFZvVFjT+eTQWm7eLRS
Tf1lSEm09VP00fc5sNYqIzOxRnksxAUzFzK8ab6DaFa+68i3otzITJxRHgfH
9NzC4F76X+LRNrve3Kac64d4qPMKGvomaN54CMYrR9POcefRGZlJWGsYWWVk
nZEZOX6WzfArU7n7gxy3WBPH/Aq99g+laYOV
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxFzglI02EYx/G/2qVZLUzs0C7FMsK8NjNn+zV1Tp1malZiDQXLIPIIpEXG
MglCyoEFQZmVzdU0NQ+UHNqmeWSimWiUWDJEbZKmQ4xpFz5vvfDy8uH78r7P
jpT02FRrjuOEf/bfky3eYElGkF1785KmRfwGQYnsnzkIbROUimXMqzDbmapR
mtvIPKwc63C6OcW8AfqA2WiHIeaNOLu86+3VAWZn9Go8Lh3VMW+H23FFjaiI
eSfEW2UTKQXMbvh4oyw38zqzO3xy8nIs0cy7Ibj3a0HuzrwHrTPmE7L21+S9
EGd3nfZMY/aEVcPJhH5XZi90ycuTk5payd4YCMZcaTSzD34621SUzbeQfWEZ
Kn1/8QuzHzpfxdyd3MbMR0TjyIW8tcwCWE+b6vNzDGR/VJoK2/pG9eT9eMod
7ndTMQegNixvdtGf+QDqYu3OpXPN5ED0zReEWAc2kYVQpM5rezt05CCYXdfb
LG5iPoiAI8P8FodGsghGtXbiG48ZcOouzPikq1+yEpB3myZFdi+oH4JeeH5h
S1ot9UOwb5JreE6si1H7We0x5UVWiqE2OKTLEzXUgyERnUrcd7+cejAMPnfK
i1aUUg+B4/SZ2xZFNfUQlKumvMOT6D8uFLnSiidWxVXUQxGpMvUnD9N9TgKT
LibLcaySugTf/cTT2fwa6mFIuSLPjLevox6GW+tE41FG9r4Uo5erfN88YPNJ
MeJfZ1ssfEQ9HH49+S67jNdESz0cXKWkxsW5cMlcBMbj54wfgoqpR2DzV8GP
QX4J9UisKcqyHOt4Tj0S2h4frfTZQ+oyxBni1Pmtj6nLoDfPVL9braUehfyB
kSSV5SX1//4Ndd40VA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQMC1xcX2HId3w/hfbDXjEk8JsAL4zM41Dn2hyzl
gPE5HCS9WBVl4XwBh7K0xa+7OWF8EYdELrHf4d+PQfkSDmIdjeyxjDB5GYeL
T6Nl/v+AySs4rC9e+pLzJYyv5JDo1rnn2nkYX8XhaFF5nucTGF/Nwcv5u3PD
BhhfwyF1zxLtoxkwvpbD6ul82/8Jw/g6DvPEF9m++3YUytdz4Gs+z2jlA+Mb
ONx4b10f8P0IlG/oMCUuf9qxuTC+kcOGW2WnNKxgfGMHDzezGecvHIbyTRyC
f/Is2XcUxjd1uLVtdWTKUhjfzOFqF4v9riQY39zB7pPNo/q7h6B8CwfNGqud
1z7D+JYOM/63TltbCeNbOYSFrPvNtP0glG/tUOn9gem7HYxv41CftnPvI34Y
39bBXIvlWL4QjG/n0HAsonG3KMw8e4eNppZZVhkweQeHkN27Xkb6Q/kNDg7z
Qp4cF3wMk3d00Hs16cG7jTB5R4dnIeuy/bRg/nFyEDq3aILwKii/wcmhKH1O
D/9fmH3ODosf6QfmXIfJOztcK7NhrY2Gybs4rKiZk2a8ZQ1U3sXB3/1wftuq
TVB5V4fAJtYz/hYbofKuaPJuDnduNjRcl9sClXdzkK2oXfCQd/t+AJmu58M=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zQlUzXkfx/F/lkolKR1JmfuUErIMKZrUh/ZS2vfl7l1D1qZNmb+naLFk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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlQlQE2cYhqMcMl4DeCG3WEEBrSgeJRwvilxyhTscIRvQioqCClIrGNES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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9z11Ik1Ecx/FHcTK3CG3DmpT2YmZmy01t07X207k5J2FGSC6k0XuEmVhG
mDSZEF1orEC6WOKckuzGaPZitGZb9gpCw1xdOITETFet8sKWSIvOvwcODx++
/3Oe82w43LDvWDzHccrY+vumJznoPKsWvPD+U0QjP1985WsSmUNNKp/L4ZP5
uHPzocSaSE5GbvvQQJRHFuPil3vavv/za+ALnTIdWn7OvBa8lQ28+Z/k9ZDF
WSPRN+SNWLS1yY56yJnwlwbW7XGQs6ATi1IX75KzkVQ1sNdxnZyDyfyu2Tk7
ORerfmuGnLlkKWSChe4bGeQ8FPqqI6EcsgybHUtpGfFkOSaa5a+bIqPM+TAe
CFtc+eQCiBek13a8esZciIbadF5XG3knzNkz84PVZAWis2FHetjPrITwg2d/
bx65CIHtoZMjreRitCZkfXedIKswYbClclXkXWhWWQOeaR+zGhIIOpbHqO+G
teeW/ZGUrMGK0+Oac79oHjB+bhUGS1i3AHir3vreTL0EPZMOn6iR2VKCC4OX
PFPREdZLYe50S46PU495Wt0UmKP9WriVB68q3j1lXQvVGbRIy5m5MgRHN9ml
OnaepQyu3n6R/7aXdR3aX8apTP1PWNch5ZNeptXS9/Woe2CTbGtj8xY9OjQK
l3v4MevlGPMpC0L1HtbLERT11WTWMXMGJNk+Lq72UjdAWFSrb7w/zHoFDAkm
Z/0Rul8FqizytO4fdH8jOltmhJc99H8xu4ciidPUK+FfSjF866BeiXRrUcvU
Fr/3D+CNF+w=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n9Q03Ucx/EBSxI5DiXuFAmRkF9NGvJrQMALhowNB9tgk1ySdFAnICNQ
qUwZEGtAuZuWdCZ2QD/AEzJRSCQZ6PCO4XnGCD1C0vgh/TF/cFzhMa86Pm//
aHe73eOe3/e++37e2/y2RlHgyOFwdv37/u+TXu7jraXxLtf7V/QoscPgNh+8
iszB8Z6qTQUvkF/EkXL1qatOZHf4HS/e6sUlvwTPwLm4P6eGmNejfpMqoGOE
7I2gP6ImNG1kX3xx/6MP4k6T/eDgdf/ZwnP7w2DtrN9oIAcg70j7m6+VkoPw
VVGYr7SWHIK2DRZ7dzqZhxufOu6pcCKHIlJXHvCq3szMx6y4djzJhXoYZpc+
O+rwN/VteFAwxXXiUQ9HoS583Ul/cgT8qvqCHC/S9ZFwi/Xu9xCTo9CkMf52
fewaczQ2asIKh56QBYgYiR9uKCbHwFgjuSXcT46Fs7ti1h5NjsPvFn3ejeGr
zK/j5VDr3EEf6vHwWXA2Gw3kBOBeyEJdIjkRWdxAQV4sGZgZk9Sm32XfpwVa
eFtd3hgZZD0JI7bPe3YfGGA9CVznLTFOIcycZPSWqq/MqqknwzKc36kQURdi
umR+qN3VxLoQdT9r7KHBzJwUDEzeDDkQ3Mt6Cp7dyed3qi6xvh13berWrgs/
sb4dvuMXa6Y6mTmpeKyRNhZZullPRXNl8jHPknOsi2A3hyuXIpm1Iljd7Mbc
vedZT8MJc6XoUGwX62mQNv9luv0KzYvx7tMa7nsbaF6Mb4WL3KJc6hLo1w4t
iZ6cYV2CpHcqJnnGH1lPx/oKU/RDD/p96Xg0serh4xN0/x3QrtalvL+Onm8H
hNbRtLNz9PxSZOhLEg4bmbVShGZ+HbSUf4X1DJxRBbTZbMzaDATuK95pAJ1v
Jn7Nkehcn/dMDOZ+Yu1zpP3IUDht+3J/xoUVQ4aTPgvn1zbRecjA43P41QfP
rtgkw2jVnd3X6lrYvBwNxuUyi5kZckjTuhrtbt+zeTlaHGba83d+x+bl4C++
9cv8vW/YvAJNligvsY51KNBx++lkwh6aV2Bsedn3UH07m1fAGGFXTQjo/LMQ
U13oUbb8A5v/n7VZkH9Yve90KtuHKQtrugRbFnvZPjjZKAu3VwqoIxv+XgPb
8qy0j2wMho3mjN9i15uy4T32wNgov8zmlSjtzvEs6GaGEoN7e2Tlevo/K+Ex
1+A6rWb7MylRfrj1pv0c7VeFj2vXHGs+xe4HFY5uNrT0zfT1/wNZ8tC2
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90gk0lXkfB/BbIm9R0saomRsqShm0SeVrzZA9XNku97qoKNqGUlfcKWnR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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQMC1xcX2HId3w/hfbB3DOStWSQI4zM4LJmwfF84
H4zP4cA8Y8aUUEYYX8DBdUPup13/j0H5Ig5bPDJvt7+E8SUcfllxq8++COPL
OLD8fLfHfwuMr+BgWe4iNW0WjK/kMEn30j3rGTC+isO7H1f/7wmG8dUcfu9g
rv2sAONrOKyb/fOFzP+jUL6Wg+XvNz4hx2B8HYeIfHXWiFIYX89h1/L4JskO
GN/AwZb34c8lPDC+ocMLL9stWUePQPlGDhaPjq26qwDjGzvIcP3obCg9DOWb
OHwV/bg0Nv0QlG/q8PP1hxlnMg9C+WYOL+/ebRR6AOObOwRVNs1fLQ/jWzjs
ZbvrEcN0AMq3dNirEtv45MleKN/KodnnY5ZDEEze2qHqdca0RwthfBuHPOWg
Y+zqML6tg8+ipgUmRjC+nYObtVORqA6Mb+8wYf3Jkx9990H5Dg6TJMXUryTs
gfAbHBy4tvX9vZkM5TM4OlTcEba+8243VN7RobDu7uYY3V1QeScHVaV7S66/
2Q6Vd3J4rL/BwDoPJu/scMb+U2Z+MEze2eHNvvoH/aXboPIuDqvkT3kuNIX6
t8HFYVPzNJZfoVD7GFwd1uwLfLmvB+reBleHg+f/y9d8hLnPDZXfgMZncEeT
d3d4bLf47JO7MPM9HAKvOol1hMD854Gm39PhxoobU66YQeO/AcEHAHwqFfw=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQMC1xcX2HId3w/hfbB/tDQ/VIYHxmdw4C2cuv3f
v2NQPoeD1N1XGVc+wfgCDr+VNrUW3IPxRRx8C7jfqL+C8SUcHOZw7ZC7AePL
OOy/0t3HfA3GV3Aw+ZO65fI6GF/JYUbjFu/MRTC+ioNMbvftqbEwvprDDO39
a265wPgaDpyRLt+TrGF8LQcR1b1G9aIwvo7D1q/1ryq3H4Xy9Ry2bxeeErYa
xjdwOGevucFwN4xv6CB4RMxJdQKMb+SQeVPy0uyfR6B8Y4cpr5NX9u6F8U0c
ehc2/7upBuObOhQ/uyq40ADGN3MIeHN4nsqWw1C+uUOJucQcpkswvoWDjkY2
28T/h6B8S4dDgk47Lx2A8a0c/sQ7yqocOAjlWzvoPTPZmGwL49s4SC5x9efz
OQDl2zoUfjBdXcQL49s5XJjj6HMyBabe3qEzedejHieY+Q4O1/+0XvMQgvq3
wcFhuZdi09HdMPc7OoQsm7n9FB9M3tFhlu2fg8kdMHknh5zf8ywKVkH5DU4O
9TktvyNUYeHn7JB34brQUhOYvLMDu8obrciFMP+7OKjtbjr0/QbUPQ0uDrcW
d0a4PIa5z9VhnVHPSis5qPoGIH922EWZ7zD/uDmEzmB52vcRpt/NQSXL6yzz
IZh+d4ewMKtNVdcO7gcAsTfwkA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQMC1xcX2HId3w/hfbAPrjzAYMIJ4zM4bFCYy7/q
7zEon8NB1LLQr/sTjC/g8LsrWFr8NYwv4mCRXyAecQbGl3AIMuZ5m74bxpdx
CBB/V2i9AsZXcOgW6u0zmAvjKzkkiLbZ/loK46s4PPr8OmB9GYyv5iAS3eNt
XwLjazhceS1Y8UYZxtdyYGy5/4F/51EoX8fBe8JU3gVNML6eww6TnrMPW2B8
A4ffQtODDjnB+IYOUxtSOGezwPhGDtwaYjV1e49A+cYOttmhwT0PDkP5Jg6F
QUmeV2xhfFOH28nCOhFfDkH5Zg6Zk6QeHv4O45s7fHVlNpsTBeNbOFw5ZcH2
8wyMb+nwjHUGx+dKGN/KIUzHQP5W90Eo39rh8SbWOJljML6NwxvnaK+YqANQ
vq2DwYe7MWv+7YPy7RyOG8zbnmgK49s7FBb+WTU1bA+U7+AwaZVL6uIpeyH8
BgeH+V9L4hc074TKOzocFqiWCd2wGyrv6LDReyV7/0GYvJPDjG+/OXoCNkPl
nRyOVL1VZxDcBJV3dph4aLOY7LINUHlnB1E+tagqvdVQeRcH9tJctslLZ0Pl
XRwW1Bs/U01cD5V3dQiy/HzbUW8bVN7VgeNX2JY3E3v3AwBK1NXJ
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzVtI02EYx/G/tsgMnFE00WKVGiqhZnNuq22//zzMebhQHDG80OVEQzQV
yaKwQYJWkl2IKUkWJrtQw3QTncd5yCLxJjOwVLAWgYGChwxPFb5P0V54efnw
5XneU5evpma7cxyn+H3/vHS8PzQVKj3HB/e0rB6INo66/TWHrKBUh8aD7IHK
9Ns9lwRkbzi/uxf0b7xiPorPDlO5yEn2Qdv+XPW+EfJxuBWLv1S0kE/COO1c
aL1LPg3bsfHNnVxyAPyj8t+2SMlncMQ58XwmgByEjOrkrzI/cgi2gsSmuYUx
5rO4XnrQq72DHIomu0ZeXU8OhxtvKYq8QT6HJ49K2yxTo8wRuOaeX+pfTT4P
4WS3JdNAliArTciv+ZAjUaBrlGTkjTBLsWk/hKrHw8xRaDkRLHxdR5YhihOU
LF4hy6GfKe7bbXAwK/AjLUOvmCVfwFBz10CZhXwRN7ciKu41DDErMWdYX7pf
MsCsgqJ+8VnfcC+zGtPL7b3CNTJgrAhT5n2y79kMrNQurYcG9LHOQ9u1/XJi
vod1HndyDJKFn9Q1qJHKJ/gN9p9Zg8LZsltVU7Q/Gr7apyHKQJqPxk7YtuiF
uIv1GAT6PZQ/UNlYj0Fanslm0neyHgt9WMykrKiD9ViMGQcP6ARW1uNg3a2b
/vaR2RyHlMokQ7qA9mthTJnJdspovxaVzZLulXCaj0cmP19bktzPejw6vd5J
/Ve7Wdf9b7OLuQSXnoBGq0rkOdbGeiKCfQvE5dtNrCe69CQk5awefv+mhvV/
/gXMOST3
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0G1IU1Ecx/FrmIa6MKjQiHIRKjlCZ+Z0Pvx8uOrmSmvgm7RiGZSNjCLI
SL2ETy8SDBXERNMZZJK2ZmabNsulpRgxdWIlQ0wkKDXLtWFmhf/zpguHy4fv
ORzOX6zJP352E8dx8r/r3599vpO6S7FeQ+YNLcVXLhQ2zIqYORR8Szb98mbe
AmfWlJj3YPbFl7KSKuPvQfJ29DY7aqXrzH7IVIZykfPMu2HW334ebGAOQFjs
yPnuJuZ9mJy5MHmthnk/djjuLtvqmQMRMFYe1V/BHIzpilb15hDmA/jpKrhs
jGKWoInXzBlcr8gHsVfXaT9jZA7FsdL0wIVw5jBwylNrry0WshS9BW66QdsA
ORxfR/XiNOdL8iGsh9nzfxhekCOwZ03KbzMyH0amFu2ySuZI+HsIPYInswxS
7XeX2mAmR2FCUV5o7ekjR2N1vNl3aRezHFdtby1qi4kcAznv/1HcaCTH4rHd
HvPh6DNyHNz65leDup6Q46GpS4g8UddFBrobx/M2XTdsWAC0OxdHg4YfUU+A
rLB4VJJNFhKQ4QxuqVXrqSfC2n5DPFXHeiJkNxUNjtmH1JMwFiCJ88l/QD0J
K3mztuXhe9STIRtoO3drooV6MqqmakJyr9B+jsdFfXR4XzY7z8NnJCfH3UH7
uRSs6Nr8Tq/RfUIK1KWeHaI37P2pWLWq2j5XkYVUzD2t9r7jovdyaZjZarqv
KmE9DTYNH1FdxOajQHyzLkszRBYUeO8Wp1l09lBX4qSo07reSvMQlJDkiiwh
Xp3U01HWkVc0rWTzScdCY3+GqZjNTwX3dyrDJznNQ/jP3BF0a+dDO1T15j/A
3TdY
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0AlUzXkfBvAr8xqZSiXbqxlZ88abESNJeuS2qdzWe1tUt7t1kcrSJqbb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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1z2tIU3EYx/FT1lmLoCVJc7YyC5vm2pyZtk33U+cUpBeKGYtYFxXEXizr
xbIV29ryRVIihYuKUqYhZohmWGrbuugwJVgkYQlBq2xTqOxCCa4L/Z8/HP58
+D7ncJ5Nh81l1Us5jlP9ff7ddEQvPUdzVgZ8//VZp0oKnm9fTubQ0Vg19pQn
r8Cp8q560+IoswiyK43Rq1/Ja3Hyl9YpjZDFuOEc1Dc9J6+H7W63QtxNTgQ3
hYUPveQkiGJNCXEO8hZ4+wXlimPkZFRMzlbNyMky1PbPWZSx5FS43rvTUkZG
mNNQ2rm12XCTvB1Ni85Z/jpZCYcz9cBQAzkdZ91vx4zxZBUKLDpTk/UJcwZC
+m17oqPkHTDu+71REkPOxEyG2St79ph5J+YjQsdoGTkLq76taV6iJmcjJO+o
7/Q/Yt6FZQl3Tk9kUlfDfCS3LmCmrkFy3UCDMfCQWYtx/7q+20rqOQi/GJf4
bORcxHPW3rYTNK/DoahBWhn0MwOfLl1cXdPCbAfeXXgjjNn8gPU8LCj7+IpS
L+t5+LH/dfrkx2HW85EtqP3iyWLz9nwkCUKvgsPUC9A6taHtcuQ+6wXQ2MI9
7vkB1vWom9Zdm6i+x7oecyXCFve5QdYLsdjlmtKksO/ZC2EJ1KhLbg2xboAk
0bX7J8/m7QbIz4h8x1vp/SIMiMMtew/S/xWB91gq23vYPlwxpr3a71Ir7V8M
Txwf5hV+3x+vZ/xB
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxFzH8s1HEcx/HL1ZJDkslVNm7VVKhwJOQldzi5C4uhH5NjfqyilVmibqv8
yM/CisXVKD+KE05EOb/14580Q7dqqzVatohI2VS792d9tu8+e+z5eX2toxKD
Y/Q4HI7v3+/fzY7JaGWSh8Fgl07Tnh+ysqwWeMwc7OrSjEu5zPrQcuNC7nKY
TcA737BifGaAbIbieFW+apLZAs7Znf2nPzJvhniVR6XBS2YrBJ/gr7TvYBZA
FjahXl/CvAXa+eofy1nM2zCzfbHqTiGzDUZLZILlI8w7UGiZpl/pxWyLz73T
3MQtzPZIrPFJvm/IvBvHBjsn7Sb7yXugnjeVNoUzO2Ct9Bi3eqSP7AiF0/S5
xSvMTpD4mrTONTILEa41bdUOMTujIGcG38HsguNzRg3Gxb3kvYgYrtgpymV2
hVA5P2bsw7wPoRlKfh2P2Q0BEVOr++/1kN3RkNqnFAuYPaDndzR97GI3eT+G
TAfPaMo0ZE+c4r6WRYx3kQFHO21k4tlOnRVAMD8mXljQQd0Lb1wvWn8QPKHu
hdL6XxmpfDLnAFTDPeUPv7ZRP4Bb7XLnZ+vJHG/IlFajJ+Wt1L3xe9O3zCh+
C3UReGZijfF4M3UREuLqQ2t7m6iLYfEuuap6o5q6GJaluV9U+irqPki/bWR+
I6mBug/mDkePieprqPviWqyNy9u1tdR98SLeZXgkhszxg11pneJjD71X+KFN
MDFmo75PXQJvB/XP2Jkq6hKY73W/8fxJMXV/rJvLjF0SZlP3R/u5LveU2WRP
XT+IkHS5wLXQVmfFQTx9f6kibiqaegBabPOdJButaR+AsrNT5V7F0fR/KRKK
bJqaUi5TlyIlbLG9/nEadRmWRhea/R/mU5fBcLZjzXTeTeqHIHoXblRwoYD6
ISQp3SLXbbhOPRDRzSMVA420RyB4CbkVkZuL6H0g3l/tdxDml+isCYSe/M3W
7k85tA+CY9kr7SNJHu2D4Kp4sNQpL6P9f/8Ba/ZoRg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzH1MDHAcx/HTs1RKDZuGoscZ6fnhuvv0dD0/Yqh1PaxGacXakjXthNr0
QHNxWlJ39HD0qJI43YrEP6k1ZmnZYqJDD1gPysP6/tj6bb/99tr7+/2ZJWZE
JatxOBzBn/v3Zcfwley4p+7T7hVN8R3S5Bmm+swcBA8d0xz9Zx0Yvxd0laox
G2KfRa951kwf2QQ16lXi+FnmzfATf1luHGI2hbXQ7UKCknk7GiK5C2b1zOao
6OqM1brBvBNr+uckWqXMlogu81gaTWK2xsZAxTMrR2Zb1I7L3rXOPSHvgp33
VV8XKfNulDTkJ+4QMNth8qiP8IAH817o5VxMK+h9TLZHvqSpSfW6l+wA1aR/
4FkpsyPmE3IWFb7MThiTGmmIq3rIzoiWH7Z1XWB2Qf9LSDXKmF2hZ6c9od/I
7IbPOV/LBhOY3WHAt27v2cr+9wC3Kj3NqId1LnKzw4ZS/Fn3RI59arpgnnUe
rjd18wbWMvOx5aT9QOaskgxYvLjX3LGNLAIyKwdqNOMV1L0gP6RfPCjrpu6F
9v6CYn7rI+reEJ6pUBOOd1D3xseyuCnd4XbqPoiIUVkV2bRS98FlbeFEXN5d
6r5ITYnaU/S9jbovnA0eSCKTW6j7IddHVRDd1kTdD7/qAlQ/hlkXID3WXVvW
SRYJcGoua8P+I3Lq/tCqnh5786GOuj8Kb4/E9CrJnAAYW9Twnp9gPQDNipK4
03711APRInI39HapoR4IbmuMWc/PaupB0JUvO428raAeBDVTnk2mySXqwRDx
OnW4B69RD8bDK3nakkUZ9RAMN/J5lktS6iFQXxcTpsisoh4K6Gp+Op9I86JQ
xIr7OEs6NM8Jw/pKSe2mZbYfBqXhOfs7kzeph2M63rrNOZEsCse3QteCGQ22
HwFeUvn97FvlK8Yqi1ZZucqcyFX7//0bxBZg3A==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQlczPkfx/EfVsiRo8gdRVRWYRH/6l3pHs3UTPdUczdaR8JqiUYKEZI7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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1z38s1HEcx/FvfpfRXbtSKlOh64fz60R0eeE4R8umK6nWmkZqfvVj/bLQ
cmtNTUdbLImY1WjoMJryI3fR0h/9uGxCy5hSMZaRWLXe78/22WePPT/fz+f7
WRefFpNgJgiC/9/5b+Uh+lCerljyovW/JoKyvvlNHhaxBchMPR3JtmwbnNE9
GN1owRbhe19/Z8+CkSyBNMm7xmmMvRJKt2sRYx3sNRA3xWXll7Cd8S7ROd0/
l70eslcpR9wS2S4olml1ukNsN/yeUaut9rGlOOpa0nXPhb0ZOX3xmzLN2FvR
P3t/oHY1W4bqqvYs46iB7In6DeL083q2F+af1R4oSGB7I9nXWi/SsH0gb1LF
anM7yXJct4tpqZ56TvbFXljG7p9gb8NN/SlRcx3bD3ndg3KtPdsfcyM2JWma
DvJ27HYNsur91E4OQKrz0MxQIPdA9A06vVy6mL0DP31Sq7Lv8n4Fposrkhrv
tJF3wiQyZIo17CAUSR41uzo+JQPj1k6NitCW/84GamRvyiUZT6gH46JlaZqf
Rz31YFzxUnx+vaqZegi0xrno+eIG6iFwN1UEeFfqqYci5G3O/GVTLfVQ5E/9
Wns8qoK6EhqpvUP0iSLqSkx2SZVx53TUw+CRlzJ+sLWUehiWy26IegPLqIdD
Y1y0YiG1ino4Lth+3HWykCyo8EVnfKiS8/0qiDPKr5aZ03uECHy95LjMMNBI
PQKnz/baNRXy/6ux0B1gPnzrMXU1XN63HYt0rKMeCUmuAwrcydmRECw8hx22
8PdRCPPcUzk9y+dHYcRwu+GHb13rHzFSFzQ=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAmIQDQMC1xcX2HId3w/hfbA/9btw2j1BGJ/BYUPXF7Zd
QjA+h8PuPK2tO34fg/IFHK75Xtl0F84XcXhe/G7zhfcwvoTDrMvphxccgfFl
HP5VL5jzZxWMr+CQ4qb8qK8axldyWKHWJH61FMZXcdgcUSnD3gjjqznsFyu1
D46A8TUc3D0ZV3Naw/haDmVN61c6+sD4Og73Y5dc/vr/KJSv5/BNak2g52cY
38DB3J0/y286jG/oMMWqLLuzAsY3cmiccHjKJEsY39hhUrbIo6vHj0D5Jg5u
rG0htxhhfFMHqY8+Dh7dh6F8M4dN3yaa8wTD+OYOkwrP+EYqw/gWDgk/Ts/f
WXcIyrd04OAScTeLgPGtHJoeLGLetg3Gt3ao7V0XtuLfQSjfxkH78cqC6mUw
vq3Dd8XW3IhbML6dw+4nhTvXXoHpt3dInMLwqv4bTN7B4X17+VGZg1B+g4PD
x4cTa79sgvnH0WGRrMmfRWeh/m9wdNjKc6KU6SxM3slBW2dRVw0zNLwbnBwe
nFq/k0UNFv7ODkr3OdZe3XsCKu/ssHYOp4DqOlh6cnHY87fw59tPx/fb/p99
5oOEi8OnS75JAhEn9wMAF2zegA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0m1IU1Ecx/FbKJsLbZWKWq7Mx6QiH2bqcv6mbjoVbWZkWok5ScfCQMps
ezF6oxFBpUhIGGI159MUIzcrrSz1haOyF60HMzSKIqdpDsPIis6/wAuXy4fv
OZzDOTfgaHlOyWqO4+J/v3++9AhfNJ9IEAwP/NVs4smled2sK5lDeCG/bvCf
+VjWzhQJvw8xC9HRMzbZt0j2ROv02r0WB9kHRU+8tFenyJvgeFt98cc4eQtc
ylKjfo6Qt0I35haxvpccBEeFfeDyJXII3Fq7LmTpyWGwKPLO5YrJ4bCbNmsW
pOTtqDov4/J9yDvRpDlsEbx+zLwLN5dzXZqHyRG4pQ1zLQE5EplDDTWdXuQo
nFUHKys+P2KORg7PYfw4Qxbj4LfgA5Wh5BhYF3XFXRryblzZJtMdKibHwrrf
LFqXM8gch+yJG4USd+rxyB3veCZse8gsgY2vV/kH0vg9MLeskrYoyQkIdgpV
obU0Xgqz71zsDjE5EQEBz23eejKQf7s/pNyP2QBEhgqqzbb7rMsw7ehWXdP1
sy6Dr7zL6VJ/j/UkVKoDs+ztd1lPgthvbkO36A7ryUg44780mm5hPRm8mqEP
ReJe1lPgycV4vxq1sp6CuLps/nAjdTm+auZFomi2nkGOd5qNtbzrtL4C+0aO
v5wqpf0pIDG9GTNa2X64VLSbRN7Gzj7WUyGQCtqCFA9YT0NjQ9/pNVXs/Axp
8MiTGG0+dD5KuJt7Tpm07D4MSjgLJl0XCui801FW3/804xP7PwzpODah9niv
ofkZ8DvypbTJQPNXmMtc0f/7F/K3IgM=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgk41fkex/GTmhEN2kkqtGgRQomW87GEbNkd23HO4RxHU7pTYlKav5Zb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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zAlIE1AAxvEhUTq16SiyaB7rEo/SzNTU7dumzmMmjRhkIRHqEPIgMq1M
RpqknUSawiprtal5TUdraFurzKOJSNRCzMzFhE3NwNCE7MD3evB4/PjzvoAT
hdIcFwaDEff3/nvp8bKqiuKZ/aZVzfPljpHm0+7UDOjTJnQWFrUrUqYnxJme
1F7IGL/xge1CvQHdPc88CuxviH3Q6ztWZvzvrXD5vFHga6P2x4VBpv7TQ2ou
fny08EMaqLdjob/az3CReid6bHlWlYg6EMNXJfWhUdRBsF/qUrsO9xGHYHLF
FHRXSb0bK9mX5wfOUoch8ahOdiuPOhxZJZkjU/7Ue7GrU+jfaXtNHAHH4hnv
I2LqfQjxWWNmB1NHwi3SbBjhUu+HRDAgrVxPHYVjrDqOtfQVcTS4znO8iPqX
xDGY+tZRE8qkPoDp9KrjrQNm4lg4xpbuG9teEMeBya8r1wVSx4MXVXNFpqfm
wd3OfZtnoOZjjnObdXjUSAzUjrbLZiqfr1oBNLJii5MXekgXwDn+LlvIMZAu
gFZXG3v9JjFDiOgmz77NfD3pQoSNxbCafXWkiyBvadXYS7pJF6FaGWzJVXeR
ngCHdebgSRWxIgEdGlHRlkWyx0hE71fZRPTSU9IT8bjZUuj3nfYkrDVyzOvy
taQnQX5I4mRPakgX49qe2UGttYl0MbZJC2DTqElPhv29luWwPiE9GYqqNo+K
L/R/Cpy/XWd2aFtIT4HWlFX7cxPZY6RiuV1RdSq/jfRUOH9lZEUm0P00FA8F
sHOkj0hPg9vs+YgGYyPpEvDUc5aycBXpEiz7DHXfczwgPR1ud0zMUrmS9HSU
B1V454pUpj9ldzep
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzl1I01EYx/F/Ym9TcoZaW1MrTMTKl7XVdNP9tjlNhygrimWwtV4IqVne
VIS5IthN27LBKHuZ4MKL0hIklhSmm25dFAbGWNBFtGmIsBFIraJVdB4vduBw
+PDlnPNsM3fpT2ZwHCf9u/+dtPjhwXN1vODEfyWUwz9jgekcMofWoaJvR1b6
OlxYltju/55h5mNe/sv8I07OQ/RmsUv/ibwZHTa1ci5IFmFu0p+84SFvRcSz
/Gz8Dnk7HoqEFtNVcgmS3mBJPsil+LIk+F6QQS5DLFOi64tOM5ejebHbIvtI
3oUlQ6VG4CVXIPju6eEtJnIV5NLFo2cryNUYW2gPpYYCzGIcsFVfcRSS94A7
lZvoXLEE/a6pna1GshSei86YKJO8F6Ph3udZZX7mfVjLC50ZVpBlWD/iaMku
nGKuQVPKvYbfPslci7Zr3t35b8lyuGdrrCoXWYFj/mi8dIZchx0JzxutiN6v
R9fqSKXnCVkJR5h3SCGm+YCDlhE3Ftj/VmCTfWO28jbNo0Kkp0jsamP3rSok
L3dkGU9QV6PYPiYc9LP/rWoEdecfSLtpHg0erZJVOQV0X4PPd33C07OvWG/A
hg/lDsPxF6w34H2q97Xe7mNdi8ejhoHaBLNVi7yAuV8N6o1w5Nwzxi+Ns96I
6/qeW51hZq4JGaF5U8FX6mnm9qf1NHPNaT3NXAv6XtbnOnW+iT8xqgnI
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10mtIE1AYBuC1aOX+5EqsH+U0I8zNmua0aWuvu9sFai2stFJphJgoLsLw
0hgoQRT1o2lSFllEC6xo7GLTOWfKYERLV1Ko4AojiK2UjBbd8HwHDoeHlwMf
L19Gdb3BxOVwOPn/7v+XTvLb3gY5f8y3pLiinZ+XAI/MwYGegnTHcvIqxDpM
Gx8lRpmTMWU1qbdGySnwWbfL1k6S1+P8XiOv0k/egIUyUWFggJyORUu0vPEh
eRNUaTcGlrWRN6OuYywwUkHeggT/mcohIWdB/L1J0zPzgjkbfbd+dkcDZDE6
Pa3Tuk7yNnxqlH/sspElMFiNU3fLyLlIq+NnvgyOMOehu360NU9N3gHXhZlZ
/UKAOR/j9sxD72xkKVSp10+cFJILcK3LnMTlkgth858+m31mmHknWnq5f1wZ
ZBmqjt8ujij8zEX4NZxxc0JALsZRwT5t348h5l2wx13rnpoHmOVocCuKaqa8
zLtx8f19syl9kFmBO0PNKf18MnA5XhuW1biWbAH87pWeQTszpwTOpBz9g9VO
lpeg8Xf5lZw9/SxXQhlJXfwaof9KiOJeXVYz5SqMSmNGUczNchVk0jIRr+o5
y9U4uGKyoyLkYbkaH9KUc/1Bml+DJ/O9ueNq1p9FgzfiMJpaqA8t/NOv4k4N
s0WLcwFJe+089amD+vPsXOgxza+DQuD2tl11sFwPuzCsNHSz/ix6NOdWrpmQ
0z6UItp3rOLUl4DvklAbune4FN9e769OPhL0/QXAVAvo
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0FtIE1Acx/FhaEtFphlZLU0TXWFjWmlTlz8vc6Z20R5aUGxkKqzEmXSB
SN1DItFLlpQpkU6dJUTDtGnaSp1ZTg20ZHSjHjIzdWWRlGJG/78PHTgcPnzP
ORxO4JH8zGwXgUAgX5x/Vx6iUaNe4f7E+k/OuHf3P/9K92QL0Gx6Vl7twRYi
oDFIP73URegryi/Y4sr2RcPtK92n5nrJfuiJvdn9wcEWw0Vpr+szszdAP22J
uGxiByGkVm8rPsMORr9qddeMmB2C18PHyzT+bAn6h8VGUTx7M5QVzgznrI0c
BtlvtTqsky1F+sh1fy8dWwbf+bU5vX7scGjlbrY1Qz3kCHjsy1xl8eK+FZLk
sUHrd+7bUNocpa1rZG/HrL/Dc0TKjoSw5ay+w4cdhZ/Ru+cCyrvJO6DRKaxu
drYcMUfXTV0ys6PRVG6RnlzfRY6B48CbwKt5j8mxKJwoHgvzYSvgpW5HQhR7
J4SuA181mkfkOBiyQqqXT3WSAW1GqltWMbkEkE8OiYoKH1CPx7k02fPcjW3U
43GxyBJ+4aOVegI6zNKmmlDaX5KAgRcyY7DzIfVErDB8kXiX0ntKEtFzUOxt
X8b3J2HG0xBZoWqnnoQ9wtyXh5M6qCux0tGmsO3n80qcVrlPzmfzfyTj0LHB
8dZB7smof/tK/W3hHnUVXExNedGjLdRVeGq/Jd670Eo9BSn9n/SVVdxTUBnw
Q6uboPcIdqHxhkfVea2J+n8WpOLa9InhkbIG6ql4bxlXG0JrqaehYDan2rLJ
SH3R7jW6O3drqKcv3fcHxsYhUw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwtUTYkex/EjUt41uvIoHSIjKYXRi349laLH6VSn53n1oOFSUlyZnUYn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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0Hs01HkfB/BBRAiFXGobQqkoxLalvBEbmZjc7zNjjJFtSbdt256Gyu7q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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90Xk41Ykex/FfWiQtKqNlGpcSIaPGpEJ8bEkiu2zH2c+xRJOidDNnqJgW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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90As4FPgexvFBlyVJN7XLbrQdBpt0c9nIazRujTCMS27DzJhJKemcI3Fq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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQMC1xcX2HId3w/hfbD/NNc0aC0PjM/gsL26q6lC
FMbncBDtVRXaJwXjCzhE/DS9+FsGxhdxkDUzFT4iBuNLOGy5z/mu4PsxKF/G
QWVirNedjzC+gsObsB+H916H8ZUcrt+WOc68DsZXcTAKOzbz114YX81Bu9zc
mOEwjK/h0CAzJawwHcbXcgjOyZTNTYTxdRykX7wsEtSD8fUc9lV8i7G8fRTK
N3AwObN0edpPGN/Q4ZbTVv8bVTC+kUPfO+uFfNwwvrFDnqjuV5XiI1C+iYNk
eb51ePlhKN/UoYLj2d/mOTC+mUPMqRkcQrsPQfnmDtF/+XzesMHkLRxqU8W2
fPsOk7d0YHZhMzE/BuNbOSRtW74m6O9BKN/a4W1V7QzPFpi8jcONxvm+EV8P
QPm2Dn6rrpif37gfyrdzmFWjuH31vD1Qvr1D+z/fDdeW74LyHRx8p1Smmb3c
DeE3ODi8fHVpe8g2mLyjA19ra/HfaCi/wdFhsfOeBjP9vVB5Jwf13ogFxi+h
5jc4OQT5v1U5JbcPKu/sUL/pSkjfTpj5zg4q4qvSp7Bvgcq7OKQKz87Yog+T
d3FgCuGtOfcMFt6uDtq+13YdfAEN7wZXh3ctbsy2/Af2AwAORduL
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90g1UzPkeBvBBd+UtUUqoHQ41KW2USt30KElJ6X16m2aalyZEpRcUTRqR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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0H0sFHAcx/FDD3LTnIexUwvJUzePqQvXfXDOnXM0Wm3NUur8Ux5KtqY/
HDOUPETkaYtDdI1pxbQ8y0MNf9jkYUWSa60tqpGQVbvv75++22/fvfb+/fW1
j0uKUhlyOBzR3/dvszGbqksWmQz36LUi1uz2yP9pzMzBWmPpGx2X2Rj9C2fu
PNnBbAbl5ZgIxcYQ2RL2HdqSuCVmG3zL8OCNjTPvQ4eX+dx6NbMdxka3NNyb
zA7oylTZFLsyO0Ia9LnEh8fsBO2X0Q+RE4NkFyTkfkw0L2B2w4gB3ygmllkA
jjSq5ccuZneYWEUb7Xn9kuyJ3Fpx6nIKsxdi4ju7V72ZvcEzEPHdLJl9sGb7
O75ZN0A+gmxH28nBIWZflJe1jiykMR/FnPW5aYdT/eRjSNA921AI+shCVPPK
b19c7iEfx4yT86LSppvshyTkxCUXdZH9kXm9Nv7r/U5yANqGeZm9eE4WoUWV
FaN6wXwCPnnCG4NZ7WQx6nplbgt+bWRA0hqyd8G8WW818Cld2C9QNFEPRNn8
RGpAWBH1QBzOvycxkduJ9T0I2/KkmVJuud7qIDx96zzgulVJPRjrhlMqZ24F
9WBkatR5/INV1CWQ58HqXXENdQkS26OLNRUa6iGY3L9rxiaglnoIqkbSa8e/
N1CXov1RhnJURf/VUhzatC258uoh9VCc1zbeXTlJVofC2f2s0qWpnroMv4IO
FPovsi7DVZfYGWNdK3U5GirXvIRjrMvh6ylRF85rqYehU/bYwnC1kXoYrgmq
TNvqm6gr4MGP71s1ZV2B0++XNi9wH1APh/Ut4U738By6bzgiMZueMFtB91dC
bFuuvZRSQ/0/cyIwXViQvW2R1vMHfW0iQA==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQMC1xcX2HId3w/hfbA3YKp494YXxmdw0Kxsen4T
zudwEDfyfJf58RiUL+DweHd+vsgTGF/EQTxf2DrsMowv4RCS+F3m/UYYX8Yh
dcZ0TYGlML6Cw3fBNVlPemF8JQeBOaZ63dkwvoqDSIhG1mZbGF/NQT+FT09U
HsbXcLh7vfxOtSiMr+Vw2qOHpXbPUShfx8Fu8kL9rh0wvp5Dr9LOOUZ9ML6B
Q8T6HO17ITC+oQN/e6v/mT9HoHwjh5Tdh04tZIPJGzuE/1nf3x0CkzdxOMKS
82/q/cNQvqlD/KTpdg8lYXwzhzka4erP7h6C8s0dZn9a/6fIHMa3cJi49e9f
cUkY39LhVk2b0C11GN/KQamrhu9S4UEo39rB9k3i3D02ML6Ng5kNw+51hw9A
+bYOQqVltSVHYPJ2Dk1TLOx2ScDMs3fYkVCiMSMPJu/gUH2X2ST0KZTf4OBQ
blvUsi0NJu/osOlsXbNvOEze0WG70o4nNvIw85wc9rU2/JThhPIbnBxcw/88
8bwK0+/ssHlO6o3I0zD9zg798+YoPU3ZD5V3cdDSuPBgXuA+qLyLQ71zOeuq
aph+Vwe5dkG5G0V7ofKuDp1CSu4JPDD/ujkY/fofncsI5Te4OTxlmNtzgRGm
392hY81X0b4lMPvdHT5Js/JuqoHJezis4nZ397aDuR+Nz+CJJo/gAwDUg/zS

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIk1EYB/BpMeetjDRmMyorybLItKmp8z916lTUDCOVhLzVt5KQKNIN
Z0zKEsUKQ0zYHPMSQxCdc8s2N81I81IqdLWbmMYMTCstKjpPHzrwcvjxP89z
nvd9t+eeSS9w5HA4Yb+fPzstj0nV2UiXgd6/Woi6cvomil3JHKSNaFNkbmQe
0lNysGu1n9kDpR0Czw3TZE/oX4z5ztjIfKRfrPMr0pN9kKQ53yzqJm+DYb5U
ca2c7Iu8vuFK71TyTnwKUciWNpP9UBnUNn17ysa8G4afrTHWD+Q9KOHWq51H
yQFQi9yqzUfJ+5Hs8GCSKyQfwIzW4sC/Qw7EidVXZfNbyQdxSel2bOyNlTkI
YbVK15Yv5GAYCxab+aPkQ3DqCkgUFJKF8NFVc8O9ySFoau/5Wu/VxxwKY4Zu
XCW2MIeh+Lhja8gtM/NhCLPTgt/9uM8cjvfXTS5lWeQILKV9m2hX3WOOxKB1
ouaGtIdZhLxNpvY+lZE5Cldffs9+tsPEDAzVfNS81bLzcqDoaWpmzTj1EwNt
pRd6cygXozE0d/1aO9VHQ/P4YVTBMptHHg1702CTdInmi4GgqkO3bDCwPAZZ
0wMJGXxmTiwUvLl1sz5UH4sKpZr3pI7qJWjtvFw+NUf3S/Bc1OL+eraT5XGQ
FDp5+XK7WR6H0Qi7s4eti+XxqI1oXJTks/PyeFi0e4czpZQnwOyetE/df5fl
CVixluSbqqi/FCuKc/qGU3qWS+Ev3LJwREbvnwgvQ8Waokfs+8oTsXFcMCT2
p/mTMDLx+WQgl/1P+X/mJP/zL6ssJ6I=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0gtIU1Ecx/HLMlGDpVlhIqjDR0q+mmbz+dOpc0vnpijGepASSVlaamBN
mUlKNcdAMS3BSkmzEqx0vjWfaUoWUSuXzF6Kplj00DSs6JzADS7jw/eec8//
bvZJabGHWQzDCP9cf7/px/xlVXqg2WDXPy0Ea94kWihNqBk4l7mdbmZRm8A3
madRb6Q2B5vDGbG1pd6MZO3y8UpTaiu4zLgt6v7vZ4Po3E+DZl8HiO0QOTBV
HfuBmoMXccr0uVFqB4Q/ubY1r5baCaoVn6B4HvV2yFMWS9sYalfkG+dMt430
E+9AqGXMmW/Z1O74VZSTK2NTeyLeyMRjcqCP2AtsoaQ/sIF6J5palmNYImou
lhxrG7xUvcTeGM5gOdrqe4h9EL5pdnS2hnoXLuptQlNWHxL7Yp+j1L5+rpt4
N24+Ha9zsaTmoXiin13oR+2HKP2WgG59F7E/eq/MDKnmqQPg7e5Zwi3oJA5E
k4ep/mM+7UGYsTwxO5RJ9wuG5tUjjuc7eh6Af6m+s/AymUcBlHooF+bzaA/B
hkOa1ZTrZD9FCNyC26tb19PnheJ9nN+NH4W0h2Ja5WyXKm8lnQ9Z47x5yTS5
X8HHyWOClc/yZtLD8LPgtnFPSAvpYVDna4fXqTWkh0M2pRRbK5tIDwdnSqdO
KCJmIpDjLau0F7WTbmBGYNAF2B+R9b2PS88XibNZ05Nia/I8RSQu8K0e71U+
IF241goh1A5WB8fryXkZEVa064xfu7aRLkK2T3x5Eq+D9D1wLJ/qeWZB5zcw
E4XE2nF5TT+5XxEFmzU9GkZHPDItBLRHI0Pd0bhtif6+YowFvs3S0f+bQmww
f4zB/AZmJGsNCc6nTo75T5D3o5DgagW38qgTma9bggNavj8vjZiRQnzqfkHd
LfI+IMXoOV3V/PN7ZL0U3VW9ckHZHbJeCiSoKopRS9bHQns3IpL3parrNzHH
dF0=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQA2IQDQMC1xcX2HId3w/hfbC//3Bj2lkeGJ/BYU3CXRFD
Fhifw4F74SL5i7+PQfkCDi3BblxSr2B8EYe1x6O1bY/D+BIOhXdnrp6+BcaX
cTA/I5nbPQ3GV3DY52MdOK8WxldyWCm9+JFLBIyv4uC36cX7Lh0YX80hNsE9
P/rGUShfw6HOZMo75rUwvpbDk5fRj6RaYXwdBzGhk2lG/jC+nkN2UlKqkhqM
b+CwWyO6+f7aI1C+oUPN2aRlhzphfCOHnZUcSW6rYHxjB9vLE5p8kmF8E4fi
phvrNvPD+KYOv4r/rNBig/HNHKylp+duyj0M5Zs7LNy4+dWjD4egfAuHNfKM
lQ2fD0L5lg52139tTdGD8a0cdGVV58+4CuNbO2xUs/j4pRbGt3FgX/n652kh
mHm2DoF6fo6xB2Dydg51l6ydrBlg8vYOLkpJYQumHoDyHRyc5CpSeJ5C1Tc4
OOxb+3rWwRcw/Y4O/V/S3XRLof5pcHRwy+zRu7sTZp6TQ39OCTfDUZi8k8Oh
SPnDdzp27gcA4mm8uA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91HlUzXkfB/ArS8tMqYciD7lulhZGSErSu0iXW+S2L+qu3duDxgzNjDTj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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1lA1QzGkcx/9XxEXKcVfWoVR0ac5LLwrpu2rp3ba1W/vSluRaUZGTFLWp
dTNFKp0iUVaqQ6srYRK9YHHUuCbNuOI4cnebyDhuKPcy/Z6d2dn5zOf5PL+d
ffb/2MQkiTYYcRyX9t/7/0/2sujVbvE01V8do1dejwq6zvEmMubQs0qdnD6e
8US4G3dL9o/eILbAuHHfWXzzlPF0FBp9iK2/ytgKHpc2ToquZPwloj0OGToK
GFsj3r8ownMT47noXLegcb2MsR2Gm1qWf+XLeB4cgkxTJUGMHdBuFtgitWTs
iGifrWknb18ndkLMbV3OjX7GXyPAeWpRRRrjRch+N6P/oR3jxai6LtjO018j
XoKqbO7vLCPmnWGx8fT9Ch5jF/TF2uZkDrL1rhBkJVcpPjJ2g+pV+KeyI4yX
ovG+Y6pzHWN3gCeb32LC2APt4syUyUsYL8O9ShPtzG0dxMsxjW+bECdvJ16B
w269Oc/bGXvipdx1UHqmjXgl8lxnP7hYxtgLc7xv7bqivEoMFJvYDD27e3mM
1UCKRpiVOtJMno+fmvn7XHKukOejxbp8mYddC/lV4CU6dUbnsX4VLjvtU75+
coG8NwZi+D1aroG8N/wS6/VRm38g74PAjztm+mQSq31gWKP/PDWhlrwA7us3
JCUFnCEvQOtf07LsxWfJr0bS8LZ1g9V15Fej7M+nuf8E/0h+DTIcEjeLhurJ
r8GBhIGSzmnnyftCIxSNGPWdJu8L4Whs3/HWc+T98Mf+5ndR6hryfqivzau/
3UHM+aOmp9xUalRN3h/tvlvazNNPkg/A4oUfym3DT5EPgJ3g5M9ThpgPxG+V
bZqOGZXkA9Hcr20S/U7MBcElfRmPp6sgH4Q7x91qimXMB8PDPqWqb/tR8sEo
3dApdmkg5tbCqrbBzzXlCPm1yH88eyD16THyQkxxz40vUNB+EMKgN/TrLrB5
QoSUj3jdW0HrW4UINduTYH6I9SFQCYKfTE2m9QgBb9IOY5HrCepDUJGb+eqy
TRn1Iejta9tZml9CvQhv7ze1L1pZTr0IUkPG3JibudSLgAnDxokZO6kXQe6Q
ou3VZ1MfinU+BXvCVEnUh0K/tS5m/kCy11gfipmr7c4vNP+W+lB08gQq5aPd
1IeBn2UT9WJWGvVhmPLFSLKVVRzND4PDKX6tplJBfRhe7C7cGX2wcGx/Toy8
+Nib7z20Ywwx9G+GTTJG02m+GP5FntPdu8vGuFWMOljz3D85Sr0E/l0Jg44J
e6mXIHu/VG3oKaZegsaEwqzP6g9QL0GK6n3cw8Ua6sMR3BUUGK7Npz4cZ3X+
iUP2tF4djniHX1wmjNJ+reHwmHPA0ukjzeMicMp5gtvBNPKIQOndWWqzyd9T
H4GknqLqtVHs+0fAJ9V1vHdTKfVSPD9f46I1LaFeCmm38NdnSwTUS+E1q0nd
dbSAfj8pDt+ytDRTJlEvQ/fbCouml2y+DNajOc3XF9pTL8NAgeFYOzuvVhkc
d+/z7CnZRecnh1Iz79rFunw6PzlcTyyXvi3T0vnJMa4hZu6mUvp/t8rxoG3G
hUAV3RecAndUFS22Bh31CrRtzzDc1NH9oVage7zzUs74EvUKLLUsHFRr6D7j
IpHZ6Pxc+IbWIxJbzctMSluKqY+ERDfxtUDLnp9IxBVcq9JMZfebEkGNSqPM
efS8QIkFi7oe51ZXev0L3xhf/A==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlAsw1WkYhw+7pUJpksuJijUbh2zYcs8Pued23J1wrGxSSiqzKTnlUorN
ilxCiUqScsmi5BDSdaudUm6T1uwkdmtS7Ulk2/F+7dSZOXPmmef/fO83Z77/
p/HDZn64NIfD2ffx+98v+yh0lURbzrrWPEUvrbQ2tmTfVGDMwe7kmvYyecYz
8DIroeaMHGMFaCrL+Ht/8opwli9QXjfeQayC0+fa726bwbwabj3TahaOML8Y
rcu9BZoDjDUx+9Q/8gNljLUgf3amRWsx429RnnncOduXsTaUuL1fb7FmzEOP
JaTK+9uJ9XBiWGIQG81YH8fXNyqdm8t4GRxl8zvj1RkbgLPDSK3BmLEhVsoG
vhVYMzZCoUFU8f18xt+jNi97Rns74+Vw0i5+xbdkvAJjttKP3KvaiI2hH1vq
trqHsQk6ExXD+FevEpvC+p7RMt3HrcRmcO/802NiB2NzpB/zff7zihZiCzzp
cxRvVm8mtgTfSH2IW3aJeCUcNx653/2JrXBGbaKIm1BPDNy2Ghl7KvfrFIuA
D+8Cs9KNiDnW2GIcUVHRWE3eGrUpleUbeVXkbeCfXzpZIUsssoFSder4q/ln
ydti8kqm0fRnBeRtMXCkS3lXbw75VVD6O16qxzOZ/Cp84Han/RG3nrwd4g6Y
Kh3TPUjeDrfUK3daTKSTt8er3EOmTmuTyNsjSrO+ROSSSt4BVYfkreN7mHdA
m1TCJrPd4eQdYVsiVtn2fB15R8wrTq77qmEfeSf8csIhtL0ojbwThve6Pm+X
iyXvDPHv8XIFqtutprwz7q2z6cqfjJ5ijgsW9mk5j94OJu+CgciFqSEZa8mv
hrvXMt5wUjz51TAcbZF5nZZI3hWuBguMlxYTi1whs0fT7M0iAXk3mKZeco1W
2U/eDRqzZsn8GMXmu2NkU15Kqdxu8u64Vv+gLzeTre+B94oXuQ/dcqYYHrjM
6z6or5lFz3tATzJxp23B0SkWe6Cyf8n2uhWF1Ht+zvBEbKNO4ttbtJ7IEw97
NC5HmtN6Yk9knJfESaQyqefj8czQSrQcpp6PjjjF6CcVadTzMS/TXX+sMJd6
Pk5aHY5QGqH1OF5YNY+71eIG278XvmvR7jtanEe9F7J1X6heUGDzvSCZnuKT
EcDme6PNLPjkBUkK9d6IlArsW3Iwg3pvNCcbFalO7qXeG51D4TeWuomo98FO
+SjT2QpbqfeBrmyqpnQ1eZEPOjLNY+wqyYt9YFLYE5M2vp56XyQoy9y9+het
D19ED9qXJjZG03nzxRKN9DeCPR7U+6Isp2X+Kf0d1Psh1GX0g8m0bVPPww8b
Lin/9pNWFvV+2HJaGCS4T+dX7IeORkWbDbe30vn1h9f51+mPyul9hD/CdaY3
1DhkUO8PrsLOF2HdedT7o6NOabmjCXt/A5Dk4DIU0U/zEIDce0+aeBLyogCo
hjyUN7jCo/0HgFdv99TEmb3fgTjasHnwWkMY9R+5qXpErzmC/r9ASG6OVgzy
2P4DMUddJaNoLt0HHAGu8IzvrOWWUy/ArgnxCdvqOpovgLS5+6OA2ovUf8Gc
NbjbnzDz9QDdb1jzuRd9weI1GLTWs3eWq6U+CPVRis8K4sgjCDGHXTAUweYH
YbxJNaZPh/VB0HftUtP2ZfODcf3AnrAwGXoewah60BS66CTrgxGZlNPEayMW
B+Mb/sLujHzWh2D2u8lmQ3XWh+C8vUPHsRu0P1EIYk0m3y+Yw/oQWKTqvF1s
ye53Ibb3tu6f1kP392LhxxMYNXZ9kP0fQlyweTquH1ozxUIhSnoNhysD2fpC
LNpbEuJ1hPzxL7z4f/4XEaWgLQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQMC1xcX2HId3w/hfbB/WrI810YAxmdwYDy/eKUH
D4zP4TDnlJyLAly9gMM27v/ZNt+PQfkiDp3fGnPvPoXxJRxk//3hOXsOxpdx
qDD4uN1kJ4yv4DCreb193kQYX8nBIYS/Mq0BxldxyBWZU2kfDeOrOZg/3phR
kAjjazgcutcl1R4G42s5PCoz7XlqDuPrOKjqN8VoCcL4eg6zZYRKXxw6CuUb
OHjdXGp6bTuMb+hQv4NhiowjjG/kMK2g6PB5Vhjf2OGH/u2Hjh4wvolD6Wv3
5Jt5ML6pA+fhD6WsEjD7zBx86oxOOvHB+OYOiyN0F2/5AuNbOEzrvTirVg4W
npYOC2u3yE3aAONbOSRZxPE4zIbxrR2c205y6+2B8W0cXj3dU3VqLYxv67D+
CPPDRxonoHw7hxtNb80Ygk9C+fYO5y9uXaLGf3J/pjp/u5+pvcOnS75JAhEn
9wMAcgajgw==
           "]], 
          
          LineBox[{{32.518760463386535`, -0.198}, {
           33., -0.19015113509090187`}, {34., -0.18935330084530763`}, {
           35., -0.18945831467660387`}, {35.639527405082376`, -0.198}}], 
          
          LineBox[{{39.08268774580942, -0.198}, {
           40., -0.14850866985398356`}, {41., -0.16731891554518397`}, {
           41.91267245763043, -0.198}}], 
          
          LineBox[{{42.1028209954026, -0.198}, {43., -0.172384413886228}, {
           44., -0.172384413886228}}]}, FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQMC1xcX2HId3w/hfbBf4XzmkD07jM/gYNz481wh
H4zP4fBHxfKlBweML+CgfH/Xnop/x6B8EQep7KqV2e9hfAkH3wvi39jOwPgy
DswcHqqzT8L4Cg6hwY/dC1fD+EoOWdHlXYcWwvgqDuXljf6S1TC+msO2pro5
KrkwvoaDvNz/pdsTYHwthxLbmBw1ARhfxyH6xbUNdQYwvp6D3KPtK3VYYHwD
h+/a+Q2nFxyF8g0dSrV/vfiZDOMbOfgsqn/e8/IIlG/sULfhRP/c2TC+iUPC
Hd1T638fhvJNHS5nfJ993wzGN3Oo8Jhpy7sRxjd3KJv+YLqLCIxv4VDltbiX
Qx3Gt3R4fPGxl4wxzHwrB/kVO861VcP41g5TrGxMs/fD+DYOEnvn+i6KhPFt
HXYnzpr7qxHGt3N4/n0C340MGN/ewTCfNeJ65UEo38HhfoKwe44alN/g4PCx
2FX7qAHMPY4Ogs9f3C1KgupvcHQo0p31ZKMGTN7JIUljk5f3NZi8k8NZpS29
ftaHoPLODtf+bN/yux/Kb3B2uFEXk5+cA7PfxeF/QI/63FaYvIuDes78XyX/
Yea7OoRM3jgxmQWa3hpcHQL45Q9OvHdif+Ch5faMa10dPl3yTRKIOLkfAOtQ
5yw=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90AtYzPkeBvB/N7etNHFspxxaaiNWE+nmMm9JJOk+3WtmamZKUkiJ7ZjI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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdkw1UzXcYx//yUhMtKjrY1HC7KllRotK31O395d5u96W0hcNu2fJSaFbt
Cr2xoSaJmNCSYoy8lHal4pS1lqmTOu1gtF4QtWlnspfjeZwz95z/uedzPv/v
83t+z+/3t1y+RrZSTxCEjf8+//3zz7j16Fq3sde/f0X97jej5w+OMmQWYHYt
PVFsxGyA5EX6nd+89sYw2Z6gezyK2RS796amNvXWEZujub4pb8Ew8zTYPy/N
ab/NbIEb9g1Ghy8zvwcP549F4jPMM3Fa7/gTlwPMImycZSPfF8MsRr/fw9oh
U2ZrVJ3t9Hl2qZbYFsbnC7wPSJjt8LQrICdlAfP7eN52LjJ6NrM9DDUpjfE1
NcQOkN4t9sn9jHkeVsf0juqOYp6PVZvuPHBbyeyIjh80Vw3vXCN2wv3qxAbR
CuYFKDukdq41YnbGU8eTA/qF1cQLsSPe7uVmD+ZFmJ/4lbl5N7ML6sun6tvG
cd4VQvXeLc7zmN2gjH/eaSbn9xcjee6I1LIsZnf8Mk674vF4fh/IEI129dmk
e8VaoEd67EBtWxV5D7RNq0+Kf3mJvAfGSlePyDxSQd4Tfypkjr6J58l7otkt
dPeUVd+SX4L7ppVbtjWcJb8ERt1rrftH0PuCF2ruTWnQ4SJ5L7iYjC+YGV5O
3hsZHX1jCzsukPfGl/5XLR4pviMvQfmD2Kya42fIS7B+V8UpiyBaT/DBX3Vr
WuakFZH3QdtbmdHt3ux9MQ2hQW8ncP++6Mm3yZ5eyv374VzMmG2mm7m+H965
6NDUpSIW/JHtntNel0b9aP1RpSxLSkspJR8AV6hFkbFcPwCf2DZ+OpzC+wvE
bfmzsr4+9oGo379hqGjyafJBOOq7z6XkdT4IPwdq3Ivj6DyEYPyRv3hbXDvP
LxiFA9XrdD8SCyGw1Ey4O0PCPgR5mel1wy3nyIfCaLLNgOU66h+hcFx3QaSv
IK8NhWeLzSGTbpqXLhTL3221/dzpJOWluGgXNT7t3gnKS7He38ImT0bz00qR
e79z+phlVE8nRXFIwL65Yj5/GRz3BEUHOlB9yFC6yzKqfDvvVwa//a2HN5zk
9WVQT0rYOTOBzycMY1r79meUESMMx6cWFm2cy+cVhkk/5bwYl8X5MCirRsrM
bvL5yXE7V+P74Q7Oy6H2+zs4Jormr5Uj39sq3OELzsuRu1OTKpnN9yccbh6X
r08s4f7D0W2wtSEsgPsPh3TCYOG4ImJdOHrunBhqWsr7V0CTrp21dTQxFMjI
Pua0p5/nr0Bg2G9WHTWcV8BT9ujGB118f5SwbTHyyp9I3weUSCpeInaKv0x5
JVbvaSzeakjfq06Jg782m1acIi+okGT8+5aFD6keVHgiuuDVkkmsVUHlEitf
78rrq5A9Na+8MpbzaswpMUhuvkX3EWqkPhiOq9Pj/auh6r1Sf6SC6unUeLJZ
6lTpxvOLwDJxx5rKap5/BOxCrphli+k+aSNgnlR99KDzMcpHIN1akNzKL6R8
JLxMDkoyvb6mfCRGTiwqeLHsI8pHIq9bV5OQsIHykTAozbbKG4xxf5Vf+n/G
G6x9g3VvsBCFGUV6OQ+tPGn9qNf+H271XBs=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxTTMoPSmViYGBQA2IQDQMC1xcX2HId3w/hfbB/tXiSRCicz+CwZtOZY60M
MD6Hw+uajzut/x2D8gUczq6Vvt0oAJMXcbh+t8ZJ+SdMXsKh3TzeJfs9jC/j
sEKq2D9kD4yv4JBa7jqDaQ6Mr+TQ2Hm7uqkIxldxOGv1hF+jFMZXc1BdUszP
UgfjazjwH9SfMacHxtdyMD59pn1OCIyv45BfYldWrgfj6znM8RCceNoGxjdw
EJZe5JErCOMbOnxsYFiyRQLGN3J4L3Hi+exvR6F8Y4fYL9LX+9bA+CYO7ktr
vk0ohvFNHdj+a3rOWg7jmznkrk5pvbgOxjd3aJmYsPbOFBjfwoFT81TT3RwY
39JBO8hAaudjGN/K4cDzouiJIjD3WDtYqhz/J8wG49s47GuyC5ySCFNv6+Cb
ytQ+IRLGt3Nw/nW9/ckMGN/egaHHdH/DZph+Bwe/ny+/Z2VD46/BwYH/pvGv
0soTUHlHhwW/V6/bdBLKb3B0uOlfO99T5SRU3snhbrLQ/xDdk/szO5sOb5Bx
cvh0yTdJIOLkfgBuu8EP
           "]], 
          
          LineBox[{{39.14886714809657, -0.198}, {
           40., -0.19339727369834409`}, {41., -0.18828659667292366`}, {
           42., -0.18360561062621025`}, {43., -0.178348833606152}, {
           44., -0.19111872797589033`}, {45., -0.18617698944738642`}}]}, 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90nlIk3Ecx/Fnmm2FlZXRYXmUptmU0rRMax83dZrXtjQhSztw/tFhoF1I
OV0U0kERWpgpeZuaOq0sj21mG5VpiOUJFv1RbZVHBx0mFX1/DcZ48eb7PPt9
n8dpT4oiyYLjuPA/37+/7GPTV3xo00yj9p/GRB71Zg+lNTOHooDsow7/uwCV
GboBKx6zDcpGdqx/9tlAtoV8ibG8YZx5EeZP7bWfY2JeilWHz0ivP2N2hFdS
tiT+DvNymOtaUifOMTvDojvIzf0w80q0m1735MUzu0EcYmHwns3sjuTZ8BVN
ZxbC4Tv/tmPpQ7InescP9FiMM6+BEwrtN6Qzr4XUM1DAn8HsBbfkkdVNSR1k
b+xTGp5X2TGvQ6KQJ56V9YDsA/Ua7WenM+1kX+S/DVZf7tOR1+OyTjS3JpN5
A/Jvy3L8FzP7YbhxXnLJ3jbyRlwJ7s/06Gwl+6O6v7nDZ38zOQAz20riravv
kjdhp61k6JtjA3kzetrS358U1JJFkObVP7/TWE0GfvYVJGQeK/lnFbAwld+Z
+6mIeiCW7SrrH7peRj0Q6nTDQIGedTEUvVNWmkdklRghpafi+dvoepwEAaIc
SdZkOXUJnEQd0cePVFAPwo6rG2URsTepB6FLOFaUFkrmgtGWxlXYDdL/VwXj
TcvZl02DVdRD0C0sL0i5cIt6CL7udjGHj5A5KfQ/7iuNp2qoS5FXLezqqWTn
D8WHMGebazx2/1AMnORpzj5hPQzpUT8nX8VpqIfhsWvsSH4hu/4WFE8tn7Pb
ns1vgbg8Q/CAV0A9HBcPquNcprHzh8M0nJNid7qUegT8tnf36nPZ/iPQlRAT
k+HNeiRc4/iWDl5kVSR+fRw9Ya64QT0KlxIV2i/HiqlH4XvdRavWJDYfjdyJ
rEULVtC+VdHwznPRlrpWUpdhldT4YqiTzgsZBt4d0JdFsn3K0FfT9OHNXJrX
ybA1ga9eomHzcvwaNe3KmqDzQ46nEmsj58f2LUfssHLybSg9P50cysHRF3G1
tE9OgfP8Ks23rfdoXoGpWc2WHdPo/VYpkF1l56Py12t/AxX9f14=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0HlIk3Ecx/GpgQdeUYlmQpZNKQuPudI0P85j85wOCTE12mqUeEQlGJE+
YfSH0UVqh2RbkiRGZanDXM2ZZWKkFl6ZTCUtTa3FrDTJin5foR54eHjxfvg9
PB93ea5snzmPxwv9ff950uXYV3kwxKZN91efQ0cW5Q4OS+YhWX7FOMIjW2HK
xahZbkZ2xGitdWLhwjPmlTh72Gp21XeyM14rE1IWx8hrIBXKMzg9eS1KT9u3
lZaT12F+/FVk3hGyB9Lz7mqmZWQ+bI8mtXelkr1gkNT2KgTkjRjbGVIvNj1l
9sZ0koab1JK3wOJ+Nr+hnuyDBRfJhCqT7IvKKF9eZ0Ursx9s67QF421kfwz0
VD5YLyULMB3rZ7qeRQ6A4ERGodvIE2YhrkxWNEs05K1QfTC4zYnI2+Ccv+yR
obyFORAK0YsWQRc5CJeEh/jCb+TtUCpNnpcDyMGw0qlHS5r0zCHoTXOZur3U
dyC/3fzcVTv6XijUaUEWsz+oA93lyQe+pDBzQPS1eXXjW+phuFPXIQsaph6G
GsNx8ac31EXoTh/Sz51h53Mi9D9PvWW0pD3CYWfjXWxG+3Dh6HOde1dXQj0C
MzqvGUUZ25+LgHwxN1M/ST0SiYGjNebZdH4k1Fn7la321KOg1e1RSdXUozCQ
sMHHQ0j/K8Z5ebaTzQW2DyfGxZ6f7lOraS8JOopduGP8ZtYl2L3CWtrr2ch6
NDbJnPamVTFz0aiqyCn6uNRj/n2fi8GQ/OSNeWMD67H/9VhkVpuqVR3U4xCY
9LU/sYR6HMYKBhts05tYj4flQOOku4KZi0dR2fvpHD31BASf2jX8skDLegL8
Z24OdhqYeVJsnnjoes/ise4XqdpMGw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQMC1xcX2HId3w/hfbBf1KG1OowTxmdweLyZVaSF
FcbncJhQ1hZ16/8xKF/AwbGdK3r7FxhfxCHhQ7pHGZwv4VD+oSnvwQ0YX8bh
a/X1butjML6Cw7oVDyJurYLxlRyiprDZVTbA+CoOPan/67ekwfhqDkWxakds
XGF8DYeTM1WFbivB+FoOItGV4S/vH4XydRxEsr4UHF4L4+s57FJNFIhIhvEN
HOzbjuwo1IXxDR0Cgu8//HbzCJRv5MB5lOXCkpcwvrHDJLf+8GMtML6JA19u
7Xl/aRjf1OH9Yc8DiocPQ/lmDgFn4uZ0/j4E5Zs7nNqSebPnCIxv4XBGsWAm
00UY39KB4Sj7K/YrML6VQ4zsjlLPwzC+tcPOXYfeVD6G8W0cLnqe1C07cBDK
t3Wo/zdteq02TN7OIXO1aoaCLcw99g52CrUFpR9h8g4O6dwNx451QeUbHByy
N07u+3sSpt7RIb5Cb7rURZi8o4N/2DaNJnuYvJPD39ur9/58APV/g5PD6W2a
ms1psPB0dpi6Vju99i00fhqcHRbbSe96/usEVN7F4ZnxC91HF6Dpq8HF4cKy
O9Eyzieh8q4OBxuYHntpQNU3uDrMCX122tMRFt9uDoa6gu8WJkP904DGZ3CH
8wHCiPKJ
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zl1I01EYBvD/RuIMGpubKJtCZmyrbOY++tiHe9x/zmTURWkEfRBGILEy
lbFkrYbZ181mhIQECRYiQmYuiNC1zDVZrV04WBdSERthWrIuJDMvKjrvgcPh
x3POe57K1vZDZ4Qcx9X+3f9OWpL3Dy5YN85G/ytvWzUOX+qUkTnkhaFlt4Qs
gue7bHRTEVmCUbvW8rCQLIfCPXJQIyWXwTtUfLFdRC6Huknd1rMWZ96MEy3z
/Kk0eQuUybJx31PyVgSyYefgI7IKrg7Tb8VZsgYV4XcR8zHydlyVVE70KMnV
CF+b/3VaTtaiOPWj4p6QvAtcV5tfJyXXIrGgO59TkXWQddxNX46+ZtZDbokN
bAiRDShSPG667SEb0S9uLvW5yLsxtcP8draLvAffQppMykjei8TEz96qXIx5
H3yf11L5arIJR9wLnVrpDLMZc6XpJ0eXXzFb0Pphcmk9Oc1sxdB165eZHLkO
6elMLn+HbEP5WLNBcJjeA4t9LSu8lzkAiLapR4Jxul+PSGrgo7TuJcvrsXhO
PO6ZjLDcjht8LL8z+ILldmQtSb0jRjkPk7fquOBAlOU80uKbysElNo9zIPms
4NZXA8134H7AXHNSQHkD/MMrBS4Z6xNoQLw76J2zUX8ndP7+Eksh9XdCFOn+
lJGx/7hGvMnqewMl9H8jnl9JrIZrWF9uP1RTob51PhL9Awd+8w8=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQMC1xcX2HId3w/hfbA3el30sFMAxmdwmGqcUXGE
G8bncJhgetX2HAeML+BQa2b0QPnfMShfxEH8UO1y9TcwvoQDYz7fdLszML6M
w/xTMutYD8H4Cg5TFpzwCVkK4ys5sP/JEr88DcZXcTDj8F3tFwvjqzncbotf
PF0Cxtdw8IvVqt7IAONrObyPnJq4fOtRKF/HYWOP1c0HM2B8PYd9D978ua4N
4xs4JFav9juw9AiUb+hQ2bb2pY4tjG/kkHPwcpbq4cNQvrGD261/y39nwPgm
DvZrEpfGusL4pg6ns0qrv62C8c0cPpxdsb5+Hoxv7nBj0/T8KS4wvoWDlPek
M+1aML6lw9zMW6LC/2B8KwferlMHfNVg7rF2mJyfcOz/70NQvo2DacxbrzfH
YXxbh3Pe/8OSpGH67Rzapv1NW/TiIJRv7zBZ18K/f84BKN/BwbxBoWcRzz4I
v8HBYS/366N8pruh8o4OGx+u74mR2AOVd3RgVz9YmSC5Cyrv5FDtZ54in7Ad
Ku/kMFFGIWm7EpTP4OxwsnFeYSRc3tnh3dmJj7MrYfpdHJZt1L7T6wez38Wh
NidyJ6c5zH2uDq/fBJrwz4O6p8HVoeOU/OYD9Ruh8m4O7w/1VH8Jh7nPzeFU
UOSHhSyw+HV3YDN+LNi0+PB+jckOk90s3B0+XfJNEog4uR8A9RH12A==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw903tIU2EYx/GlWUNYTmdWU9BMbWU6zXkrbT91uqnbhMVUzJDmBc1CsTI0
pTUtpyGVQiQriUy6i5qXTPNamtofYaUhBGoRZkLmLSqjC75PBw6HD9/D857z
cs5WXZYm1YzD4Uj/nv+udPDHarKDLQe6VjUnXY7T1vL4ZA4WGw+H8v53Lu7j
OPe3DZmPPMPEc3cLsi2io7jplrP9zJsx56OB1SuyAxzshTkWrWQnXPwqbwgp
JjvDse7RmqQDZBd0HFX51W0ju2HYZeTeCzOyCF65aTrB1DPmnbCxbJ2WGMi7
UFpenXxJR/bE9LotNvb2ZC/IZjrV101Pmb1henBTay0i70ZuhGHwclYfsw+E
P8Jz2iZ7mSXQTrQrY45Q98WUtCw7XUH2w616g29ZBd3vD1/ujNbfSA5AbMNQ
/VJAD3MgloIXeAdTupn3oMRq/PTCfCfzXtzOdOrtmyQHocWO9zK/qIs5GM3i
Cr3rDer7kOEgPLWioS5FpfmvT+/iyMA1l4ju760dq9YD7kkBncULzJwQVJmO
Gf35bJ4+BOZusvOpV5+wHoqN6NluLKQeCk67oMTNgtYPQ/6GHZmL8ex99GFY
dh61EyfSfBliqtPa1iY8Zl0GsbftmVy/dtbDIUwoUAdVtbAejmSxqMC3tpn1
CHBr9F8EZxtYj0BhhbFUndTIuhyOtoHWid0PWZfDtN81/v0FZo4CAyespPk6
Nk+vwJ2honGbjFbWI2E895k7uqmJ9UgM1yi631Yyc6Kg9L4b4vmG5kfh1LRb
8OwVWj8agqbIpY/l9PzR8BLVra91pPlKZI98+8CX0P4osSxf6Q+zo/1T4aTK
3TGWS/urglWKmcOYE30/ahR65GnCrdn/oFdj9LXK4CIZ6PI49DOobEiN+RGV
jh8/2PUH3/0u6w==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90Qs0VfkeB/A9FRnVZbkaCYWMMnoaCml8PVLk7Xi/ztvp1jTqClHTqUmu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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzX0sFHAcx/HzUPI4ScNGqSw9oCIUh8+583xHV24rLSlcaoxQ0no4iVrt
bISEck7k+CNT8zymS7JW9Mjowe6sJxV6GLOyar6/tfXbfvvttfd3v++K/cnb
43U5HA7+3L8vO+aDVSk+Rr1d85r0u5+WPRRmwsyBJOel6iOHeRHSlW3u8rl7
ZHP8ND1zPnKW2RL7yrfZCceYrZFkOTPQ1MlsC+4jPbFpMbM9HEPlBmNHmFdC
lRrVeNaf2QHDXwwaXV2YV8PWvn+VbD3zGtgY+qpqlzOvQ4XCzaj9Ww/ZCU90
ZjI83jK74EpBtlyuYN6I7jCtoXEr8yYofOKPapOZXcHveHhb7c3sBrvBisNJ
2rvkzTgQKx25dZnZHdfifIciopk90CaRDNTHM3tiOnxxQmsG8xaM7Al6J0tR
k7eiP1XkkJZ/h+yFHqdP1Vd3dZO9kYPdsih1B5mLp2u1ExZFbWQf2PA1Xz90
tZB90W7eku/5qonsh4vCaJ69TjMZ2Nv8bMkPKc3LgB01Ar1kVSt1Hgo1mujP
sazz0Dfumjsyyv7zR4w45uCNyUbq/jgZufPEi3EldT4coivFfa6V1PlobS7X
764ppS7AMmfLlsaGFOoCWHvl5k71HKcegLJeiWCDRQH1AAx7dZmlTmVRD0Se
c+d7aXmx33wPxDgMRbNWNfPmBCG9buIQX6qgHgSrBRnpBrw66sFQavK4pdO1
1IOR7BhpxJ1mPQRRD7LM+Mb11ENw6XnH9GAhzXNCodEX8X4lXqceioXiQK3d
G7Y/DImJ1rouF8iyMJio1aclS1XUhbhp8PiY22vWhRi1bChJiFNSFyFDLgzv
6quiLsJcZsk5ZQft44SjLO17OTezmnr4fz0Cp4qCRxRT7P9//g2TyDuX
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zg0s1HEcx/GLkRSZUUdqhZ70cF15SJz7eDzd0R0VmtaDh5SHSW3donLp
HK0HJemmDStLjDOpJZ2Jy0NrSiwkedxYRQ9amVqPu++v//bff6+9/5/f/78s
Kjk01oDD4Yj/3v+e7LLouXlYYNraoNcnoTjJqzv8vznQcN0F/bOYTVDVm/LS
/2cL2QIX21s0iRPMVnhftL2o+QUzF7Ly2KIKHbMdcstHpuMKmJfC1Tpm0bcM
ZntYpgfbTu1mdsR9y8ysnjXMK5BmJlW+MWZeBX6ZKksw00x2wmj+PfGWHOa1
mDKy+N12hHk9ip4WRhusY94AL13NWFfpYzIfeRzepike80ZM+Hw5qPmuI29C
tEv1kbQDzM4oGyk/HSJgdoF8RzHfMpLZFdNL1ZpV3sxuKO80XHLPkHkztB3z
hxPnMLujMlp1fKqpkbwFxtzF0nwRswfa61t5FzvryZ7YwVd9lB5iFmD51+xa
90BmL0SJxpInY+vIQgy6cF+bCmvJQNdi0fXGiLt6KwD1sY7hyw53qHsj6XxY
xLz2auresK0cNzFyqqTuA6Xf8K6XBRXUfaA6uvpUZG0ZdV8MpsrVbsrb1H0x
k67VaF7cou4H8/QfJ+I09L7CD7b+dS5RcSXU/aGt71sx9ERN3R+ZsePaJtVl
6gGY+bDAek1ZIfUAhHuem7vLgXURciST2TZ1+dRF2GmKr3Zp16gHwviqfUPf
ggvUA6F7a1QsccukvhW+KXYFbk1y6luxvu+SsnG2groYXVUnw3UdTtTFUPWa
73mWFU9dgvN9BmHXXu0X6rsEFXGVeQ7cfXpzgvAoqEEhG42hfRAEyyWJZ8+F
0T4YpZHWMWbXk6kHY9knTxvHZvb9beA/f8d71R9P529DrtB1vpf5WepSGPZ0
qANMM2gvRfHnEvkV4zP0fRm6lRnaoZlsvSFDXkKgM29tAp0nQ4vJTnf5dIbe
j2RY2bkwx3xvMe1D0JDX9HDEtpD2IbAfkPHTxfm0D0HbwOeC3cdSaf/3/QcK
K8sa9v+hePorwsPxRq7eCP3f/wD42GrJ
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zwlYzfkex/ETQraSRpaaFjG0uFENE+mjVYucVu2d/WQ3jnIbI/9RM8Yy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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxF0nlIk3Ecx/HphpriQSmZZJqVhFne6czpx205r80LLaTUDMH6xyAIS8mF
WkJoGmKZsKZSJuHtFM1r3klp5ZFHoftDLY+oPAnJCn9fGzw8vHg/v+/zfWCH
45PCE7Q5HI747/XvTj+Tj6XXBPp97Tv67hPW1uO+umsO9M+PcbR1yHoY448H
puqRTXAgOFO5yCObojFic1KlRTaHR/y8sfV4L/NBLOuqzYIaydaoX5g2nSkl
2yA767FksYB8FOpnI2vJOWRbaHfVVn29Tz4OoymRJp9PtkP4oFNnza8eZnt8
mdsYH1GQTyHgyYVOVQnZEca5Sf2lrmQn2KSs9VXMdjM7w1T5ukPLjOyCiZr+
jaTVLmZXVM5oTjZHkt1gYJHPEyeTTyPb0rDlxodOZneML/j4GkWRPbCtiLO6
s6Rm5sM9IqrcY9ee4FaXDQ0mks9gSVjreMSW7IWndcO8xcl2ZgHWM6zNb62T
vfH5uuyBXzvZB8sq+U1dJRmQZixNLys7diwH5o/FxhufYOb4omOLtzm8h7ov
9js4aorT6LwQ7aP99ip1G+tChAwMFPXWNbMuwmBYdOFeEzovwu3q1EMxqzRf
DE9t+xGRFZsnF4OrKIp4+KaV9bN4V9moUyuhfhZL6ReFUyn0fj9EF/vNvxXQ
fD9U2LlZ7ftJ5yXIMZBGbkazfeQSJBSGNGRfpf38MfT71ZRGVsu6P7p1FLKi
RBXrAXC2iP+WNlfDegBy884JLotfsh6IS7MYerSSz3og+KGGL1q7qQdB4fl+
W3C3jvUgZGa53mvxb2A9GJkaB2FJYxPrwZCW6+QHX6H9pRiIFfLcC1pYl6Km
jOvwafe8DE71lt0RXPp+GXqeV0zF5bF5nBCgODd9toU9Lw/BypbLxOhkFeuh
EIVlev1wYEYoYjhNdZEWtE8oOgO9K6VG7P/a8d9/AHtqYSQ=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0n8s1HEcx/FjMrtpKYbMLEZMxvkt5bz8Ppzfy9rVYsRu5sfl8kf9kcP8
bEtEWsVwWkzd3JlUY8dFasMmFRaJrtTMujE/R7/m827ru3323WPPz2f77LO3
bVpeYoY+h8PBn/X3T5/JlFwSwB1R70sX2DXd6KIzIHNQlDLTnK1HNsJsLXe1
Yuclswk0b7QSsZZsBu3TsM5Pk2RLXM6q7VwaIFvj2p5UMa8mH0N9294VeTvZ
DhNdr0ct7pHtcX9T3yn7n49DVb1e4pVCdkLAQuB4bzrZGaM5Cw7WFWQX9CXP
r/KkZFescQ/HmWSQeXhcYLY6Fkp2x+et75PyuWFmD2hMgytn48me4F8812Bl
SPbCDVPe1TQ7sjcy8/wcJLZkH5TaVyl1RmRfROamNvXIh5j9kNmiE/FE5JM4
4PrgaLH0BbM/fP19ul3KNcynIBYmuRVnDTKfhoGVfkd9MjkAK1p3RUIS7efj
i9Jt3PkhORDVh3gCgzsDzMBWRFmZWM4sA358tUzbbKMehJ2hEm/njX7WgyDY
zjW0dHzOejCMy8r1svu6WQ/G1Eyz43k7Zk4IGp1aPxQe7GU9BOb3FfFmu9RD
8aq/2pyf2s56KG5pMoIFvzpZD0NGco/9Uk8d62FIsLppM90iDtzv4eh4uz0z
LJKzHo4lzwmvtWUlOx+B7oSRRcWCivUITOXbdi1WMnMEKLj+frjUgO4vQNna
u/TSFeqRUPkoG8VDPaxH4sx8gzCxsI/1KNS4K5oEG8yyKOhq7p7lWtD7RcNY
+mxY+UTNejQER/JTchqZOUJ4TtvJ5i7R+wtRZfIzpOgEnY/BXN2F4lo+mwdZ
DG6PpUo/WtJ8xMLj2+6ITSubH1ksmtZFymUuzVvc/5bFYVCiKhSLHql/A399
TL4=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzl1I01EYx/E/oSCBa1oDW7JcrLKh0XSuuVr7zb1ppYhGo2y0is1QwxEa
Rmgjokkv3sgozIisvMhk2IVp001ZU7Gg7cLGLImggqiNMGI6JCs6jxc7cDh8
+HIeHvHp5hrbOo7jSv7efy8dfuShQ71+2v9fPzTKjGj+BJ/MQSKvnuoTkDNw
4VO9ObRmPq4ZrNVNOeRN0IgEttV0cg4u3k0UponJudhy1npsKZuchyvOkZ6f
meRtCGeGNgS/TTFL8LbVu1Jzj7wDno2KyvI2cj7iRT7X1yqyFNHAwoe0CnIB
zjlVJmjJu1H/y9f4tJS8B3Fv8Wp7LlmGwcGRwOxAkLkIsiVzrOENuRjbFytn
Ol6Q5VDM3XB1WsglmLxe6LnT+JJZgb4jm3uTJ8l78dsenPJHA8xKhHldWx1u
6qVwvz/VYTxEVqE9Nt0dEZH3YWXIvCB6R96Py+dtV5NfyGqMNe20RsZonwOo
Upl0tl1kDUJdpmYjRwYGrKPDrwTMTiDGKzga76F5Wlj8871ZHcxOLfIkDbdM
j6iXoVXsFt5fnGS9DLJhoaW7doJ1HRJnWj7PZ1PX4bXXrhEcZub0iMXCJx64
qeuxHJB2DgXpvwHSUc8zIc/HugFZbXWPP7ZQN2I8Uav/7vKzbkTY/lztqKNu
gvim8knyNnUT2i/1z85I2TyuHPKi9Lnjy+Osp5irSOkp5g6u+Q/dAA2x
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90glYzXseBvAzeFQY0u2G0bQJTehSokV621ftu3JOZ2mhrnuzhdvtpGVM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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10AtYDOgeBvChCxulEiKUtii5tOneSW+6bk2X6X43M80le9yOFRttZ4Ta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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz3lQjHEcx/GncmypsVJpZ/uDBqNcKwmt9NlOHdrdkjOzinUNk3E3lR6p
0Y4OFckRRghthBzV2HZzNJoc5YiGCsM6plGu7TDC7Pc3Zjwzzzzzmvfv+5vv
MyouPlJtyXFc+J/375c9wubiDT42dTVmdfoeajK8Wi9k5hDf8t3twlBmAZwS
E9ScBbMQjvFW8xOsmR3AX+btRZbMzvjmeTC/6eUdsgsQ0/XQ+Jh5JCKiRo1P
rWR2xZLd9yrqCphHI69MVzg8iXksvjxI8ypfyzwOjzQ1qdESZnfc986qOiNm
noCldhHSsgu3yZPwdFDP5ru5zBJcdU0ad3Y18xQMaBa475cze+DAxIIcdcEt
8lRYfT9ucjQye6L743LrEeuYp+F8R9/CE4XMXrAL0Il/tjNPxw3ZNkOciXkG
hmg637YGMc+E8yqpwwzhTbI3njWvOjmpnHUplqhiuK7DrM/CilMLetM7DGQf
aKMb+5xNevJseOaLi93TdGRfWL/oHjFRVUUGapt6Bc4/Ks3mAasfot7ketZl
qICdKqG6mroM37Kn5kftvEHdD6Ml76tdX5F5P6x5I+wy1dZQ94eb4GvRhFTa
h/eHftl17eDpbL8AOFmkNWansB4Ax65WlcqG9UB82BnrN1B+jXog3D5/tY3z
KKUehOjK4qIxk09TD8KhlynYJyujHgzjrisfp1QdpR4Mg16Sfr/mJPU5uNl5
rv9yRgn1OeiIVfhHbeR9zT0EDWonecn2vWbzIZCJY3/teZ1OPRTrpSVBDcoM
6qEQPOfqByTvoR4Gr6fZg7p9sqmHwfKakRP051EPx/UHIXYt9rnUw5FZbitL
FRRSn4tLn3QFd+fTeX4ujrwbFhKYy3oE2mwfJ26R51OPgI1pR9KCNrafHFLt
FRetQUNdjmkWiSvE3vQ/nAKtLotK+7fmmA0FMkQlDpGiXXRegQZd0RmjYrPZ
egVakluyNmnZ/UoMVdeNFWhofyix/FxD5xN5Js0rYR9Tn9l+LIXmlRiStXLw
YhHbPxLx8ypybBqP03wkeoaXai5KqPP/Wf/PvwFbHnMq
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntMk1cYx/HXqihKBxiYyDTjIkiwOoXaFS3w49IL97YkNiKEthGjEwSJ
0UA2rJeSsU0sGoQghkoXysYUkM0CG9KNW1QYS+PciAG8xAsogRlkaLIwTZ8T
E9/kzZtPvuf545zz+uvz1Tk8juOUb963X/Z4/GUpiFwx0O3UTPRY1dphowsz
h2vTeX4DPOblSAj/U6Z+0U/2wIPa0F1tU8xeGPB237/vPrMPgrWDLgU3mNdC
Y5pNlncw+2EoN6S0qIw5AC+jBHn7EpjXoyxYUBLmxhyMz6xhxlpP5hBYd8l2
uz3qI4ciJ2uxGDZmASqXDm6+pGDejGrLnenhGOYtMHW+EnuO9pK3omOmZOW2
G8xhuNVn9g88xByO13FHWnWOHrIQkn9FWd6HmLehNcTn+SzHLMKdya7aKz/+
Rv4U7U9W/5Ax9StZDJWW/82ZHuYIrLwojivUMm+HL3dW8H2LnbwDu7funezk
WJegKfAEb6jpOjkSo66Hn7vIuslRCDAd623cyXo0SpYWq0StrAOavsr74xOd
ThsA4yqxUhTxC/UYaMcdG3qkHdRjIAhz1a2baKcei9/H0kTbfWzUY8HLfObm
V3WVehwk9RpHxYafqMfh8R73dn5qK/V4zHxesZCbR+sN8fDc5GqrNrIuRXBb
4pqPjc3UpYiu0y+P/KKFugzFBxbxhXevUJeB53EvfGyogbocc8MHi4T5F6nL
MfLf4+yYjDrqClx/0D0+N1lJXYHO/MGPJJJy6gn4LunrdRvPnaWeAGOgjq/1
InOJaNHHTiRbDNHOnoh+nTVU4ZVDPQm2jKflUyOnaD4JjnhNwc3sMurJ+KCr
9GfvtuPUk9FcKC3riqiinoLT8svLhOfJhhQ83HtrIT3oAvVUTAyO6m/baqin
otEaNdWSTfvl0nDwXO/J3BQD9TRc1Y10+dZXUFfCIt8xP2OudhpKLNwcNYcX
1dN6JeJTxAr3o1an7UoczTyREZRjoXkVZpsd1n82ldK8CnV/X944PcfOUwX1
4aya/f103vY3vW5e8wf/W5pXI6p8if8nJjPNqyH1zayZX0T7M6gRUKgym/zp
Pu1qHCn+MkKf3kTz6Qip/Opk6b1Gmk9Hg9CSWvAh+1/es/2d/wdGCIzI
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0gs01HkfBvDBotSudEH30Vp0WV3dauShRCiXIff8zcWM2pKtdKEMkqWL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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdznss1WEcx/FfktHNqVES5hZWCLlfP8fhuHMSGou5d1kbJc20zNyaKfWH
IVuTS5HLDEe5n1Nym7ZqTaacVFhuoc3smFOr1vNtq2f77dlr7+f5Pj+D+JTQ
JCWO4zx/fb93WryJmlS3ncOSP1rzyFsssnP6aw6lzlrf2zXJqoiRC/TTVcg8
+CocfxQuDTFroMxsQpiwQNbC8tOv50Y/k3VQZqPETx8j6+NDgvj09WGyISxy
ZhMLGsnGiDftkcVHkE0gmLi9tulENkO04aGiSV3yUWRYqnjumh1kNseVVucL
gWlkS2zOuVW81yBbYXkmd3eoMtkatyzy9BLGnjPboHrCts6li3wCNXJNt0+v
ybaY1uZVlw+R7fBW2mQ94ki2h1rB1rsoW7IDhJU5VToGZEdoBLQJilsHmJ1Q
mJ8ltz9Fdoas3WglqIrsgpn7ermRBmRXlERhJXztGbMbZLFX9UqsqLsjanx0
XuFP9sCRux0beVV0HlB/EXExIIc5GwibngpbMKbzfEhtKtJHNKnz0RuXZV75
RsK6J8zP9sE4uY91Tzw8eT4jVY2ZE6B0XaW6uLWLdQGm90WPv5R2su6FrWMe
wZOT1L0QXlnlzsvrYd0bErOl49kj3ax74+OZywbiB3RfCJPtPOWgV72sC9HM
r4u/GdzPug/2rJY1Jqawedk+qB8wCtmoo/u+EH1TdIgiab4v9KPlratxzJwf
xMXd2vcGxKz7obnFIRMJ7H85f0iTpQd3pLF52f5Qr1UV93dRD8Bhs4qihpgn
rAfAdK+uX982No8LRNONxvz+5jbW/zMXhND1zGtJU/R+EBTF9cux5R2sB2O/
h+tIrftj1oORIZlbvDTYznoIVO7Mf+mMqGc9BAr+wOYBZZov+tcQoaHlkUyG
NslPB/1Uyg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0V1I01EYBvC/TaZuLBcunNVGbRWWJjZXumzumV/boi6cVCssK5EoVo6g
9TGNoQxbQRehjcooNGnSTWRRSs1V0/9F+JGLRNYMoxJScEIlrqAPOm8XHTgc
fjzwHN5zVh2qs9Yu4jgu7/f+c9KSjnU49CK+769ihu67Yx8zBGQOanNPjeLH
AHMyIi/3dI9Mk6UwyZb6296TZbD4Qh4+TJYjpu5NKQqRV8Bb2xGeaiOvxPnk
Y0kZl8kqiMIJNx+dJa/GqzpBhWQ7eS3mGnYvU1rJmaiPDEihJa+HXVN1BIvJ
2QiYL8W/9/Qz5wDybbMGGzkXCWknhmU55I1Iv8/Pp7WQNXjw82TlKT85D+LU
C67MDWQtFqSBx4qJEPMmyDp32grt5M0YEcxFDaPkfPhuB1pcYnIBko5rhxWh
F8w6XPS+GZ9OJW/B60CTJ1tDLsTeT9Zx7wx5Kw7kBnnOTtYjq0nE2648Zy7C
1dhMvUz3jNmAJcpWYbuEDNz6kLhP18XsBmL+wfhnMeVGBNOXe3aJWZ/biKF3
a06rZqm/GF8jb+OWTsqLsaPSMXWtkuYrganxxtP+g+y93CWY9AkT5c30P6WY
j1Y5Ygt0fymcR++MTrZTfxmcUXnvuYfUX4bm/Y0166QBlpfj2z2VWpLSx/Ly
/3ITBoVZzokvT1huQn7B4TPKIWbOjIaK667W6iDLzehyGqv1PDNn+edfZnH9
XA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVywlIE3AUx/GxMKUsNkmosLzFeeWt6XQ/j6lzLiNT2og8apJIeJWEmk3S
NHU2w1JBkVppTtM0SyuWmheSBIFNo8AOCc0EDdNMiIreX+gPj8eH7/tbp2Qc
UXI5HI7wz/zd7PGmtJlB28b6/2lJlDua2Ni3k5mD2i31L7w3bQJcvNUlNGfm
IWdlnjvIZ96FzFmhusqIeTcmqvdtFC6Pki3gY5fV1W5gtkJeS+ve1E3bIK1a
7xc3w2yHteHxV+8vMTvA3eqBZEDO7Ahlk+JQVwKzE7ZOt83XcJldYOEwubSn
c4TshvYfiYvqn8NkdzQ4nnPhNDN7QNrB/3zgBLMnUg3+6o6vQ2QvZHqa868r
WPdGmSGidNWF2QchZnXxKh9mX9hPNn+zfMj++2FAPBJWc+E52R/rUbbpNuJB
8kGsJuZmaeaYA3BMnPYhfz+7D0SAprjVOJ91IQo+LZQ5eQ2Qg7CmdssWpTAH
Y9RD5/zERE8W4bLOVCbb/owMSNU3rijSqauAWN+C8oaIR9RDIBO8tky910M9
BIGHE5x79d3UQ1FUfWZ6qLKLeiiSOgXdK0k66mHgnQrL/viynXoY3p2P37Hc
cJd6ONw25Ar5dy31cJTUuSavjzdSF2Munlv0uPcOdTG0gtnJxYAm6hEQFI/z
86+SVRHIUIuydeUt1CNhWpFiLM+7TT0SKyaaOTNlLfUocPkT9qff1lOPgrXC
P+GNvYa6BOZxv27yxiqpS+BkxLctqiRzoqHNOVsyK6miHo3lo1VtyYZS6lII
CjBTF3ufuhTXvizoKyT91GP+tyoGfq3F6aU/nlKXofB44ck41z7qMkyN2NUE
K3v6fwPBYCoy
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1yV1IU3EYx/GTFB22i2YMVFaWYm3aXOtVV01/m24wSNEUE5Nq9gIbWbso
K8i2Cy3EddMLhqWI2oXKjrPUmUwnh0yDSZNk0grEJfOmojAjSKXE//PAj4cP
35Sqa6cuxXEcl/l/659ONtvh0EsmAhv6kfukdjn+BU/mcI4XLc0yMo8PmuZO
5RayDBqFN1T59y2zHHsi3TM18+REmJcuFKjC5B046zltejdI3g391uvVNx+T
U6Ev9bvrHOQ0vExOEgQLeS++On1Vr5bHmVXQ2hViV5ScAfOfp6vyCFkNO3/l
llIkaxDZVeKu85O1sBptHydqyAdQb86K/20lH0T5e9+daBv5EL7ciFn7et8w
H4a40CgILvIRFJVdvL/JQT6KsEQdG84gZ2FxKmo1nCRnI6z97m1RkXVQn+f6
m0SR+Rgs0+Lm/TPk4yhZzFm96ySfQDCykiJJIusx9WwhGZNjzDk487NUcBYG
mHPxrVU39ugTGZgdCSozm/wbdgGfU6fl95zDrBtg3+ax9cSYXQYoC0ez22+/
Zt0IfskTDRX7WDdi5JdDl/5ggPU8rCm03bUtfaznQbo2f1WqYubyEYw1GHTV
/aznYyUkTXTbqJuwby5t+1zFEOsmlD28PLlz0Mu6GRUJ9QnCc0/gHwJf5GQ=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1AlQU+ceBfCINoAYpa2KWn2NaF14iqjIZtGDgEFk33dCQkKoiIAoYile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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zQlUzXkfx/E7lGN5cgyZhNEuZBCVEvXRKqW9XK23u3Wp0WKJyfKX0kY1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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz3tMlXUcx/FH8gQIclFocpngQZxDctxBFM/Hw+XA4XA7FwRpO8AixgBB
LRHI9hSy4iLYYgwUFbkVd2QYFwkeM7W5gNTEFswMDkWUwyAqNdZlfH9/+Jzt
7Oy19/M5v9+zLTVHnWbEcVz6f9//f9nH6kFjbtCGW6NreiKz6fJb3GjCzIH3
L4otNmM2gf34LcmYhNkKro/8Xvnmr5tkGzikadR3ppi3IC9587rpu8yOGPhO
4eTRwOyM0W2rp7c2MUuhupPTfrGCeTtKHE2XOz5k3gF9tMTZpph5J6Z+XX9f
Gc3shsvJ8/2Z9szuMGvJXwhsuEHejScGSYCDM7MHenbWdL4x+gXZE4XGdo0d
PLMXHHkHP0M4szeqT40YJgOYfRCUMfz0thuzL7qns1bc/K+T/fD9W4J0NoXZ
HyflStvgi5+TA1B5t2glwJd5D16Xj9UW1F8jB0IXJYn0iWN9L/44nHNmNZn1
fdgrs9Zr6wVyEBYeviS/8MkIeT8etRyxq/K9SpahwvBqTkbrIBnYFWG7OOlE
5gGrZlOjwu5+6gfwdhLvLmkk8weQfTZXf+I228vxeM+NwUsew9TlcFlqru6b
H6IeDIt15jmVCXQ+H4xUz/snVtTsPiE42j5t7rI6QD0ErseSQgKff0o9FIm5
ljP5mT3UQzH87dAWH1kv9TAYu89c+CWpkXoYZoXjZt5FpdQV8A8r43wdvKgr
8PCzp3XKifeoh8N8xGzTVWU59XAkPVssHeh9X7bWI9CnK7Nyute0Zj4Clvom
m6P3GqgrEaq3eflcOJlXItnE5Ui29BL1SGQo8vpX6wqoR6JNOPVuW2ktdRUq
vzqU5lRZT12FiWOZN+cO1VCPgsK1vLqkpo56FDYbN3u+WXKeejTmVamPq79O
pftHw6PK/suPNmro/WIw2N7aoko6TPsYPD+enraUws6PxVjtuLZ7d+uaITIf
ix29uvXntPQ+QiyGYw1Oedc/pn0cshYCgryX22gfBxe5SZmHVy/tRRZE5tSw
mpp7bXniMu3ViBuv+Gf2px7aq9GZYmdwj6cuqBGjkG1KNaHOaZCtLef1bl20
14jO12B/7uRylXUf7TUYOm+ZfraHzGlffB5ahHUtmZ3OZueLLIjM6RB1cMNI
1tAV2utEex26fzxppCig+wk6FP75+64wVSft4zFusbV/romeh8h8PAoGFM25
P3fTPh6rsB6QfkD/xx180RCZF1kQmUsQ7RPwd/47wjU5O19kIQGT24stfpCy
+yei41nVzG/72P1F5hNh2iS1fTB6RfYvjXnnxg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zXks13Ecx/FvRI4mzD0rR/SLZo4cP35+Xj/Hz/H74RetYx0rkyONZnJM
vx9tYiVC/YH8lV+5iXK23NGwUlRbaQsjiznWNGOmmvenz/bZZ4899/68LaOS
Iq6ocBwn+nv/vezofq687q013LOrVZ+V1uUXsdrMHEYKOzKKNZk1EKlck4+q
MesiaOXaPq2dIbIB+CWpewfWmU1QUWpruDjLbI4leensh3ZmC5hIBd3pHcxW
UNk8cXu7mfkwpBvlvWeUzLY4u3BAdSGFmQfeUq1M7sJsB7vTnpcbrJiP4WSX
pcJi7jXZAbLFZeOlAmZHeJnNmUUZMTthgF/lqikaJDsjLlKLZ3OI2QWFYyGy
4rUB8nGUWYrs2iuZXVGW3/kj1ZzZDdZBimTldD/ZHZL0mpzMDWYP9MSOzNwC
Mx+rwf31pQ5s3hMxFdtORW2se2Gqm5+4HcssQEP5wtXxPczeGBp8N5Vl3kcW
wlkSObXjy+yDR81vW4S9zICruvjjjTu9u84GcsNHefL8HuoiCBTVka1ur6iL
ELG5FS9Y6aTuizSJ/FK+bTt1XxQrajUyn3ZQ94P9XeXvNwut1P2gHuPT3m9A
5vwRY1pk9GD8OXV/HIlK2tT5ReYCINU2yBj/0kI9AFW89Nq+CtbFWJ8b6PWL
YPNimE7zLuR1NVIPRMP5useJL59RD8TEhLVoKYHMBeFi5UPtlZ0m6kHwkDXa
ZBiTuWCsWlTEtY7VUg+G6s3k/HNrNdRDUDI4b3jqIPs/BLr68T/fx1VRl2As
/pt3QQo5W4JJ/a/DfMkT6lLECt33b1koqUuh49wkr+NoHxeK6Hm9NsE92pcd
itz7OT5u0fXUw8DNZqrNfG+gHoZJsSjBXlhNPRxpvDyHo7ns/3BYfXJUy9Kr
oy777z+h1UaB
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90glUjXkfB/BHNFkqZRtDcl2mKEVCRfRtk5K03/bu2r0iaRMadZOyvF7L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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0gsslWEcx/EjjNIWy21OtphLLsk1SYffcTvuR1qaxRE5Yl04bVbGcqaN
tWJUk5q0QslQkms7nUMod5uFY6E0RquFSp0uVOv5t9W7vXv32fd9nj3v+zxm
CamR4nUcDsfn1/37SZfuWHkab8NT+R8tereH6nl7aJM58P3a3pOvRdbGY25U
ktqPbmZdfIoryscyWR8h/SYuobNkY0iGsjMDe8hbMLJSaDZcT96K5xybOP0b
ZHMIb09qDIvJFhgsq+Ru5pKtEGnaJk3SIW+D37kw3kFlF7MtPshiLCpayPZY
Py6KV0aRHSB+M4fEPLIj0iU5yXdayU4ISuu1fO1BdoYizC0x969dINp+pLhW
1cnsiqbYkgv21WQ33E3n+nb3PmHeiQYDuPVdJbujSpl+qyOXvAvfLnmOvJSQ
PdBfYXi5sqGDeTd0Vz5HGx2m7glVh9oX/9V25j3IaUq+MlFF7/Mw2PWqcUBJ
3QsXDUqXKiYVzN4oqUwqX+JTBxqnEyRtjqxLAa8do5P1eXLW+RBwtSwzw2Ws
86Fle0K3VfaIdR84nFRdkwuo++DeeXlWzTB1X9i1jr3P02SW+kLvWf9ChsFD
1v0wM9Es00m5z7ofeNeNq51OPWDdH/HzOQIbUSPr/jhdcFw+atfAegAMxGa1
43tpfAAWU5oKAmZrWBdgRTS3nMJn80kF6DxQpq5nXc96IJbnpvyqrWh8IOYN
U4URNXWsB8E72+djpYp6EDLsBlyKsmh9wbBay1vYFMPWIw2GQ/H0C/URWl8I
htzzD5X2UQ/B/tlou5ty9j2cUKwGGK3YzrSwHop3zvs0XM3Z/+SEQU+pqTDp
Z/sh/c+ccJj808MxZbp2NJ9H+yuE4TrJseZMdj6kQsQWfT/7No7OSwRK63R6
Nnqx/UcE+MWKwjPWXfKfoHRTgw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zn0sFHAcx/FL0oN0/kBMLRGzSM6zK3w83LlTjTu1tJ70IKkQs5KtulRb
/ihrTKlrC2GtXHdMbIk4RVOhrFJylbitmzq5NtZ6XN+v3/bbb6+9f9/tu3x3
tjLNSiAQhP69/14+9q+qDkcs6Gr7L3OUuVyx/9hctgAfDZaSkzOeh23y0dgO
O7Y91nsJJwoc2Q7Ydc77W5cV2xlTvVvLMwYekZcg5ezi1pzHbDf0meRVWWq2
O0aCi1rG9rBXYJG959NPcWwvjGinFfcC2d7oHVf6tDmzV+J9ssfxyLGHZF+M
DNr1fLjE9sOoPt26IJztj7xuffOhwU6yCIWFsr0OV9gBSJ89IE9SsgOhXCb2
i5nUk4NwMbNUfbCWHYwWX40508AOwT7R9xanGnYotngd/W1Rs8NQp6uuMEjY
4RC61Gg2Xeggi2H78o5OkN9OXgP3IdORwRsPyGtxYMjfTa1qI0eg6bpQajG1
kiOx0Deg//IXdhTOZP8MSpTxPGD8UWazMYCsAoa1SadcS/l/NNyMEck91vep
R+OF5xO7a6nN1GMw7O9inLRpoh6DCn1WXtiOu9RjIc8J0qQVkVWxUGRUzzEX
N1CPw+lu3fwh10bqcRjLmnLyGeV5CRps87dHneAuQUZqaE/xMx11KVa9kzSG
5JJVUhjHI1PqX2uox0OrsXJcevUW9Xg8r23P3VlZR12GzR5v+tSV9dRlqLIk
Fgv1vJ8cCTXCfo/z3OVQrC7pDBHdpJ6AWWUTb8W3a6kn4Nf058ANX7XU1834
DwnjGwQ=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQtUjekeBvCtRDURJveMklCYk6lGF9VDJaX7deu6d7X3LpVy6XZczhel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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zQtUjAkfx/GR0Lq8O5REt1Hu2o6K9DbSL+nGii7TVDNlpmaa2ZJCkRKj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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XtIU2EYx/GDwtAFtTnp5sypo0REnDWduunP69y0xAyUyjJDJ4K6KMoQ
wWRJVKwLdIOgmogliMuYhULe5tRZBhWV1draLBOKMpOmrCu9j3904HD48OU9
7/ucE15et73Cj+O4pD/33yddguetehV/tP+fvqTVF3l8eh6ZQ5XgV/FSIDkA
J84oTIUBZAFk79d3+PtszME40HXX+2SRvBaSsZINZidZDKWtPLLjAVmCpdfn
FvrukSMQ5s1/FmUiS1EznazOW/ZG1I286h7dR45CHHSi0khyNOwrZpXHJ0eY
Y3CyvsCkMpJjcX9Q/0FoIMdBLXYmTvLIMjS65puFe63M8fAb23qKJyFvxkAL
Lzj/6TDzFpydUN8+VEKWY1xbfutYzxBzAjTSXic/mnoi4i3Gdu8sdQVSOiKM
C25yEtzKxa/bgsjJiNPU1hiV5BRMHK0+8ugxWQlOVH1lmqP3qxC7pmDdDQU5
FZfsc7LrU4PMaajU6jt3viED40WHh7gW5iag8WGZfMdP6ukwhje/DAll+zWl
o1r02XHhKvUMzIRY9s+upJ6Btqmwt1YP9Uwo+OIXfd0DrGdiOOOT63ItM5eF
PaWBhePz1LPgKNY1XFxN82Wja9XHXZ2nqWfjTsmoh1dG63PgajgY1GvoZz0H
578Z5LttzJwaEU6vTSeg+dSYCnG881XQ+XIxF39NOtPGvldTLr6H9lj9aul/
azCdLq5sT6D5NNgkdZurLLReC7vqh8gooPVaSG5a6loddP48pEYKY8b8zaz/
Zy5/2b8BQwkg7Q==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0nss1WEcx/FfUslGZ4uVJSRMMpdCuZ6Py3E/nFPLOSUScSjFVirT7PSH
NKHUyq2NWC6tjMNSwiGnjqZm84+szPUotyhjrbEu83xt+W2//fba+3n++H2f
Z09sypF4LY7j/P++/7708PorUz111cpVzfON+HN8sR6Zg2jX3tEEfbIOZAsl
ek1r5mGhyGn66Np+A6jq5niJa96J+MpvzbWjb5mNwW3U/mraSjYDL6tu2/RT
sjl2WOYLbBPJFsjwS25IsSRbIXfqmGzx3Rtma7xVWfXvqCPbQJUjjK3PJNsi
3ik6YOoA2Q4yYQ6vx57sgDcV528vc2RHPJnwNcsbUDEfgHm/6srkCPkglNL3
BWclZCfYZ+nbxFmQnTE7ZpTtPd7F7ALpxXsXhIXkQ/BXPOzbLiIfxmX3vtSJ
KrIr0voM3YujyG4IKuo95Skmu0NqOJ1RLSN7QJGbPmqneM3siXTBuc+chuyF
iKjkrpR6Ws+Hvvy2w3db6oDm90yMdKJz1XJg6ePpWR1jZs4bNfeT2qOCO1j3
htbJ69ITkW2s+2Ay4XhI8tJL1n2Qxaux/pnbwrovbH9lVmlnUvdFdGF5bW30
C9b9MKwe79QInrPuh8S0/S1GG5pYFyDuR0faSrmCdQGSh8yV8hvMnD8mzWPi
JjXU/fEsacgntZF6AD5IqosNxhpYD8BAm77uvlJmLhCd4dnK2HHaH4iST4UP
PMlcEMq68+KdFY2sB0FqOtg7PMjMBeOO7ou50d3NrAdjUN5e6Zz0ivUQJG3Z
xK/QZvOQh2DRpKhR1MPmwYUiwu3qZvEC/X8orD0kFelKmo8Q0qxL1zSSVtaF
kPxsurl1RMl6GJZL75YX1ND5hWH+UuiM3IJ6OL6E+d5a0WLnLQ+Hi7pq2cGE
7qsIOt1lXq757P5DBLX748hHJd1s/Tp3rDMn/t8QY/6U8RnHiC7lHzJ0aIQ=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxF0QdMk2kcx/FqLIoTxUW0Yh2AC7WOgjJ+QKG1rA4CiYqJVVxBQbx4iIG+
toJxJBhBTKqNCggVKRRkCSpVEKJoXAErirguSs5FL6eC1dwZ/o++SfPmk+/z
e/ImFWqSVAmDeTye+v/fzzd7XB4VJPsPb20c0KdAzbau0h9jmHnQWB7k9P/y
MDQltpgeD2N2wZHIxIxcZ+bx4O7saxN9ayFPRm3jbYH7K+ap2GFMD0i+yjwd
BXv7dn7NZ54BvWFm3YIU5lnoV6c900qYPRCcpy1JFTJ74WxW96Hdo5nnIijl
zbOEihvk+eg0mN7Bk9kbrYJxzh3Hm8mLUK7Ji8z83ERejJTsZL4wiVmEaHns
CVkF8xIk+aWZHzqYl+KJrClV8Ih5GUzXr/1xysy8HD3H/kyTHmQWY627qar2
5HWyD7pcR3D7NzP74uLGFTv5l5hXoFlV3ta+he1XYoOdX+zbweyH0oQtPekx
zP54f8xFvP0j2wfgtZfjwysdcyAWGpbFpMZfIwOe0MsmWsgcgF6+ZdRpdj4I
Y4dsbTtrtlIPQtxk/RrOuZF6MAqfutxwNV+lHoyHsy63fp7TQD0Edt0ge5l3
PfUQqPvzR53qrKEuwfs4m3DDjjrqEmQJoib9sFykHgrXjvHaPG0t9VB8uuue
Wx5G5oUhIvTK5RoJ3ceFIaez/1uZvZK6FAGlNXrxrmrqUtxaWyFdJ62iLoPp
n8DS7qMW6jJs6zs0PL6kgvoqnJlnrJxiZ30V1j8embm6uYy6HHs8DFMm5NB5
To7pit44Jyc6zwuH0ertpXOj81w4lA3KENG/56hH4Lm47v4mi4F6BHSyt6Ju
PUc9EvXhzomQZFOPxE35bHFVtY56FDwO3Eu5mbibehQ6Y1/6jvw7l3o0HJfc
/F74GKlHo30af3C0o4C6ArlypdZ23DRgKODj1Jrl4JM5BZqLMxp6pCUDtirw
V6Ag4N4d6jwl2uuNE+KTimivhHBNr2Ilu59TwlYt2u+fT7YqUXTksL7LXkh7
FbqnfqlcLTtDexWW9h19a/5KnVOh1vONQ1JE91tV2LjYppk4jb6Hp0ZLhuZg
5gcz7dWwbeK+D11ygfZqlM8pcL9/+zzt1ahMH/rCLa+Y9jGInTSmMNuf7kMM
NHFB8/V+7P/67f8A1BCtUA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11XlUzXkfB/BfyCTl9FCmYnRbx760iUrvNmnVvi+37lZMQh4mlBvSYwst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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzn0s1HEAx/FfrWT4g2oiuiEna7SITon7cA6n83Q71Fpjxa0pu7Sw0sOv
GpeJNhcqNA9hqj/C5fmxFO30gMS0Tg9rtJa7NUVCD/P91vr9tt9+e+39/Xz3
sz+glCUsZxhG+vv986WP+UjFUR+T3s4lGYTayw6Ft8yoGSyqNfK9ptTGcF5l
P6E1ojaHOLu8Qmd4RLwWanevurJJaiukrR+clL+jtsXV5NyIG3pqO6Q2jWjv
jFI74LT3Cl7cMLUjEt/wu2saqJ3Qx/94e7WK2hl4aVEvlFFvhipzf0HOQWoX
tFYmRkl9qLegxfoa/xCfeit05Tpxjf4hsRtUan7G6E9qd/TfK7sb+5x6Gwa+
laZpjvQQe+D4ho76GBdqT7g9KYm2jKXejupudmXQ6ANiAXRNMZ2vF+4Te6F0
QiaasqXeAcWl4enpCOqdGOJFBvenUHvjlA9Pol9HvQvjCjMLV10nsQ8u1H+2
SJxrJ/bFHl5Ct2sRtRCpSl9D7XdqwFT2OFS1sXXJLGBdkOS9YNlCuh8iLA97
pIY3k+6HPBUzFNDbSLo/zosX47RVxKw/HJ2kywYymkgXQbLKuE3/dy9ChVoz
m97WQHoABoXsdet+YjYAT78Y3Qyro12MXN1YsdyK/A8rRnumYLY4jt4fCCYr
TzU3TswG4kzPPkV2lYb0IKRNORjOTdaRHoRmxck2nk0t6cE4IfCUK+KrSA9G
lLJm/kpHJekSXHwlOvs2vZx0CRpLZt7HCMpID0Ft8qYPWY1q0kMw6KS0nP1a
Svpu/LBKyT7mUkg6x4yU0zlmQjk9FEo7/yFJvor0MOjmxrz0Nn6kh8FsQPYi
qShduNTDOT0cGZ9646NL8kmP+N/gmOW4i2MmkrPnmOW4KxImfTN2ldocspdx
9jJoquefrakvInuOu/6d/wWgXopU
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zXtIE1AUx/EtlYYkyhy1Pywyy6RaqJlv529Ot9HTlqiMYQ80l8QStLCh
bYxwpFEkkYMhho/QUqgxYa3NlStLRSKXBa6BhQ2NSkfBAiszvKcLh8uHL4cT
f/q8smodh8NJXZ1/P72Yd921eZEv3Gtayk/3mjOMUWQOFiNluo71ZB5UGwY3
/wyNMsfge5voQvEiWQBhrerDzDxZiHphZeynt+Q4TPpb9aUO8lbc8sXe5tvI
2+DZOfIwy0reDqkjWOdtISeiZOOh4dpGchK0XK75iIa8C5M8Z2lFNXkPpgKd
cfwfz5n34otlSSKaJifjXhh/UFRHTkHFzJmOZTU5FY08TfCkgbwPkhuyhjEX
OQ01fH+4NIK8H/PvtUPj//fT8au63eo7QM5A10C7KzrnGXMmah6kNYvvk7Ng
3W3vmXZ7mLNxLVq3sGwh5yBR05TU8Juci75AwqXR0AhzHkZM4onr42QxbGW6
4hXLU+Z8aD4qc0MmMhDWrCmPz36yZgMw0T17orJ/mHUJdvgj3mQmu1mXQH3W
uSJsc7JegKKEu8GQ8jHrBbhqXLAaq5k5Uhzsu6yWT1GXYm72yustYtovxEvN
4TK/18F6IRBQHa1XPGK9CLwowSnBOTvrq+bqe5tSbKzL4Kpq0c+VMBtk+Gbp
Uh4rpy7Hn+Om2Ve+Idbl+Ky96dl0h93jKPC1s9U00E/3FTBf1PaMhdvdfwG7
WQD4
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tI01EYx/E/tVCX4UgntS1yK0KdW9q0mW79fzrnhdJqUmHLoFIHvdiW
GslsMa03MrxAgQQ1sIlIQSFCobEtl60MgkULu2AUzSGBskAKytaFzuOLDhwO
H77nPHDkp2ym5jUcxxX+2X9PWqJZr10vfBL4pzif9koSbl81h/eNc7bMJHIy
mmJNd9+uWgT1xojdJiVnIDrsKQinkzfhqmx2qX89WYbDwpTN6s8h5iz4Rcre
4mWyAnysNtsZIG9Hicw/OHeNvAN1ug16Ywc5Gy+9PRfGreRcfPKMLnXtJOch
VVL/JSedrIbjWJ+0f+wxcz7W5h5fPOgjF0CskFallJB3QeO3Tq0kkTX4aHKE
ty1PMxdiIf7sBmLkIsxcaVBoWsm74Q24U9W3yFoEigzmXh25GCf3W0W328h7
sFBqT55//Yi5BIf0CpVkmlwKy/XTMyNquq+DuHzsnrybrMeLliN8yB1k3oub
wu9D2i4yj8a0ofN9JpoHKAe4N8oD7L0LmL8TSQzm0X/LkKm5FH3awO67ymAe
cYSaEzSvHN382SJBGfVydDp7wF+k+QaY80/kRALUDcj0JCYz5NQr8LxlX8PW
+inWK3C52KOxtDJzRijb7gtWnNSN+HquPSvspV6JM5OqX3VHfaxXQrslWiOe
YOaqMDqeeOD+Rr3qv14NleCHT/DOz3o1PvjjnYuRh6zXABbnwISU/ddVg3XW
jp/B2mDgNwGn/Yc=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz3tIU2EYx/Gz0SoHuhkL1Nkqk3DdqLxN8/JTN+952x9JStDASEcZEtUq
wy7qH4ZFpHShwKyZSilYLSdlNtM0klTMBqFZYFfQDEtER0bPU3BeOLx8+J73
ec9ZbSrMypMKgoCF58/OSzlceyBS3t3+V5PRgbsnVy6TsQW8LiofM0rYS+Ha
n+s84uoiK2EMTuxaMsdWYaov9In8J9sLJoMk5EIf2xfDRbYqYyN7FRr7tHme
lWw/6N3uOwpy2f5otbfmj5Wx18LR5a0yFbIDkDObNZGpZa9DS0VYROka9gbM
5Hwpmu1+Rt6EMoQbzJXszQiq1h0uMLO34KbUeN7bg70VV3wiB2+XdpIDkTSe
LFOnsoOQqXbNX41iBy/8n0TW/NFBDoFnlkJxTsMORZ1V46HueUrWQd3k6o8u
ZodhT3+vdlzDDseJjW7+p1o6yNtw7eVbtdWPewQUAQql7hv3SJz2TnfvCOUe
hYzki5aZbHY09lV/lysX8/cAJe8PHeyW0vkSoOFTxkDPK54Xg+flg26dPY+p
x0Cjs0mbJshCLKpc6RhIaKMeixX2s6ajtQ+px2HgnU/vC5WdehyOXc92fLW3
UtdDY/5R8sHWTl2Pxvp78+Zyel8wYC5ufeWo+yPqBtjaLleo/t0fj8++y/f+
kjygHg+n55uUsKoG6gkYadPuGpq+Q11kIRGj07emLqlbqCdCKq8/KV/URD0J
+ZY635Hjd6knic4ni+aLLKSIushCqqiLLGwXdZGFNGSoLEE7apqpp2HU4lU8
ZL1BPR07ZXmTZ5xW6v/9GwItSpk=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1lA0w1Gkcx/+nhOtQVx1mXJc4pFyKqFtd310vtV73xWJ3baR0OZHLS1GN
LV3dXDShjS5ziVMI6xIKZbXSCzXVleYqRam7XsRdUqO3u5v9PTuzs/OZz//z
m3me/7OPXew6SZwRx3EZ/33//2WfSTfLkhd/fK7NQMNLiqcJJ9RaMuawq7PG
etxExqbw99b+3jCB8SQ4jWrtxSaMp8Ky5kPz45FOYmsIByqGGy8ztsXhy8lc
XiXjGUgftGpuyWU8E6Xemb36TYwdML1i9janIMaOqE3X1HZYMHbGjk/FmXvs
GLvgfLOw3PPvs8RzsOIPox77+4y/Qp3Ol9+/irEbXmSfvDCmYDwPrtXi/fMG
Oojn44fbV2ea6hi7YzRaXy1sYOwBWefU/LPrGC8AL35azIcCPbEnngk8zk3c
yNgLmgOT3a+5MV4I9Q7O5LGS8SKszq4vsnp/hvhrpBWH5JcdbCfmYZFFfltE
IWNvWF33KBRGMV6MpCaX1/JtOuJvMGscdje9PU28BM8v5po4XzpFDNyVRI04
WbQaWA2oU687NgYSc3y0vErue9fbQp6PRIE+vsWHmBOAv9v/hCaokbwAFzft
n6KxJeZ8cKLtuD4/pp68D/zOcOJTmcScL+5Uxt26cpB5X8TGhTVsH6sj74fi
V/MP+7+qJO+HRtf1SwNel5P3R07oyndrth4i748H7pyRsqeA/FI06l1a0VNC
filCH9ql9T0vJr8Mp2N2rZleTs+rl0HxLtUskNtHXoid7pUODfXMCxHbPpxZ
1crmB6Ba2v9kwbRC8gGInGW5wtc+n3wgRM0vuwXPaZ46EDe+z/gzeyrrgzCu
waY2e+hH8kGoqDgyObdLtsTgg+HWZHc0pDHZwOpgJEZ77vG/kUA+BC4OkpUd
uanUh+DnoOiep1WZND8U0wWl+b3Oq8iHQpm0tlzisZq8CNaxc9IWfbLVwBDB
LPXWy4T3KfS8CBOUx5rM12YZWCdC4hP7v+5l7aVeDGORPOEf9z3Ui1FqV/TI
iZdLvRjRi9UPXowKqBfDS2sqHHKdTb0EwadkvV6h8wzrgQQ2qaWvY/p9aL0S
XDq6weJN5hoD6ySIzotZqKrbQeuX4lhC0l2+9U7qpbhr77wlY2IB9VJEjnLl
N2u2Ui9Fq7PwoWpsG/VhCJtRWX3/ozzqw2Bqe8+7qn0X9WE4Iz3gMOiwkfow
2JVwUwbMU6iXwWtQ5RYwmkbrl+GS250NJiW0P2oZzuVnZEnNimj9Mihepj99
JGTnLxzn75hNNjGn84tweFpd4RkHsPMcDonmscpCXkZ9OCYldnJdb36lPgLe
folx+5IOUx8BbZvm9OdHSqmPQNmNN9p1C+j86yJwb7mz71g/zeMiwevePSXw
M9ZH4hl/luNVY5qvjsSxb9v3tuVVUx+J/Qg/yrOvol4OS5tN+plCLfVy2I7U
dYznH6FeDkfz+LKoepqvkyM24OH6EQ39nzkFan5SW0tda6hXICKrve7QILFa
gRMXRMd9smqpV8DzduHe3nR2PyjxRblK8n6IGEoU5mzpy8v6jXolvnvR+naZ
mO4XnRI53TkeA100j4uCDU95cm4KrQdR0G5u3m70lu4XdRR4c+Wbv0yh/dRF
Yd/osL57/C/Uq+DlFnxNZkceKswNMI3vKqD3q1bBWKWdE+hE71OnQgmGkosc
aH+45Ri/oTa8z6O67V9lH2Cv
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtI01EcxvE/BpmZqBmuF8NrDE0Tm5c5de7R6eacW2kvzLSQqZmYWJQO
ZbKhkWUYZGowvKTmvEFiOF1GOfOWJRUjyxAplxX2otKKcJlWeE6gBw6HD1/O
7xxPZUFytg3DMHF/97+TLqdXrWcEOyeGNvRVaBdk6bA6UDOQDPbZd+ym3oGL
OsuU1JnaCQ80nFxbW+o9KAir7W1aGSfeC9W4LKvQSs1G+bkv7cwwtQc0Verp
WAO1F9g+Su/vrdT7wP1ZN++qpuZg4l0t55aM2gcNj1bv9LhR70fqjwt5Rk9q
f0R8ULXpg6kDEHK3JTOVRR2IN5mnDEty6oNgG4paGgOouVhUyFnDDHUQeMZu
Xv/nUeJgrHGXVQs+Y8QhSDi73Rwjpj0U4Tml+bllI8Q8LNen3bd6UIch37KU
kyx6SMzHuFl1VFgzTBwOhq+dflFCHYGmlLHeBil1JIwns66pWdQCuP8eEJcz
1FHI6NkVFSIzEQvhOj963G79HjHA4x3InuAOblgLRAa5VCvLjKRHg29rE+Eo
7yc9GvqadeHVCgPpMUhrz8jI0BNrYzCr8fpYYaVdBMXjpycqKgdIF+G61LXk
sojOj4VbG7vqij+dH4tiR0XXyhz5DxMH7vnnztxP5L/aOEw5eHVOutAuhr2D
o//MW9rFqA88XW0d6iNdgpFL3r66pW7SJSjVve6r+9ZJejwEkmwO1vSkx2P2
15P+xEZiRoq8Kqmgg99FuhRzSe5+hcoW0hPQnN9UXvPsJukJkKlfHunf1ky6
DMc0t60zdY2ky9AeajEVF+lIT8RieprZV0nvJ6KyJ93Een+DdDmisGyKyqkn
XY5qv0z5qpnOV2y2VoFJmUfqQgp5jzm02dotZg5vNrZYu8WmLWaS/vsPczta
jw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0Hss1WEcx/GfM8ut6WjUKZdhWB2XXM9xCB/X43I4QkSSau6W/mFI7aex
zB9WlvhD7o7LQRetodyOW023ocmsKbUdmhpZO/4oqnmeWue3Pfvttfee5/vs
sTifE5XCYRhG/Hv9+dOPO998yUt3anhX6z5ZC2uFL/SoGWTWxPpO61Bro9jD
ajbzb+diaWVl/LAmtSFMcl0lwo1JYh5kVyI1xB+pTSByjxuYe05tjgleWl1Z
G7UlrPdIwtPzqa0wU1yVys+ktsEBpW1HvSn1Ecif1tfwFRPEfNx4fZlpGqK2
g75ckTE/Se2AvKPVi4Ep1I5IqvtUNVIxTuyEucHSTD1Damd84Vub16rGiF1Q
NNmXzD1HuyuOOX/L0eZRu2E2YfVuvJxagAj7gvAGDrUQnfEcT9FVBbE7NIQO
dyJ06PkidJ/qevN5fZTYA9ELfSdtsqk94W/s9UOUPUJ8HGcbAvO3MoaJvWCZ
WOEpq6TdG32muVrG+tQ+2NYfiFGlPSYGsrVm3EKtn+yaBW7nDtZdK+kl3RcW
mhd0TfZ1k+4LnYvpPVKFnHQ/RE82j9+06yHdD0bK2K335R2k+0P17Gd3skU7
6f6QPdze8dxPzARgIt/gvkZcK+kBMAxYXt0wbiI9EEtsWE0Ur5n0QCi5Qx+c
zBpID0Jof5FQNttIehDaCgX94u4W0sWQzdiXqMrofDG+lzYtDPM7SQ9G4uJp
d1sBnR+MPGHnVNGajPQQvBLsrYoZJGZD8Cg1ay5+k94/FAabbIxwh7wXq2Ym
DOtJo61mHNrDkBBskNCm30W6BIrp6tl3DuQ9WQkaBy+/vNVCzw9HjqPRIfkZ
Oj8cywelOR0ier8IvC3XEyiLaY+A99jX/E3lPdKl6DW93l6ZPES6FC5TD2q3
CoiZyP871MyqeUTNzAm1/Wpm//kX/q1kiw==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0G1IU1Ecx/HryJKFuR7JUlo1RW0M2+ZmLvU3HzZrVFpJmWIhVLgNV7oX
SkOWlVQkYRLZq6ZWykSSBE1ds7nKogaSE+0Ji5RgOWcvTGPQE51/kBcOlw/f
yz3n/DeXmPYf53Ecp/y9/rzpEYy1nErlDw381Wy621F899tKMof+o23J8WHk
MPRO8vO6fzxlFoC3IB/j5slrYLm35FAuj75fj5CKnrKJaepR8Hcv1/8cJQsR
fJsnkzjIW7AnpiQm5DxZhHMq/b6qYnIstr6oOjwlJschKWXe4lSQE+AxfTZ8
DTxhFuPBu3x++lWyBKIVq7w3OsiJkAV9mthm8naMXDAK9hrJUtjCNdVxS8ky
rD12ZVPHp8fMckQPe2b6XOQkXGvNNzfUkxXg1E1+1Ss3sxLRXz4MBtyDzMmQ
9gjHn/lczDvQdsZgHS6gnoJQpTG+/T11Fa4b6r9v8w0w70SkdFwlq3Ewp0Iy
OeqNED9kTkNpa1GXTk9Ox8I6W+fcfTJQ9lJbfrOW2QrIp2YO1t6mroZ+4vnr
2XIn62psCHe5Ei7R/hk42cnX1ix7xHoG5JfrRpwR1DPhn9Z5kj6y+1gzcSA3
9Kw9l+aRhcLE+NDTpWxe1iw0mts5eQHNLxuD5rqW5iPUsxE11NVrGqH5aLDa
a69ueEP/1+CEpa9yo426FopbRZUiIXUtKsR3Cvsn2Xm5HAQDwrTwOTp/DuyR
tY0XW6jv+t/WReZ2L+qLzOn++RfikBdC
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0nlIk3Ecx/GHssOZZWlsgn+oqWlKal5pHh81j5bTHZpSdKDFipBpdkkH
T63StAgL8Qjz3DKV/iln5bUyq0Vms8MoNTJDSisTSSnQCn9fog3GePHe9/v8
9jxzSFXJd83hOE7x5/33k15WvdUZIYKH7bMaCxvJLFxkXELmYHDevbDAhrwQ
Tu+LI5QWZCuYXfSbls0l2yBkT/2K0ukHzCKI6pXtvTNkO1hFZoUmviDbY7vo
eYyuluwIN3cuZ6yK7ITYL/qMJBnZBW/Fy/sv+ZNdIZwSywunO5lXYVxXMtCx
hLoHmipeNac1UV+Nm5mKiitZZC+onrqsvupG9kbd+FqFYPt95jVwQeHAV2uy
D4SHGz1G5pF9YdYzZ7CkoIPZD/sM1rpPW8j+0AzsVQVVkQNwcOvnwR2h5LUY
t+3bfTX/HnMg8r2LavxADsJHpS6lI+Au8zoEqLnANX3tzMFQP3izv5VvYw5B
ZaNvrbGUHIo8zwifIAE5DEMWQiefcjKgNR9oWNnDzAPiMxNt04YW1sNxuUz7
zNGSejiU23iDcDHNR+DE5rKDGdJm1iOgL5qveJV5h/VIuDboRVFK6pFYesXY
MMm3sr4egupbjuph2r8eoac9pZa59PuicGLY7tY7d+pROLv1h26ihOajESi/
/nLoMTMfjRB32yjPn3S+GMScK/8u8dSzHgPjB99WuRvtj0X4CzN1djLNx6Jo
QpJzPJj2b0BT2YXHhmY6/wbU4fxOddJt1sVwvqZNl3Q2sS5Gy1Hbh9G/Glnf
iDGv6huVhTdZ34hReYLw0UnqcchNXjDYWs/MxyG4u9RV06FjXYLNaneb1Dpm
XoJRx8q8Q3qaj0eXpH1p3ijtj4f/sWJl2jVmLgHifAcvh2zanwCllZdF5zLq
Uqhq+0tE92/MGibmTayXQtMbN14xQ9eXQbOp64mqnp0PMgydej9pb8eePy9D
t6BXa57Ovq+Xocdb6qE9TP8POb7VaFKOzLD7CTmW+Rb7Gy2ZeRPrTcwp/jdM
zCtwYOrRFtFrur5J5xJN5k3M//Nv5ryjkw==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzH0sFHAcx/FTixunYVfLQx5uSFKLEN3Jx+EeOFo2jVBbIRshhsVWVGrZ
sNlak3LWuSY7iRzqrg7zEOtpLWJJRS6GedqqP6KH+X3/6bt9991r7+3rcior
JmUTh8MR/t1/l8bqvSo7yHzAsKGlYNX5hTiuNZmD1BrzdFcLMhcWIa+ujvPI
VshIrLlQvpnMx1rFfJP1ZD/zDuSVReU3DZMdoC+Q9XT1k52RF/Nj4JiKLIDG
bzo2NZnsivWulxPSk2R3iKBfXvMke+DNC3mU7R6yJz4qP1+qWO1j9kK8vfLM
aAN5H2oDE00G1eT92J0k8hm7SfZG43V+bW4m2Qc+jzVV4SfIBxDrXvp61oHs
i21L3r+7d5L9kDalqzTakf2RbJJwLtmUfBD5ZRe0M9O9zAHoP26jazGQAyFR
+Ko7q8mHcOVatluegCxEg83PmXvNPcwiZFXwBgqV5CCk8Pd+WNxOPoxfSyVB
pqNdzMEYK8qwmnfuZgZ644emVGnPNlwMVEfnTypXn7Iegrq7/qcT9MzFIRBb
xnF9L1MXI73Kjb/Fi7oYhka72x2lT1gPxa25+mHLvk7WQzEhVH6fBjMnDNHc
ee1RYwfrYUjJnbs44qRhPRwluwzctysPWQ+HU879IK3kEesS3BG9q7E3oy7B
l7O2ZuWZzaxL8Vwwq1S0NrAuRXtwsUKtYObIUGQcqXNRt7Iug6hQY+EhbWNd
jtlFYUD9Ay3rcvAcbYwLYuoRqK4vWP822MJ6BNoCj8g+JbF/nEhIhnScG87t
rEciemU8R1ipY10BvZxXaVjWs674r0dh61eBIy+3w/AHL24sCA==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10G1IU1Ecx/Gbg9GVDHMxGhnUMh1NxnRZ6tz229XZohGWjghfhFEpYU02
KsvAUb6JmBAiWiQkY+tFFGONkWa7M/MuqRBGkiBtUL3omYE9jGiuwvM/cDh8
+B7+B862Y65DJwo4jtP92/9PWsWv/T2mwoS4qozl/aDa0beOzGGs+8L+SzLy
WuQjghT8ITEXo9SnXyNfJm9EODu3JZImb8K1xXB3b5JcCssLVehRiLwV7bqi
1O0xshpO73lnb4Bchu32Hnewj1yOeWtrzYiZrIFRuDo5ypF3YmhzgX394ixz
JZRKKTjfQdbha9XNupyNrEd5y4e3vp9Pmatwalh6M9NJrsadi/L+s3vJBiyc
LozlDORdWOLzme8tM8w1+Dz3qvbuwBPm3VD5PiF2dJp5DxTy4TNXRuPMtYg6
+epkllyHhf6KLo6n+/U4GcikKv3UjdhXkdWqp8gNCKykFYkusgmudn5l4ojI
bIZ7SOt5XkLdgshAh0whkQGlTZ/Nf4mt2gto0w3HFQ5mzop710uW4/nHrFsh
ieeW2sKTrAvQTH/81So+ZF2Aye24PM5PsN4Iu+elzDPF7G2EIXR4x0Ej9Sbc
+pYTDmjYPG8TfqeSZW31NN+GwWfjUfM7et+GokRi9gbof5px3+/SxaPUm6H6
M/JgQ2dE/Auftujq
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxFzm1Ik1EYBuCXxWCpiGGZQrNtaaikpW59bDrvObeZLJMRaiChiauEaEKI
MLZehDKyIkGpiUm2hjgtWhLEWlvmTGaxHxIqxrDZB0IEWqawH6Oi89SBw+Hi
Pvc5j/T0BVOLgOM4+e/956SVMu+0lCZMB/5qtWxds/QsnkTmcJPvdfm2kkVI
9IfSuv45BZ+0cuecgLwdH/rW/AOrr5nTYU6wXsxfJu/CqaHL98fmyRIIhk46
xr1kGRZTIiPHhshZWK5xFao7yHvh64nUNKrJORCfEc2dUJHzEGguNtVJyfvQ
1JNxw7gyxVwAn76q1h4hH8Cd+IPHOxzkQkQV+9OLRshF4Iy3TGEhuRhZM6nT
so0gsxydrqT8axmUK5Daunl+PUj5QZwzf/MkT5EPofWhuv4FTz6MGYUjqBik
/hFYytsi+q9kJfZczdN5q8kqtC+4un70k0swvqVJ2fJzkrkUXPZGwyMbWY27
CntgtJ7+K0POwJNhSx3lwNps89P3/cw8EBK+eW6IvmK5Bn1hz3dzJuUaLE4G
syeaqV8O3plbYkxi7/PlcPuH273v6D8t8szcF17O5uW1uNetPKtZoH4FqsIh
aa6K+hVwRyU2yXXq6zBbEKtuEFKug9BpnWrspfn0sMVES7GdNJ8etWPKweMK
et+At53xDmsPu88bIBZvuyKJT7C8Eu6Pss3dycx8JTzdl9r4xJcsPwp72krm
7c9+lv/3L13LBvs=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzV1I02EUx/G/YSUu5kLTCRqWS2NGrWU23Zw/N+dy7qIUKQtUZkFmMEMl
sy4SIS1EJaRdDEvRCyNoMCmzabO0zSJTYbIGzcrMAptt9GKv9kLPIdgDh8OH
L4dnk8FYcHQVx3EZf+bvpidw91Rlhjvt/+TP2tI4icrVZA7xsZI32l8O5jA8
GuEnXg+QBYienWvtf0WOglfFudtmyEIc442nlE2R4zBX2FidMkxOgDRG2/G8
k7wZT8bLG3pbySL4xqIHQg3kJCQvxvZcKCJvhTytPKRrH1kM0YlRnimOvA1n
Vfx3QvsD5u2QhjiW7/aRJTA9tBYenyDvhNp+7YPgClmKQEJxuvgIeRcOm0pf
t/nHmFPxlqd4GZgn7wY/UHZ++io5DcaJF5akSvIedNZ+jlg3Ocosg6fE81h6
kJwOl7NDPbPxPnMGam3dIxGRZDl+ZhW7omRkBXqVnuofcnImbvtbGsrryUo8
W3YvjArJWYiM6FOcTiUDt860nzSGMZ8DkgfEN0cKqGdj/sDHqfD991jPRrNN
rpMMM3MqLMn05qUF6io4JN+s3kzqalxaXzG42ERdjRVZjVnfTj0H0XOhthte
6jlYnO74qtxB/2vgS/xe93TYzroGQo2zfk3VEOu5GKr5VFL65Q7ruVjrSqyT
VAyyrsUG3bJttqmf9SBze+HoVh7qKrKwHmQuD1an2dAsop4HX0zL+wkJdR0y
8i+LV3jUdUH3+YgPvXjKYjCyHmROH9T/+zeGLyfv
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJw9zmkowwEYBvB/LC1HbY4i5Po7WixzzrlHkUUomTBfiOWDW7SISJlyJFES
OSNJiLL2ZXJMU4t8QFHLB6KcK1uEkP/rraenX8+XN6C8Lr/SjmEY9ie/TSc4
m6tPcTzQ/+lZNl+SZd/qSmbgF1Fb0fa/86GVyHkTbwbOAviKBmyWF7I77JY0
+ioz2ROMKVwd/Ej2gVVXUDi3TfZH6qKDSbtEDkSV+VQ400VmwVbfjUeqyCFg
vXgLY2JyGAa3ZqWHXmQRXuXG5SlvcjhUvb25mw/7nMUQZpd0iQzkSEjL1tjL
brIEHqONkvcjchS0pekifg05Grkqq5POusc5Bi030e4tq+RY5CmSYjv+HYe+
fY31eIQcj9rbaXWHmiyFzpbl3CMmJ2DIbTX0/GyXcyIMTZ85gityEvpHM5uF
SnIy+HuOH6Wh5BTcPzzdmIvJqbjWMCEy0w5nGSZd5IxfDRnYuDCaFC+cO4Ht
9fNWi43+ScNKkG97xZdBPzusnMhoSIPlJKdcUGTUfwODBbV0
           "]], 
          LineBox[{{36.22883678945518, -0.198}, {
           37., -0.18436900427433406`}, {38., -0.16519662366699692`}, {
           39., -0.1580021260673464}, {40., -0.14991515289741428`}, {
           41., -0.1373763895796069}, {42., -0.1373763895796069}}]}, 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zwtUjHkfB/BZpNUJtbmkWCNt1NsSFS2pbyWKJjVTU1Oj5t6El2p1RaYX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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzwlMk2ccx/F6wZQmIspRNwcCUqNCQCsgUvvjspylB4oaTxSNQaCOiPdS
RMUbT6CtFgmDMVQiUCCK2iIq8YCqSDxC6oVzGukQW+/EzfT/uMw3efPmk+/z
f57nHZuWLU8fyOFwUv59v37Z43y3XCkc1mawq0/Ub3a4yP1mDgapfXssQ5l/
gCwu8qXMmdkZtbt5uQIn5lF4M+h4yQZHZg+UCuRJuvdXyD9hlaN7pvIRsxf2
5HhWqUzM3sh5KuEWtjH7gt+0q6S+jtkPs3nHe7oLmccj+JPm1RoV8wRU+oxI
E8iZJ8Gp62RDQQhzAFIme05b48ociN6ty/ed2XuZHATxpoQ/PkuZJ2PczwWu
nM3MU1BdKnnb8SOzAMWnglIPPr9Enoo2Y9mEOy+Zg/H8yagsnYE5BPUOm9YV
8JhDwctObZSOZp6GKz6VZn1hKzkMRboqUzOX9emQiPPGh7swh6NbK/z7YzZb
L4T/4nkOz1ayPgNqy+3X1hBmEVY4hd+fZ71IBkymkm53PlkF+I87cDDDk+0X
ARU/KvR8EesRMPzFa/FpMVCPxLF4/oKA12RVJG408m0Zx85Rj8Lw6d5nth1q
oB6FR/ovwYIpzdSj4XGipWLjrbPUo2G03QoaYNNTj4HBYmt9vKSWegweWw/k
iWJYn4kHuZoOi4HtPxOzDi/ky07XURcjpNPFLaqthroYZaL4XQ8PVVOPxdXl
Aftalh2lHovEOjxZ0qmhHofR6xYdOXm1iHocBte8LbsZpqYejw6v1Aq9NZ96
PIb8+aLZL3Mb9QTEqLou35u7mnoCxBbX4GWa+SJ7T4Snh1e+jaewW5UI45zz
prPmXOpJaFowIzPZIZ16Esbo9rtx1fupS9C/2qfPpYl1CbRubhfar+VQT4Zi
Vr65eYeSejLKu9Iu9NVG0/2k0KgzJNbylfYOKXJdFm9pX7iR1kvh7atXvDPt
tq83SjFcuF0ffVpJ8zL06jW/ldSm0rwMsX6dvYG/R9D/yuAeaF7r57ze3o0y
NGyuGGbeS+bI4a9Nf/Yl81eal+NNVv0vS5XFdL4codyJodX9GXS+HGU9wkk1
2jiaV6Axr76n9cMWe4cCO31rToWV5tD5CmxPy2ofGaGleQWGXNftsaSTOSn/
N76z6jsb//M/mTSlpA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90QtYzPkeBvDJOUhuldh4yDgbEStJ6d6LdFGU7reZZqaZZiilk+RasyuJ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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11HlUzHsfB/CfjizlJhKVrWvpWuKaaKPlLUVK25j2mmaaZiZliXst0b3m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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zwlYzIkfx/Ef1bp3Y0mpmEhrHeWqbKJPd6FjRjUdqt8czZRzXZUO/UTy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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxFzmtI01EYx/F/djWlVs7y0ualZprDcqVpav7c1Tl1w2UoYqVZ0gtboVBS
kDVKMqKpZJlZhiuN5WU6hta6eZkiCSVaKF1sKRFEjN6UFVHhc+jA4fDhyznP
CSk0ZB3w4DhO+nf/O9nivWo+krR86PG83MnfAue8J72YOWQPuyQ6X+ZluFSo
WNq0mJmHLyt13eIfTjIfq2sadfoxZj9seP42tnaYeR1SD73Ub3YyB2N4aE6U
2MAcitmjpybzC5g3wNm57+yeaOYwBD6fKiqKYA6HcaxFuWsT8yYsrOJ8zSHM
YrjGEl/2aZij0CcIyJ1Zx7wFJ3IkatPgIDkaUbf5hz+1MUuQZuqRC4zMWzHb
bhD2nGPehunxuyK+ZYAcgzCfSG/pj35yLBSe7jOt65m3o7ChTLK0pY8cB6HC
oKy+xxwPD9GQrLLyKXkH9l1H5KjjCTkBtghtwkD7I3IizE0dAkkx60m4nLf8
c9Ao6zuhjXlmePHTQU7GVEBNLW/NfTLQKp6o+xzaO+8KQFDQ5l91lPUUjBZ7
dfGKu6mnwOf9eFGFjMxJ8Sur3Zq0xUpdio6yFeY3pi7qMoxEzjyLb2b3ZfBf
xa9XP7RRl2M6vzf8ka2Tuhy5NRVXv1o6qCtgLB1fZfW7TV0BR9P3qHeN7H0l
vHPeOhY42X0lykXHM1TRZE4Fu/OC5zHtLeoquF2/rQ9UzdRT8Vpobc0rqKee
iv38hFyBrY66GtxkddBF5Q3qauwvCZVZShqpp8G8KN+V9OEm9TSsjVjgFp2m
eZwGcZZj2QeXsPkajKgdi2eLWE+HXlW+1//pHerpsJWmTH0QtlDPgN1XM23Y
fI96Bkb63Xl2I/t/JtZb5QGx5ez9TBg3ZvuJ9deoa7F7vMe+43cmdS1CPtbI
zzeZqOtwMjhwYlB+Zd747z8vE0C6
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxd0VtIk2Ecx/F3UrYUaorpLlaks9Fhusw2Z1P3e3fQNljoDArCQMGkDNRB
ZCxlFy4kK0d0ITRiUDfiIV1FHpuHalsnVkydQRd2YoXIsIGQSAd6/l3shZeX
D9+H//PwvNl1Tdb6JI7jiv68f7/0iBbuNpem+H3/FNPKpGczvelkDsH6UPWH
/xbCflm+o11IFiF95kaSc+M5cwYe6GNawTJZDHfD9Nr4V7IE2uOSbe/nybux
i9/Zlhwk52CP26UOT5FzkWW93mHwkGVYKb23KLWR9+KYv6t7NpW8H59OuLav
JJPl+J51flB49RlzPixNy/01PPkgRob6pFs95AIs5X47x+WQD6Fa+VHWEnnK
XIjkeNHwKyv5MCYUioW3+bPMSlRU3f8huTDDrMIWdN9MNZGLsG/p82rv5mlm
NX4Wq8RrtT7mYoQtIVtreIL5CL4ULNwyeSaZNcgoUfQJAuPMJShXhhttPLkU
rjvr3nb/GHMZhuIXF9e1NE+L2EuN0DJJ+wFB97VNPS1svQPotQfO9LROsc7j
V2GVU889YZ1H5+QpY2P/COs6aKTRtFq7l3UdPJHBBqd5lHU9stVzXXmPab4e
NRFdOHSJzmvA7ayB5Q4tdQN4seHRixU6nxEPyw4YK/20vxEydebp4RjNLwea
pbmVYnY/jnKMRfs7X19h67kKbAhUNfOL7H85EswdRZo7wOflBFlPMGdK6Anm
zAndjLk3bdnyaMBXPRpPSRkwY/WdpU50Muj7DT1bEKU=
           "]], 
          
          LineBox[{{55.915264057919025`, -0.198}, {
           56., -0.19736734680648413`}, {57., -0.19702994833295742`}}]}, 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxFy30s1HEAx/EfqXm4uLbWzhIqs0tqcinPPrg77jw1XVKmulOqLTudSJpn
bdZM4jgxEVpWHjqTJIZb7mjUpuWqnetBK6VVEvXHTQ/z/dZ3++67197fz0aZ
PPaYOcMw+HP/vvSw9U2pAda6gWV9Dcqo9Jz2YFMzWGzW8tVW1JaYtJlSF66i
ZkNZbLg1btISr0Vw7q/O71PUHDyaG2sy6qgdsHU4d7LiBrUzVMzjcF479Sac
mmZ1ljRQu6Awr03WrqR2RaR2pWC+mJoLzySW7kwKtRvs4yRrOkKp3dFTWsAR
uFNvh1l67b5Re2oPSAKrsjX/vAMa55qfM3bUnkg7eUkibRkm5uGCdNIp4RD1
Tux9UjSbmE3tBc1qXonjAepdeJ04a3TkUu/GQoW3udnYA2JvJBdV5NeZ0+4D
5XpmLLCKdl94GRtUrjINsR+MD+tbhZlDxP54vnBEOy+hPQAdFj8G8020B+KV
i+s1J8MgcRDsOqQr4n2pgTiDZ612ijgPOGwpEtaW0x6MNB3KO8S0B8NhaUnb
0tBHeggs3stnut/0kh6C3D3S3rZP90gPxYaR6qPfFLSHIt7sODvnZQ/pfNjw
350fsuoinY9S8YTCq6mTdAE0CeuylCo16QJwuMqauJFm0oW4qu4JYVKuky5E
o8CtRulHzIRBkTGrsHIj//PCkJBfMLG5ju7DkSzkiFhZjaSHY3xg25Ut0jrS
RYgN+Fh4P7OadBGSpmOUF+0qSBfDMBrvLNKUky7GHTnX9ottFekRyGrdf9e6
rJL0CPBFcuPND7RHwrK+xL9vUUV6JIL7T/hFz8lIj8LpHIdnvPTkoOUehbMH
fUwx3aplM9FgnupZ/udSyT4ab0239foXl8k+Btquz/1p6jLS//s3sBpELw==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10H9Q03Ucx/GxP5w/KAiybDoiQ0TyFJMBssFe/BgM5359tyM7SYfatHaX
S6tTY9wmMEkwQ5GJMFQUUloEKKSAOSlBUw81D13cUY4Mj+r4cWZyUFS39+d7
973vPe75fX2/3/u+snEb9zafx+Pp/zv/v7Ij+N5JS9Lsnkt+jcpmDCnDowKZ
edh0I0BWJWCeibK4/U7v393kYNQbXmvI5rP+PIZ0S8y7R1mfB9+XXTtiHzEv
QKHlmKjxe+ZwcGei8kRu5oVY1Fn3+d5zzBFwKAre2PEpcyQebm7Pe7qJOQoh
CY870lOZo7Fv+b1FpWrmpbDm7QmTRDMvw4ZprnAykDkG5SOqafX+K+QVaItZ
7/r9RebX8UR098Ez+d+RV0KXfdnxciRzLPjLYvICHnxLFqN1c/fgyChzHIb7
Hdk525jjEdfXkKC83UVOQI9G7D0uZ16FHv50TknvZXIifPdNmSHXPWQJjlp3
KvquMkuxL9EZWlV6iZyEsMd3FJ4J5mT8k7u9yt7YSZahbdW4taPpPBmYOrjW
O7OZbAP+OLdlzwddbdRTMBKp/zFT2kI9BSe3pxkHhWReKq5xAzWVP7CeiiCB
KetJxVnqaYhudfeG7GqmnobW8zc93Ufd1NMR6Joe4rd8QT0dU1OTxUduk3ly
BDQskRpzWZdjhlj4oebiGeoZqBUktkW0nqCegbq5roHquS7qmTAfmCVcd4Vs
y8RGid6jGC+nroC3pPeCstZJXYGXxiySd9JPU8/CqeLGb0pM9D5bFsIL5X8K
hiupr8ZWWOZt+bqC+mrc0McnS1T51JUIezpWN7HSTl0Jqa/YUH7EJvP3NRDd
D9XONxf5bVuDnaKMR/VBrKvg3B2693AzR3sVrMtdnRkfO6irMbumozT+2Qra
q+ET+ZSm8WrqGvxSvi44+FUndQ0Khb8J60zHqWuhC3evcOec8BtatDwUX/9q
sJbu10KtbUqIff+w3x4t3q2/ujgo7iPa6zAWafk16doh2utgf2vX/E7uFO11
EGgSI245a2ivQ7uqX1KU/BntObzZ7p6YLKHng8OC/vr8DccO0J5D33OxL2hs
B2nPYfiv0VnS94ro/+qhsy9u7u4r8xt6GD/52WhfWED/Sw+ZsUx8N8Xqt0eP
kJvyyltLD9HegJwUxwVNk5neb0Cp2fvT2BR9j82AOdW5A0nSAtm/6nKZYQ==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0AlIk3EYx/G3dR+WHYaElWVJSGTlNcvcT81jU9f2emRU2g1dZlSESvnW
sBOyWk0jITMLtVZqUpqGSzMbCV2geXa5ooxmd1LRQc9TbC+8vHz4vg//530n
rdgkrpYJgpDw+/7z5Mux+UzKvCENNX/VoxgdLM/yG8gW4Becc7jzXx+E+PLB
brovt8iO0CP9yMHX7DHwNLdvcOlgO2PmkSeaqi62C06XqMcoW9muqPXo/zmx
iD0ZsxdZL+UcZ0/Bg10Vb1cZ2O6w1Dgklf3r03C/t676XibbA0kpQSObg9jT
8eroMvlCD/YM1KqefVsbxZ4Ji9XJqhvMnoWd6w+Vi8315NmQOz10/GRle8H8
rLiin4zf94Zlb1d+dyF3H3w+YOi7fB3bF1pjynP3yptkPzS25XmunMSW405J
R8KW83Vkf1hG7/qYXMSeA31YdVx3FXsulD2ZJ5zXsANQrqs/Kfqy58HDcWKl
XFVLDsSb231eW7bfICvgU6+vlnmxgd7l/smGO2QJ2GFMFzWl3IPwxbLP5YEr
9yCk5/fXt4/gHoylqQ6KJl0N9WCsz0nURjddpx6CCa1L8g6lkaUQGDaeSi5+
V0F9Pn543c+Qr6miPh8W3fafJZFkIRQOhq8+Ad+uUQ+FzCfXO9DKPQxf04x7
VBN5PgzHXFMDHsXz+eEozBuWddbVRD0c7T2ZjxOzq6lHYIImIX5KJ89HoKBy
3Zv3965SV8LUbLyV7Ub7SkpkrFrsPfRAOXUVHofddFaayZIK48rco28kX6Ye
iYy7A9wWKEqpR8KtVLE7ovsi9SiEzhl+UDugiHoUxuuatjZsKqEebWvJzoLa
rqtxfe2FK1qRz19ga8nOgsbWsLOkgW9nyL6u02V/bdJAflQ19lw7WdBi/8tX
ausQ+j5oId0O/N7Sy/tokfXB+mmznmyysyDaGiJyF9a0tbzgeRHTGjf3q7tK
/8sk4lpr1tArq400HwNpd8G27LdkxMBfPaqhfhZZsrMpBpGNL9paEmhfIRap
3WnmfCPvH2vbpVgk7emY+tTzEs3H2u0fByeZuWJDAc/H2XbJzqb//gW269vB

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zgs41OkeB/B/tpNLJRZtq4tJ4qSyKyqUfEtUo8K438eYQcl2W6dw1LS6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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zwk0lXkfB/CbUURTTdHGFJleMkVaKC2+lX3fcnEtd3dLG+ltpMY12hdK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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1Ik1Ecx/GnoGaxxSqDqWElKyxyunTOOed+bnMrmhJaamEMLB0RuREr
qAhGN9kLmTBjJFEhRWqjlrq2aC7c3FIKBlHrYrnQWopRGgXDGFR0/hf1wOHh
w5dz4LxsarHUtS7lOK749/jzp08Y67WqVkYCfzWvrtG5pCXLyRzqv7epOY6c
AU7T7n+bDjMLEe3ePb72MzkTEe8SW+1rsggHn4a+OaLk9Zhwpm+MTJE34tOl
UN3paXIe3m1VLA5EyGJM2jIalLfIWxB3u4ssPeR8NN80G/l68jZ0dEWv7eGT
t+NIrm62iSNL0HxV61zhH2MuQrCgcEP7K7IUCsHz28ci5B1oCkM85iMXY/Vk
ymRVkkvgMErcNl+IWYaKRhM3W0YuRX/WgGlKTpZDNMpDQ2eQuQyJrvCL3OlR
ZgXulAulZgG5HE9qVJ6eU8+Ylbgyv8+i/xpgroCCl7Ou1zfCrIK+b5XfyvMz
V4KXffnM+DmyGkfjM90xMc0HZGe9Wcc/sPXtQNAiOf/FRetVIQ+HvXPKIdar
IBxsvC/MfMi6BoLr5gcF/Eesa/BSkFBnD1LXYv8yXnrNx2HWtUjN/ZhRyj2s
63Bic4fDX+tlXQfF4qE3C22032q0dMripT/ZedircTeVdCZS9B71uJAz3Oo5
wGzXY2/SUN93kboBhaL3E74EdQPuVbqGThrpPnb+a/t/5nZhIV/3OJYcDfwC
x3wAyA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9jgs41Pkeh6fE0WWl4imXMiq5HDqELoRPhIjKJYwZzMUYdLOoQ7qMylay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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQMC1xcX2HId3w/hfbCvf594YCkbjM/g8Edu9To3
OJ/D4RHzm72J345B+QIOOmHN8xSfwfgiDpFivIfm3oLxJRySl00Lu3sIxpdx
0Ave9DhkMoyv4FCy5r0lszWMr+Sw3yr8+24pGF/FoSD03eXd949C+WoO09ie
6pyZA+NrOKR/4Un55AHjazk8uaVikW4E4+s4FK374SJ+6QiUr+dQ+ZL7TNY0
GN/AQc7gwsJsVxjf0KHA5qRCbjiMb+QQoKt/IFsaxjd2eP7tqZF432Eo38Rh
+7+VNq5Fh6B8UwdNizL+8n0HoXwzB+V3LKe1nWF8cweP1pm+vz7th/ItHOJq
zjL8roTxLR2SZ5q/e8kL41s53I8KSuTlhvGtHdKPXb+t47QXyrdxmMGw3GaT
4x4o39bBjcfa/pcxjG/n0Ox5hinTC6be3uG9Tlf7hUcweQeHZ4WKop37ofwG
BweJkEMrE47vgso7OiSctd1ueArKb3B0OO7ia9GnvA8q7+SQVvaGz4ERJu/k
0NEzz0PScRtU3tlhSXj97hlXN0HlnR1OT3Hu+3ZjNVTexSHu5vaHZlVbofIu
Dt+mnXzjN38DVN7Vwf++5zV93rVQeVeHA6/jzr53PL4fAN3S3Ms=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10G1I01EUBvAVCKsIxkoy2GSzMadN86V8WTOfzelExtLqQ6gfyvKDZa3Z
C6vp9oeibBARg6KGrCkrbLVGJVJpczNXsI1ekMyCVhRYSDVZOBZ9qPCeC5fL
j4dzzz1X2mHa0bmcx+OV/dv/T1qCmaEjNSufBZeUrFWpAxapkMyDUL0hX8sn
8+FOLIy2/o4wC2CwiW3ROfJaqHRKfdM0OQd3WjdmWR6TRVg1O7XzlJssgXk2
mj14nZyHvtW+ZXIXWYbLLcbbPSfJcrjCKb4ll6xAlyaZ7CohFyJz803PwwKy
EvyB+FFzYIq5GOmic5c6+sgleNl5L207SC7FnHSdtjv9lLkM5tMT7b5X5HIY
Qv5HohfkzVAOW9oMVvIWpEY/OeJmcgU8koJfQ2JyJe4nC98FByeZq/Dt1uQx
2SZyNQTjY6LdsTCzChJ79TTfSt6KvVdk5w+0hZjV4Az9rmAxuQaJ797cygB5
G3o/qxe9MXItskaUduuZIDMwsy/dXP7nyZI5YJc/JtzjoFwD54fXP9wCZk6D
L/pDzYr9dJ8W2fHSnLthZk6LeKR3zCSneeuQqcpvmUiw93N1UF8YOHz1BM2j
g9j3Nhn9SrkOCoH7p8NP/1GP9ynPiufzzFw9FpVGrXM75Q0ImPKunW1n/bgG
cJEb80YP9ddDWmSvWHhA9XqMHPd+FPVTfSNUTeHucSfljbi4fo1HkAkF/wJV
fwAg
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgtUzHkfx/FRq8JDF6XEbmNcajsetbFSoQ9NUkq3qek6l6ZmxtLadd2W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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1z3tIk1EYx/HXJXaBzCy0yFtiNUVrc3O6Ld1vc7rlyJaZlQWRlzJvmyKV
pLhicxZZRCz/KUqSiSBaTi3Z2mw2JcFLUVlkVGAgjC5EklZ/VHSeFw4vH76H
c56zuciQV8rjOE70d/370xcyc8eYvmrM819fFbe3rFH2ryZziCiR9hSGkleg
WtsyvjKIHIKyjHy748co83pEJbhlA37yBlSo5efKZskRqI0v0LXYyTGoSlr3
q9BKjoV4jy2310iOQ4xh4fn5QvJW5LgKYvO1ZD4Mn6InptaSE7A7/O1lyayP
ORHWGduN1GnydlRanOZaC1mADn2vzlZPFsJRFc+LOkxORuo7W2RyKVmEtGXN
lrAUshjhr+05c8cfM6fgqP+iV9BOliDqFX9fYxw5FT9Dm/SCQXIaFLeuduu/
kKWob+V9OPGeLMPS2TfBfSfJcjSZc++K5kaYd6JueL56sZKcDl/zpRLhpJc5
Az1Pn5UXc2QFWqeS+K7Pj5iB+U68OLacdRNwb0jvm26groQjQCIsFjCblEic
mGpQmYdZV6FuR9hBb4eHdRX4N/f+XvC6Wc8E8sYXg+4zmzLh3NZ4RGNl+zk1
3KeWRjfVOFlXw9h+QPVRRj0L13mTg/LTdH8WXnZ+D/SP0XuyMRBZemiknObP
RvDG3sC2QJpfgwDrw/3SLjpfg7a+C2d0NTSfFtHfuq8p/S7WtagQd2nnix6w
vgvmoSuOJ+X9nj+k9vxQ
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1z39MzHEcx/FTQ4TKZBkuYklCSKG6e3UXV/Tjro5uWq20ZHEipzEr/Vjz
h5puhUVGZemk0M/zq66ffuRXK2WcylBhKDIpDOv9/m7ffffY8/P+fL6fhTvi
gqJNBAKB77/3/5cfy67CfZ5T79aNa1D8uP7tB58pbAFaOu8NKE3ZZnDJ+F1k
HGohW0I7MtNtuZE9C280RovqF2wbVFg8yY4rYc9DdajG2TORvQA9ad/f5oSx
7TAwJjuuDmYvhn1QUfT++Wx7pIonqA/8aiY7wP1B8dTYVrYjOlTHBi3PsZ2Q
a97vka5lr0B7r5l/9za2M0atwoy2uibyKtj2r+vTe7NXo63i6IWvHY3kNVCp
Juma9GwXNCc4787bz14Lrx5VeEwg2xWRf+6rm+PYbvAYFuVmWLHXQSLWVXWH
NpDXY/In5dYzr+rJG/BRZL1zbjrbHQ4l0XP2HGJ7wERuvH4xiu0JqV3Ot8Mu
bBGOSYTpWUoDWQxBfure8phaMqDvD5a+a7g97mRgyvSo4cmpZIEXklqTyjK2
66l74VTPy8axGTeoS1ADoXa0jbsEykdpbiLvKupSfC0p/1Qgq6EuhSEj0eu1
YwV1b9z54Bo0ybqSujfGfj5Pkpwvp74RroXCQ7PrLlHfCKeFn/PM40qpb8Jr
Y2G4m6KM+iYk1rXFLuu6TF2GbvOWUqNfCXUZytqHomLyi6n7IPjcrSMJmdx9
oA4efJJ0WEfdF2GVVktNI2h9si8iZxlU79/Q/wg248/gyIvvw3Re8mZoGq74
CruvUN8C2YHOiaKb3LdgX/uzEEkV7+8Hi45fS8wc+Hw/ROnbfU4s4vv5Y2Va
Y/6XvXy+P1bEm541yeX9A9Bz2mnGNZur1AMgPD5tyMGR7x8IzfsU9+yTtF9y
IPrEtQeL1deoy1GvOV8w0EHzkOP5Ufs+42xeL0ekbe/pkNC8cRvk2DVNkRWe
eJHmFbBWWiaEeJKhQEVpSlPlw3yaV2BnhHbk7NMCmlcg1ini3Y/4CzQfBFtD
Y2bKqK7uL2jgfKU=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0Q1MzHEcx/G/jFIipWJ60q7WqqXrgR71uUrd1XVPldYs0hOShzzUbLEr
lMhjT1gMGaor0ZOcq/RATVkYRk0YlWl0jAwzrN+Xrdtut9fe/+/399v/Fids
USTrcBwn+fP9+0sfo6flW/3177ZOajxge3SeZ9lsMocqbcO2AAOyHkaqQ2pM
/9kIJw5JrSq+3WGej0vpRt/3fCEvAOfSB+dXZAuYdNulPW8l28DC2Grk2jWy
LTKcny1bvoHMQ2eC1cYXUrI9RFeM3qQryA54WN81Z/5KsiNiHz8QdvHJznhu
u29JoxPZBdFnwovOfu1idoV7VuGFmmwyH94TeXt4aWQ3HFPnWmeWdTK74xRf
mjDoTvYAzzfD7qkb2RPZtvk6MVbkpTjygmdp0NfBvAw5nit9LFrIXmh/Urna
Uk72hrHE8tiq67eZfVBhNzw6uonsC5Xd2ngDEdkPpmqVyQF7sj8Mdwafdtna
xrwcoZ+ysk5OaJgDoC3gfg73kQFhUrGBoxd7Xgl87ho4flBM8wL0Ft7zb29k
+5UCzGj6niYuoPMC4Rgjy62TsPsrAxEp4DsoTdpZD8KXVH/+aCnNByFFVVsb
N0T7gyGI3R/j20A9GHG5wkF1Ce1fgQvm/XGlt+h+K5Ce+iExcy71EBwq096f
uYl6CDI7Kmf6KdSsh+Jq8ZoB10fNrIdizFdQLH/bxLoQ63Z+5FRLGlkXQvN5
3vC5ghusi/DeSVd7tIdZKUKy6UBZti57nguDRlu12XDgOuthePdh4UTLD2Yu
HNvtdZvPO1APRy2/vX5In7oYrw/a/FK21rIuxq5yc59o4xrWIzArNbE76GU1
6xHgFZyyMBy6zLoE08ez+l9dpP0SmAnW52h2N7AuRclg3eG88nrWpaiqFM91
Hacug3WY3miSc92kIUP+WODpfDPaJ8PD0OKfiSo23yaD+tbrplwR3V+OLR6a
wR5D9j4gh9ZLHC+PovPkEI/leI94sN4mR9QO3jSvXjpfAb+9URmLVOz/whQr
p7hNgaLOi1Up326y+cgp8//9G1rZiGA=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90mtIk2EUB/ApRG4qDTUKzcukVtQ0b3lLt7/Ozemm0WqgLBrNJCPBEEkr
wtfLBysjRpMyyJgzpRjODSJr4lp5KZeZRuTog7bErD64RlhEtYre0wMPDz/+
nMM58Aj0derqYA6Hk/vn/n3p8F+bT+bzJp3/5JOMxtdUVkeSOegrj/UkRJBD
MJyhCUgDE6z5GLEvZlpWyFHQIUwdtEDejIlodw/zirwF+5fOpi25yAkw6zi+
RRs5Ebss00FeI3krNAPB/rZ6shDq2uU76kryDuz2ij9o8sg7wetwDim5ZBFC
mko7TN5x1sngDarm9X5yCoRHlg3jbnIqbv1acgTM5DS0X53qS7KQ07GhSdXe
YCNnoO6tPDx2kbwHcQ/emz1WciZm1qLK2mbGWGfhhl32ojuS8mxsbDF0njZR
noMrUf3NojhyLmrPn1mw+R+z3ovosZrmmw5yHj6d6n35+fsj1vmQmObUU8fI
YjwxzN7f5CZL0KMdVAmtZGBi5dJqgYM1A6SY9Ob5BupfAIUyR9r1hvICZE8/
46b8zwuhvHg3bHsFa6YQwtpW/oHnNL8U3Qe5wnVh7L6MFJb46CpBI+1fBJ13
VXYhlPIiDN97eO1rEtXLcKi5qvx4BPWXoaxLG97/g+aXY1RlGzn3jXI5fobe
liR+ofpiMOIWTX465cXgzjrWG4ZcbK5AVo1IUO9izSiwrxiCBBHtV4JOefVq
wMf2Y0qgOzHS1rhG85fC7mqRFHlo/lIkr/XGtHZSrkTqbOTh8gGqV+K68ONl
bSL9TxVCY+KMRuuk891CxtFtUhX8c2V6fsVT52+HmCkJ
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zAtIk2EUxvHPJs4KQUtMrNCJXRhqLnUXa+1xfs7N0EgT7c4SIVK0lESa
1tQsL0WkBaasTaXElpiGwyVpZltSFKiJRqaVlhgUEmqECRWetxcOLz/+nCM6
kZOUsYrjONnf+fez5znadFq55nnviuZU+qK5tfdXM3NQR80oTwqY3WFIUdYM
f3eSPRFuavTLn2b2hkJsaS3/yuyLyLQdgdHDzJtQm6ybq7IyB2C8Je9FyH8H
onfLx8INVcxBWNjfcbwnl3krjgovxPpJmbfjtoAvqfNhFqOibDbX9ZuDHIyl
kDc/l34wh2LgSN6Qh445DBeFnSXNY8/IEnA35DXhs/3knZiSbl7uGWQOh8vo
fOd1LXMECtaPtC9PPSVHQnJW9MEZwCxFv9N1oDuzjyxD2eS9SbfZJ2Q5UlOv
9embH5MV0JiNKYsy1qNQ8JvvWGfpIe+CLV2Y1rrIvBvbtLbP+kxmJWw3fWqt
88x7UP3WvWDwWDdZBa0HPz6daicD9jvijW45XSs2AiMdErtQ9Yh6NPKzGvkz
9WRjNAYui7lyI9tXIz1TyskddN+oxpVKr4SMSrYfA/1heYwtq516DA7mN4jd
DW3UeSz417WM1z+gzuOUuv6XPukh9Vhoaq6a1NWsxwIvsxXFEXSP0yDUVzL2
StlIXYOgsi8VhzIs1OPg8N4XXG5ooh6H93nvZkbONVDXou6188BUl5m6FhPm
obBiFxN1HZJLEy3WT6XUdVgyTFzyCi6kHo+Uu47Eolu8aqXHo7vNahZ5ZVPf
i/MJ/g6RwNT7B70dEgo=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90gs41PkeBvCxHd22U0RlaWu6bKJN2MjdSzeUMON+mzFjZmzbBbFd2Ezk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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzn0sFGAcwPGLQja5XuiGVsrQG+ddd+R33J2X4w5r2dXVxaX14i2RWZfu
tLwlNZU6nVYpGtZq5WIzp87JS94Wl16GbrkysqKWSKr5Pf3Rsz179tn392w/
+7jk6HgjCoXC+nP/vuRQX5an+Js/Uy/ocwC75Do/yZSYAr0Dk7NrFhGbQb9z
jC5urgVNBXqbsOLGNPEqUJ4/Js0YJKZBhn+Nha6F2A6K+t6N3VQQr4MrBQc8
H8iJ10PNhu8Kg4DYAc5pu40dGcSO0NH8yv4Ej9gZmi2Dcm0ziTdBvSYhp1VM
vAUy67OWsH5p0S5gFsHUrKWSTgfVTsnyFCdiN9B1qwTMdjLvDq20nExLJbEH
eLG+iYQ8Yk8wK3tTRAsl9gLX8fQyUWUz2hsKVfvoQw7EPsDQnVxRN6tB+8KU
3hDF+PkUvQ2slnmHmwwSMyB2oKd4nErmmZAS5Ttg7US6H9TFZ80wjz9B+8Nz
pYtFpCvp20Eq8vnitos4ALb2qy/fSSfzAEu57cy2uaYFywCip2ZSjB3QFBZc
7fgg/SEinQVxnqv9aunkfyCYuFPEpbVq7IGQYbjgVH24AXsQnPlqLZnuQcuC
wJtjuM3oU2FnQ8cLG3GZ7SPsbJgf0ckWV9/DzoE9ucIZZd197BwYSTu4m0Wr
xs6FzU20+UnLW9i50FtiSFWLK7EHAz/xtX1JehX2YBgd1epHwpXYQ2B4pbD8
8UYJ9hAQRF96eKjqFPZQ8HjbKvFOLcAeCnZ73ToTzXOxh8HZ7NojbBnpYRDb
ONQm+JSNnQcTNl3vteVoGQ+GB+VG0ng59nBICHSNmGg4ij0c9jfq85I+JmKP
AAqncPbuJA17BMSMKbidO05j50NacX5T10XcV8YHqwn5Nb1HMnYBaEzzFKUV
+QEL/T9TIv/5N9qMS2s=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90Qk41PkfB/BRVhdLZSvFX4fd8Jc2ZeSoeZOkcsQwbmbMYUIisWmTqXZ0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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90gk41PkfB/BRWUkXpawOxBLdZVuJvKUQyX1fM2bMTLY2le5jpiW6/Duo
1WWJQqgh5YyJVI5C5a+ValSKUqJjt2z6+z8+3+Z55pnn9by/7+97fvOMXsga
t9BBHA6nqv/9/0/2Gt2UEm457GbZgN5ZqQSoPqpRZubgw7f4awfVmIfiZoty
uFiTeTTiZxiufP09H4vo1wU7higxayH+o2O25qsb5ImQKEw+9DUx62L2RJ3N
P5xinoK0B+GSmOXMBhjjKcsvMWM2xPvifR7ifyrJU2HQPcfVponZBM1TV2/x
+e7pGLpTluhTyzwTXJ3GP5wkzLPRFvSfek0V5jmYejJ86pmk6+S5qL59yefr
ReZ5OLpHfdEdD2ZT8OUnn33WYP4ZlVLnBb16zPPRo+eX8Op0BfkXjDTM6Ztb
w2yGOGeDIBVNdn4BlIwbiqevZjaHosf4h04Vdn4hsrzSuae3lZMt4O17rGK0
/TWyJfY+54/5KpGTF+Hupx35wvHMVvC7dFqjZ14xGRBsWLddUlI0YCmgvD33
tuBaAeXWmBXVJfn2MJ9ya0jUbFcXzZdRvhhOeYWfuaVnKF8Mh2aHk9rbkyi3
AW8Yp2H80xTKbSCyelt2J3MH5UtwdXikEk8rmfIlSOubu27GEdZfio/ea7cZ
FKdTvhS25Zbtj3lnKbeFbENR26YNdF5qC3X7at9PPdmU28H9zIWnl/7NpNwO
Q9ZsyBOvSqXcHqMF+jrxOlmU28N7v+jPLRHs/mUYOiKucndgJOXLcGnCv+qX
o1wod0CbdebmuPdbKXdAUkRgW3PvKauB3BEbbX7WqnC5MGCpIxrP7OUcv5BH
+XJcbt36qGZsLuXL0Ss+LB9vwXInRCbtqI1dz3InaMY5f4m0vUz5Cgz9yUnX
Zo+M8hUY8XjKu84Z+ZQ7I3lJRuPz2BzKnTFrh/n0yCjWd0FdvfJnzem0BxfM
/xBXYNR7ic67oFAla4a6PvXlLqi2PpB/fi/tcVxRYF+Zp3yecrjC9UT34OHf
n8cVq25lOK5Rp/vkrkix8NSu6KSc44YKWZ7+p3DK4YbKjUvMbyWyfTesMr16
ZH4nfT+5G7abPSjOUWW/jzve13nmW3fT88AdvVfG2Bmeo+eXusOh5XcPt18L
qe+O7Ax95B4uor4HCqo+2preJ8MD7R3C0mCbEup74NtPr7lv5pHlHlj4sir9
8CEyxxPn1vv6bB1VSn1PrK9/5mv+opj6nmh507cmpfAq9T0xwqJJJdqjjPpe
cBE4/5GSI6e+F2Szj52QFJOlXpj8oSG527yc+l6weRq4UaWHzPFG9r2+rLje
Cup743pHxvCtvtep740F+dPMJ9uQ5d4YdWOR2fw9ZI4PwpRDWo1UK6nvg+WZ
5243d5ClPpgUn3hEby1Z7oN/Ug/ZrX1H5viieVzzluEr6T744q8EtYoANdb3
hUD9rc76Sazfb3PV9ph2tu8HvY6wW7WBrO+HHD3ViFwL1vdDrKNhL7+T9f0Q
9exaoGoD2/dHneeeqNQVN6jvD2HNicuNq8hSf6QeTP2mZUeW+0OsF3rU+wmZ
E4B0+y0SWdhN6gegcVy3jsl+sjQAvW+09+/ik+UBmHgldpKBjMwJxIjFGxe2
ZN2ifiCMVEv3PesiSwPxPGzN1zdnyfJAnF0Zs7bxMpkThATl7DavD6wf1P//
MI3f/ZH1g9CbMETa4FlF/SCoHot27NpE5gTDpNXsduuEauoHY0HZyPv768nS
YLhJMn0D1tdQPxibV6REbtEjc7hY9rb2wLsUsi4Xx6Of6D2sJoOLK7dM1+mL
bg+Yy4VFRpOGSfEdup+L2sTYf5Uc6wacxIVOTo2xm3E97XFhVX3vjquMcgUX
9Q9HBCR6Uc7h4cuuio8vpGRdHixvTjOuaCODh18gHLT6HpnLw/L8slS1arKU
h0L/QY6FMnISD+l5o4qM3rN9Ht6u7so9WkBW8FCeWT45OJfth2ARLh5KvcH2
QzAttT2sfkED7YfAxOrrzYsGZG4IFAYl3cYzydIQ2Od9GsovJyeFwJk3c7i/
9V3aD0HXRrcyNRlZEQK9TGfr3nIyhw8/C6XSjL/Junx82bT969Yx92ifj8V3
37ys0iZz+ahW05i6Koos7c+/2CXEPiMn8WEgf3Hy6SGynI91B/e+bnpJVvDR
GpKcbjb5Pu0LoD8vJsImmKwrQGHyzJEOPDIE0DXSTpx3jswVYJBHmvbx42Sp
ANl1RUmTXpOTBCjYvfC3pSKyXIATueVHlTXJCgHSYkw/b2ti+6Go5PftmvNj
I+2HonSDU4elBhmheHTyr1NF68jcUDiV+H6bq/Rf2g/Fp4dL/Wa3Up4Uit9F
QWW5bpTLQ+G9K1p/fABZEQqFxo9TMtLIHCE6XVt2Wlwh6wrhFG4RoXaADCHa
u+PPdOSTuUIkt4iczr9k+0Jo6TqoVzk00b4Q3NCS6EY/slyITU7jIuZakhVC
nOOUBusMIXNEcFSeldXWyfZF4Lv2ZPwJyiFCXa38yD4tMrc/VzXaq8NyqQjj
B/12+HA42+8//3inJE/C9kXgPcyZM0zB9kWoVX40YWcX2xdj8LS3MamDH9C+
GM99DNu6sti+GMa6lnf2y9m+GKlhS9K0hGxfjOuvUiz/bmD7Ytzdc3fpWBnb
FyPB70likQ/bF8OJw3tn/yvbX4kDycJmLfcmq/8BQS745w==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0GtI01EYx/E/85KawSRJRRNLsxi2tHKumvrzMqdOZ0hvkoZkTGwgakS1
cPZXU1Gx7EXUiNSwNKEi7bq01HlFjFTMtBHhELPILlY0xsoKz2PogcPhw5fn
cDibsvLSNQKO4/B3/ztpCV815ke6DXQu6Uv0Aat0JkhI5uA7U+fxYrm7QHZS
W3fb1s8shLlrPmfoN9kTyofjPu4LZG94jIptno407wePQO8WL2dyALJ6jzpY
luc3o+tC1rzGQg6Co99bU3AHORjf001N+gzyNvS8MRuTJGQRxrOb1R0f+5hD
cDimiW8dJotR+9Mgmlggh6JGsjVqrpwcBu3IsdFDYeSdKL6x/m6TtZd5F6aC
53LTrpF3o9JfUcEZyeGo7w0c/VZMlkAh8JqWKskRUFa0nlc7k6UoOFMvTDX3
MO+B1qmkJfs6eS9O2IaTO4bI+2CpPK3mf5mYZZCL22IvhVCPhH7D2IB/Zzdz
FEaCjZHT9i7maGzc756pT3nGDMi8vV6r7nUumQem3EsLtUHUYxDoGjY7eaSd
9RgclORf7i5k5mKxvcBe8qOvg/VYPBLMfDU10HwcrrwvUrdtoR6HvHXhOomL
kfV4iBdVN62nqMej7KJSd6uamZPjbE1EacMsdTnaR+8bPmRQT8Dcc52uzIl6
AiSqOjfpGHUFBvvMY+n57D28Ag3vGl9Oyuk/ErFDUz9RHkY9ESKbRpZ7/Cnr
SUi8U9lsDqCeBPviuatPfNh/ccl4zIt8rYvUk1EkWFswaKD7lTDkTOhDHZh5
JXQWaVWzlnoKqj9/cs30oZ4CZf+D2ioyl7rSfCqiW2rsa5a7aqX5VebSVvX/
/gPGrUjz
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zwk01Xkfx/H/KJGyNJVJGUlIKm2WJHyyp+3ad+7lum7T84hEMyr+mpom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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10gtUzHkfBvAppRW9b4jNSibpKt2T1VZPhCirqy7TZS5NMynlJRXyNspt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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQMC1xcX2HId3w/hfbD/UPLykT0HjM/gYNh3/HX9
32NQPofD7whV+3i4egEHf+Mzts+5YXwRB3m9neyiP2DqJRx0bDRd7ryG8WUc
5J2WPe46CeMrOFRklrQuWgPjKzk8MZfYoTcBxldxOCsoE3Y0FsZXc/jj/EM8
UB7G13BwrP4VUCII42s5sGgomt1ZdRTK13FY/Yoj+1UzjK/nUHleVfVQAoxv
4NDfnieY5QrjGzq01J8VXskC4xs57Du1WmHNsSNQvrHD2lcKravmwPgmDnp/
d9ZpHIfxTR3WbO0Mn9wC45s5KLF5/ftgAuObO3xYuScs8e5hKN/C4fqDonOT
JsH4lg7RHTNyWWNhfCuHqfft8+dmwPjWDk1nl95w6DsE5ds4+K2WfG2uBuPb
OmwtNXL30jwA5ds5HInpObHuGoxv79Drk5q57vl+KN/BYcb+N2alfVD5BgeH
pfksCq80YfKODh0RcruVz+6Fyjs6uOpWcBcpw/zj5PBNolfmjdcJqLyTg/bW
0kTlgzD3Ojsw1wZkF+3eB5V3dtCav3nKpStLoPIuDp8Z1t2e5bMWKu/iwPj9
3f277t1QeVeHvw/r93CyTYTKuzoIcF7deyl4yn4ApsHbQg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQlUjvkeB/DHWOoKyXKZbsubqBSiMkmp71uKSPu+vL1v79ptsbQY25mX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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1kws01ekah//IJWGMhLZmSCLRfUJ7yE+5hmK73/fV3qKrLqSmHUVWg9K9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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJw10H1IU1EYx/HLLJCZNEwywsxFhCwzt5W96NpP3VvZZipa6dAY6MJh85+B
CclysP0Rq0wzGJSKygjs/Y1Va3PqLCgK5yzBzIwsmaWURA56xfNcuFw+fM85
POcKDebiah7HceJ/7/8vPYLX3fUy/rBvWQvyhbiWsrlVZA7t8+bb8SvJsTj2
03K5j0cWYPHchY6pxSBzInjh0eCpefI69Hw6WPtujJyMH6Z70/YpcioOpF6S
SLzkTRhohdLdSd6M2iTJyUE7eQu+H5Lcb20kp4GXfrimSkMWoeJti8IzNsSc
jkBcTnNzIzkDqiB//a0V5EyIfU7NtruDzGK41x53ns0mS1ANe8EJzwCzFO8j
Vd7fZ8g7MJ7V8XJaT94J05J7osERYM5CgUtfWvSrn3kXdE0l3dqN1HejKUO2
VVtH3oPe8hejw3W0fi9uvmmTJ4XI2TCFK0V6PjkHCc0fHjfYyDLIR4o7uaif
eR8KiyZmFe3U5RgPXqnotVAHUhxDoRmdd9lW4PzqV1qX7AnruRBq49sqNzxi
PRdWfeGfmfKHrOchpsBp4/s9rOfBeNScWb/mAev5CMn8su1G2p+PtM9RQ3yE
recUiBh7LvZL2XlWBVy68KSjlM3DKeF2xsxKk2k+JQJXn9sS+2h+FQIJpwe6
9rP7WVWw3Pha4l6i/6lGV40wKrrObFXj2pcyzZ3Jp76UudiPKr8a30a0BsGR
Z76/Cqz81Q==
           "]], 
          
          LineBox[{{48.03694892943989, -0.198}, {
           49., -0.10229650786558026`}, {50., -0.10229650786558026`}}]}, 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90wk41PkfB/DRNf7SpmLrv6V0bIdjdSm3t0KOZMy4xzHDzBjsRuc/Vw1d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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10gs0lAkfx/EpK6K2WmkTG1u66YYUk5ifkBC5k0tzY2Zqd6X0qiiNKJdq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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n9Q03Ucx/Gvyw4KKIOOw9SgFWQc22m4+LEcrwmMbWyyn2de4gnm0vLc
vPD0BDzsxtidngnlYLgEBSNiwa7SfoBuOBcCOtTDDNKT1EikA1bedYbd0uP9
8Y++d7vd4557fb+7+3xfKjXrNvE4jjM+/Dz6ZteCqy2WlU/3eec0kyMMWJuS
opk5RJV2pYYe90i079/+svoJ5gX4yFG2YeyPH8nPY+hF+/3jQ8wJ6HfbSrQ+
5sVoCu96V3qCOQmGLUvqpq3MfNhdxsYtSuZXIO3NnZSImVOgdDXIpkuYl0J+
NOgOaZhTUdrytw6JzGlIFD5rNAcCZCHaFX3LDvuYl4HvH7cNm5mXo2fQq0pf
w/w60r7rTDklYk5H78/rzMUpzCvwT/rx/rcunCWLEG2ZDDj7mN+AKO/red8+
7hlY0rgi5p6JORPF7oWiAp6fnAVRq/byeHMvORvhjmeCTjGzGIJU5ZjyNPOb
GPZeHXEOMq/ERMTsVIOaWYL6fMuZug+95BxU9FQLLDWsA/G3lxqK3yZXAetP
75op/4B1KULS8PXdoz3UpVDLknUxMT7qq2Bd1BH1Wvr31FehMjHYLOn2UM9F
dv/7M5muVuq56NbfWF4g+ZJ6HtoaPdbI659Sz0OwZEfSO/ePUs9HrLXyYHX5
Mer54P0r/HNrylfUZRBPH0nI9pGrZNg53BTM8J6kXgCuzHZi4y3WC/C54JBp
vYo9Xw6Z/UGl6ZabuhzyswNOfzeZUyCh5xt+wNxBXYGd/gOeLIGTuhJjr+7Z
V9tRT12Jlpws9+bWauqFiJDWii1/1VEvhC1t/OTsAbZXYW/m3qrkuAbqKjgq
K+6d4Q5SV+OIJXYivvAT6mpc8/9QlBjH+mrM1GyvGHGx+6+G5HySafA2mSvC
3dG7s4j8mHoRIrQ3Gk2fsb0GNZtVvw+dq5kzNOA25d+sv1JBv9fgctyGK7bm
3XP2aWBUCPa8F95Hey2mM9buWKwiQ4syXshR95SD9lqU8y/5fxs6THstFA7d
/JstLtrrELn1zkX5fvp/0GHkmFtYW8LOWwfRL/PFydvaaK9D8jbXT+bRdtrr
0dz7wOSZoPOEHlMLf+00ZnTSXo/y52IXRV/7gvZ6xBbHTV44xM7XgIGpJ+PX
hul8YYDqTv/AGjt7Hwzg2S+deyGqi/b/M2cEv6vNZwt5vP8BTlm0HQ==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz19Ik1EYx/GXlbKk6I0MB0tassZcZmrONLf5m9vcpigxMwlGmmIoailR
K8S28CInlEYXxTATUoxurKDVZuXKamoYFMkUTFYGgg6TtOnqoj94ni48cDh8
+MI5z9ldcdpSJeA4Tvl3/ztp8YE7DeoY/+CaFnMUyROG4GYyhyT3r7eeWLIQ
FcsNqQEhmUezy7lcsIUci/nGby2rG8ki1JYP9N2efsO8E8cfroqHn5AlaKm7
KjKNkBOQ0BRZSHxMliJ4YcYeuUyWwb1dOGZpJ8thqu7pOlxGViC+NLFIZSIn
wW15F92xlZyMprJFxYnQa+YUfKpSltgGyKnovf+d/6Ajp+Gs5csuu4x8AEMf
7cMTTnI6XFK/1RpFVmLKHW12yV8xZ0CyIeO930A+iKzqfI/rJDkTtijZ0flO
chYEvMS7n6f7DmFy/GdvTZh6NoK3zgQ+82QVbI3ipQnxELMa3tA56cjQS2YN
+h+kCPa1+Zhz8GObJrAn9zkzUG+aM11zPluzAzBo1Uvd15+yroXxXvhSYQ11
Lbrkcfz4CjOXixf9meFTXna/IxcdsoLz7hl6Twf9Svdscwl1HVyaHuHc70HW
9TjS6fPFuqnrwbWNVabH0HwGxBW31+6IZ3YYkOY7dmN2kt7Pw92iqYXWsIf1
PBQWX9w0on3EuhF11q83s1u9rBsRqa8MqaYHWDfhSumoIVTK/utYZ868rpvh
Kx/dK5qn+fP/+w+27w48
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQMC1xcX2HId3w/hfbCv+MeyoYEPxmdwMJn44AUr
G4zP4bBBqlH+MguML+CgyloouPfbMShfxCFd9fC50AcwvoTDA13z8zeuw/gy
Di8yL15Oh8srOPSqvFvp/wrGV3LQf3qpVfcCjK/iwHKMszS6HsZXc1gSIqcZ
mQDjazh8KtbI01GF8bUcYptmnXhZDePrOBw43lX4yQDG13PguzTLx+71USjf
wMHlleQ+xW0wvqHDORP7wuz/ML6Rg3z578Lw6zC+sYPQgz8zl2+F8U0czLtX
sm7NhPFNHWYeX6vyTBjGN3M47OnU/OTbYSjf3KEz8GZ9pdURKN/CwbkkI72F
Fabe0qFqU9+VKU0wvpXDHlv2yp+/YPqtHc48EvoR6Arj2zjsOT7ZuaXmEJRv
6zBZ6H7UwWSYvJ0DT/b6XeFMML69w6vL/Wuulx+E8h0csuNb9y8NgPIbHByc
es2usDLDzHN04Eq6Z9qYdgAq7+hg4vP0zvxqKJ/ByeGE+fc3L7/vh8o7Oczf
Y/8kIxom7+xw75qZk2UbTL+zQ9jXJ4VtZ2HyLg4PjDY51jTvhsq7OPybvIt7
5x8on8HVofjST++gjF1QeVcHwXt/z7x1274fANGq5Ho=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zm1Ik1EYxvFZ0cqmThi1hUpFyLaGmHtJV3PXdG66D0VSWSZNCpWoVURg
ozWsJRYWEX1ZMBjlrAkOekxorNpjmfODYtGkCdNIMsQES1RcFvRC5+7A4fDj
f5/D2Xr8bHXDKoFAoP6z/560xImOc4b0Qf6fvhnD6XfdXzLIAvS217fossjr
4P2Y7agRksUYnT4pn1yJMUsQed/s86TIUsjquGTHPDkHWSv78/hZ8hb0nEkr
fdRP3oZW8YnsTSHydjzMvRIUXSTnY4epM++XjSxHaNCdIVaQleBEBzRKPVkF
TnBkKZhDLoDbFUm4lgaYC3HIYWwqMFDfiZ46qejaEPUi3Bm56fvxmKzGMaf/
QyBA1sD+6fJ00EvWIrAwpUobeM2sQ6ttLP/eW/Iu2LqXDUeF5GJ0m7V+fnU/
cwnWHpYszzWS9Qi2XVV04SXzbtwveVffu6GPeQ9ufBYm47nUDXAt7jVZi18x
l2JjKrp+ZoJsxIXxNF/mKZoH5DLz+TVfmVsA/aVY0PqG5k2QBYYPap9QN6FD
dWsm2U73y9Bozku0SamXQTIfmwwp6H45ajWO0bkq9t+WctzOHOHHVdTNSPUt
vmiYoG7Gz9yiqllrlPUKLMQL1b5Oer8CEs8+rtrIs25BK1dxvan5OesWDDk9
3prhZ6xbIQ/Ypyz2MOtWnA471cla+n8llP7NugcjEdYrEeX47/Gxp6xX/fdv
ujoEQA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0n9M1GUcB/Dv3AKDLBg4Sp0TAkEQOLgTQQ7uLceB/Di8X6KlpKAgqBXF
rjPW8tuYpIkCuk7TDUVkKhPFiCsFux+cumQTPAW8f1BgTSMX5EnRhMjW51Pr
u3333Wvv7/M8n+fzPMFF7+uK5wiCkP/i/fvLj99gU3mKz03rP5pQxJkL3k2e
xxYQ03/4pPvffC4SjvzeKj6/QfZDyvCvs6um2IEw51t/mHnMfh2umvgFFjd7
EYTbxRuEO+wlmIn6M6u6nR2C8N4t1RX72aFYcLdItjCHvRQ7z5aHrw9iR6By
Lz72PX2dHInN9xJltXL2ctwaa0tOHHOSY9Ch6JG9UsiWILbjpc7TM93kOBhj
X7W/eYodD9Xud37ueu4gSzEgGZCPR7NlULT0xviM2ckrUHNOetdPynkCCvMj
wsd8OV8JxweTasvbVnIicrvFbeKG78lJOGD0Mv9Yy16F+s/tg1P32Mm4EKJ0
fbaEx8tR6TjxZaqVnYJi737nfAk7FVVXGzoK9NfICqi3ljzr8rABZclH201W
sghEHzftMh7n8avx9GifI2CU89Vwbs6Y3uTVRXkart8PfBKx8jvK0+DTt67d
bL9CuRIjv+xrTpOQRSWCzoRVVas4T8eQSz5xxMJ5Ot76dHldgJlzFaZulRxM
K/+WchVMu3KXHpOThQz0ufIeHZqxUJ6B0staQ1EZ1SNkolZ7baN/UgflmWis
a22oH/mG8jVQNrzhkGR2Ur4GqoJS/ewOspAF31O+kk1PuL4s7By9/2Glm9fP
xpke5/mA+quUZ+Pr31ZE5tzh8TlILtpTdqiO+5eDP+q1ex/0c39zIR3szXys
sVGeC6PW378pmCyo8cBuzPiqie6PqMbNFp0ssoH7n4ekc6Z9ATaymIftdUKZ
5yKvvxZnO9sWvzfE9a99sT9T06Morl+D6Tkvq2+kUg4N4oYavRe7uR8axBqO
jljSaX82DSpbSwc8Lu6vFudNYdHP7DQftFBWHW7b2sjnpYVfdtQXD6/Q/zYt
glyTntlLPF6H1z45FlZ1meaHDiHTy+IXOrleHZRz98fvaSTbdAjd0qKev5v3
r0fCU7Ei0E39hR4Hh9UpxlE+Dz02KiKaJ/m+2fQonUC7MpT7Y0Cw9/ogmYfq
gQHNhdLxCt6PaED3onGvn4bpftkMaC9Q367pofskrPu/8Z//AuDRvpc=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0A1M1HUcx/FTpxKGkoJg1gLEIpYEgSDKw4dnuOvw4DjukEBgolJdUM4S
PeVUBMEQEzlwPIMhhHI8CMLi4XgwxAFCdlwIw3ABAu6W5AOiVja+v7a87b/b
a+//5//7728aFRsYvZjD4UhfXv/+s5++piTOWberdUF/uF4wbhweWMXMgf3I
vlruamYdtKxqmK9byayPRueJcw4cZgPc0iu79PrsT2Rj/Onc35IxxvwWbssO
Zp7sYDbBVyfdm8KUzGaw7taZi1Iwm6Nqzixh3QHmd9EkqvSYsmS2QJntnuj2
8WtkSwxtSHOYTGf+AC2Tcdc1rsxWGHynZzp+rJNsDT2Dpme9Hcw2eDpl/d77
Z5g/QvLA52ESIbMtXIc9zjsFdpDtsNkuR/VZGPNmSBZFvHl6vJ1sj5t5T3O7
+cwO6PAZMp9exLwFTxx4pevC28iOeGRomJC/jHkrDJYabMyMVpG3oXV10bSJ
upXshMel6X4zImZn8JNjJp5FtpBdEDnIkRRtbCa74tCKb/tn65kBsyqJyG45
WQ54CS6WmNuz7obEQwp++FADdTfw5mU6B63qqbtjzcwabpPyCnV3jDnG2zz4
u5q6B7QyzUHdQiV1D0gtU/MjEi5S98R0bITrcM0F6p7Q/yVMFWeYR90Lawd0
O7+0yaHuhVnz+eWnCvKpe0N3NNq8fDyXujdcHH7cvKmimLoPGu1f+Hr6fU/d
B82Xzu/MX1pB3RePl3dWHc4gy32hEOtLQ1ey9/NDnXZuMEfN9n6wi/ecGfU/
Q52LA7W5a0p7Mqhzkf2wd3e7cYTrQuchRq6oTRR9vWA5D3Ft3GfTD89S/xhb
k9OOZdclU3/pVXOPRlL2Uuej0yd9306zU9T5uPPzN0UZRql0vj8a7k5+d5Wn
oPP9scKIr9Qc2U99O4yuJzory4/SfjvycnYtcRqLoecL8FpN/+zEjV0L90OA
iGPea/0X0/eTCyC1kJQdVdL3VQkwt1K2TXa1hJ4fAHVWbLaZ2wHaB2DZsQaH
c9LjdF4AymOM2+brsxasCkDXUyuby52ZdH4gxG/MCdUZJQtGIE5kfXK2zvEC
7QOx5YdG84g7ZFUgUsqOazcI6H6OECPrrX1Cf6cOIfbKPf+q1MuhvRCfGuk5
Jmw7QnshbLI/lC65F0z7IPT1LfXsUSfT+wch9Tf+C8NwGe2DYJv0xf3MK0m0
DwKnXvNrj0Eh7UXYk+mSPllRSueLkH2/T7N79iLtRVDf56YlRpJVIhRob0dZ
5JbRPhjtErc4Px0ygnHjuUa//Fo57YNRqe40uL2BuioYi+89jt9fSudxxNCa
bjWrsiimvRhPDvNSZxXs+4mRuCzpwXP3y7QXozBKL3ekp4L2ErQOOle3pihp
L8EDuajxVlc17SW42dYtThmnrpJgu/ei0+uba2gfAvmW5ole0zrah6BYq28y
FVpP+xBsejv8uMndWtqHoDmkFqOmVbTf8X9jBzLCuobE6gLav2LVK+aE/ud/
AI3NJho=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQMC1xcX2HId3w/hfbDXWxG/00wAxmdwmBXIq9ci
DuNzOLyx1EoU5YfxBRyMI1JSAthgfBEHl2+LLqR9OQblSzh89bxheug3jC/j
oHKKb/r2tzC+gsOOiScjKm7B+EoOwrYubdIbYXwVh85fVwt3F8P4ag4pYZPY
c+xgfA2Hx1xiJp4+ML6Www5F6XJ9XRhfx0Fabp9Vw62jUL6ew7fdTgUtPTC+
gYNbuJiE+DwY39BBq2XW6QldML6Rw/lnruaNT2B8Y4db7pyh9/1gfBOHYw+8
Ts25dgTKN3VIL/u/UtUCxjdzcH+3mSd5z2Eo39whuPFtuclEGN/Cgb3ZvFvs
8yEo39Lh2OlVin8KYfJWDnslI4p6P8DkrR1Mpu7b6v8AxrdxUOm8HcZ85iCU
b+vwXSk4knnxASjfzuGI89vzKzNgfHuHPX+3/V57GMZ3cGhePsf3fRWU3+Dg
oMrc/u6tG0ze0cFfPZlB0R0m7+hguCpKcbk0TN7J4ZLM49Nnf0Ltb3BymF/S
l91zESbv7MDuKawUuAKm39nBrKrObrkizL0uDsZ7fWwv3t0NlXdx0GHTnFU7
F8pncHUodEz51f4DZr6rg5rMskklOrDwdXNYeF9e93oeND4a3BwiDXrTD5fD
4sfdYdbEfzP4sqHps8Hd4a/DH3ZP8ZP79TPiM1ZPdnf4dMk3SSDi5H4ARd/0
DQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgk01Xkfx/E/1dOm7SkzahCFmknJEqnwKXUtieLaLq673ysqKkeburRO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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10QsslWEcx/GzNs2MXEoIueS2RDpI7j+X43U/WObU1OY0WqvmWKKQWays
JtIU5bTcxiFD1DgIR1LUWihbLuHoomU1C204qvV/nu3Zs8++z/vsefdYiJNj
ErfweDz8nf9WNnTGqyTeGoM9//XT11NhKXVQY+bB0KDZtGbjOVkd8hZbbZ81
Zh3UC5SR25aZd2AuL0A/eJrZEDuKcrjGbmYTtBbKBp1rmc2hfjXG1rSE2RLK
OAf1iXRmK3D9n5P0zZlt8Es+YLJrfYBsh+094rrhaea9qD49a7X7PvM+LOHu
VKENsyOEyyPtRsXPyE4QfXpt2Pqun3wA3EjwvZOFzHzwzDJPdHHMztBZnZQF
5CjILviutKg3Su4ju8K9dC5Bact8EN8WU5qO1vWS3VCakFXcqcd8CGNf4zJS
K3rI7lhQpTpobDwle2BIWmk9ucbsianKxtvdHNvvBXefI2o657rJ3pCmFOjJ
wrvIPki+Phqfq5STffF2NknmMtxBBrKNXbI0T5FzgKVIRXeqJ+t+4DKq5yRi
1v2g5ZQWajLKuj8GBMcca4aeUPfHfO7jlzPxbdQDMCYsVmloNFMPwI95oyXN
PTXUA1HnVu6lUFZQD0SDlekZflgZdQGyP8yONUeXUxeg7EqIl0RC5/GC0MaX
7i/yaKEehLxYaUnaq4fUOTirqrSd+pqocygo5+JWmtj3wehX1O4s/l1PPRiL
8Z0il8t0H14I3mwezl+Yr6UeAnuha7bvx2rqoTCLPR6dPs56KKS32oztC0qo
h2Fis+OaVuYD6mGIyb/glah5h3o4GnQN5PVydr9wPIqrdNg600o9AgKRtXjN
jf1fBM5HXZTZCdn7R+KGbhTOlrVTj4TqEr9zpZd1IXrXC9+v5rygLoRks+zL
TdFgzx+quUgs
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9z11IU2EYB/DTbhzaxVonGH2AuVpmMtqqqVvL/zZ1QmQp3RhJrVqE2RaT
aqOLzlbW7lKKvm7E9YGwQWXOFlozmxtxhiGUY4FTCWEF6+umz82K3scDh8OP
//N/3/OsPeRssUs4jtP8ff996ZGlbp80Fiei//W5VrtrstCxlMzBG4velMvJ
UqQqs13CCrIMCX+zf/mieeQjokfGkRXwvvF1KDNx5tXoCRyRPEySS6E4kGzy
PyCXwZawD4e95HWYu2jov95JViEZVDrTPnI5+kRljdpDroCQ77zhaiFX4pzz
lMNQTFYjlJupEqvJm2EzfnXMN5E1OKgdftRaStYiG/xpz8yOM2/B1cLQ6fJp
8lbINw5qvg+Rt0GdOXw/0krWwR3xDQaPk6twIS8GM09jzNXoFVaVnLVQXoOU
uj0kvUO5Hs/SbWZN4AWzAfy8/knRLHk7FEJybsJBNiIiTukWFs/fgQ/3fmS/
qej8WrgqrljPq2g/wD2V+FL2i80LwOjCzvevJ6hvwsgY331MGGO5Cabx/LtQ
/3OWm+E7I46MSqlvhm3SdfSjgc1zFuh3h0/sW8nmBQv49njO1Ej9Ougu78+t
v0X9OtgGYp/6QPfXo2f68csC2P8K9ejual7mttI+DfCk1/Btd9n+QgM22QN7
f5dQ34ol/IZXkkuUW/HWfS1s3UP9RvC9QpF2Jh79A3wu/y0=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90Ak4lYkex/E3U0YipY1IRwt3ZqIYlQg/u5Ds68HZj6VFdG8yMzqpbm4p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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxd0w9Qk3Ucx/HHTYyM02nsmPxJ5MhDHYqoAdrGRwaoyGQb2+wKPPPOpKNg
aMdhBK5TElQ4uoOchjX+6CzkP0wS3BZskBzDpXb0B0hIDbLDElTa2Vmd319d
7G63e917n+fZPc+zZXsyVXt5HMel/P3+55O9BIPVOsn8XutT/RbtON2etuhf
cxiTRJuu8pg9Mbff8p2BzyzAzfJfX2gd6iF7o+O9GxlvOplFeF/Zd6Wnh9kf
NSsafhhpZA7Eyaby6sEc5iB8xBucK5IzB2MqKUMRuph5OXzcnv4tAuYQzJtI
OHD8Fwd5JZbvrjlYV88sRr+96MEpE/NqVARiTdQAcxgSPc7odu5jXguh+Ofw
VDlzOHhqv1qdJ/M61AbYxsLv2snrEbz0uNvZzrwBEWHi7KlQ5pdgD73Bd+Yy
R6AvXePOO9ZNjoS2oDWbX88cBWfLgwv565k3orCi1CJczbwJJYX5suenusgv
49auvQfOTn9JluCDcGnWvRjWpQiMKh3xljNHw1VSd+imFzOwxDCQMrCT9nrA
y0c358THrG9Gb3Pun2JfG/XNqHzDVZ22yko9BpllWY8kEgv1GJzbf+tO4cPL
1GW4u1Dg6ZjupC6DQyQoaihhPRbjgVK/8QKyPhYi8Wujrq/N1ONgjy1f1eRz
kXocDDMho094rMejc+KY8dVFZH081hnrZRpLC/UtCEk3jXr80Up9C6qKMtre
DSRzW1G5tjjLa00T9a1QdYiecy9opL4NxUKPkYChZurbMEe2Ydn5YLZPwK77
g9pDcnb8BHQ96xLOa2ujvh0hh99Z0VjGft92pIxNp/ZnNFBPxNCQcZ+vsIZ6
Iuy++198pDZSlyNrZqXttpOsl6Ov+kzvRq6S+g5ETJd+EvRNFfUdUMc/zMk5
YqKeBNG1yXMV189ST4JTlG83X6bzcQoc+ar2Um7YZ08NBdp72oZf19Jer0BR
aV4v/zZ1mwITosc+qRfO016Jg8bQoN9/ou9DiRmxuavgKHW9Egv9O9KvP/6c
9kocNriH1d1kTgUPl9/bXBldD6gQf3WpT76jjvYqLCn0DoiXsfOrIF3wvVkX
yfbJuFS6O+hHKd0fJEP8YWTjp0b2vCTj3smcizNmuv62ZHRmV7UevcPujxqG
4WZMWshQg59qctieYXs1rK2nbRHjX9Beje60b58ITpA5DYrzmmSWt+j5xSzr
NZicfypucSH9/22zzGn/b8yy/j9nVm0a11i1uH9NvkfwyhXrXxdC35U=
           "]], 
          
          LineBox[{{91.03726137206529, -0.198}, {92., -0.1878092516195511}, {
           93., -0.1669692400959424}}]}, FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zXlI02Ecx/FfCWpJNS/UIbbEPNJSs7SZcx+PzTMxo0NwZUPBRCw0okNw
gQblkErTmjkNSbNDTbDEeeVvapIxTcqy5iwlbH+IaWBW0kHP1wd+PLx4f7+/
Z4vyZErmWo7jxH+/fzcdwXjdKcn6wZ7/mpfyfOPDQlsyh4a5yG9B9mRrGKy0
oaWrFmDQbBjWrO47QKcp63u3MMDsDOPY0TyhkeyKKcNU4a1WsggKu4z6STXZ
HY18i/FlJtkDt7Py1emuZE9UWh5xLpjrZ/YGZ9N53fEpeRsuPF/Y2p9L9oPp
qjrYJCfvgCTPTyTfTg6A4Lh7UqqaHIg0i6LAgBDyTrw+vDEqP5scBJ95rc9H
G/IuKA8UF7n4kndjtEPeseaTnjkYNTLP714F5BAIh2QTiTqeeQ98tZ/LbW+S
xRjN/jAzrSSHQtOW7JjT18e8F2dGRKNfBeQwxGXU1DUskiV4cfCevuQO7Ycj
vFKxILhGluLsrFfSKycyMGRv/uFtYPsqoETvEWxy6mU9ApfcFDeEY12sR+CX
S1V6aiX1SPjcPWG2EnewHomwpZH+dW461qMw6T9jt9zL5lVRcH1bnLZpP/sf
Fw35hibzrHUn69HIEorq+aJu1mWITbNMtGin92UwLYlW3ijYPCfHuGN50nT1
E9bl8H+weNm4j5mLgbCpILdsoI31GEQH8Pd1xlbWY9F8rIL/uZlZFYvlarvk
0/rHrMfB9n2puHaihfU4LKbkPAtrZubi4V2hLJn7zeZV8aj1NEuzhun9BKwc
Onf+i6Sd9QQ45DzSSoOYuUR021y5qOjq7vkDa0wjeA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQMC1xcX2HId3w/hfbBfYR2QdJoVxmdw0PTMWCTA
A+NzONh55y1TZITxBRz+614ormSB8UUc9pc59c1ggvElHEK190yvfnQMypdx
sF3R+f7XURhfwSFUrSjBbhuMr+Twc83rNUKbYHwVh2N1F5fOb4Hx1RxsuY93
6dXB+BoOTC8e7f5hAeNrOajOluiKZILxdRw62T6qct05CuXrOVzNinR4uQbG
N3B4ofHm6h82GN/Qodwr6kXdoiNQvpGDeq5NYPVLGN/Y4WaMGb9HHoxv4rCv
h29XKROMb+oQkntg6/lrh6F8M4fT73IiZctgfHMHmaVRE4rZYHwLB/fOeZ46
9w9B+ZYOvzun2Fq3wvhWDtlPrgiJXz4I5Vs7zGZMU81bfQDKt3Fg0SyzKuCH
yds6yBfdO38lE8a3c4h55/o47S5Mvb2D0qxztd1XYXwHB9FEf8uDz6DqGxwc
Zl1Peb7cDma/o8O14NkzGE9A+Q2ODpKdsZanN8H86+RQ8P8u+y0vaPg1ODm8
DT6wiG0NTL+zwwXFHxOq82DmOztYeVrOdfgOc5+Lg/GPg/0LZ++CyqPxGVzR
5F0dPrS1F7ww2QOVd3NY2yFy6OCFvVB5ND6DO5o8Gp/BA84HAMt7+so=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9z11I01EYx/E/misWhlGZ6KRcY5pM2WbTps395l50BEFZAyVWTNqakvOF
bparmeUuCiNlllE35lDItRqylyw1c7M3KMGwLjSCbEREXsQIJKjoPDtwOHz4
HjjPKbA4jpxK4ziu7O/+d9LKWrrbpuLPT//Xmjp5Lmh0pcxhaKuqdU/Km3A0
MDj2kyNngfP3fed+xZm3Q9Kht6QnyDkwOauHembJAnz+cMikiZJ3w7Teu3ky
RBbi0oBPwx8ji+DUnJT7nGQx7N7IeLKSXISVY22WlSpyMTpFqyZ/OlmC5MEu
z6gnxlyKEOdbyLWRpcioXVVuiZNl0Krrs6UXyHJIpIVNIiO5DNP6PNedbPI+
9BsFO/a+nGNWwHBZIR9uJJej0zuvSxSSK9D51VC6+Ju8H2sRhetwF1kJW6bg
/eLyM+ZKCHQjTTs/kqvA7xdaVdXkA8jb2Px85sksswrcw5tfymMzzNWQtXdM
fDNPMasxdVX86Xp0mhkwWk87XstYdwM/gm8j4tbHrGuwa2JJlN/xiHUNPGcc
/GHzJOs1yPVfXN52K8J6DcLyuWLuWoh1LRrfdd9baKGuhSzJa2gO0jw62NU9
JQVmdt+tQ1g5MN6eYO9xegTO578K2Ol9PcI2nvC4Nsq6AWnW2GDkNpvXbYCn
aER+xfuU9Vqo6/vithNsXnctXtwo6W05S/+vQ3dmRkVi/T7rdeDlvGnYoHjA
ujHV/wBBOvPz
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwtYzPkeBvD/w7ol4pw4KFuSLJJtQ22p3tHFdL+PkmqaZqaL9YhYFqPJ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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQMC1xcX2HId3w/hfbDn+h/7wosHxmdweNaY9tqE
CcbncKhw/Jv9kgXGF3B4027+6+zXY1C+iMPcwKscOz/D+BIOzP67tlw+B+PL
OPzRnHIt/hCMr+DQZHNp14YpML6Sw5rzRreSM2B8FYc/ZS8ufPaH8dUcxN8m
Kc4ShfE1HIIWGTmz7z8K5Ws59ImdPLO8BMbXcbh4yKcpQwTG13NofFST48kB
4xs4RMz6I+t95QiUb+jQGPTnktwDGN/IoVT33vXqpzC+scPz+wVr5Zhh+k0c
+FQTJl8whPFNHfgmNX/4pAzjmzlM/ax/ozwIxjd3KJPo1c24CDPPwkGgOmei
Ji+Mb+nwz/LypttOh6F8K4dJUVXzSrfA+NYOexNyGuUWH4LybRzeZBU7eujB
5G0dnvJ9vXtnIsw8O4fgvq9xd2JgfHuH3Uu2mM15AlPv4CBxbKWebAaU3+Dg
4PHrEK9qG8x8RwfLlJzMmEqYvKPDqsj1QZl5MP1ODvZB/voX/0LVNzg5PHjN
/UGnBKbf2eHBPud/n5wOQuWdHbKcN1RF390PlXdxKMlPl6m7tw8q7+Lwk1tz
wdYVUD6Dq8PihV/kZ2fC5F0dnO6tLpPK2b8fADBm4ys=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10A0s1HEcx/H/yuiyLl3kIVkeZioiufLs4/Ec53HF5nFTiQhZXCIusiKy
VbRZD0ya1pA85qFTnDy0yTTUVleOZSprZJkV1fp9/9t//732/j3+jeNSQ09s
4DjO/e/770uP1mRNmsvml/L/+u5mbZGotNpC5rDklFZ7nk/eBP7dgAILHlkL
Na+io6LnB5i1EZsg6+t6Q9bDpegrZUXTZEO0TEg7vyjIu1GtnaF80k42Qb94
3TPyKtkMSpFUN+kc2RzmsynbmtzIFihy9o0PnVMw70VhgvC3/CbZEjsaO0o+
ppL3YzjbySTcj2yDYGFestSVfACn3057bJ3vZ7aFsap7oXc79YOwGuAkGjeo
20E4YJ8/pksWAgrD2zE9fcyHoHy98m5Vj3wY73fJq2J5ZHv4a87GTeS/YHbA
sQKT6Z+DZEcU51XtKzMlO6F8xn40N4fsjOmynq+zF8kuOFomhrndc2ZXNMaV
r1Tpk90gkO2x1gknA9LH+pW3UpllwEiMYOSHhLo7XL06lR/Ke1l3h8A08VHa
qpx1D2zkxme5kh7WPXDZ4Gx1qScz54mT1ZVJBYpO1j3B59cZF2t2se4FYwfN
z4ut3ax7oTxjZ7aHiI3nvKHhqIhePk7re0OrXeitw6P9fVAqT28YCqP5Pmgz
KJ1K6qb5InT1n1Gb837Kugg5otpRlX47677InBh+JrBjlvnCKHMBZlEdrIux
uMw9LPRqZV2MexGxv46YM3N+UFtsUHdRNbPuB8vi5dUmVRPr/rizNpleIW5h
3R8hZtfWBh+w8ZwEkzqClZQImi/BusQmPrKG1g+AUc+Yuq0unT8Aqvr7gxcq
6H6BCOGFOV4fZ/9TFoiA8KypoSU6fxCaxz6dqtOi+wUhOYOfnDXK1uOC0Vef
O/NN0Sb/A8v1SsE=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVzH8s1HEcx/HvTLn6Q+dHRLZIi0ycL+LbJS8/zo87xzr9w7SVaBlNZIVy
M5ufZTXXbrbGlEk0R0fCWeW3ttwalf6IsynWhLSSZayaz9vWZ/vss8ee78/b
JTlTlWrGcZz07/330hFP1l8O2j3yYkvfgvMWq6SPxWQO6W7G2RQHsgitPiJD
wXYXoyHO6ci5bdvCqldX5vJzmHkfZtvkHfwy2QnTrpWWzYNkZ5j8fjmYCskH
wcdm9t0vJx/C7TVen6AmH8a7HzvHfRPJ7phbytQLErIHaq6Xf7CaHWL2hL2H
4WzLBbIXpKeEnuVAsgQiww3J745BZh8o7HPEiyoyD+uG19WqzQFmXwxX1Go2
oqj7oYrX7Ldbo+6PxKGmB5GO1I8hZV7QT89QD0BbmruxTt3PHAjNwsBq7Uey
AG/tyhl1Bfk4dmQ4HLBJ62OWosx27E6uK/kE+I2podSul8xB2Cxykt+UUT8J
s7ffHd+UUA/G54Saxsn158xAf7Hik2evYcuFQNLoK2P23m7WQ9BZkVe/S089
BBaigvyxRz2shyJ25rT/0btdrIciwntPs6B8xnoYBG3WxKKuk/UweOU2WjZk
UA9HT+61lVvap6yHg18vmCoaYPOcDLbDOZ69xbRfhuqrioR6K2YuAnNJOudL
rtQjYJ7tdt7mK/VI3Hu4WWpXR/sjofsSopIk6lmPQnmj39J4ayvrUbDOGilx
F56wHo3+ZIOwUsZcGI2mi0qLK7VtrMuxYBxZLRrsYF2O/DDzdkU6M6dA/JRd
gOl9O+sKlMaPZk90U4/BcmV7S9w8/Y/5f55TbvsPbQYvDw==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQMC1xcX2HId3w/hfbCXmTjzu7owjM/goPVGJtqa
D8bncDjdHbMujRPGF3D4w7dV5SIbjC/icNFWXXLOq2NQvoTD9v03he9dgfFl
HM69i+m8fQbGV3DgUdNkm7IRxldyEOBQ1otYCOOrOPQtqvk3Nw7GV3OQn/qx
9JwZjK/hINyp2/yEH8bXctC571i68vBRKF/HQf/L0kp1OF/PQSLW4rPhdBjf
wOFRtlM65xIY39Dh5OcEhskqML6Rg/IH3wV3uGF8Y4eGpzxHozOPQPkmDj1f
d7xwuHUYyjd1WOztoZB7HcY3cyg+4BB8SASm3txBMmdGIjNcvYXD0tKWVTET
YHxLh9Q6lvqJyoegfCuHA1cP6d97ehDKt3bYM3O5vroHjG/j8HX++ceNK2B8
W4cHmsrMXaEHoHw7h49Oh92mVcD49g5nU54tKG/bD+U7OGSvbknqqNgJ4Tc4
OGyPuXL047NdUHlHh40+Vz5320D5DY4OWuq6kirvN0HlnRxC71o+n22wGSrv
5LCkKmnTu4dLofLODhJ8X9b9mbgDKu/swL5Wjkl5FtQ+BhcHp4WxOz/Z7oXK
uzjsSy/mvnxtz/6doUnLN/90cfh0yTdJIOLkfgB4Kdri
           "]], 
          
          LineBox[{{44.79441404795809, -0.198}, {
           45., -0.19491158802650868`}, {45.20558595204191, -0.198}}]}, 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10AlYzPseBvAhydLmcFIhCamuoyKHNvNmL9K+TsvMNNNMSJaTuJKRo5ul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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgs4lIkex/EhtS6JdtfRJnY4dKEotbQJP+s2oVxzjxlzTfdDLZWaWqlU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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9kglMk2cchzuHCYipYBAQQVCJoCxMDgWZhR9YWg6BnpRSMGpF5jHBI8EJ
ZEVM561TwQoFkXkgjLuACkhVLpNVRWVONlQQj6gTt8hgIGNb+L/7kubLk+d9
3uPrO29diiRpCofD2fTv7783e6wefp/Km9bRMknvg7pVP3GPWjLmIE8SUGKa
ztgcz+RPJj7+z1ZQ6i4e7ZtoJ7aB4XmNKmmEsT3Kxo488XvN2BFPZ2sj2/sZ
u8B2Xok+5Tnj+bir7LtVXs7YFY9zQ/rn6BkvROMdm/Dbuxi7Y/jrtNOHeYwX
Y8dgYLOtA+PPkPijcuOaJ23EnvA11rnc62S8BPeTEl8G+DD2QvbRtZ4Xz7US
e6O+Wr9cqGLsg7knJWa7FYx98fvw0JWUbxkvxaaI9CBT8k3iZTjNeZnP4zH2
Q++7zgUP624Q++NCvLerwZnxcnTM6nGt2XqdOACpE8sfFfYw/gLDZr9mbd/O
eAXs3o44JRYw5mGgIe/N7o/XiAMx/NeepuLBZuIglKbbdtv7NREDJk7Kyr5a
4yRrgGDdSbdCHfPBuDIkyeDubSAfDEOFRLhlH5s/BNZjX5bEmLM+BIKJwWUn
/mwkvxKO/lZmnHrWr0TqOrOdcm4deT4MxfpXFtoa8nyof/bkXb1jIB+KudrN
IUPZ9eRDsXZo4Gx1aRV5AQSp7y8nj9SSFyBSPbfrsGMJeSHezewaLeaeJy+E
+71MQcz6PPJhiF9a+kwdS6wJA//qb4nCpHzy4UgbWaPdoysiH44tFi8ze1U6
8hFY+F2HlGtH4zURCJ76eoHDqePkI+E4Pua47nIO+UiYu8mquIuyyK9C+aFD
bUUe2eRXoe+DUd+xSUs+Coq2iMVjt/aRj0Ks7nZYd9UJ8tG4vVob5LqB1tNE
Q7Bt5oNPwtj6MaiYEZ+WKaL1NDE4INPlBKmPkReh6ZtFJot9tH+IULnTx9mq
4SyNF+FZ74YP4RuLJ9koAr988/6b7uQ5YqgUzouOJZCHGNoVn78rC2TfS4xl
plmRx68TG8UQtqz3NzkTcySws9Ql50vZ+hI0729XdRXSfBoJDC9WZ1U4XaRe
AstCizelRZeolyI31MUrOaOMeilsL4jH1dIL1EsR2DKtVq74gXopMmvGt+3S
lVMvg8OL9BkHrSupl+EPkbB3Ko/Ga2R4MOgu3vyolHoZes8Xt44GEnPkyPd1
m/npNbpvkKPvoL864QDtRyNHvcelhEo+7ccoR4dFlyDgDJ2HE4so12i7RhWd
B7HY4WnJu5JUTX0sekM3VnZ3svPHosot++6UUbrPHAVy95zhj1mzXgGvwYI4
88Bz1Csw4Oz06qtzrFdAlL7kqca7gvo49NsoM0rmsP8vDrUe0gjDXvb947B1
Ou/97DiazxiH1r+rb/S46alXYui50o/vRvcBSuTckA10zc+lXok0n190XJ9T
1CvRM7vZ8/6UAurjYff4ft7bezQe8bhqLxtPqNO1/AP4CCND
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQksFmAcx/F3HZZq89YoVMhRFIYcFfJzvM739b4dVEYJ6VhIjkytXl65
3jmi6DWv6aVmaymjV3N2uFm02WrTOrASQodaoWvv//Fsz5599v3v+W8Oi9l3
fAmHw/H4d/+/7HBfVJx1XtnZqtKMi6PVnSmd1cwcLJHrlgQs9hVo+dMVYbTY
uVDE/ZY/XsGsib1jjfUTq5i1sTEqN3rwUwd5I7gpIWXKMWYD/DgWO/j2LrMh
Kng6cTE3mI0R8WxCqZHNvAXyBqkwJp7ZFA61lsn655m34YKf7UDXFmZzrDf6
VZ863U62RHNYeCSvndkK6VkSUaYvszWi7E2mijcz20CoiOLPdreRd4BTuKHa
0JPZFmJdN/PmdGY7SDKGjK/cf0q2x6iepUWpkHUH6AdMWYwrWN8JrSR+6JGc
J+RdmLfSzayLf0zejQdBTV/seh6RHfEqXzQiiGZ2wuXvMo2Po81kZ4RkJ1Y4
fmPeA50dF50XZE1kF5RppVfWfG0kA3d+DovfvqcuBur2rSntTGTzrsh2as4L
UdA+sStcc64t23+6hbob7lWNbO0ebqDuhpbkNKO4ZCV1d2Q4dsj4bTXU3XFo
r9qlikoyxwOas+NfrM2qqXtg0+Guh2rPy6nz4NBm89rqjYQ6D2nzpupVYVnU
PdFpWVvyITCWuif6+3o15kJSqXvBuzY1cr6f/hN7YZ2gJ+OPWRV1b0RwuWcS
ejOpeyNneeip4Dpv6j4wK7IbHC9NcFF1H6jPnCs3XEhRmeMLJ2nDnnppIXVf
WGstPSozLqDuB6lSdCuyM4m6H4L8+uzTBAfofz7eqEtk/KXJtJ+PvDnx2IBn
OnUBRsIvybe30bxYgHpFwe21N49T94f2y/wcPfNi6v4wGTrxIUmcQV2I4UAD
20lJCnUhgkedp40mC6iLoNjtfjX33TWVIcLJVrmcKyyieREOfo7atrynTOVH
Ilzv5dTkKUta/wJ+zFSR
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zFtI02EYx/F/uqYMsVFepPNCx/C0LdS01mzut5xuNwtMRmYXy9HsAOKG
5F3plJTS4akiikVl5GkQ7UIlZ1upK9MiO2AgxepCQnFWsMmWi4ze54WXlw/f
530yzQ3HLHEcxxVu338vHeHSgFUleOH9rx/q1qadzdNJZA7DxSVPTvPIiRhw
PpiX//IzCyEMN5yLrpJT4Jp1f7zyhrwX5qaCi6kj5HRcmnctmWfIGejLqt1s
HCOLkas0dA/1kiUo1JzK8djIWRjMm0qyqsk5qM/IvtoTnWXOQxtPtLawSpZB
InEu8wU0vw/BHl/VyURyPvoWfmonF2m+ANm76/LXN8mFiLUlu1+PkfdjziEP
BJvIRbj21VF6tIhcDL+nP16ZQD4Ak93glW3NMB9Equq4f4+frEBy5Hyd6/c0
8yGMSzsEk3ayEmLZn1Jn+DlzCUKfJgoqY+TDCNXfuG7WkFWoqmz22EXkUvDX
ucyz/c+Y1VDrb4VfPiYDE3LD7ZiOuQWwWETBXRLqGoi/d7za+uBjXYNvNSnu
9h20/wiq9cMr/C/0f9vGXlvgLpvnymCUBEba37L5ljL4ahVxl0PUtXiXdvPM
Bs/DuhbpowqptIp6OaLx700VC09ZL0eXqbNrsJeZq0Cu/NG9lWXqFTB2Lw61
2tg+TodI7L41sjHFug6Nn2vGH4povx5p1Ql3Ok/Qfz1Ma3O6Cw6v9y9pnv9c

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlQlQVFcWhl+UuGFFZE0UZRERDSIuqIiEn0UQULbuZhlZeqUbXKBFcYFo
AyIMomALCLI1qwgTQEXcGGkFg0apcgGldFQERRNGBZW4RHQyxXmpCl3V1fXV
f//733Pu6fdMhFF+kjEMw1z98/v/X/ajdbcs2n5SW/MIDThM0tKIXT+ZZQYD
N9+vcvvyM/EE6JRbZnb9xVowff/wvccgy7rgiaYNtz5m+VsYXTwV/0cXy4YI
ykhe19fMsjHmx79OW5vFsinuZq7Z9SCaZTMk77xWPdWGZXPopT6ZNwcsW8Bg
MMC1aArL87BdFPZS4+5lYksU1t74MfU0y1YILfzFTF7HsjXupx+UX9jE8kJs
LW2TC+1YXoT1feVfjyloJV4MM8eytHMeLC9BUsoRnjC7hdgGHf1m3s49l4iX
Qrftl6Vd2iwvw4viyhW5nReJl4NryTN4uYVlW9xui90VYMjyCpzbuF7/U4Ga
2A5cN+t+bR+WV0I4M3uY9zW73h7tFmdT7h+/QPwDTDyteJYm54gdsGCTNf/O
+LPEQNHz81yZqGmEFYDjQdWgVgQx44gW2b4qvvIU6Y4wPRtY7HLvOOlOeNs8
tyqyvI50J2Rs0vJoHKgm3Rla+030dG9Uku4Ms5lbYz/HETMueMmzHUw8Wkq6
C5TZhVZG5sTMKmjrRx8L8iwgfRWitC0f9/gRM64QzvbSm2FxhHRX1C1NNlxp
nEG6GzLnHi+b/Hg/6W7Intw3qNNxkPTVaHh0v9PC8BDpq/FhQmFPvnkm6e7I
Kde76X4in3R3LG43GAq0yiXdA+1tawPW5StJ90BrgMfinGDaj/FE/2+u0i21
KtI9YTSr+ZzkJ2JmDSQT/WKfTSshfQ2GO17qP1pSSPpaaN6a9fiaJdvftQgN
PTh9ii7bXy+EGqeN01XUkO4F7+1rvXrkVaR7I9K19+GnhjLSvWG/YTdnVmM9
6T7wFy+LO/qG7hM+0Fxt67ltyQla74Olgo9J3s9ovdoH+spHCZlc9v59cfth
YYr+eNLhi9pvYjrc7BvI74vj+QGKDWJitS+q7927PqmZmPGDMsUr2aHkJPn9
8CXh1lN/Gev3+/t+aj+4vubGj2+jeWQ4iPbuzy+4Rjo4sL909XL8E9pPwcGA
QKc3IYH1c7D43/kxmq9JZ7hoVnXE612gesEF84o5+8KQzefC/3nHHM3zlKfm
YpHRIvGRN+z5ebCL3NNf3kI6eNC3qSj7bxObz4OzgbTH7gP1S81Dz5iwsbbL
KY/xR42juao3oYL8o1jhD6tbWRcbkli/P5xsvjdLusjeXwCuXJ03PDiJ5gMB
qAjhfM6z+hf5A2CeXJWllUCsHsVMIMw4pnPyytn7C4TuC4N+k7fs/QciyiGd
Z+RK9agD8aahsaZAyfYvCDU18hxVHTs/QZg29KjLPpitfxSrg1DdFP95Sr3S
YcT/j78zRrFiFKtHMbMOk73Gnh3I3E7+dRhqeJX8HX8f+dfBuUxrTFt2IvlH
rWeCR/mDEcbX22ae70fnD0aUvf8DrfpN5A8G+pxat/fKyR+CQ74fH5st3Ev+
EAResZgXp2LzQ0adPwTXZ5h1Gq4+QP5Q6GnbWbTZZZI/FE8O21QOZB4kfyii
p5/+nHVmK/lDof1+ONszTkr+MNzbX7SiOHQL+cOgummmLHGOJ38Yvi2x/b1y
XAz5wzC2dlxQTkUQ+flwnpvxzuPmrhE25iPiSFGwqsSH9uPjk0alrds28Ug/
+Hzg3rSuJvkO6g8fX4VPLdxwXjLCKj4Wm7+IvbY7ie6bj1zToegFe+Uj3M2H
zsyYJuesOJofAQ7s4xR940nPS2MBgp6mTF9xbh/NkwCX/onh+Z0plP8nr4kp
4iQoKF+AsSWlR/qMOZQvwI/d3gLvLcVUrwBOtze2R0xNGuFuAerKuRV6C9Ko
fiGsuSn7/fI2U/1CDCrlC//zmZ7PEMLG9XlkQXQ55Qvxg81yC7erxyhfiNPT
p3wITqT/q0qIlsb1d7xi6H2kFuK33SF913OLqH4h0lMnHX4gZ98/Imz8ouD2
zY6lfBHuGDZO7BjL/h9EmDqhpeNub84I80VYVr3c0T2d5kUhgobpHs6Vzckj
rBIh6pmHbnEIzZ9ahAMpv28MV9A8dYuQuuzN01chGVS/GMKAVx+fi2g/YzF0
LXIXJv1MOsTY1NJVml12mPLFWNFt+vJUIzufYlyYm+hnollA+WLssGu6bZBY
QvliHN5gm+n+MI/yxcg6VPqxv53qYSQ4NGOqXvrJQ5QvQdH6Xl5AJ+mQ4Htr
jQNHZ7P5Epx8k5xRpZFF+RLE72l95VNHrJLgxv3Ut78qyK+WoCoyp6D9TC7l
S7AnTLnoTBadjwlHVez1XouESsoPx4wIz96P9VWUHw7dKIFOWfIxyg/H8aeb
55t+V0754VhpI93tHKmi/HD8MSPuwpAhsTocy3O4p1ze0Tx2h2Nv8sQkNxHV
y0hRUpNV3OJO5zeWYs+Oorz5IdRPSHGqcN+tVdqFlC9FQuUz3xfN1A+FFGUu
fH6QfinlS3HntdHJIa8aypeifMeSA7/a1lG+FCfeaV0+E1hL+TLs8kgKSveo
p3wZXuel4eE7Ysjw/tpX7mee/UT5Muw0j/QZM5f8Chme7NdsVc6j9SoZPu0U
1TooidUyJBhFVOvJibtlsC6edbPuMjETAc/ZnTaP1PUO/wMaJfVP
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90ws01GkfB/CREuJlRe2WpJsiYZOoyFcNkuR+GUyGwRC1KbZNVpNZxXZz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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQs0lPsexvFJon0qicoOoZRu2iglleZRikTujFtmjJmhrdRxKULvka1S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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9z1sog3EYBvBvqwlJI3KaQmhtc9znNKdnThdSJBdSi01SiuHCiNpuluMF
hbawMkniTnLIqZhDEQsRt8KFJHxOyZDv9a+3f7+et7eecJ2+tEbIMEzUz/z+
9MRnE42Znjvrf3rIPrbZmyxeZAa+Qv0J+293dHvEfUo9yGJw9aLeUgHZD9UP
RavDd9u8A2EMEZwYbskSrL0wMQsX5DBYByrlXdPkCOz2V062jJEj4fyQ6Qf7
yNFo2FA4g5vJUlxqLWY3LVkG117gQE8uWYGvDNcp506OxaIk3zX05eAdD4SX
7JqXyAlIvq7dZ8vJidCJrf5OFVmJ1+lokSSXzMLy3H7ORJKToFC+sSvcFu9k
NNuODIY2cgrshUFN6n5yKg4PduJSWjd5p+GmWK5y3ZBVkCnrbE8ltJ8OaX1F
47KD8gwE3Gs2ruyUZ8KHna+Sr5CzUD3kzQk7qH82Et+lI0FayoE8QZmmjOPv
mYDH2aljeSflamjGQ1jLHN/PpIZeJB7VFVDfHBhnQq3mWcf6N6EptQM=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zn8s1HEcx/EvscqWsazSWT+OmZnIz0vIy8/z486VYquIGLVGEcXMOBoh
NaatH/phRE4/NJnKjzvyK6Efd40J83NtJXXyY6akmvenz/bZZ489/3h9dkac
CYzS5DgOf++/lx29/rI4F51OxarUrpe+BtdOb2TmUHuVJy3739eh6KjqdNEG
Zj3EJMgsX2sxG6DwgoHX+6UO8hb06WVdNlxkNsK2c1aiuXHmHXg8YZcR3cDM
R8PNINVQKbMJrIS/FlcqmE2RUKKb7Xid2Qy1j0IETV7M5qiWaatCF9rJFihN
WpCszWO2hDx1pW/uCPNuSHTNX6VoM1tDHBpZ3hXWRrZButa84vy3VrItLLOi
0kTVzHYYno6ayhQy2+OYbNnzlPIl2QFbpbqSJXkLWYDgdzWz86PN5D0o10j1
rtBj3RFjgU2zd/RZ3wvxjc6B75sVZCd0Djfm5IcyO6PK0aFT0cXsgrIeXlGR
JfM+XDuh5Wdoz+wKgcltfoKfnAx4GJe6qOKaVi0FMnUu5q13InNumFzzoUSt
00jdDYOS3/JkCzLnjijlLY/2hQbq7iiI1Bya6GbdA5OLm8KtftK+1AOu4UuJ
xqP11D2R3xu/oiwmSz2RXq6MkaW8oO4F+YHWN3djn1H3wpWeHFO7djLnjZVP
BRG51nXUvcELnNlYtVxLXYj05nFR2GINdSEEPSHFJiNkzgfHR/cP8W2eUPfB
lOBkvD6fzPnCR+42UPf5IXVfVGRHnw3ufUDdD19Gtle+9WbdD7ygtkO2sgrq
/jA7+GMsseM+dX+kxQqtck1k1EVIdu6e87Wpoi7CcuHH4uq8SupiiC2MDqvt
yFIxdnnK2/PraY8LQIuyVDTIp/9IAzCTOvi8sZ/2OAmC1VxDhus96hJwSQlP
WzSqFH8A8vVP5A==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2lIE2Acx/FlljbDJA2tJDxyHpPRap5T9/PavCYzc7BJhdJSUVAs0Apl
pYlNLDvYG2OZWlordOpaWDibeRQpGV7DEiozampDQlPKDnqeXvTAw8OH7//h
4fHMLjyosGEwGFG/95+TLqfJpqJI5qDxr6wCFtP2Z+s/MzCdaX9U40htjwzx
HsOUHbUTLpZuEahXBohdkN9YN79opXZDd9/uosE31O4YsvioPSaoPTAxe4Sv
aKb2gqSi8llZLfVeePt2SwpKqVlo0N3mndxA7YfVd4Hbl7dRB6DnldyS8LGf
OBAhzV/43DlqDuaz2JmF9dT7UC1tEVVFU3OhyuJ7u357Srwf3PPqt6166gMI
GLpcZ06m5mHHmPfAFSZ1EFScU7ahA33EwRir4UpzNNQhiDbkt/Y4UIeioly1
ljZsIg5D58xW183vqcOxrq5OYxup+UjvrvEq8KH3I5ASMT3nYEcdCbFCgcls
Oh+F77IXVtPoE2IB1kpONMiXeomBTXnjCP5ArASec0vhX28kPRrrWkuxuayH
9GikyziGfg0xIwZ+fPc7ZiGZV8YAuWrdoZLHpMdi2cQ5rhh+QHosJhyiYjry
dKTHoS3Op1Iu6iQ9DpJqtpuOrSU9HiOjmc7Sa8TKeBgfOubeu3qLdCEucHZ5
+ge1kC7E2Tlf3s3yNtJFcAvTz2p47aSLEDa+UnjMRN9PQEC419cpmYH0BCwu
LUu01/WkJ+JcU5BZ+IjMKxOxc8F59aWc3k/CRouLnUFL+39mJGNkpav9h1MH
6cl4rWJmCFj0fylwrpeeri2+S3oKGpKEVlkj7WJ86iqf+cy9T7oYvVNLLLme
/i8VCzmHb3DlxMpUnFm7ZJNb1Wn8BUoeOdE=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJw90GtIE1AYxvFVIlLL9sFiVpCuDKth02zldNuzi5tBSS1brUxMpx+ksSIG
K4RWTnDhpTAyWDidWSyMWqMm2VxzXpDowhQ1zQ8FJSiUlk0soguetwOHw4//
eeFwkkvMurLlHA4n4+/+d9Lijbadka4cCC5pVt7/sNk6yyVz0GhdnHP/73FY
t344lL3Yz8yDvvyuOHaKnICrVmXtiQkyHxs+WwzL+sgbMRp7Y+x6CzkJkxGp
Jb+aLIAwp3TzuI68BUOPDAUDheSt6DormS+LIaeitV0TmP7Vx7wdnqqu6Scf
yEIEPLVDxtV0Pw2Jvy/aox+pi7Cto97V7SWnY7ROVzFeQ84A95a9V3WBvAud
rYkOiZ6cCX3ULXs/08u8G53hEc+5SrIYr+9VaMrnw8x7EPXOphoc5L2Ye7Mv
OXq7hzkLDUWph5uEZAkMjptC11iIORvqtredvu/kHBR6ew4qVGQpNDVrWxac
z5ll6DCfdLoFZDlEC+OTziYy4M3ymobTgku2AacjufHtHc9YV+D4Cu6O8w1d
rCtQ/8IWzTQ/ZV0JU0r1oRE/s02JmR9H13y6xO5zVCitMz7mm2heBa1I9sB+
38+6Gq4Ky7XL8QHW1TB+K5IGxN2s58LXPHXKuYq9x5YLx51wY0IlzWvgifPy
LVU0r0FKQXpx5hcf61rsz5dcOeJntmkhdwqSdk7Qf+XhVShm8Gd7X/DlO33x
JkUevkYOlPCODQb/ANaxBZ0=
           "]], 
          
          LineBox[{{51.90366083236311, -0.198}, {
           52., -0.19726717571450006`}, {53., -0.19726717571450006`}, {
           53.03707358428648, -0.198}}]}, FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQMC1xcX2HId3w/hfbD37PXqzoLzGRxe3evh8mSA
8TkcAsUFYuPhfAEHaRumN5NeHYPyRRxU25xV+2/C+BIOOYd+nd55EcaXcbB6
yRUethXGV3B4vmDmTvMJML6SQ3ngWyOpEhhfxaFE2UBWzA3GV3MI2hTXtdoX
xtdw0J25xOSGE4yv5VCT2Hf5ghGMr+OwNfjU20pZGF/Pof31HBPdH0ehfAOH
h1XKu3b2wPiGDhxTnDkM5sH4Rg4z6+c4KbjB+MYOUwzrZ14NOQLlmzhc2OFT
MscQxjd1KNkerC3++TCUb+awMVko4qArTN7cYZ/Kh86tfjB5C4fbke5Bwntg
fEuHNf5Zz7bcg/GtHJYcYZB5Bldv7ZA1e3s0/8tDUL6NQ0DPv61W7TC+rcNX
38MX5kTC+HYO9/c7Sgqwwvj2Dr4hVrdmXDkI5Ts45K28YnEkCMpvcHBgNJ/Q
d/ryfqi8o0PSCYE3j/7thco7OrBs3mShxbkPKu/kwLD4SHLQ2p1QeScHiZnr
Xxys3A2Vd3b4biF/W2MTzHxnh3M3wz4ssIK5x8XhZFfU8l5NmLyLw7ll5Yfm
Jx+Ayrs6ZPwsdmHQgMm7OthtNP9/LwoWHm4OdjG86Q0LoPHT4OZQw73Mb7sa
zHx3h6duv76unHVg/1mzfy2P49wdPl3yTRKIOLkfACme8u4=
           "]], 
          
          LineBox[{{48.12159473075832, -0.198}, {
           49., -0.11543058831283014`}, {50., -0.11543058831283014`}, {
           51., -0.11543058831283014`}, {52., -0.11543058831283014`}, {
           53., -0.11543058831283014`}, {54., -0.11543058831283014`}, {
           55., -0.11543058831283014`}, {56., -0.08652270833915662}, {
           57., -0.08652270833915662}, {58., -0.0584270687154214}, {
           59., -0.07621170636271035}}]}, FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgk0lQkfx/GbajIv0Z4subZeUZHJVsmvpOzZiYu7XzWKkorU3GhVKFNJ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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzHlIE2AcxvFXSRzSMS3SdGHGNAmTbGmZ23zmNo+VSQqpqGATDWulFuUf
sjDIyBDdggwTsWE2S0zFSvPYrNUk6I/w6D4gg7RCPGmtRQe9v4K98PLy4cvz
hmhL0gs9GWPS3/fPS0f4rKVU5jNi/avZ+HfiLNWEgMwwmKVtnfQiC6BMt5XG
eJCFaB+903R2wc69BlNpDl3Aa3IArvQaZZcekUVY1OSPTfeRN0CyfnA84583
wre7fKizjSxG3IrHlgojOQzN2Vbp9TJyOJraZUypJG+G2fv0mRHXQ+4IRGgv
Xm78QY7E8uf6aEkeeSteLlR4z20iRyE36KO9ypO8DXaHuuR8JFkCS9ro8ZUS
8nasUmR2uFwPuKOx6K9fLTOTY3DkhNC3o4i8AyaFuWepz8a9E3KRcSLjKTkW
5oFrw3sLyLvwtWHMeWP+PnccGrui39YbyFLUeff3xVuGuWWwHVp3zquQLEdu
86ni5BxyPD5JG3S1nWQgyD8yf18TdyWQE2rPNRy18q6AaUuB2n6BugK9g2Hf
J+9RT0BdV8835zHqCSj2U2lbo+h/JYLnQ3B73MK7EuFVOueyW9xMhUD52vdt
VuoqJAk8Tr7SD/GuRvZ0mM90zADvarhmPJ32Im6WCGeZI1BUeJf3RBzsGj9Q
94abJcGreurz7Aztk1BTqxClhtM+GVdVzfKE6l7ek/Hlic0v2MTNUrCY2V1Z
NtDPewrm2IcaSR7tNQhaCjVUvejhXQPnz/p+S+xN3neDHS4XC/Z38u5mtset
u5mluvX//gXJ0CzW
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlXlUU2cah69iEQUpzGDFAg5aSmvBVgQ3XPipSFTWQCCsSW4Q0UJR6QEB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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zglYzfkeBvBzG5F0p1JaMJwzMpJMJbRQvVmqCe2nvdNZWkmLCbeb5agU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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQMC1xcX2HId3w/hfbDfme/KfpEPxmdwOMC6Q7hM
BMbncBBwDT5+mB3GF3BQ0bxiYsME44s43Ha+2W/6+RiUL+HwtE47cuM1GF/G
4fPqPFbzfTC+gsP+66mGe2bD+EoOR8PcJRyXwPgqDlKlvFH7gmF8NYesa8/F
XqjA+BoOmgeXXF9jCuNrOXQcs7+tIQfj6zj81bpzOEwextdzmPz9mda970eh
fAOH/pTbv1Zeg/ENHepU6z5vDoHxjRxm8mf+2GYM4xs7OJifVDrcD+ObODw4
/9ydyxvGN3VICPras28ujG/m0Blwrle7A8Y3d+h+VJpVzALjWzh4TLb9eDDo
CJRv6eBbkdf83A/Gt3LQaOBxtMyA8a0dioyPGcUEwfTbOFxrV7ASMYL5z9Zh
746SPsOJMHk7h7m8TVfPLj4M5ds7cAazyqfEHYTyHRx+zDx/YHEElN/g4CDw
smzvnbJ9UHlHh7pbC49uf7kXKu/osP7Xf/0N2w5A5Z0cJPKX9E7xgfIbnBws
Lv/8USUG0+/sELTlTqV7wzaovLND1/RuqbvXoHwGF4crk3oUN9fvgsq7ONTP
W2WjZLgTKu/qUHDy/Mnj1fuh8q4O/xR+He6o2rEfAPn94DQ=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zws4lIkex/HRcRJddBFaq3RcEk6US6Wsn8k15U7uxsyYIRXZKHHWtCei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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIU2EYwPFDuSw/lC4js8tUmmVWNs10XuYz59zmtjSFLrJSzAwL2Sos
8IOcoKzUL5UJiZiQKTlsOp1Lp21Ty6XgMPMyWNNuKxEjq1VoaUXvE7QDh8OP
/3NeDs8JzFGmn1hGUZTk9/3niZf3+F1VvFe/8a8+JmRw6KqrPmgKNMu1PkdW
o1dChbVD2sRAe8OoM2s8e+kJsS9sFDd+G5tB+4F+KCSo9D16E3z/UMPiT6AD
YGpm2N5kQAfBuinjpLYSvRW654xl4+fRwXBtyFrYLUVvh1PTJXUCX/QOUFXz
c6yTj4l3gjaguN3cjN4NpQ2OJC4fvQc6Q1+PXlmD5oBUHugYyeojDoevzx5F
hrHQEXCnYUWuXoLeCy8pyYX++l7iSEhnTG2QFKD3gSIzW8gToKPgJDP4R9hg
D3E09D/tPPqpBc2FItfwLLMaHQMDhzkuWTk6FhY8KkSK4+g48KPLMqpumonj
oZKttJzbgp0HD3lVrS+WoxMg/BhzxGU2EQPI1B4RlbXENMC00KjZlYCdD0xN
+NLEWwPpfLCXiL2GzB2kJ0IrmxF1SUlMJ0LOWnZuGkNPugAM/tdjoxntpAsg
U6jOnhXpSE8CZ0soc72ujfQksNsFYcWnW0kXwpjmeWLXBDmPFgI3zj6Xf4bM
U8kwINTZ5Y3NpCeDWnvjvnyhkXQRKGJYvezCetJFkNuz6rJhM5mnxHC2tqbc
omkhXQxxFbaFn5wu0iWQUajwdC6S/0dLwFNV2mYrxn2mwBtff1t+k5H0FJi2
FXw56NCSLgWuyWR1xOD5UtBYFK94edhlcDuqYLBIh10GF3UlrHtO/D45uFQM
K+fWA9LlELHNJJqvI/PUfqBCDqksfWRftJupVPCc5+ryDLifVFj8/E4/plST
nva/wc20m01upg64ve9m2s0mN1Pp//wL1iyO7g==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9lnk01Xkfx694QoskDXNGjaYyjUREE5I3umkh135t17VdlOzLMMqtqVT0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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XtIU2EYx/FDYXkdM4fX1JnpMnIutdSuv3TOy8zUVaY5GoYX6I8JFWaY
ncJolpZof3TDJLW8pKXVsEKaWkuCLNBaGEFpmkkXQWtSIBU+b+E5cDh8+L7P
eQ/v8cvWp+Us4Dhu+5/775NdYktdwUb7Jw/nNLn5cLdsYYMjM4egt15VHouY
bVEbv9fhoNVMFkN3wVE6PcEsQdUNzbciC7M70kuKuPgXzEtRqJONytuYpTjj
3K/KLWdeBkOWTUtiAfNymHfWrzEuYw6EPlNR5rGEeQUMx6I7W22YV8Kxdf0B
ruwxeRV0xRNOu4qZ5ejI+zHo888KyIzrGr145tXw9Q7rkoYxh2Jogxz2/sxh
mOmZactJZA5H6dHFq/3fPSKvgbhCemT0IOtrYal092wSM0dgjDd/Hxth6yMR
8DpDdXmYOQpOFfvKi68zr8PxkPF8q5Z5PWx1iquWN8wb4Kvar51WMm/E7FCh
6GxsL3kTlp4W9TlHMG+GTdTnmtRfPWTAr7G6xktEnQcKr1hPv+LY926Bd7PZ
6qqm8+W3IHBsqmIqh513ND5lHy/t1dH+fDTy6soDPlrYfjEIb+toCAlm74+B
U3BzgdHWRF2JPTby2pPv71JXQnfKILIbvk89FvzIhEakZT0WuyNy7rt1G6mr
EKrJb9FWk3kVeuozJblPO6jHwfVM5tvuo7epx0GRHliS5HKTejw+tKsXWsra
qMcjO8/nU0pGO/UE3Os9lPt8opF6Ariu2M6hUjKXiO8nnutcHZqoJ8LNN8ZP
aa2lrsZggYM+IPcidTWqgvSihHOXqCehXyJXfn1wjXoSFJ4DDyJvNVDfOt/8
Vkjn9eT55pNh92WxBlN11LdBlp76TDnZTF1gLmW+kQLJ7IAuKfkWrU/BbOis
OnXfjTmbBOu5VMG8wLzAJoG5NMG8wHwaRlsM+19qW2leYE6DrvMSVVY//U9o
oDf+TA7qIvMabHMZ7+u8RzZp0L5jxL7yDvv/2wXzAvMCm/77NyFhoM8=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQMC1xcX2HId3w/hfbC30XhvZcwP4zM4tL55+24i
XJ7DQVFma8FEERhfwMEy/aZkMBuML+Ig9cth/fPvx6B8CQc5Hk1nj78wvoyD
6lyXez9uwvgKDqfrrJ85r4fxlRzqrDVurlsG46s4bFHJE1pbBuOrOay4H7Zw
ly2Mr+FQbyt/mZMbxtdysF0aVH/n3lEoX8eheU65z8kJML6ew6VTtufVZGB8
A4f5iw62b1l5BMo3dNBbWjzxxQIY38jB+M86xR4/GN/YISmmustg8WEo38RB
Zc/LdQn3DkH5pg6rXj9b/DEUxjdziM/SZBMrgfHNHWKs6zInLITxLRyir67e
xKQOM8/SwTP931+dJhjfykHx1NadkwRhfGuHCz86Alx4YXwbh8bfu39fFoaZ
Z+vQs4lpfd8VGN/O4enCc4wtVjC+vUPtMtYZq94chPIdHK6J873Z1QM1r8HB
oTRPb4npFJh/HR2UrmkvOagADd8GRwf3qvmCE67D5J0c+L/1f6oPhel3cug2
/HPgfOUBqLyzQ2Hxgm/pGVB+g7PDQe/ggI85O6HyLg67E8UN+pJWQ+XR+Ayu
aPIIPgDxG9yJ
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwk4VXkfB/AzWkZJU5GKXpEoRLaUJb6RfbnWa+dyr3uvlDEttFBHtI6k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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0A9MlGUcB/BXRSUquA4kMDv+yjzCJBTJE7gvx78DgfvDHWAZKJxLEoWY
IijUnUgaRGAg4HEQxKHEmDHPkkDlCq1cY3Nik2RpN3SQUYhG8qdBtvs9Nn23
d+8++z7f3/M8r0d6tnL7Qo7jUh+9/33Zw7vekhNi932vVffEdddUW5bwmDm4
Bmg3R9gw2yKvsMxXNv0dmYc3F5xY8MMMsxNMIvXZO49zF7y9LcXNf5J5Bcb4
d0eMPzO7I992ZsrOxOyJiHpxf08OszcOGqfnRjTMPjgy3y3s38C8Ckckq136
rl0i+2JYczhWWcrsh1eirhzNOsX8KrIbg7oKPmP2x/SDYK/UJubXcGHXnW07
EpgDMJ6fkyUcukhei7xlXrNtfczr8Jty7d5Be+ZAeJUGpyUV95HXoznNIBXz
mYPgmOCwyMnyLfl1eLZ2No3YM2+A9nbD6EvzZrIIrrlz6D3PvBG+G0UnruqZ
g/FTsCXzbiBzCOa7AvfrP+glhyJX+GXli0MXyGIciLdtzhezHHBrON3epSZr
gV+eq3GwizlHeRjW2F3iGRb2UB6GFbz9s7/6nKVcgsrUmxdTNF2US/D7gcv5
3tdpPRcOX+dO/+LH/XAMxtWKmuXsvBF45uYXm5f30H7aCLhNT93WZbD/EYlK
gz55YCVZGwl+8TclgQOsH4XdGZ/fv285T3kUKqqkfU5qdv5opM0PF+0Tsv2j
saTEFOAc+xXlUkzI7skW3fqacimMxzP6K4+epDwGDZdVNXn9rZTHwOQp2Ds5
8C7lsXAY39q9M1cntuaxWByuCHTN2G01twleZx7wXRz2Ub4J6eLJZwVZtJ6L
w5nWjvSyUx/T/Dg0v8V3jtpC5uIx5vfpjy7DVZTHw73l4YREUE15AoQvG0/L
21iegI7S8hrtdjIng6JgqaB85BPKZYgetukIER2mXA79rjWTqXXHrIYcupzy
40V7amm9HO2texT1hSVWm+WQPK8RvZD1PvUVEGhWfTTzl8J6HyhQkRYS6hdT
RfdVIChvzk9WZLDarEBy9XrBQHoT3V+JMd1U3MEdjdRXQtoelmpYqae+EsbQ
DzMbs6upr8R7V64uq1JWUD8RXjY3yjLa6qifiAG4bl138hj1E7H01vIbxY41
1H9k7+7Rvz1oHqdCrcnep66F7a/C+Og7c4sfkrUqFOgqvDsttdRX4c8hd2mW
gOZxaugOSWwt9XQ/qFHooVm9M6GF+k/ZrIZj5rnBxAkyl4Q/It9Q9KQYqZ+E
3H9GZqfNrP+UzUlPzuOSnzT+979W4ceV
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzwlIlHkYx/E3p9DWckWiKTOy0GrsWHVqPKacn8d45THjkWU1MVGoaKZi
k+xSDbWym0dluWEuhh1aoqbZYXjkaHk0FGFpY6WbTdiiZaQRtQZtRc8T5Asv
Lx++7/M+/3fhtl1ROywEQYj9cn998mVrOpu29qfOlm96o7BOn1tgN5MtIP+4
aNzRlm2F7TPkxR8s2LZ4Y9603/yxgzwLTW+t1zwdZ8+BleLl7fEJtgMyFMq+
ERPbEXmt/SWL7rAXobjPIke2n+2EfVmRIo0zezEkhT0ZsffbyUvxtmf0t8Qd
bBfk6fYF+cvZy/Fidkp7ynz2SiT9d65mqoTtCq8mmc/VoltkN5Tcu9hW5sp2
xz+tw6+GWm6SpRgZe9ccYGSvggT51yNz2auRsKJGNlrIlkEXPmiUxbM9kKCR
JN7JaiN7oup8c3ZIPNsL87SPpfJOtjcuPF3c7mBgy1ESvLxfrm0lr8FR01jl
5gD2WgQGX/NMX2Eg+6BbnFp6WNJCVkBc3DD0XMEGpGHasXgtWQ+Yj/6+u+l0
M3VfTJg96zoekfW+SMn5eevmzEbqfmi+Md2+7cB16n6oWDnzhHsEd3/YhFqb
nWy4+6PWvihmbv4V6gE4m3RMZfIg6wPgtinxoan7MnUlQm6O+ej+ukRdica4
XNGSXWQhEKUFwr/TnnEPhLYrpaztzzrqQYj721tcvZO/H4T3ds9HKpdwD0aV
Y2+jSw5ZH4xTotj1nRPcQ1D/Ir3c+z2dR//Fw2VPMp7x+UIxVJMgsZ/BPRS9
H4TB3CY+3zocudXw7qpVLfV1qBbVSAbE3MNQJxTq7ZW8PwySnfcOPRqg94Vw
SNMeY1Yy/184ehZYmp/s5R6Bra6WJ5N9qqlHYIpNloOujnskNmxJK5qt4/2R
uD966Bf3TN6vgptztzK5gjpUsHM+khd3rYreV8G4R9fvG0LfN6iQ6qeuvGt9
kebV6Gy4nWnsoA41zmQNGh+85nk1jml6u3o8Kmheja7U2mzRp5M0H4XyU1H1
4vrTNB8Fjdf/5X2W5TQ/yYZJFqKxcaBUNsfpPM1HI6k6Q9R7kPbpo7Fh4R/z
fpVSN0RDU3Ci3iWJ52N+NGIm7Y/BsoLhCcts/v9JXYj97s8WqLce
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10AtIU2EYxvG5lGoqWklqmVlYWdjUmdV0bs888zKnc1lENCipRMzMQtJK
k4mpIDMNBJUa0QUVo4tdll28ZGmNylpUs5bdSCGjnOaN2rDC7z1wOPz4f+c9
L2fZrpzUdD6Px1P8u/8/6fK0nD8QLXjUMSObLGpMcPuHM5mHO884rsyFPAcV
F/zt1rlkT2QsHDuXyid7QT5sL9SO9jD7wOybc3TkIdkPmS/C+M0t5AC0tVwR
WxrJyzFx0CKYVUoOhF4iFjkqySvBn98w+XMPOQiSXaOqKY68BhZl6VpbXzdz
MJ4avnmlZpGF8KhPa3JEkUNhcK2N0f58yByGB47+ifEPZBEkOz9ePFdADkeI
olu+wJO8DqHbLn3V/HrAHIEdXcnmoQPk9VDqT9qaVF3MG9CXkBcR6bjPvBHV
1pD8rTfJYvT3vg8v0ZIj8SS/N+55ITkK1op5ttWVZAmqs9t7yvTkaKTW3nXa
PtjJLIWwuMdXFUldBmn0sWW2pbQP8Lom1j3LzqwD6sUu1X736Lwcp1cU+T9u
pC6H3S3UtuII9RhwrUaP3YnUY3D2uG1lmoHmc/ii/V3r3kCdg2vv0PfyUuoK
/BBy/KktbJ5Ogd55RlmuhfaPxZ7RVR2y9HbWY7FkdrdPV1Eb63GQl2RYhf7M
ujgMiN+O35k0sh4Pri7TJM25yXo8FFczOwK+3WA9AauCD+nnNLPzugRIX3Ej
gi52nqdEvFJn+Ox8nXUlcr18pwODrrGeCNGbJO/Te5l1iVD7N+zvu8/O81T4
E3I5cEDLvqdTYZO5Jdt6mOYnYUuVSfLKSPslQWBKS3ZrpZ6MipoTXpok6skY
cTLkFZhpfzXUUu827wH6vhqLffq3PxXRfilomn6sDntE+6fgzLvh/E92el+D
waqEYvkpNh8alE/EXvcz0f/QYGudc/BLdeuMOzXo7Ny3aHPNrY6/7e9efg==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zwlYDHgfB/DZoiS5NncxQ6oNbYnK/U013ek+qTmbKcq19HaaUPuuVbta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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10Ak01ekfBvBbiYyrpomoSd1hLGkZ2VomPCNLm3KvnXD3e9V0KEl7t/Bv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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tIU3EYx/HTMC+tbOAqu2E2MTdF1FKnbe43L3OahZRODFFUFILKC5u2
F6tByGJdGGQSlSheohcp1gu7rJzTafbC7qErgrIhFYNmauhQVtH/KdiBw+HD
l+c8/39kVd3hGh7Hcem/3z9fegRT3fXydU9sf+VRdLVrTl0OIXPwTs5dmFxD
DsaeW0VubnWcWYDWqtVYcSB1IT5NHc/2zFMPx9WFIafERd6BvtuVBvUweRdE
us4BSyd5N7LuLSxpLpKjELS+aIV/jhyNl6JQvqCYHIOlDbXShnCyBIFBeUei
3GPMcSh8f6ywxE6Ox8qE42SAmZwAkaU3vtpETsRKSk2EPpychOfnt3t5Zx3M
e6GXjie16Mn7cFAw8aytlpyM0bJZZ9prcgoKCrtkAa3kVGglvo52OVmKV7jW
L/aNMqdBtM279YuMnA5+aMZ1188R5v34Ec0hv4K6DEcbrS6DiSzHlTDXzLdZ
O3MGXpQlWHVtZAWCwyK/89JpP7BWLFnUKdm8ERg7MT09Y6B9StR1L0829bB5
oxIzvXXNyjePWM9E5U65pb5pmPVM2Ob4JdFxzFwWNjcUhIR2DLGehcQujU3R
Rz0bpaZBc/kh2p+NyHaNUFNK98mBPubmZ62P/p+D07bmcue/+6lgySlObjGz
8xpVaNyiGayaf8x6Lpa1ER+GzTSfi4q0Duemd1bW1TDH2oUj1Q9ZV8MxkLqx
aZHm8/DxUl/KVy27rzEP7vtvM++qHrCejzPKfs+Np3dY9zN3wK/7mSvw6//9
C9gCKVg=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0gsslWEcx/F3GqJax2hh1rCjo5LOOUTK5ed+HHeTsWaNzWK0MLmM2dtl
GbU2ZSJE2VqJ0twvuRydk40jMoQu2Fk02rCionWZ599W7/bu3Wff93med8/z
WsSeC4vT4jjO+/f950mXYKI62UX/RfeWlt0kD9U7C3TIHBYiHkemfVYxb4f9
64LMpA2yAClWWgOiVbIRljQJoq4PZGNomSrNcjRkMyh0RCWJw2RztDVrr14r
IVtiXJ2jDufJQhxqqoywPUveD8eRyryiULI1smZMu1Su5IO4pGht0+iSbTBq
LVS3dyiZbRFdOi10PkkWI7zK/3SONlkClV5Fcf/T58xSZA0ulM1+6WO2w/o4
3/oxn2yPjuvZApGYfBQtKuFKZyDZAdMyx9B7WWRHiIQ/8+bGFczHMPlj0uqM
O9kJJXtrqnKLepmPw2TWSW8mhnwCEWXy3qVosjOGxsYGtI1pvAuSDdfavtpS
dwUSLJNKg8luiDJQDE+k9zAD86nt2yQLz7bMA0/SxcZDVcycO97fTbUZHe5g
3R2x/XWbtX5trHvgQHyt33psI+semArLkVoqmTlPVJuXbMolzax7InsyRnCh
lboXIE7fCC1sZd0L3z33fcosYu9z3lizvqrhDdh6vDc2cp0UMqd21n2QstbQ
oDvWwroPTIrjyl5dZN/L+eLWkStLd87T+r6oX5Eanaqg+WUQJGd4do3Q/DKk
9JWv3R7sZt0PbjdmC6OU7Px4Pyy+lH9TxtP/IUdnbn+p/k1mXo7LFYctfB/R
/vpjV8vy+LtIdj68P0ZLw6PEI9QDUJMmtdhjQfMHQJCmbui1bGI9EHbKDPOp
TNrfQMxNvJUNOdD4IOQnJAY4BtH5BeF+vVf5mwedrAejbr45d4eK9icYUGvt
Dmxk+82FwGYxxm05ghkh/3b+P/eEwFCjySsvZ/NxoX/9C8nsaj8=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVz3lI02EAxvEfZjUPyGyg5qhcotNkTLOZOeeT85hXyPojPMKZGZUdNjWT
oMZEpmMlaNqIpoJJoRY5bWTodLqlGVpKWlBUHhlRlLBo2uwwfN+iF15ePnzf
g9fv0GlZvhPDMOKV+Welw+N5c2G061DfqhZilhRZ5eq/ZuBvsAtPsKhZMEbJ
LtrWU3tAYJsuYTkeErPh2pZrtTC0e2O89Oy3gg+0c3ChKGPd2CT1NgS9GrB0
GKi5ODks/KSqoPZHRvCmNenHqAPgqUhyLC9ZiXkIN2/xarFSB8NcalMVHKQO
Aaf2axU3lJoP9eJIUN4vC7EA4oQfxrKf1KE4XNY70/WaOgyBhYNrbFzqnUhX
O0x29SBxOKY2Xxlm66l3oWhWZqzJpBaiUhw3tXSHOgJBkpzrn8cGiHejotcz
s7LfTByJeZ/s4bS2fuI9mNBzZAE86ihsYAeOFl8zEYswf1Rxfjt6iKOhFdSd
eabrIxYjvWF+x3gk3R8Dz9jLAvNaamBrjzrmZlHvqpWAx4gocVpHzOyFhm8N
tjygfcUjbmGGbno+FsrGjzzVgfukx+LR+xxfeXkn6RJYbm180sntIF0CETRa
ffht0uNwLl/eNNvdTHoc5iZr+iYk7aTHA625Ln66FtLjYbRXzVmkbaQnwPux
i/VLdSvpCfhuf5m7v76R9ETwDKNa/gs96Yk4Lre8WX57iXQpOKIctriniXQp
sqSSqMyndaQn4YbmXf5gRCXpSahtdxqrZzSkJ6N7zo3f4F5PejIWihcVIdnk
PSYFcp+ucauJ3p+CCIepJH5GR3oqlHmsIXch/X8q1L4jhRXOV0lPQ4Yq9ZR2
iv4/Dcp71Ue8nO+Svu9/K//5NyxuOo0=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90n8s1HEcx/FzSk1sV2IyWnR+1CxUVxeOlzvHOa6V3xMyppUasau0/rgv
oR/WTCLHVMpkbgtRS34ckZC14YxEslGbWpOZ0pRqPu++22ffPfbcPp99vu+v
fWJaaDKfx+N5/13/3vQIRh+clZi+0q9p3ney1iam35zMg2d/+fRHE/JG5Gnt
Z4Xfe5gFONNUu137ibwVZjc0qedmyNZoNLkoevuNbIsVL4u+wn7yDlgOJ2xK
ayI7wK1T+NuslCyEdU51lV0S2QnmF9bf9TAmu0DdbHfzw9xL5t0IG/Ku+/Xf
ruBPpb0bfk3eg6ICh8+VCrI70i1KTnBSsgcauRRHFwvyXlR6Lf8YMCbvw/HM
ihhusJt5P0pCVZw8kSxCDXevviWCfABKtesuj/Eu5oM4WdczVGlFXQybybRc
WTf1Q6gonI1Xt71g9oShbmy6KprshfeauUtOYWRvVBiVdlxZ7WSWYNDjzdR4
FtkHQs2IjaeO7Av/qOWUdbMdzEDCtdhtouq2NXOAIcE0XZrFzPND4jPNltaI
Ztb9cBljhqTiJ6xLIc/QHL7u3MC6FOZHFRJZzmPWZViK/+koetTEugzWxaeV
Ud7MPH/cjxs9NX+H7cf5Q1yu0yz10v5yKONmLN0qqMthH+B8tW+lhfUADKTu
dAovYuYC4B6ezI+53cp6INo3HCmI09H9AqEQ3tJmV9P9FeCbbFZ9NWLfk1Mg
8KnYJXWCehD0I+fLOnjUg9C2WlNvsKF5KfE8f3FBp6WuRMPDdCsHHc0nGJET
7aLYPOrBWO3Pzwz7QvMIgateslQmZudxIej1qTtmLaD/TYWMDjdbK78ufa46
224xUoWFIVWiILpP/wetnzD/
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwk0lXkfB/BboWwxUaRlRNuUvNIu6ZslQrbLxbVd97ouamiixDvVVVJM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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90glUzXkfBvA/Dco6IqRBlpJKGZIS7iNR2ve93KVuy5CETEa6sgvZVUOL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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zwk41ekeB/BDyTbFHdEy43YqibrpjlRa5IsU2fedszmHadMilCenUWlv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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQMC1xcX2HId3w/hfbC3nK+xzZ0dxmdwsDES8Wvh
hvE5HAQeuuyp+3MMyhdw6JhuZ2b6CcYXcbgU1HVq/wMYX8KhQUAzP+csjC/j
wBZ1/7z7AhhfwWF+zNSbjxbC+EoOCVznzRoWwfgqDs/Orl0dWQXjqzkwO387
uV4Lxtdw+D7vn869c0ehfC2H90YmE1jqYHwdh82MBy6YGsP4eg7MRQa89SIw
voHDJi6+39KHj0D5hg6Pq16ecp0B4xs5fFJbtyfp/2Eo39jB+esmNbF+GN/E
4dabeQrujTC+qcOPGB0DhiIY38xBWHdrt/dCGN/c4fmvO0uKhGHmWzi84lu9
yz0AJm/p8F2bYfLCykNQvpXD1Py6xj71g1C+tYPXNv2M8pgDUL6Ng6zys3UP
fu2D8m0d5h1UnNg+B8a3c2B3/hbK2bUfyrd3SJvxadn8DzD9Dg43vB+2sMyB
mt/g4PArvOgKm/teqLyjg4DDEzvTYCi/wdGBg6t2h/damLyTwwI2Jc6cRVD7
Gpwc0qWmGV7/swcq7+yQZRTCNfsw1L4GZwd9yejtRxxh/nFxmFz88SHPO6j7
GlwclsaqPG1+D3O/q0Ndkc+9Z9th+l0darUq/PkcYeHl5rC9Y+XhQ0rQ+Gxw
c9itJ12/Re/w/mbtXOaJT9wcPl3yTRKIOLkfAGg16+U=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxFkglYjHkcx1+zadvSym1bHXYVGyrrnhp9K5WiY66ao6ZXjpZ1tuRhYyce
pUYluqNkEVGUaLabVilX5HweOVqsdj2REGrX7j7z+z87zzPPPJ/nM5/39z/e
sRGrJUsEHMcl/vv975d9LG7/vEZk2lRnoJduAo8k234LxhwO11R7ZQ9ibIIt
TY+9VnOMLeCk5XODuhuJh8OlP/bvGV2MR2PFxrf9/e2Mx+D4fNdj1rWMbaHO
EcUlnWH8FSTj9h03jmI8DtU1ZottFjK2x1xJwbzV3ownICtqjpP++XliB4yx
bUve/JLxJJR9vrlw+yXGjtjtVBt1KZuxM0wfDk/eO5DxFAwbuez+q4u/En+L
HcYFjV2hjKeiMOtohkDIeBqi7w/pNWlpIJ6Ovk+Nro1XM56BKPX0DsVgxjNx
8MJ62aCAc8Sz8HyA8P2SaWeJZ8OtZ3ruwMx6YiFkGcuWd0fXEbugcUbbhPOV
NcSumKwvPnAgp5pYhMizd18/L6oinoOMskf6ji7GbjBPdVNLljMGfKRbc2OS
qNcCMvHY6kB35t2hsrzO243Tk3dH53UbXatpBXkPVKx5/FO4oJy8B96mn+pO
HkvMeWJAhKXD6aJS8p64MzgkuLq+jPxcjPDJy3TcSqydC2GNOM+eP0neC8/2
6tTS3mPkvTB/VIH55r8KyXtjdFpM3aamg+S9YW3kvmBJ5CHyPogYY7pS2nqY
vA9qe/Inb2k4QH4eCgS/vRhygfXzcDfTK0Foznpf2CeZPb90cj95XzRmH+m8
U5pJ3g/y7OQkrx3Z5P0wK23eF3+k7SE/HwERPRb6Venk58Olx6Z4omov+QVo
V1yotS7fR/5ffjbi6+PTC8j7Y7CNJPSoA1ufPw4JrU647CfmAlDYNnKbyo/5
AJg6XT0fNoL2ywWi9+nGD1FmzAeivytcMVbG+iCscDwn96/INzCCMMhxal7x
yRz6fxC+LzzYPKeS9lcfhFqPpRNvaIk5MRY9mpT40SqNejHiFSFZMdNSqRfj
qfpse5BHAvViJLTN3iA6HU29BBWaZ9VJLlrqJVhzol7St5BYK0H8uMTcgFE7
qZfA9XGS0Ytf6Lw4KToCBZvMs+k8IQU00etnXt5NvRRD5QXdDybEUS/FtZba
L1dfYvNlWGl73mG2cAn1MgR1PfIu4JZSL8Opq5aDtlT8QL0MbjNzuJih66iX
40q6seCqscbN0MuxYbxG2Cw3NrBWjtbC5tRcGZsvR3CZSPfyxDbqg6EUx6Ws
rVtP84Nh9UTreit8K80PxvLIroabt+KpD4aD7seHi3bQ+XIh6Gozcf+smfaL
EHTwPdfbi7dTH4IY62RdhNEu6kMwLW5lp6knez8VGGnSxj+wi6VeAfHjq/1e
U2h9WgX8dKqnvnwi9QoUX9l1e7EZ3QenRA1/r/U7XzofKNEzLLRo1US6D60S
+UElduV8FvVK3C/Wlf5ZRe8bp0LUjSEpXWtzqVeh756w9Mk3GdSrcOhVS2yK
ktZbr4JV4O6WbV5s/2o4+d9aVyVSU69GZKtxwuUJa+j81Zg8+BPBGEmqgevV
6Oms1gQrEwzMhWJDeslNZ/4I3V8oVNZ5jjmxJdSHImt7R/7l+FPUh+JlU8bw
exbEXBicN0h3WtmXUR+GiBSd/wc5sTYMviF2+pbEY9SHIf+NSYRywSZavwai
3Z7Ly5/soV6D6Lci44ot+dRr8LtLbs8BH3o/6zW42BCp/+h+lOaHIyDPyLPR
OZP6cDT6Kceb7Wfzw9H82qxR+Kac5odjhKx0WFEfWz+Py023+jgL8rY8xCs6
K93rztDzeGS+093sfa83MM8jP6myTVpSTc/nIT9iaX70TK2B9/MQOLnWvnM6
S/N4nBkaa3mq/ZyBH/LY5mwrTO2up/kLIS6rep3f20Dz/+d/AF+FukE=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zg1UzPkex/F/G6valqKuxaK0WJ2yRMpTfaaSCj03kx5npqaZKFuHEirT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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0GtIk1Ecx/HH0kgltSWh0pYNs5UlmnPLOedvOi8VYhikMljmpgNHLooh
JtSGZfTCUrpN2kAnldAFEZlOazqvjcpgWUvI9IUgCVYkZlhEheffCw88HD58
z41nV7mxqGIDx3HSv9+/mUaEv/1MRsj4wJq+ZnpSmkIfbyFzsCWcS5sPJm/G
t5XTgrLVMeYIdF+WyUO/kCNxvWLU6p0mR0F0q3jxTQ95B+au+r2ednIskrKL
Ly3XkoUYl3w3WFTkOITfOKDgRZPjEXAyTrHiG2UWoaZljJ/bSN6Hxt9zk7UJ
5P0odW2Vf54eYU6E8V3SvTo3OQnWE0Jf0R1yMtQNfJtdRj6I1PLSek0BOQXc
fKWrciNZDFmCw97dN8yciuRNYz6nkizBB32wxVg4xCyFZkawPajLw3wIwh/D
AUEN5DR0FCKyt2qQWYamOv1emcnNnA7/67mHv5b6mOW4fb7hirCynzkD1d1q
0aOdtF4Bi3q2YF5M52fCYfIVH/fT+YBad1M1pWE2A4G8/PCYqGesK8F3vm+9
5nWxroR2cHEyxUT3Z2FmlGd12JnNWfBKNDUv8+g92dAuBTXvLnnKejZKYtoW
PsXS/Spsa75vmOgYYF0FxUTYwk8vvT8HI06xoSOa2ZyD5YFjfXs89H9z8ZHT
TUlme1jPRfypsABteifreehvdRk6nV2s56HXlRjzouou6/kQuN8Grl7QZa71
fLwasoSkSVtYP4x6+cXqoudP2P515o5g/OyDMr3exvo6c0f/+w/hKBHR
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0G9I00Ecx/FfJlQ6aIspiiusNC0s/7RZrbZ9dM6ZggwL9FlpzTlLF9sC
a0qzITmLyEUpFKSUkTOttphRuVrpJJNBDZIsSp8sYsgqyeYjK7ovgQfH8eJ9
8D1uY42hQhvDcZz4z/570uJP3Twhixt/9k/fFOfrlrKO8MgcTIvnJEMC8mqM
z9abI7FkPg7KxuRno35mIbRNcZxygZwElyyxvHqGLMLxO+HLnn5yKoKLnZH5
G+RNeGSoik/qJqchx1vetaGLvAWirybZtQvkTISsMY5sPXkbihNsLhGfnIWE
uiWDLDLGvAM6u6Rk8wQ5B4m1mrWxPnIuwo7cV2Y7OQ/eQHzKnIe8E4LsS16D
hSyGpl7tqJ0YZZbAoz/zxjD9kjkfrz8+X7lGTn0XSheC7aFG6rvhlEelzaXk
PRjuOdmvMZGlqPxizJi2kvdCVZ3++dD2F8z7MMk5G9LayDKMNB1WhZR0X44D
Db0S1zB1BX6GO77fzvMxA08GbSsq9MxWoDv6YX3UTb0AWyuvCJ9WPWa9AFc/
/cjkzT1kvRAtulNvLS0DrBdCMXL6vbFziHUlLvpatcagi3UlBvzNgwH3fdaL
EPh165iu7wHrRRD7bf5ZUR/rKlyfzFiXOuVkXQXNvVU97ea7rBdjNDl9/l0Z
zS+GpVUnSG6k96kh7LBbPTNu1tVIkfKsxhqaX4J8U1nbUR77L+syc/uX9f/+
DRaAApc=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdznlI02Ecx/HfDEJMSIdI09SUsFDxzk1N99nmuXmgSVoRYbLQImaZBxk2
Uks7PMssTCxRscO71DxmXkH2R4i5cKYNqWWoK9IgMqjo+0T4wJeHF++Hh6/j
UVW80oTjOPHv+XOzY6GtTw8ye675q89iA9/WXvbPHFYnclsrNzObotkuQZjA
MVugZuGmw5m1cbIVVOrzAnMD8zaUrAt5gtfM2/GqyHIwfYx5BzI9hooVLcxO
ULW72Q2XM+9E/uKM4kskszMCpUkTwX7MuyGKk2dpbZldID2SMVuoGyO74URp
2Pu+CmZ3eFuNa9drmT1h2CS6rRtg9sLD+RFlhzuzN443mE290I6SfTAZ1FOl
i2P2hU3eS15i7Qh5D742SEbDo5j90Fo9LXoyPkwWwljiORN7n1mEmcGLBUrj
M7I/Un8IOlP0zAHIn7Cpu5LCHIikB8KqyZgh8l5IkspcJg9qyEE4XOGBiKUB
cjDuzk1P8XOYxbju7jXn+v0pGRBw2cWyeLIaSM6Wp5VrWJegcuXCjQJRL3UJ
Umdgcaiwm7oUwpFQ/adVslqK5aKf+01NeqjLkJtm7+9kJKtl6LZs9eX3sR4C
k29njV6g/dQh8FAutdxZ7KMeirYDgoF5I/s/FFOO+/Iyrfuph6FS87F97XI7
9TD0x4xlqNLaqIdDXg2XY2Vd1MOR0WSeuMu1k3oEFIZlnr/sMfUIGIY/5Fwz
0HsuEkOpDrGnAzqobzAn39DluLXSpu+1pn04Bcr/t1qB5Pparukq61FY893q
907/iHoU5Oq6U41ezdSjYR/75u0sv4Z6NITWkT5jwnrqMfDLutftLCKrY7DA
U14q3dJIPRbi8XM6/5Ndml+5gj6K
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQtUzHkfx/GxWLd9Vsmly1pJJ6QQKop8Skr3qalpuk8z08xEQogum79b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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzH8s1HEcx/Fv2kyU+bUVU5IjPy5Dfoa8uPPrnB9pWdRWq5lGhMiPm2WK
NWs6ya9hrHMLZbtadoernFJ+dPQLu7YLyzVplT+kk6Saz8fmPttnnz32/Lzf
tmcuxCfrMQwT+u/+f+kxmRRlBhq+eLKuhSAhK8Sxczs1A/vsFs57fWoDyBzq
htQb3QRss22DW9aeE1vgq0Lg0byN9l1IFYW0vFyh3RqKGoFF7x/qvTA9K/Gd
WqDeBy9hzqh4jJqFtRvVfp8k1A4wb3SwkeZQOyLLeKn9nDe1MwqH3+it7qBm
4557/4hWM0DsijZFGXdogtoNU+KtF2PmqN0RYVwbw2HovAdepZzmC97RfhC3
zJrG1bPUnuC8bVh6/ZvaC5OeKq2wkdobLOlSiTCb2gez3sdya9OpfWE+nVBm
k/+M2A87FwvV7oa0H8KPxWRpwBjt/rC6WyPjlfYTB2CmSFrRtUodiI+Gl41M
5hTEh1FaOfktraSPOAgjznYStugxMTDZaimXzPSuuxjIsK+673Kyh/RgVGQs
y+d3d5EeDM0HjUGWDzETAmXewgHruG7SQ1BWdaI8L1FKOge2Cn12EZfsK+Yg
96ZMo+6Qkc6FNt9AjnK6nwuZampmpOAh6aFIMOPVpJx/QHooxGqfPflO7aSH
gdf31LL92m3Sw3D0s/53ZWYb6eEwCr1+6ZRSRHo46h4tr/zi0/kIlPcirSux
ifQIVFrVi/3K7pAeCSWr/nh9divpkVB/SdckddP9PAi0g8Pz8R2k86D52Zm2
zEhIj8KYaY6t3X4x6VEY74stSHVvJp0P22YvN/YAnefDiV9dpGooJz0a05vm
oyG/4i+d6C0lPQY9LpYqvrInaL3rmInV6Tpm4mAkHk1y1HavG3Hwc3M1VF2V
k/9xm//36Zg5suG/aeRidA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91As0lHkfB/AJNbGUQlHt7sgtupFtJ8nrK7dl3O8yxhhmjCLdU201TfFS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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90gs01Hkfx/HpRq2KLrroNsRu20Xl9pTIJ0aUiGHIuM2MGWTj0VNsbdE8
tYqOsLpJ2iYtuVRaLUUr49IoiWLlbqkN6ZRsbJYuT3v6/p45Z86c1/nM+/89
Z87oSv7Nl43lcDj3Pr3/+WQvrcaLYZZfVJZ81murCJ4Nr2kqMwc8O3+nMf/3
RIyP6M+LV2PWQvjRWIdvJzPPRGSdp7r+3yryHJS0al6KrWeeD1VGdGxjMTMX
yZbiZzuOMetBEbQ0qfYAsz5ORFWKb0Yyf4n2F4bqJw4zL4Fzpu7B5JnMS7Es
NiVV8O4OeTk8azpmJCcwG6LlO+EfwULmVRBrhwx0KivIq1HD0997X85shLX5
mu8rU8vJxsgtn+NipsVsgtQfjrXsUZWRTTGgCmkXxDOb4c73byyHB0vJ/0Lw
suPcKb3Ma6Czw6A6uJZ5LbZbpEVlRyjJ5sgp3tH+8izzOvTXNc2Ozb9NtsCP
c3vF/CVst4RJYrSJ7EwJeT08tU/HW5f9SrZC8SSzQrvVt8gAryLde9UWshyI
v3/76MLVRbRvwOjHmm8vhd2gfQOaR78Sl84ic6wx+Dbb/v7sX2i3hk33hecj
h/Jot4G1d/mSvrZc2m2gMbtH6wEvi3Yehjflz9ick0M7D8F97XlJz1Npt8Xh
NJX7n4bnabeFh/3K8Qa1MbRvRGWDTnfgcyHtG9H44OKbzA6B1efdDk5m8hf2
lomfLbdDg2LA4mPOadrtEblzMtdp6Djt9sjIcu7XCz1L+ya0d8mthioyad8E
WanfWLXCn2jfDP7Vk7cL47Jp34xatWn2D1N+pt0B1YEaJfLaPNodoKN+e+f4
/uu0b4HRGnFOisNN2rdgUCiv+rmphHZHTKt0NJasK6XdEWPi1D+2cMtod0LR
tfy3dvvLaXdCT0/YSNMMMmcrbP3f179Rr6B9K65eibEYmqui3RkL3bxXFCZX
fjacseJlQWT0KbLcGTNq1hwN59/9bKUzTG6Z5RruJ3NccGpx/yVhBxkueKua
q590hSx3QUqzvmFdCutd8HzKEmVVEev5yB7xsvItZD0fa9edyLh+oYp6Po53
qLRPKclKPoyl1boOvfepd0VEy9KHceEPqHfFbpsatVx5DfWumBz56ssn9bXU
uyK2Pj2j1vgh9W7wa8nf27HpEfVuKMq47ClJJsvd0L6hybTgKVnp9un/VZCj
0UDmCOC3PPPgbkfWC3B33ncf8meyXoCk6/KNx9nzlQLIjpyffrGE9e749Jvr
rItkvTvKvA2/8TvMencU5DiPS0Ud9e4Yd10qKw0gczwwOj3tcGkBGR4wb7uk
GTlMlnugbbmT9rnfWO+BXUW8bVNW11O/DZavjX/gx5CxDX1Go7er35Dl2xBX
EHfZV/gb9duwe8eZ4APpZI4nouse9Y7rJ8MTKzWbRwYGyXJPaFmsUVgfb6De
E+K1C672fP2YeiG2Ov8ZLvQiQwiNkXd1rv8hy4UQhmUsEu4jK4XofLLB6sIf
rPfCfw0Sw648Yr0X9tziCNffYb0XKpyqp5s/Yb0XRu8UveqtYL03hqLcYjJ0
Gqn3hmNX1BPTCLLcGx0beaf1VGSlN0L3uprz2sgcH0hu5r37ZlYT9T5YKNXb
t9OHLPfBF1OSq2I8yUofNJ0Kye2zJHN88eCm5Y19xqz3RZ37WvXRMNb74pzu
V4tr81jvi9n71RZeTGW9Hw4u6Iv4kMR6P8Rp6uzjJ7PeD9Vq1W3Gd1jvh0Yu
VO83N1MvgmOv2sjXkWSuCD4ZWtluB8gQITjLtP+aLVkkQrRzuENNKFkuQvEK
7Qzf/WSFCC5B5V3PyslKEWzVx1s6tJE7ReieEaLhV8zuiyHf35qQksbui/E6
4vGyOS/YfTH2lKbqtDxn9z958pBjs3oL3Rfj7qFd0uJFZIUYFVMNJsYvICvF
MJ3gIbK0I3eKYdicoKhKJ3MkOPCse1DQRuZKMBh26FhWNxkSnLJrfJlwhSyS
YH5mYvrpKnZfgu9f5FUmNLH7Epy5nJq/b0Ir3Zcg4/dQXUd/cqcEOxp0X888
Q+b4IyRuY5magsz1x6Ehv7/FfWT4495ULVOtAbLIH63T8vYos9vovj/qf3xv
EpVPVvjjBjdcclpAVvrjg3vmUycuudMfPe8tfaY9ZfelcE4S5O7sYPelMH5Z
pjc0wu5LsTnx+qYSM+pFUqwpj0urm8fuS7HPLvGkvgG7L4XD9qzZeUfYfSmi
B9JWHha3030pVuq0eYTMJ3NkODOmaM+5aDJXhrzKpw532fchw+BEp1cffyWL
ZIielO/XEUqWy/CwVKr++CxZIYOG7dCRrrdkpQwLJ9ua/2TYQfdlWKUaDuPP
IXMCMCiwPrB+ApkbALUonsvHODICMNXj6bVddWRRAIYjhYOy0N/pfgDSx+5V
BCaSFQEYm27lauFAVgYg6mbr3ioluTMA2lcL01sbyJxAHFlmnPNgUifdD0Rh
B2/n6HoyApGlZyK6Z0QWBSKmx6hh+CRZHojXizTncJZ20f1A1CqWjE1YQFYG
QnE+fvFjIbkzEKpfdg0fSiNzguDa8leYQTaZG4QXgpBgZR8ZQWgTtjp0j3lC
94Pw0vaqduYF2uVBSIqdF9QYze4Hgd9qozvlMrsfBPO/tljNimX3g2B86VzS
6hvs/nY4JhklzXzUZfU/980GgA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90gtIU1Ecx/FZISJUMwtbCNryETLUWVNXzv2m292oltJLaYTgnIFhxaWQ
JdRgODKjXBSZhbYpzZJEKqMsW8xn9FjNKKMXrRa99K6SrQeLiu6/C4fLhy//
w4FzFlfuWGeaIRAIcv6sv3/6hI87dipiR93/FFTujlwL6GeTBTib8Sxo/99j
4Dx5fG5JaIS3EJt0Yv9YgDwfVS0b81oekBeC9Somv3nIieDa571tc5GTUXVi
4nS4iSyGPylzPLqRnILr4VDtIyM5DfWGAwtkBeSlGBaDdceQMxDXcPd7/Y1h
3hKI+rbmM6nkTMTp5YckD4d4Z+NozVSq00GWoued87x2gJwDT80pxjZIXoby
yGVJWR15OWa22xUeGe0vA7NL3le6n5yLXv3Pr9ti6Xx56AoNxGs3UM+HMMqq
NL+i/eTovX3njaOTvALTH16sltoGea9Ea8+eeG3Qw7sARp/YapZSVyC0Zf39
ppvUC5Es0jWsYakrUcua9nGdZCAg+cyZ7bwtQOT9LNeon7oKPxKyyurWUlch
hQtzURz1ItgOTm/XuKgXYfLqHF30Kjp/MXwXzmR15/K2FKPVa0hvjNC8GsFz
ha+PVdO8GqVDxqeJJprX4Elac//hjzSvwaKXHKu5Qu+RgfdIxcW9Rt4WBp+y
m+8ltFHXYrNhxLGkmua1EF1CUpea7kOHKbuqn/k15rZWTIw/T9fhi09fKSy/
5f4NHdgJMA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntQlFUYx/FXTdgCkpSSm1DIVRxucl1k+aHI/bIs7O5kOYiEBjS0jsqI
11cdFGQYjUlgcEXjFoiuiixFCLtcNjAZXUmixqUkkj9sI1MiEZBses4ftTM7
O5/5nue8590572z7WJK1mOO49Jfff37Zx3KkVhH2Wr/mXz0OP3k6wDffjJkD
l9g2P2XKLID1dIlRKWC2RLy5U6klx2yFLT+qK9pnviZb4zd5ncueSWZ7mKtM
8w3jzG/Ded5ifKKF2Qm6vv6xVWeYneF5fvdOjy3MrjjW6L3vCyGzO2azECQ3
YV4DfdWtb/L+0pHXwqVrVhp2kNkLUYUJWtFyZh8EvmJfoB7sI/vi5677dtIy
Zj/U2+QsuSdmXof3uibMLpsw+0M0Pq0aHuslB0C02UET/CpzICIndW2z+3vI
QXi9aNj7gZo5GPo4F2N5CnMI/PyN9hNgFsLu6O377iXd5FDo2q0mdixoyOtx
0iExJrmYOQyLCpaK/6xnFiFpKCijZ5+WHI71Uwuje99gBhxns6MfnKX1PGD9
gcOxnY6d1COw1Njh4f0h6xG43nRuIDeL7b8BlR1F3PkcWs9vQGBGfXRvbQf1
jWip+8itKrKd+kb0JOVMDz9rpR4Jt1/2T408+ZJ6JEwVix/VPG2jvglvwijs
rv6K+iZs2+5zKf+7FupReNix6HB25CXqUagULQk2Zl6kHo0f7lz0Kh9ooh4N
172dZ/JmPqMegwO2Nzt9hI3UY3C1riHs94V66rE41OWlcRV8Tj0Wl7sXypxr
2HwcrI+kqucNtdTjEFptRJl5HfV45CpXwC+xhno8JhXvn7LIZfMJ+HR1q8I2
ls0nYG7r6RLfO1eoJyJ7KEOcbsXOl4hb8lHVr2YN1JPwLPbKuz89p/34JNxY
uX3PNRHbPxmHHo2EKhsvUE/G07iEDE9BNXUxKgbCVZWbaT3E6K/1UBS40f68
GAcGb65ML6X/VyvGapXBtMy+meZToOHdR0sD6bxIwWjRQ0u/Oep8Chq+1xV9
cpysTYHkrRc5y/5g7yfB87WtCWaZV2legsYgrV7lSeYlkCkdCt3y2Lzkv8/j
UvEiZM6mUH6N5lNhMiYwaVPS/eJfdn/jrrMlappPRXbvyJrbzddpPu1/509D
euuKCkMMmU+DPPNJnt6OrE3DQSebe8Un6HycFDmlipitFSqalyLg27vLD/eR
eSkEvqsG+vS0XitF0+Djo1K2HyfDjN+OZVZx7P1lqA9zOyIS0v3mZdiddndE
Gk/n1cpw6sSwaJcju/9yFBvGbtSIqUOOddVDnuVVZF6OCFuPZouQFs3fDYrp
OA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11Hs0lXseBvA3ERHJSSWpXZPofqHoOPK4JZT7LcS22XubZHdxK3LaqSbi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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0H8s1HEcx/FDfgxtSrsZNf0Uaihxftzxco7jcHcpkj9yWDUmnCgKXUvT
hq0simzGoRJ1mORHwpFsrVkqSrG2bJRSrlna+rk+71r33T777rHnPt/P+/vZ
kJAWedCQw+GIfq3fb3qsxtXpAvPhe3/00V8Qa8+t/GsO+mtyE0INyGZIM7Ko
gynZCiZNJX0muvvMazAe/Gg5bo5sg+TLZQH8afJaGAilc4kvyevRHlmx94CW
vBHuY4s/TlaSN6O9x/LVUhbZARNxiuURH7IjVmz9pCuSk51xY34pPuzrEPN2
lNeqHw9UkV1gZNQc+7Cc7IaYJ7zbiijyDqToSs9llwwy74SRk+StaxXZHSXV
hTXP08m74Fq3YGC2juwBa42HSHNBy+yJ/DFtd9Z+Mg/K6vI2l4YBZi8kBTUU
F5aRvdE4VZhh7E/2waZBwc193mRfBMreGPZzyXwkJ6m3pZv0MwsQVTQ1u9q6
j9kPLb5fzs/YkP3BVzR29WaTgYunzmZOSJlVgKIwPi/KjnoA2uRPF3Je9LIe
AOnQh6mCq3dZF6KruHbSqaObdSHMU1MXPcWdrAdiQpqTr3zWxXogAnN9BIaT
1EVY6LCT+pUyq0RoynDkF+RRD8J8hny3xTv6fhC0h6J7rzfT+cGw7Dkzc2SS
5guGA8/WapU7zS+GBV9nGnOJ/k+MpiJvt1Eu3VcINKOVpz+PMKtCYJvZYhk/
Sz0UJxLVPS0ptD8UnSITpUTAzuNIIPvuPF5/lOaTQJ48Mu01eIf1MHDtDaNN
1e2shyHr260HFT0a1sNx2LglruNYM+vh4ByfeC+uq2c9AnskK2s8pQ2sR+BK
93CnWHmNden/VumZI9PrMrzmbWkNE7ayLv/f0LNKz33//BNGRlfC
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzHtI01EYxvGfVmKu2RKRshjarJZbMS3vLh+3uWlS0dU/CjPDzKSLZFG0
aLlylC0JtaCoYc5gzLByhTV1rrRCwaIRWdEsyMJozkVBzUkXPC+BBw6HD9/D
E1u8f0NJMMdxyX/vv5eO4FXTAXnYE8ekxrJiCprbfDwyh7Ty6rDYYHIoNjUb
ir76HzML8GxCoi36To5EZcs2t6yPPBepQ+pafyt5AUzhluJWPTkGSdaPORIj
eSEihEuBzeQ49FRUjzeIyIsx03XZEJROFiMkTSR2qcnxaGyyx80QkKX4PGAN
d/p7mZfD2fuzQDxMliFFMs0R+YmcgGPZi86a9OREmL+Yrru2klfgfcjt6BFL
D/NKrMsL2FUfyEnw3gj3dCfQ/2SITlcFCs3UU/BNl3GqSPuIORW6CaVs5+hD
5jS8Htj746KUnI76K4G1swrJGbhvqL4axSdnQug1/n73wsksxwi/JuRMA3kV
jtv2/VJbyFlILN3RpxwgA2U8d9fwdsekdYDZfvOaJ5SZy8b0lsGD8zZ2sZ6N
6OQLjefLO1lXoEYUiK9p7GBdgajZT9/ql3SzrsQDm/DokI+6EvLRIxXP89ge
p0Kl87BHuuse6yqYI7JKave0s54DnncL/9ygjfUclJRe0vhOMHNqyLlbY7yy
NtbVqOq0+ute3mFdA0N9v3y+kfY1UCzTu/Mzmblc5M8RVNVpqedid8fJNf1v
2B6XhyD+ofXt43dZn2Ju9ZT+338AJPAQbg==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zmtIE1AYBuBhUXMLNRkaY4RFSMgcNqvNmvo6d7EahRFkJlKCU5ipBGIo
6ZzrArayH0IXayzXD4VWTuY02Zau2U1W4KxGYEUXK6FsqZiXrOh8HTgcHt7v
PedsKKnaXxrF4XCkf/bfk1bci47qTN4D3z9NZX/UXYzRrSFz4H2T2nadT+bi
Wdgy/fm/49Bg/j5XsDDMLMBZi1nlCZHXwVxzKyHaTxbBdtcflgTISZjotNVK
veSNGGu2xBo6yJtwcGrJ+1JFTgZ3T/5kYDV5M67Wd/PO9AWYU3A46/bbhTqy
GLpjarHh131mCSp7hvhPHOQ0THxZNVcsIW+Bx9CYWG71M0sxXCR87JwdYk6H
pOXptPYHeStMBoGxTEjz28Ap0FcKGijfjldrO08/jyfLsNjaO2q7NsgsR0Cp
bxfuImcg1TS/pBu7x7wDsT8jJc3z5J2Q3bFK5TdpXoHCowdc+VHkTEyGVu49
/o3ms5D0QWFP0VOejaLSZO7JI/QfQFQtX67hMxuBhMYT1q8K6ucgPu11kKfx
sTwH7ZftGdbddJ8SKy68V6iqqK/EvnOXHtX1UT8X59PDwooYynMxMpM4IrXT
+yr4ZM7xljCbN6pQ7y5zjLuor0b0TMUhl5LeV6O10BQaXM/M0WAx4m0aEHlY
rsGn2q7gqbZ+lmsRDLkfzt5gNmohXh5wjPa6WJ6Hd+ae4m6um+V5aLpSro/0
O32/ATCpBfg=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zmtIk1Ecx/FHwW50WaTmi6AWsSxkNXfR6TZ/2zOfDXxjlkQRWLGBJawR
64WsYiOxkZQrrVeT7poDKbyUdnt0LmOxbFS0isqZJinVDHF0Majw/A8cDh++
h3P+0v2HKuzpHMcp/u3/Jy1J/KpTv+SxOK/pEjHGNzQvJ3NoD2ycrskiL0I0
sLegfAFZgt9xSZkiNcSciV1jcq9/kpyDCVdHb85b8hqcTo6qxIfkdeBN447C
WvJ6ZIeNujNm8ga0apvVXWvJMliPB11ZS8m5GPSKA5HhR8yb4XBnVMVayHmI
mZznqwWyHLob4dSRmTDzVjQJ6XKdSFYgeKrmMqTkfGSMRy7aZweZlQhZXqa5
hskqtPmFqAdkNWbr/AXuhhCzBvzQYdv9KLkAwbIA/1U2wFyI4oMzjYvfi8xa
XLBXPJW9ecBcBHFOmbJN3WMuxvbnl6Raw11mHYKrylfYrvcx67GSPxbZYSMb
4J1L3/QjQS7Bz7P91mt6MrDn1Zb+ysneeXsAzdG2omc+Zs6I6mSXL3eM3fcY
Eajk8tVPaB4TTnRMtXZ/YfN4TDAn3B8ar9B8PFqimVW1Ar3Po+/bx6TDT/+b
IY8tG9nXdId1MxYmVP72bbdZL4VR87mnObub9VIo9eLNInMP6wLqRl+8dp6k
LmCk/s+57xO3WLcgnheqX/2pk3ULDO9kv3wydp+z4kB0Z9ru4k7xL9pq/F0=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzn1MDHAcx/HT5qKzdkncH3KVy8xIUXeo6z53Pd6TodvMoucUIRVqHd1t
XQ+0EMuY2DpHU1HuKruu67pWsUL/lKjMqFViLs2SMcP6/bL5bd9999p73+3n
nZS5L9WJwWCE/pm/mz720J2TQpcntgXNiILq5rm6RTPQVWG3ti2lXgbN48Tb
TGdqNo7Et2jn5nqIV6Espq/xxKI5kFTkDuRPUq/FL7V/2+wwtReKh3lLahbt
gxxOt7TUQs2D05jv1v4i6g3ge4+cL8ui3oizD53ZI8nUmzD9OeVVhSf1ZhRn
lnp4vOsm9oP7rFLS8ZraH+rCl70padQBcLHGDfRwqbeBm3ox5pKAejuannUq
cqe6iAPRcl8VVXSK9iDEj3PGQoy083HdfNxyQEUtQN4PxxnhcuodGK/6rlYO
dBLvRKfIK85+yE68C8xJhsA5hzoYM5dDgnvl1CHwcVUaIhM6iIXw+6S4dWPa
ShwKeU5aRleJjViEDP3Hhok2amDv4Hq9aohYCxTwp96rze2ki7EmvVyp+dlK
uhis2F6tLoGYIUGfuXC8IJp2CQI0vhODT2kPg9tXlviCzkJ6GGwGW2iVD/1f
OJoqk/KNY7SHw97SPOqpNpIeAZMuiHf4ygPSI+CwHhRopQbSI1G4xy2vkkus
jURwqrjWdI7eR8EM9X49m1gbBRGLl9wsf0R6NJKyRSpRSQPp/5khxRbrvOt8
fz3pUnCPruAnHqshXYabljfuWS+ItTIY0jSnh0vukS7HtbIMT01sHelyfHOs
rk+XNZKugEOW7W/6Uku6AoHPs1vbV1aTroTwg9vdqPJq0UJXgvM2LHMd07hg
xm7omaWjrKsm0v/5N0wyN5Q=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtI01EYx/F/ljRT2NJeRM0yE7GLzm1qls793N/rpkhhERFRiqkMm2k4
L4QzraQU07DIBMkYWTrKF1205SVdMkvMF3MWGd2sqLSWBLlEKzrPi3bgcPjw
5Xk4GzJ0u7LcOI6L+nP/vnRE9qv5ihVDvf/0TakVPHib6EHm8GxN2JUaT7IA
ZT5jjpKFR8wiLHd4147Mklch/9qxTXYreTV2BpvarTfIYvB2waKbieyHidba
5iPNZH98KVLUFGWTAyCcPvR+cR85EMIZiVzkRw7CSylf0Ssmb8ZepQ+fZrcw
b0VLQ6vRepAcgjd7PpUUBJJD4S07t3uge5BZihAPL4OqmCzD5Ys2nXNkgFmO
GN2Z7g9GchgWu55Miu+Rw6HzllvmxsgRmORfLOhPkbdB+/OHRBxEjsS7NGGl
ezV5Oy4srSiWFJJ3IPJ1+WBeMjkKjo+5pue/+pmjsSzksCnN/yGzAsHh3Ghu
IfUY2CacBwpL+5iVGBbOW+2pZCB/na3x+zizARBXbDS2+VKPRd+wryV0pof1
WHz2SjIczTOzrkKV5rpTOk5dhXKtrb7DTPM81mZI1LNfaT+POb31bJ2S/heH
E1mdUwMd1OMg6Itekq2h+XiYb+n8muq6WY9HgKnSFtbexXoCql9N58z3dLKe
gEj9sDHA3MB64v82uJhLculJ4GTm8/rMetaTXXoyTo6PWjLXn2ZdDcPdnNtl
7mWsq132axB633Nqy/Em1jV4qrg0dTOdmUvB/scj6XfcWlhPAe8+OtRf0Mh6
KlZq20ojUNX7Gyp7Lh0=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1yVtIEwAUxvFNjHKYF3RLlqWOzaxFTs1clvnNqdO2NKYl1UulhujoRj0p
piQLvFArlqARigiFRBrL+9S8bFJZ9KIZ2lJWdpEwMxUxqOicAx+HH/+wsxeM
+R4CgSD27/59Pr+JposJImf/fy0kuu9/n9F6swVwVGDbdV/2Jsgjd1Q93sz2
A3RzJ1wCdiA6jEu3GmYd5CDUVv82bR1hB0P2aj2mz8oOxe0a4QuriS2Dyl/a
suE0Ww5l5Z22b9nscMhXDfM6OTsCDtmYPW9phLwLK0Uvh31X2LtxZsa2mHuZ
vQfK6XuDXkFsFQIWo9RrzmFyFMSFnd4BU+xo9Ja31K/lsmMg/DJe/y6MvRer
FSUGmZQdC4+5OPHnWPY+uIOLn69PDpHjMHfcphiVstVYnrqaa9ew98MZfrSi
a2iQHA8rRKf0FvYBLJgHXRI3+yCq/LPfiirZCSjRF4yN9zwjH8Lso50f3JfY
ibCc89H+zOgnA5MWn+Z4M7kMECvEpruf+qhrEJlq/trdaKeuwXR+sWC0tId6
Eq6dVAjXBzqpJ0Gh0beEHOuirkWRtNexFtpNXYvXP26IIqpt1JNhriuVhqva
qSfjzciyZ31mB/UUSNTldlvWU+opaP/lOeCfwT0VW5xXYgpq2qinokC9ZFcK
W6nr0ForzctMJJfpkKPc3rgRD6mnIVCTM+868oB6GuLaJrx8n1ipp8MV9tHy
PquZejrOG+vmIzJvUj+MhmhDWYiksP8PU0gG3A==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0m1IE0Acx/HlIs1UTCaISeUwm1JmZqbm9LcHH+ZTWJRiUKg40UrTyggr
lzqjGWQIRYm+cJTS3HxKtxy6+VC2JiWSSKgTIjSf0iIwlLKi+7/o4Dg+fO8O
Ds47s+B4th2Hw4n8M/+uNFzH1ReFjkOmf1qJKv114Jq3PZkD66Iot2fjFbMD
pgyTZwvXya44H6XTaubIPMhUXR8aZ8ke4KXqO3+Mkb1Q95qXUGEl74b/o+qt
Dd1kPu4vfRKllZN9YCtt6XtXSfZF8UmfHCcxWQClcKbI05nsj9bk6IGx6ZfM
+yBJcVJ1zZEDUD2Vwl8bIwdCnSnUucjJB7HYa7mMYHIQbuXma80xg8yH0Nzt
yTWEDTAHQyrP9jJ39DMfRqDLcpO4lhyCjpHvC8Yq8hGYA+Qbqpo+5lDMp7U1
DWeRw2B2mPc3PiWHI1+gXJUbzcxHscyrnXBpJ0cgKUszGrSD9gthmhAm3pmk
HgnvjdGYjglyFD6/ML3JKCEDo4tJtrb97LwCCDX6Gbib6D4RjO07JbwFE+si
jJQob1vcqYvBL5zeHBJC58VY98xs2ONFXYL0Gb4otqyHdQla7balWe27WZfC
dEnm+H64l3Up3J5zw/UNzJxoPBlye18v0bMeDcHdx3maSGZODIoT1r9p0Ml6
DKT3rqb5FRhYj4VK+0DZL+hgPRYRb09sX1W1sR6H4rwzX4zNLazHQdvrXi6w
6ViXwaQcP3Wj7hnrMtToK4PSq5pZj4ciXcktuk49HvMzP7XHdqlZT0AOz27p
YRb1BFhs8rUJDy3riRhMLYubVWtYT8QF55unP1bQ+5P+tyIJFvuVyIyv9D+T
4XCu3upbwv6XIhm6vVeGtjTqTb8BtoNBSw==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91HtUzOseBvBBtttC2g4pm5G2U8TeKErRU7qpdNdFU03NTDPioB1WuXSm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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zmtI01EYx/E/Zjid1YqZYtFNt7wMs2xp1ubPbbrNLmAUkZhGJVFJXuqN
SHMolL3ImIKWNU1H5TTIyhtsOUbOGSuWlYkkbKXdBuksjGgSFZ2nA4fDh+85
h2f90ZJ9RUEcx0n/7L8nLcG4qVQW5rT9kz9DdExaE/vfHEx7zQ/6+WQe3hQ1
joyHkwWY8OW5hYvJQoxNzfNivg4zR8GVcPFZn5e8Gom5Zeq8UfI6lNt0c2ND
5A0QN8hFxzvIsfhcoQ2obpDFqHUudCvLyXEIjpa57qSSE5DfHC/tCziYJZBM
tuWmechJOPyJy9u9hu4nw+Yf5Ewz1Ddj/9tIj8pB3oJOc3pDYSU5Bc2ZLw82
/hpi3gr3RO1U2QRZilVeR1l+D3kbxoIXIg/oyKmIOiK5b58kp2GJMLrqlp68
HWdy5l8v7Sano63e41n2lLwDI6L295eN5J14JwusXfmc5pPBXtdUPB1ClqPO
MC0paCFngF/B7+BFkIEPFslp2Q/2nx5wfb89u8f8mPVMeF9pvX3LmfWZiDdW
i93tdtYVSCo0+Cx3bawrIHSkdM1cH2RdCWtNjK/ykIV1JT6Onp1zcgOsq2DV
hUp7Jpn1KrQGxd3T/+xnPQthyQvn6hW9rGdh/orT4F/Uw3o2zs+uGL75glmf
jYKrxrmIroesq9EZ7q4qdplZV0NjK/22aSO91+DaSVNi9S4r6xpcKmkSnCpm
83JaKPwhLScGaH4tLvTLR3vLH7GeA25IE/rlidX2Gy0jE/o=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zQlUjXkfB/BHI0QR0vRSSTKFXOpFlPi2aBHtKS23u9bV8loLYVyFkfAi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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10gk0leseBvCv6VCrpAGVSITqlEKFFI8xY8ZM27CxbVtLNNwGmjZNOpVu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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10AtIU1Ecx/EpK7V8DC2wMDWZ2cRiTlM3NX+bOp8FhhhpGprRw9RIUUuD
FQZSaWukGD5SNB+ImVlzc+Z0pgMfYak9NCmTEfgICyshpAed/4XL5cP3nHP/
nN1p2UdOmXM4HMnf99+XHt6bhgvBW4z6/1oNKUlRZYvsyByMvy9YiLclW8K2
/o5dqwWZh59pfclSG/I2ZGaLc/mWZEfsi/zmql8fZnZCce+c7KqR7Iqk8eHH
ExqyG/xFxuaNe2Q+ai5L2nk55D2YHj0uWPMi70VI4uKAZG6I2RPldQ7vPs2T
vTDp1+G+aYm8H9+/XD/bk0kWwsNPf6ZTSPaGs6nQ4tjGc2YRmnzO8337yD64
vVThMWFG633hmiQuyNBSP4Cn8qlFXSPZD9MnHvIKEsn+eMt95VXUSg6ATHuD
16obZBZDmSUQlHuQJai4a9esqiIHwvh5u66o08AcBENtWZdbGzkYNYIP7cIV
8kGIuAEtGiXtD4FJNZPam0AdyB17sR7ezawAHFKvVMkf9bMuxXKxwcxmlFkh
RdnLCvWqu451GWpVJ1cGK9Ssy6C8uaOpkvuE9VB4/pbO97sxK0KxOpLf9rqa
reeEQZplzvVf1rAehpySoNOFm5k54eCbLDfvFHezHo5dXXEl9vHU5bhoNRn6
dZ7No5AjZWQoPX2B5ouAOiPH4CSk8yNg5RwXr3ygZT0SvVNGdXMp7Y9EpXeC
rMb2GetRuJaXPDNr0rMehcBZbXG1/QDr0dCsWTn+OMruVxGNQ/WldS4ddL8x
sN7q0iL8xdYrYtDQaC3Oz6P5YnHp8LmW3DD6fywWhu6P3frYo/8DYLonwQ==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zwlIE1Acx/FhRtOKlDJsSpi3lnmVLZvzp5vuUEsraEVESGaaXZSZmrWh
Q5oF5swUIYiZZdO01EwtdFPLFiVFJGZGCg6lUUshHS076P178Hh8+PKudekn
dmY4cDgcwZ/5d6XhMqw7GeP8rOefrLGeJmu93InMgZmTGbhjEZmLqQW10teB
7ALZcm3MwsxT5lWIrNp3+e17sju4Tp2y7D6yJ04dL8ywqcheGJvyeWL/b2+E
2b4NHZSQfVGmOxbUICL7o76gmbfXkRyIEnvh6OLGAeZgZEYNLPWoJW/AfmX0
rpeZ5I34ZF3PrW7tZw7D9E+/a+fayOEYVK8M8fEkR0BwURRUmt/HHInUGuGL
XhF5E4wX5s8G3CNvxrjmM79SQ45CqEbgtbqcvAXmI9+L1yjIfHhguLN5N3kr
1Fdvt1h+kaMxOG3uOTxL3gabpqihPIQswB6t5s3NICNzDJ6rTLJgnYFZiNAJ
Y1VeLjkWA6czTJnvyEB+Ygq/7BCzEujql99VVVCPw+Py2lR9BTtfGYfKmii9
zp3uj0fCTE66OI16PH608yKvz9F+EYpem2ulCuoi6A2CZVYLdTG43XOl3U3U
xXAez1qi1fayngBViWMr3/CI9QTMmLi8FYqHrCciVz7p/eXGA9YTYcnLCjD5
t7MuQWAH99L283WsS9BivCKxuN5iXQrhqHFSMaZlXQo/94ghmfQO6zLkNBqm
7d4trMvgFjBxQPyqjXU50qS24jO8VtblqLZ9SHVZe5/1JDQZDZYCV/YeZRK+
jui7Zj/S/mTUuann84o6WE+GuWAkWmhn/+GkoK0vvE50lP1XmYLZRrE226On
5zfa7jdI
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxF0WtIk1EYB/A3MTBJXKZhZDXDYumyvF9y7r+b7rUbc30YiSZC9WHkJfc2
sLQRgflhaOIXU6dgXib5wYUG5nBua9KFsmEYeUFBy4rQzCLSoKLz0IHD4cf/
OfA850SXlOVfCOA4LvXP/nvSEk11lsuCx0f/aVW+vHrHPLSdzGFItypzh5CD
8DZ7n8i6gyzC6/2txksB5HDMRzcNuL75mCNx0x9u0H8gR2GiYtE5MUcWY8u6
rtD3kHwA405bR4eLHAP5zy9m4wPyIWh/tGqlZWQJNlx8pSOKHAt+aO+zFzvJ
UlwLPd3cJCHHY7jiTV7gLvIxXF5eqc33P2ZOwFildSCxl5yI2fU1ycmz5CR8
vTgYp+j2Midjec96V+BBcgq4hRXv7D0PcyqG2zxLk4vkNOgdfSZJHDkd3nbx
zPdwcgYKumJ/nRfImdA/8d/gDOTj6K1plNyyk7PQH8nru2xkGTaPZDR3DrqZ
s9E4J37J140xy9HgMN8uMpABW4n9nU/K6i2AseB+Q4+PcgVc1qxc04KL5Qrk
JXuElqujLFeiLiKstG03q7coESIMl7q1rJ5TISWiur/YSPdVUB3+uK1yjfpT
o7CvNmxKQrkaLZNnnlbNO1mugaj+1UhmzSOWa9CiTvfqgkdYnoPPSvv0czGz
JQdhpqqk6+XUfy7M0zPnFNnsfyy52DTGhJ4w03tpcaq9Wgj6RPNrcaX+fepG
PP03j7tH06xNS6zewkMn1iwkGKj/PBQLQtHWHpr/v38D0K4Ubg==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0HtIk1EYx/EXS7HA0rxtealVaNjU8r55++3i3HQLVlZUJGReKEJLWoaF
viaJliGU6OiOkcTImlHpNJxmZRrehpogQymp/rAyQ/8o7EbnKdoLh5cP33Pg
nEeUVbAtx4njuIRf6/efPvdXN48kLu+x/tFscuv5a0WalWQO3y/p7q8Skl3h
7OP1Rfi3u0M3XnLshRPZC81miW/L/HNmAWyTysTgUbI/QmNaZd5T5LVovHvu
TZOZvA6FqhEPz1LyBiz1Fs/qM8lBSJo/uUQ+94x5IxqUu291LpBDoL9Rl3Ng
jCxGdn/P1ap6chg+2wvO/rCQN8PXY+/bkDLyFvD7qt917iRHYEVtV8CQlhyJ
RjfFoI/5KXMUMisrp2cukKOR0TVx2DWEHIOA+u7jw4XkWNyrui7OjiTHYZd8
WD6ZQZbgzla1tCOdLMXs3LeB10XdzPHodxEJA3ufMCfgY/LFKy7e1BPxyOJS
antAPQmppj1uteupJ6PcEF4TNU4dKKu2ZwXZmXmgQWfRhFm7WJchPL7m8idD
J+syCJysU9Kjj1mXI8PTr+JDhYV1OeYOBkPT3sK6AuVtp/MfTjPzCgzuwKa8
ZWw/p4S4W/1euqaddSX8muJs1X2trKdAuF1R/9LIzKfga27bgiyPugqi6Lqg
kVg6r4K4zyC6HcHMpWIiQGLMFVlZT8XAfrOyeYzep0b+kGHwzCK9X41QY3Fc
1GqavwZtgQJTXgKbH6/BqdxF/eIonU+Df7GowrmXmU+D6sShHpOezYtL/9+8
gzmtQ9dipqRjrFFC99c59H/+CepFLLA=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxN0wlMk2ccx/F3qJyL1JWNzrWbQkXGDHKIgFL7Q7By05bSQtlETKbIFDwQ
OcYoE2UO3JSqcSbKhmSBYRWoFBzHOqVCxYVsSIwHEDXiYAGJ4Drisbn4/Jc1
aZpPvs/zvE+fPl28KUf5sR3HcZtevv/9pBfvxpkdEueen15pSuqxumAW88kc
/N8VbDbwyI5of/iewmpH5sF3d1rz9tkrzG6IH+2o7h8kC2CUpnNOVrIQWfdr
9YJW8iLEfFdnOFtI9sDyK6oqWzpZjNKaRWURS8leOFkUXJh1x8Lsjexw/7Lr
RrIP3G3aqL1HyMvA9+SlzASQfdHbZrrFk5D94GBout53tJvZH2cKXJe1F5ED
EOceXK23XWYOxNLiJS/steQV2HV0oNIyfYk5CJGHC57FlpBX4nze416vxp+Z
g/G6IFio/4Icgi/9NNnd+8mhyNyo/GqshbwKM6FPFG43zcyrMdpp1+CdQj0M
DyWT4t9jyRLsPuh5YOMMjV+DBds/CKp3py6F/kW0Y3QAdeDmo8UC+TCzDvit
LvOS5BCND8c8h3yz1YFZF46KAZNzgIjmr8U1n/Ke4sFO1tci8P5E4qmyDtYj
4Ki2M0xsbWc9At5e3hfLC6lHon2MX+9pbWM9ElWphtbXVrDx3Dr0C28PpFpN
rK+D3NWFZyhg5mT41WyKrPOgLkNhuus20fgF1tfjbc2G3hov6uth36OfOjzU
ynoUkvc65QhtzLoo8I/frTBbaH40psrFIdJPjKxHY3b6b2HcCPUYcO8Pe4Xm
tLAegzHp3A09P1KPxdP/WxeLSs/vAzO11OPA7+jymObT+nFwOztQoa1tZj0e
n+4J6furlFkXjy77pl/8r9WxnoDPj902hX17jvUEODdHLzjo0ch6It7JUo43
nKaeiBZx7pZaUQPrckwO9e9L7Tv/ypBjJV+acFxL4+XIvSdWntvJ1jPLcTJU
Jsm1/sDmK5DmZ3pryf4mNl+BWZnsgvojZp0C2t48XmcTzVdAFWK85VLEOqdE
bUab7s077PtDia/v1tq6hHQeSjyvls1Oi9j5mpWYKC5Jyhhh5pJw4vKc+kOZ
7DyRhCfaeM4KOu8kzN931XfrZmZzEpxEUzZjMlufU6E1f2TbpIH9/lDBW1L1
59VSug8qdM8xrsk+fZHNVyHGqJybEUb3Mxk+T+c9nv6GdSRjZ/6phUMc3eeX
vTtPZ1vObE7GuJ/faHwd7V8Np6AHGb6DtH81XHdsWdhlT89X40MHsZ5Xwu6v
WQ1pSJPL4CO6/xrk8h/UN1ho/xrce6P5mOAZnZ8Ge1ZZKj/bxWzWQHQjrjGN
T/c/BTWiP56Lh9n/Fyn/9X8Adb/yJw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQMC1xcX2HId3w/hfbBnbjOXzWeF8RkcZqiq/u/k
gPE5HCwb+NesZYPxBRx2qT85cO7HMShfxEFs117ZpW9gfAmHB0p5H9gfwPgy
Dmc+5Ia0H4bxFRx6pyjqdM2D8ZUc7nb+NMmtg/FVHGJPT0nVMYbx1RxszAMu
/WCF8TUcejKtNl4/dhTK13I4y8zVuGsXjK/j8GmVvdbNHBhfz2HbW/5z/g4w
voHD7N9dzos+HYHyDR2cHY77m76F8Y0cJNdW9t7cDeMbO6zefnJxxI3DUL6J
Q1Pdk0Ma/2B8U4cFLG/nnj0C45s5XJcz/KVfC+ObO3B1dAs7W8H4Fg4qE4Un
i3QfgvItHbreX2552w7jWzlEW12J3DQLxrd2iFmmrDM/GMa3cUju1g+LZoDx
bR2O+l2QnLgWxrdzqHusy5+QCLPP3iH9yKf/HoIwvoPDOW31G7LbDkL4DQ4O
rvc4P8arwfQ7OlgYlXlv2H0AKu/oMOd/W8uu2VD1DE4OTBqBiSKVMP1ODvoR
tx+s3gzT7+zQojUrfe5TqH0Nzg6P9p/bLTMVZr+Lg5Er3+8QBmj4Nrg4mE9f
06C5Cmofg6sDy7vfjNLh+6Hyrg4K+YtaJI/D5N0cLrsInnX4fmx/XOUO28ni
bg6fLvkmCUSc3A8AP2rocA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10XtIk1EYx/FXKbJyZSiVlsyVZZlkqZvXuZ86fb0lJvRPIFQ2KzBSyRqr
bNbKEGuKq8WgqEw0ieZeLUmt5a0Mw2VkGiH1RzNRwWkRU5ld8DwHDocP38OB
wyM5cipH5c5xXPS//f+k5TVcWyhf9ca6JIdC5KwY5D3IHFpv+BdVu14zeyCv
fupm7QLZC1mmFQludrIPjs9woY1D5I0I/rJGX95H3ox8U5PxgJUcgHt86qzI
SN4CqU/TgiWbHAjfP8mNAzx5O6oLDEbJWvIOeOstvQ9/9zIHY8Jgn7vSTw6B
XK/UcHXk3Wg0Tk8clJH3oD1PZneO9DDvRVpp9mi+jRyGdSpHhrmOHI7a1kvv
MiPIEZgX9JHC925mKcrNm251fOhiliG0f3rEcJkcCdXgx+6wY53MUQgVysRd
G14xR6NbsTVwuKaDOQbXSgLmciJeMMdCavlWkyWnHofF9kemsY42ZjniQz51
Gh63M8fDylv5GDFZgarxoFjdrufMgEhSv6CxtC5ZC6gr9p9bHk73E3B/XDJf
KqWegPPhzgbTj6esJ+Lw4rLJ4tPNrCdiRHXREez7jPUkFAtOz6E2Zm0ShF94
r4iiroRr0k+t07WwrsTRWaV42KOJ9WR8bn47Lm2wsJ6MIvPtnattT1hPgVjI
3hakZtamQJd3qPJkIXUeVW6DfMsdM+s8HGevnrhbzd7jUjHkXfGzXCOwnoow
P/nXnhRmLg2aPpv7lD/1NASMrbe5rtP/0xEniVpZlkv/S8eFXJHSMkPzyUBl
UeKDklE2P20G1BLZwBlPmn8mGl7WFwTu67H+BaZaJi0=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQMC1xcX2HId3w/hfbA/Xpt+ZzU/jM/g0G5u0P8f
zudwyGfNSNrHDeMLOCQEKB+bxgLjizh83vn+/AxWGF/CwXJ34eOTX45B+TIO
X+zNn786C+MrOAg3bdlTfhDGV3IIcmDbxrMIxldx+C05U3VVD4yv5nDg27bN
5dowvobDr0P/Zq9ThfG1HHLVJ5QeDoHxdRzi+IvfaGrB+HoOtpqMj09dOArl
Gzhk/1WofL8Oxjd0sAqcp7I+D8Y3ctjnXrDi2SQY39jh4fRDGnFKML6Jwx6r
0kzeoCNQvqlDElPKm5urD0P5Zg4bHlc6rxSGyZs7BKuW/nDdDZO3cFCvP8Ae
Addv6fBs7/dril4weSuHHk92cf28Q1C+tcOT9zF7/DYchPJtHI50SYcd+w/j
2zp8jpcxFj5xAMq3c2BImOWmawWTt3foOLDlsYcjjO/g8OtL0UqZYii/wcHh
N5vnznPRMHlHB4uTEU/3d0Htb3B08JI1fVZ2DeY+J4cfU3Wa3Oqg7m9wcpij
bjaNeTXMP84Oi7TsLmtWQdNDg7PD07KVF30YTuzXF56/1fO6s8OnS75JAhEn
9wMARYXQSg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdkHlMk3cYx188NpSpIKBOWJTOYeVwAtUBQ/ot5ZJyFWg5lcMLjTJQV28s
iFJuOVQEXEDmhkCnHG4gDktAdGiAARtuRNQFRLwyyIxTccylz++P8SbNm08+
7+f3/J6axXwRsHkax3EJ737/vdmj318ev3b2jWta+lPYk2rlKJ/DmENPz9LV
G2Yw1kXG66H2qlftxPr4VC6anj7M2AhbB099e6aD8SLUxMY2vzzH2BR7dt29
X53JeClGxpLVskjGPMxI8zn7mxvjZch4sEW1bS5jc/QlPxU+ms2YjzTlXyZl
r68TWyB6QeLCoizGVtCb4zzD34PxSuCw/Jc3joxXgXey5cDNuYxtkFPsKZhc
zdgW/UnRvSORjO1w7nbj2NBAG7EA48UjmpytjFdjdMMOvZOmjNeAt0Exbixt
Jf4M822HPhJPZ2yPwXLrkIgLLcQOcE+R8cNLNcSOcDzYt96spZn4cyzsMPnO
0P4asRN6EzMOnBb9SLwWX0vq23Inm4idMVEyYK05eoVYCMvLlideCq4SA4tX
DBvrn2/UshJoGhXZ3rFj34twNzz9vfjY78mL8DBcwn8WWU/eBfffTjp0t9WR
d0HwGq/G5V3EnBgJw8llN18xL4b3xaL8ip015F1h3/wP756QzlO6Is453ufG
Fta7IX90WW5Xby15NxgtGJBKRRfIu8NsAVLdBtTk3XFF8PB6Uvtl8h4weJLZ
qfOUWOmB5+N+Doef/UDeE2vc6vX+GGHzPaE4qHb8ZgXz69Bh1KBzy5Ltvw5r
HXJnVz8i5rwwqBFWuojZfl6o8xjLNohh95fAYu9PNlnjl8hL4LNb1RftRPtw
3ni/wVK8eB3z3ngwp1IhrmHeB3lRgqjbv7LzfZBoLew5dqeKvC/OHtut5nlX
kPdFbFz42/t6peT9cE/ysEa2pIS8H2aO3tYdGTxD3h9D5qrGYPkpLcMfmRGh
Zi4x+fS9P7abCa4aF2ZpWeOPhL8r8o48OUG9FM4t8W1cRgr1UqyMf5Mbkkpe
KUVcbuDH57s2Ui+F2zxD1fpVCUJtH4Cn+3tfdJ9O0jIC8Lv6S8MXFhHUB2B5
XFxJU0aY1msCsCnBmz/QF03zAyHavkm0Pz2e5gdiOi/R98PAHdQHQl+vUrpr
WEZ9IJysXMukSTtpfhD0NzaeaHmpoD4InKiDrx6nfZRBKM6vLdoVlEb3D0K3
4ta1HY45NF8G+0OzphX4HadeBq6p+kGrz1HqZdgst+XX96qolyG1uSao8Gou
9XIc+dmmXOdxNvVyCGY11U4UplMvh0nptuSZiXQ/jRzJed59giUqun8w9lUc
irpkl0f/XzDu1JlEaCYKtKx85xXiyPDSbNo/GBcXCjs1phnUhyCu4LHXM6sy
6qewMgT9XlWP59VfpD4EBc85u1YDNfWhsPfV8Sw8dIn6UHwgkfNszRuoD8We
7JkTTSH11If+/3wuDIv2fqI+MMnmh8GgfF9twPwS6sOga6HoTDn1FfVTPBc+
5f5TWDmFNVOYi4DJmQa+jipN+C+8dDGt
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQMC1xcX2HId3w/hfbAvEOh7ZckN4zM4nLt+b0mc
IIzP4bDyq8f35ZwwvoDDQ6VQpRW/j0H5Ig4a/17NvfMYxpdwmL4l0C9nM4wv
4zBRo/Rv82QYX8EhuEG142cfjK/kIOcZdWpZBYyv4jBl/bbPBpEwvppDGbew
0zRdGF/DYWXfoqkeL45C+VoOOitSAwxPwfg6DgvZ2QtVj8P4eg733GwNav/A
+AYOza+f9skXw/iGDrNdHn8s8YXxjRx+6CfcOTD5CJRv7HDz08yjFzVhfBOH
b0UZn6wcYHxTh5jlWYYXE2F8M4demfQTOrsOQ/nmDl8mfP+XaAXjWzjEJkvY
WLYdgvItHf5m3t3MIguTt3LYWt30PCscxrd2mJ4ycfYGAxjfxuFe9XT7iTth
+m0dTlTMNv9uA5O3c2CaunPiI24Y397B6drRu8LzDkL5Dg6qspmlO95A9Tc4
OERMepRztmI3VN7RoX++mkpfDpTf4OjwsN90zo8J+6HyTg7M/7cvWuV0ACrv
5HAt+OLBrhKY+c4OUmePbt8tA5N3dli2Xom1ePs2qLyLA+PEqYHXS7ZD5V0c
2muMbd8snwGVd3XQ31yuJN/YYA+Rd3X4ZqBWIRHdBpV3c9Ce6b6LaUnRfgB3
9eTF
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwtYzOkeB/BhsbpoaWWFbCInUaFNF+LbZaYUTfearv+51dBxd3Zr2zKI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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90H8s1HEcx/FjJ5dbOT9aJqvol2F1EkLXvbjD/cJKt9GcYqyRlvVLtcq3
w8y0VGux6CqHzEX5mcrduYjbml/Z0kg//olUXIqy6Nd8Pn2377577PnZe9/P
2z358O5UaxaLJfz7/vvShzekzRTYdRsXZRFeninaNc6mZmFY7+Gq/95FzIHY
8LE07hU1DyIm3feaidoZrz+3L0xUULug2fF8s/EitRuKO585OJygXgvTmaw3
lQpqD4h7nY72+lOvx9vbGTr216fEG1GWNBNedp3aE6fG6+JUqdReiPdqnxgN
oPaBRHBhdTWPejNumDz7CyydxHz0NVb02JRT+yJonlvYcJN6K7xZdVnSVdR+
mGzVqtfwqbdBXVLFsyyn9kf1F7l5aKyDOAAWizJSN0AdiLzfZ28N21JvR7D9
aa45+wlxEPjdsy21OhNxMCb3lm3ZMNhOHIJcUS6nwpb2HXhplzKXlEi7AEkh
efMxY0binWhKrq557msgFmK8+1JNfsYjYkC2ycdWYv1w0Qywr8C5r4PbSnoo
1vXM/dDxaA+F1qz5sP9TM+lhEASrutjFtIdBOppvdTDkAekiKFhZE5zj9aSL
INEazPyU+6SLIWemTw4faiBdjGRhjg1XSc6zwuFhfJFezibzmHCopjVLNP2P
SY/A1BVnWU5fG+kR8Fam6QMG6f9HwoCMZdwRsh8mEvWNM3NyGTnPkqAz090s
LCH7YSRQOv2szRqg+5HC5a6qYMye3k+KQsfKI4Yo2mWoSnw31TBJ9sHIsHQk
O3DWsYl0OdIMge8XzrWQLgc7YgWfKaL7UcCOo7mXF0/nK3BA2XSn1I3Oj0LZ
sbZvsSvJfZgouJbH6tWjjaRHI9/PSr0noYT0aJT8Gi++mlBFesz//geR/UOL

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0GtI01EYx/GlkCMMt1Q0DHS2ZZlpmpqXrf28rLnNzKRwEBJJC8lbbSkJ
LmdhQslm0WWRopG+UJRc3m2kLnOSRZGmREZmlBBalubICjM8Ty/6w+HPh+/D
eeAIMvPTNE4cDkeycv7+6eON3zkpWWfvXdWc1K3xy8bfrmQOQmKHzlq4ZC56
C3N8gtzJPDTOa2r1fLIHJNzJOd3yILM3PvcfGNG+Im/C8NGvczsekP1gNSxe
4ZWT/aFpynN6ZiILYU1LbR2VkbcgLFdq3C8gb4Vm0tbwbukRcyAyuyZiOLPk
IFxPCXA9xKf5YNjj/YeO+5B3orj6TYN4huZDkaGZ11d4Ug+DUa+bLLJR34XS
0g09viZyOF6L1x90lpMjwK/qvCxwDDBHwu0cr3YpmLwbi1Wn1OfDyVFQabG2
euYhczSiR44ECOrIMRDZQ6JqrtmYY1GW9zJwcKqfWYx04Vtd5SB1CZa/Zb3Y
LiXvQaj7iZ9P/WheihvptRPl3n3MQNBHq7otrXfVBqDHoliqd7KyHge9nz3S
mdvNehyeZ4/edrR0sR6PMzOFoo4FZkM8Bk4HJGtKOllPgGhz39WSxR7WV5xQ
MN0WyMxJhDfnh1aRzfYZEuHpOfHE1077ZaiZytWVmul+GYShj53NJtq/F4db
Yo056g7W9yKiuf17mQvtl2PbsExoO9bOuhxjxvSUIpdW1pNQKOv/1KtpZj0J
YwnqKl9zA+sKFIi6K/Mdd1lXQGUrryh2NLGuRNLsrfqmXzdZV6KofzrKS3yR
dRUuVWfVFaeaWVchQ8m/YLLUsZ4MpWCN/MO4hfVkvK/pcs3zuM/6PtzL9Vrg
aen9/jMn5Z//APBaMjg=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzw9M1GUcx/EfNJmyxp8UJQMqpESkNDQU8ORzwh1/BLw77k5SUBSOUWPD
M9ohKzmZAm7AOJA7MorkNDURToZ4MRU6Dy+m6ziY/CujnbkOGAFGaY0gG9+n
DW673V77PO89z71+OFeicOY4Lu35979f9vEY0B/huVo6FjQVOcj95tCuYOYw
qr182baMeTmUB31DRDN3yR4IWF1TmzXCvApxEr0qt4/ZG4UVO46tbGb2wYh8
vvteNfNraHDkT41/zOyPe/p9kyezmQNgy03L/GYn85uosGZmrnuFORAqz7sl
vsYuchAE6dpP67cyB+MLH35EXa+Z/DY+meNOt4cwb0b5k3MbZ8vvkN+Bkz5A
8FkPcwiyDRb7w0PMWzAUeKBxMoV5K5K2HDj1OIH5XZzNfsFZN2Iih2K41G2N
Jot5G7Y1Wa32wW/J2xEz9ohX28QcBvN+6d86G3M4ePsn3VIErI/AlPOzUl0R
23fAvX+ksPR+B5mHvpdzDOf+vE3eCfHRVVc2yzvJkXAaXJcgLGDnAX2wPLWt
nc6rgfelc6lPLrCdjwfeYy0Tb7Gdj8c1n/PH1t+kfRdOuV5wMk3doH0XtD2T
27/+iMxF4YN+X4/hWCPtUUifUY62rG2nPRp3TJJLL1rbaI+G7GHVLeGvrBfA
TT1vnh5vpV2APK+C1cWF12kX4vu00e5+C7tfiI0+5q7icLqPi8GmDE2/zZPd
H4MJzXCvWcD2WLhqjx655WB9LIIVKYkFf7H74/C0Ld4lUUr/Vx0H5cU5nbCK
vT8eNW/MDI0qyOp4dJtVQ4em2ft2o6F3tlkd2kL7bnyVF1rhX2KgPQHBKvXP
ORcbaU/A+RN94fsGrtKeiIEHvA9Nbc20J2Jcnr/GWEvnuSTEKtf+s+E425Pg
Pm/dpLbQfdweRA1qyuzCa7Tvge1YZWNMdRPtImT/ntuzTET3QYRev5WPzD7s
PSLgtrv1/B/6BXeK4OmYOOxfeIV6MfZWrF/+qr2eejGuZ/h1HEytoV4MsTF9
LPpZNfViRAQFNoxPaKiXoE+h0rjWnaBegh+8NJVKc37kQv98dzNZau1lC+5c
Yi55sbHE6mQcz3vaHaappD4ZXWHTP7oYqqiXLjakCPC7GbXiJw31UoQVdcx/
ZzhNvRQlVmOrV9BJ6mVIneO7SJLOUC/DS4765oIyHfUyZBTlXKts0VIvw3ve
dWcV5fXUy9E+W9x6/5cG6uXIKvb70hbdSL188fs6l5jb+7//BW9Q6Zc=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0FtI02EYx/G/QlS6iyE1Z7RwI9syiZpzW07zt/NgkClUGKIt6KYDbisp
UHIRtETX1AisjMpR2emiqEjL1tQ5Y0XMlAxRSJnmRWFJibrWAd/H6IGXlw/f
iwce8f6K4gOJHMfJ/7y/Pw3/vc+enxTyL2q6ICWjyDDAI3M4PpuoFC55BTRF
pnUly8h8RGyukG+pr8JGb4/6RDJZCP7VyiqtgLwWfsuQ1f2jlzkdMoN4dWEf
WYKdqh3lrT7yeggu1NZ9O0zegA6D5E2fnSxDuvuj6KeGnAnH+GuhV0TOgrSq
djiLI2+GOFU+9nk4yLwFytY2gaedvBU1xbYpz1myHIGLkwdfNZOzUVE6fsOj
IyvgGPHE8071MOdAX5j0ybWPrMSVYKzpmIKsgvf5xJe5NLIa0VJTYCiVvA27
ursWcg91M+dibGakvm2+i1mDPTJ1eRmPeh52q+5ctmVSz4fzqNXa0PiSeTta
OqWVlvN+5gLkxNfYuUYysIn3XWI7HVi0C7h5pKU+cpuZ0+Jr/J1rxkxdixei
6tD9BOo6RI3h0ICb7XPp0Gy/VTMaof16JPf3T80lUNejpO5hMCXcyboB0ntu
yfXBp6wb8CFbHlvufMK6EWWzDfPVd9tZN2JQcW7v6MIj1k3IWKnFtfBj1k1I
i5lVv052sG5G9NL02zOTz1g3w9HUO/HASfey/G/XP/8GcDsA9A==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10Qk0lXkfB/AHLaK39FaWaoSSsmVplCG+SVR0u1d24brX5ZKjmtOrheqW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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxFzltI02EYx/Ehw2lQ2qjUkDwuRE3bqrXUud/OrUUTlUkhHmrGoKRl1tyV
S+rCi5AuolE3yhqL0qGrqGW22kptjIJCZVREBxbMKMmxXbRhRe9Df3j58+H7
vIeSo6eaezI4HI7oz/r7py93yWmRrpvz/9OKbO3e220vc8gcOEu63kvyyVkY
sIwNfywl5+LVYZVTX07eBKN17fvwRnI+Vm/nmc/+nGUuhInjEtqWycX4rJt3
mxfIpUjqeb2FYXI5ovMSweXX5O0I1DTddU+SK6B06ZrFOnIlZAVl7enEc+Zq
vBkaLIr7yTXwas43pTvIOzFouiQ1xp8xC/HBlgpO2cgijC8Gpce45F0417bl
xGlfkHk3Yr6e7vQYeQ+iXEeZtpjmxdix6lqJVZH3ovekq/PiQ5qXwOdvTAiO
k/eBm66N1LsCzHWo0/tCFd/I9fC8y8j50UJugGh0kRtafsIsRYchbL4152du
hHs8HEPmU2YZuqeh+mUgA3LZZnHtDbbfDmS1ViVHHXS+HNwi6VJAxd5vl+NI
xNrX30ddgUN5/Fjcyc6zK3DmQGCobT3dr4RBMNLS0DrNuhI89Sw/5XjAugpT
BY7HW73UVXCnFNmeq/dZV8OQfdBqqmbzdjVClsqbC3wv6xoIZrSJF8JJ1jVo
j3xKKic8rGsRfXT9yzUedS2uJL72X5ih/fuRGjEOZG64w/p//wYRYvzi
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90As01HkfBvCpxJIuW1FtbY1LDrGVWKnII0Mpt3GX25gxg9JlVV7Jq1He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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90glYzPsaB/BR3EQRLpWoCVfJWLKMtOgbLVq0L6NF00zTlEp0Lp2IpuNk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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIk1Ecx/Fn4i3LOctbELSNWJvUSNty5tTfpu7ipcSytBclLYswsAsD
x5ouY4IaiLEI6YXYMKTaCxkLlUpxc9JFUFNjIUEZmRUZZpRpWtH596IHHh4+
fHnOn3OO6Hh1SWUIx3Hpv98/X3oEz11nM6OG+//qc7ZwwV1aF03msL9rLCtu
NcAcCV9qqOrNClkAc4/hyOwPchwmrDdeyRfJSSha7H7rnCBvgcw4VpjjIwsh
13j7/F1kMZxGx53i2+RtaAsXlUpKyBJoJD5pRBJZCjf/Gi+4NMScjCVR4KLj
CXkHrL2Cau9pshwzLXMtH8XkXXhZEa5ojyenYHlQ1/i10s+cCu+FcpP6JHk3
Ouz3E7kEsgL3BCkH/W4fsxLlNzcPW9YGmfdg5ES81ruBeho0r7+PD6rIKtRu
5610i8jpCChdPoGUvBd6uYMvq6f1MqBs8mw02Wi+GqOB2I4hIzkTguFDV02H
yVl4lPgw9EsNORtFVyRrd620XyAhbC5vfj3rdsArV5vqJmmeBlX82rTWCGa7
BkdHzMVliwOsa7GzcYp3ScRs16LKxb81H/uA9Rw4VtvF7cpe1nPQwOmD/Z4e
1nMhSz9/eVrYx3ouys61eX4u0/95+DD9tHkghtbPw/jUN+X7apqvw2z9C9WM
hp2XXYdRxb6GU+tov3rkLgQzllzU9RiI0p25HkbdAIVtU9O7TOoGtNpkyTVb
qRthtkmfRTZTN6K7NzzGEk33k48DnFPaOU/nk4/ZSUuIPo16ASoeO49Ff6Je
8F8v/OdfUT8bhg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90gtYjPkeB/Apl6hVnWMJT61JFFtEJeXWtzLdpJruky5zn2FDsgirHXLt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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90gs0VfkeB/CdREQi3WpMORp6eGUiVNSXojzD8crzOE9DkpvGTR6nTGiK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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90As41PkeBvC/7cLaOiSkOtWEJBEqXUhe5ZpLjNu4NsbMmEpRkrR1zDmV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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQMC1xcX2HId3w/hfbCX9exX7OCG8RkcYlL6F2Tx
wvgcDrM/8Qs//HEMyhdwYJ53eU3LXxhfxOGAz8lZHG9hfAkHhutzTuvchfFl
HM5yZNurXIXxFRxUZUxZ7hyD8ZUcugNzY19sgfFVHN7Gqt6yq4Px1Rw8jgV/
rKiE8TUcPOv8PzmFwPhaDgGyZilKb45C+ToOc3L3z/EXgsnrOQipXvyj8QMm
b+DAnHljk8k0GN/QQaX+UX2MOIxv5MBsozN57cUjUL6xQ2g3i+upDBjfxOGb
yt+Q644wvqmDtkJU1LtXh6F8MwcX1Y3+sx4cgvLNHQSFTExFPx+E8i0cFv5Q
OXJXD8a3dFiwe7f9VN0DUL6VA4NEcMTiZfugfGuHxNd9fP3L9kL5Ng6vIn6K
GjDvgfJtHbblT2hY+Hw3lG/nkD11r9zs8zD19g5eN9TWCsyBmefgcM0nvlzS
F2pfg4NDlZfNNlV7mHscHc5OlvqdYQWTd3Soa7tS4HYQJu/k8Pyo1cvGAii/
wcmh60TBVy/3/VB5Z4f5O2XtXnhC+Q3ODvr2V3O+BcD85+Kw6X/GpQ/vD+4H
AM++yiI=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQDQMC1xcX2HId3w/hfbC/lr7N8R4/jM/gsMpG/I40
H4zP4eB84DnPFU4YX8Dhi+rqic6MML6IQ8TvN/8i3x2D8iUcnj96P7/hKYwv
4zCxqpFpznMYX8HB8+VehoiLML6Sw5fDWdyLlsH4Kg7bE/eKqUfD+GoO55sm
T3GzgvE1HLYfuK4v4g3jazkErA//t/TCUShfx2F7se63OVtgfD2HpVzPOXN1
YXwDh6u7kie4SsP4hg7pF2QdU54egfKNHKyVbr121IHJGzvcZD/B92wBTN7E
4S5TWL96BIxv6vB13qvPa28dhvLNHPp5jj5hTobxzR2Kf3rfkN94CMq3cIjl
Fqq80wKTt3R4cbOhv0Ibxrdy+PPBKu7ik4NQvrVDbP4zsaypMP02DnoCr4Rv
zYfxbR1+zss1fMgB02/nMGufRYTH5f1Qvr3DP82S1zuDYOodHIQSMswm+0HN
b3BwiGsznB185QBU3tFh9i/r0w0/oPwGR4ca6dn/xX/A3OPk8E53D99Tbqh9
DU4ODee+lEUeP7b/J+etLUb3nBw+XfJNEog4uR8AA0LMYg==
           "]], 
          
          LineBox[{{38.43804428298086, -0.198}, {
           39., -0.18877406854498985`}, {39.748386867155986`, -0.198}}], 
          LineBox[CompressedData["
1:eJw10AlQU3ceB/BXEBwK1TaCq9uCKWEWKFIFj9Il6NejgAQJEO4zCbnsIgG0
iFdNVdoqtEhdKNQrWpVWRPDAUNH6oGAJNkUCiixXVrcVOqgdoiAUl92Ov5eZ
N28+833f//e9vCnXRittGIY5/v/rz/sPVv3kvxzXYtS8Xv5qgvE68+dPtxbF
1seLIje3vDDzHsqGfCpt4pspfw/tbyy2m59DZoLRL4j8qD2bpTwYxcvsrMcb
r1EegsCQrW6Hk65QHoLJ/RW9x1+qozwUSb5XNUxwNeWhuNNQ8pHiwHHK1yHC
gc1U5BWtfJGvw1ThF+LtiypfmAnD6OmzxlanKsrDkLNX2TzwoIZyESK3+viN
7T5PuQiGVk8f33sXKA/HCYfqnYrES5SH45l/n1tbApevx+J8ZuR73UXK18Pq
qQ6ozyIzEeCLbF1rufN0EZDkXSrMtedyMVpMi9/eWsL1xTi15bJHhzeXR8Lr
q+z/hDRRH5HYpC7eN3sm93wkLn2w4954J70/Gwltp3+y9xEyE4Vu89zb61Rk
RGHvw4OyoYla6keh1nl0/0Q014+CwOAmb+Nx3xeNPB4v4ImJ60fjEz/Z8rKn
3PdEw3FB2jtPPeh92GjwQ/+ouehP/xcjgcnz12CnATIk0OxttStYW0d9CWJ9
fl8Vf5fMSnC2fWi8JclA/Rgc+y6vZdhcT/0YbHuySyUQXaF+DFyEnw3/9UoD
9WPwbLe1bWTtNerH4rr97cu+dmTE4t9625Oih1epHwvBGyOzJ29QzsbCVyDk
1Xix1I/DS54PA4LXkBEH+/otf7sW2kj9OBRXVE7XJ5PZOKxa1DbQ30Vm4vHK
p+frvDaTEQ/TSe2XfQ5N1I+HOqB1VBRIZuPhevazmBPbyEwCfk+sfMvMkpGA
5fOuCjef+oH6Cehc+MtSyyoym4Ce6EzvDQvJTCL6tb9VnVveTP1ElDd2DL5j
S9Yl4sEHLnPE41w/ESt26kocgihnkpD1LRz4H3P9JIjn1z2Om91C/SQEfn4u
ma0js0mwPd286dtJMpOMluFfQ/N8blA/GUsEE/lzKsi6ZLTyqxpOZZPZZNw5
X52/TPAj9VNw/YjNoax2MlKA5ISN/ZJW6qdgTHJmWtZIZlNQuD1A4HHYSP1U
CAcabKM6yUjF0MJB05BzG/VTsXHTCZe8dWQ2FQcdvzxw4BCZSYO31Ha0r4mM
NNSkjjdNV9ykfhpiN7RoGu6S2TR4rBp0XX2ezKQjbanbF+Fzf6J+OmZtsD6x
iyTr0jHV7B/M205m0/GHjXNJewqZkWLwoHbrUiWZL8XUrefK1UXceVKcEZtM
CQayVApRbe6Fhhvc+VIcWzmz70AuWS/FlpOzvkub5vak8AxzK1FkmV7YIkWF
68MV+elkRoYdmffNii4yXwZjVU55n/Jn2pfBz7jPPPMeWSqDf7VQdDmonfZl
eLUi/JfSCrJehiuyOmPHBJmVwbknbYZRcov2ZXA/LXGK+CeZkaP7aWjVEpcO
2pdDcyyyTjhNOeR4tCncdk8q5VI5Pnk95rTbGrJOjs6RZTZ7FWS9HPzeo18X
d5BZOdKb4ySWQbJFDhdl8BKTvZn2MxD+bnXBcCCZn4HssMzMrn1kZCD9wU1L
kIEszUDgm7t+rOkj6zJg+yFb1N5N1mdg8v3XiswtZDYDlf+N9zbkkC0ZOHpQ
3Pz9Dm5fgSoXWf/Cndy+Ale11kX7zNy+AtmPdvbnBHbSvgL1u35zD/8HWafA
GaED61RN1ivwXNwbMm+MzCqgnc874lvYRfsK7C5zL9MOkBkl7uel+sDpNu0r
Mcuw4pUFU5RDiVzXjkbHAsqlSnwzJu59NEzWKVHwVbn/vfw7tK/E1+4NpdVj
ZFaJ1U1h9Y6TZIsSM27qefMjumlfBX+BtnTCg8xXoXdqv1j7FzJUeP3ox16J
G8lSFS4saT6sEZN1KnjlKssb95D1KhgfGVacOEZmVRg62717djbZooK7KIj5
VMLtqyGucBZtKeL21eCXlr1d28Ptq+HaNbf3upHbV6Pd3iD0tHL7apQWTvkJ
n3H7aoynW2/JHO/Svhov34oq+PxdskWNNf5Jc2zeJzMaXJzhxw/aQ+ZrsOD5
fh5ziAwN5rlkPRn8iSzV4FzRz88jHpB1GvAqZ3woP0fWaxBvHMl/PMLta3C/
p7Xx7y/30L4G2wY815fzyMwGuNmvlsnm9Kz8H3ejK4w=
           "]]}, FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90Qs0lAkfx/GnlnKrVKwub+WWSlcrWUl+5FaWXHI3Y66MttSeojpdjHff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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQMC1xcX2HId3w/hfbCv4q559IgTxmdwWBK1YoUf
D4zP4cCq3tVcxgTjCzi8yOyQvPz1GJQv4hB1cHK12xsYX8LB8OqZPysuw/gy
Dhq109X4V8H4Cg7/PnhEtU6D8ZUcJjxnK+1Mh/FVHG4bbBaxjobx1RwWRB6Y
vVoKxtdw6F4cncB27yiUr+UgMs21c/0pGF/HYX/ghuprK2F8PYdVhTPL7gbD
+AYOpnkcTmuLYHxDBzsTufMp82F8I4fG+9FV/7JgfGOHP94i338EwPgmDg//
bu9sfHgEyjd1OB0gz1YgBpM3c5AKdZNSXA6TN3dYfjpS/lkQjG/h8LJlyYuf
j2F8SwdP8SmF7c8OQ/lWDqqOhdfVtx6C8q0dTjz+UzvHBca3cZinbHWU9cdB
KN/WYbVn2Z3Hmw9A+XYOq6devSr7Gsa3d1hzOLr79jeYegeHWbptWwoPQs1r
cHBofOd/Pb4OZr6jQ3+/wCTDNzB5RwfFdona3+Ew9zk5FAnb/DjhC5N3cmje
mGTR3gzT7+zwwSltdq8iTN7Z4d+l7MWzO2H+dXGwEDSaPTsZGl4NLg78Dyrj
+7lg8evq0KelLrf4M0ze1aHjTd7shSGH95cFynHMf+vq8OmSb5JAxMn9AMM7
6QM=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9kwtYzPkeh4dWSNHSyr2pTZKYLiRhfdL9RveYNM1MzZRU29p1tjj4C+eU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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxFzQk4lYkex/GjqyJpylNouTmmNBLdSVPS5qdsSTocy0FxjrMxMUlKpinn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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdy39MzHEcx/Fv7Sg/do7Mj34olRORUnKi7tV11en6dZ20EZsoLBvGyCa7
RuaQNt21G3YoEvlxiglJv8+M8iOubFkY25kfyY8J+bV7v//pu3323WPP92tq
1sa0bGdBEJL/vf9//iS28k2RI623HeqTG1qlk/xGswX0Z3ms0I9ju2JMUtW+
SxK2BP3uq6LX/m4jj0dOgCar+g17EoqPu29pvs/2RH6mWNf1iO2DusKi9J5b
bF/IhDPfs/PZ/ug4HRskUbCl6BXtUN4daCUHwHuspOeLlT0TE0Q3lpsL2bNQ
HxQiVmWxgzBbXlvZ6csORkVc+v6t91rIIbDfDy6p+8Cei6pFA5uNm9ihOFga
ul2rYIfh4OGd72JeNpPnYZ9XT6Y4j3s4JKu7Sq2fuc/H7g9Fo06JuMswxdRp
nePNXoBhMifLhkG+j4D46JHE/RHshWhU5hieqdiLUHrsxBGfiexIaNO9o9Tv
m8hRWLLuj/9eX7YcEYPtk2WGRjLQWOIa4r6Xug746OHUtk7K99EQu61MFpnp
XheNQ6YF5WOe8F6ByQmW+MhP3BUI03i1NT/gHgONz6X30gMN1GNQn1kw/c+0
m9SV2GG01doi6qkr0ZIhhMu/c4/FW+PdeTV5ddRjseRZYHy3Ty31ONQ8LCka
HniVehxc7qScCHxRTT0eam348vxXNdTjkdgh3XZSc4W6CkFG8ZpoGe9VmOE2
vvKHlPtiBFx3nv98I+8XY84uQ/tONVlIQFPGU6cLp7knoBWScfaWi9TV6O35
de5FrIW6GneG2Ud1Xr1MPRFdQvfMbzayLhGfs83BnmcrqCfhscWvu992lnoS
+pqtg85NZ6gno8gIqUtuMfVkROlXmEaWGainIE5onzYiMo96CkLb+xQDqly5
o6eiMsNU5tJW6DBSodk696drmd5hXSoKrlRMra41OdyQilw35Wu/r+W010DW
oVe4BJfRXoOwG4H26/KTtNdg2fk9u1vkZtoPsZCGp0s9/BvMVbRPQ4dn8QxL
r4X2Q9wwxIIWXvac8swCMrQQua1P09dck/8FPXF7XQ==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQMC1xcX2HId3w/hfbDP/h985jErjM/g8JE9IZzz
/zEon8NhZee3zZnfYHwBhy08ipf03sP4Ig7JAScbLO7C+BIOvz/plEqdhPFl
HLjv7itRPgTjKzgo2Egdq5wF4ys53JhkbbysGMZXccg+wPXIMhLGV3NY7ccS
8sIaxtdwOLTx1wENFhhfy2GhzMqlXCIwvo4DU9f/t01Pj0L5eg52E95oLuqH
8Q0c1jG+Z2afDeMbOnBU/zoxvRjGN3JY55//h3fPESjf2CHfyEel8SGMb+LA
4Lbp4WV+GN/U4Wh/cNQtrcNQvpmDvXpRjMx9GN/c4bQ708ncBzC+hQPruxku
EesOQfmWDhezJCY4v4HxrRw+BM87vkQGxrd2OK9v8ePeugNQvo1D+MF0vT8N
ML6twzeLsNiHXfugfDuH5CMHl095sQvKt3eolzk6oV1sN5Tv4MD2O+nPlu07
IPwGB4e9EhEKItYw9Y4OxzSbY9czQfkNjg4ac9inBzJA1TM4OUh/nF1ndGgb
VN7JYf+065LrX2yByjs7rLru67/j+maovLPDcQYzi/ZLUD6Di8NfUbPJ5Tuh
6htcHMLOTzzEV7sBKu/q8GFyRMJyXSi/wdXhyMLt8+4tgJnv5hDSKpoe2Q71
TwOCDwCPKeez
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zFtI02EYx/E/Y5HNdMNsLFxh2smMudmcm7n529/9pd1ldIBQpIEgEZma
Rifa7GJYKOTFhlFYBlFLR2Q7EM7ldOsipEiooDTSDqyoLKFCig70PC+8vHz4
Pu+z1tW8s1EmCILu7/338lE9vXrYqrgf/6/5qvD0L2M0iy2ge3neg/ASdgZi
/Z2a9GKKrMKqrEzlxAd2LlbalCuOzbE1eOLztLak2Fo49Hc+tkfZ+Zifmhk7
5GcXwH/re86Ng+x18J0tCV50sjegqCnhDj9LkjehyRx62OBnb8ZkW522WM/e
Amd9RlFfcoKsgzpRtr6ui63HZ09poLuZbYBvJO/AwNw4uRTloZ5dwwb2VuR4
38nSmWwjhCFNpdSQIJfBtDE/9VzBNiHy1aRuX8ouh5C9t0DnGiObsb3wcX+t
eI9sgSrQKOtJx8kVONk2an71nr0NM/Kua94Iz1dCcu4LHkmMkq2QT44npxQ8
b8Oa/YtnLvvZVRCTu887Su6SgY5Hrh0GE9kN6L25yjdXotTt+KTG6lOyGHU7
jp84Z7P+4P8ivkzXS29HQtRFeCpmbeKyYerVqI1d6tXepH3uajjTLa0Ls2Hq
DhT3DvxcUAxSd+C09NpuMZMFCRbbC+PRSJC6hM5BuWHP7evUaxAVLwS/ZQ9R
r0Hhyz6x43cg/ge0ed+a
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90GtIk1Ecx/GxtMSoLE22ksxbyWzmLZfp9KdzzulCUFOaQ8EQhmNkZGVS
sXRigWWXF5W2zCQzmPYi8ppJzbnSrKykC8V6kbl0rVUqUa0yOn8feHj48OV/
znlOQPHu7BIuh8OJm3//fenxetFSJva0DPyXMym9JziwbsEcbM/LGd63hOwB
VdSpI58Xkb0g+v1M4TEzxOwDdXOJodxK5qHBa81Si4XsB71RIYxZ8HoICx8X
6TrJgdCX2o6VXiIHo9Eicx46Td4AmzIv320HORQli7+oZHFkAZ4Iw46+55M3
oUXtPTPTbmYOh6KiOHf6JDkCUyaz70UBORLx+v4umTs5CsMFjW+NDYPM0VB4
Sjs+3TAxx0Cc7VsUeYa8BT+eW5/655Jj0e62P/eR6x6zaH4/t2/eZvJWzKWN
iE1achxsphNjVsdd5m1QKvOj4yfI8eBapwrrRskJsDsqzY4HZDGaj+tdsRJy
IgLcX7f0vRpgTsLZmvHhw4O3mYFdVSG8AjuzDph8V81TX+tnPRnGiVZEjfay
nozEkVWbBdo+1lNQ+zHcMFTVxXoKHJLzb1S9zBwJ1mX8mTQs62ZdgjDnrwjv
r52sp6LiQLVFm0M9FYPTfP+13B7WpYCxdWdZ0y3WpYg+6DNmaKP10xCouawZ
l9P50mDX2DsiRTQvw2xQ4dU99bS+DPoLq5tCBXT+dFTW5A9d92P/q0vH8o3q
hL1zd1iXo41731kbwtbTyVHhMslX/GT7cTJwLra7K+gKu19dBvg23gdRLd1v
JsqbXyp59TSfCffvxbNZqTSvQFa7ceXD7psDfwHDTiP7
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQMC1xcX2HId3w/hfbC3UemJ0OWD8RkcsowEpUVE
YHwOh5OJFxft5ofxBRxKrb6rpfw9BuWLOBgoRDyrfATjSzjcX7JHxeMqjC/j
ULhGOMcUzldwyPzg/frKQhhfyUFC0eBBSDOMr+Kw5YCC15tEGF/NIfbqEfci
Vhhfw+GL1JE9nOeOQvlaDmXGl9mbs2B8HYf37AKX+YxhfD0HN6uMqFRtGN/A
4dq9a8EndGB8Q4d1pcy/9j85AuUbOcyMuiCpMRXGN3bInxVUrvz+MJRv4sCf
zCa55jiMb+pgcji9cMcDGN/MYTffnnOmojD95g6dQpMuStrD+BYOuW77J2sW
wtRbOrSfvu9TcOUQlG/l8NW9rVNAEyZv7aDQfV766R6YvI3D20kn75sehPFt
HXxEPOonP4Xx7RwYf02051OG6bd34Ek7sG3Zcpi8g8Nn0Y0SUiuh8g0ODg8N
a2IUSmDuc3Q4LCB/X24qNHwaHB2Sinzvq/TC5J0cdB/UhW+Emdfg5PAyVsB1
87F9UHlnh9muZWes/uyByjs7bLm1eX3/1ANQeReHHleLrmeOMP0uDmxzt4Tt
84WqZ3B14H8hN6/Bast+AGxI0gI=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1A1Q03Ucx/GhQTz4QCggicWj0OLEAEUg3McBwgYMNmCTgedDEFdkKCRC
lKxglGCpIEiJBwpBPFyAJhCMsVACD9wJSpwi48gnPEC8PCEt7eH4/rpzu9vt
Xvf+f7b//rf97XenSBIXcTicD/99/vfKHuYjlXv9TXu7FvSQlztVkdNrxszB
/qH6oaL/uzGW8UJM31jObI7sdbzV7zz/hbwSbfVmt7SPmVehf/pUF3+S2RZ3
jrSbF8wx28Hd/9sTK2uYHTCwO89IcIjZCRMlviNyV+a14F1ZYe832kN2xdTt
oLzMLmYuPCNMcsKSmd2gMexZvoPPvA5B291eFSxhXo8WtTr+WudF8lu4uTi0
Jf4wswe40pjrtTbMnvj6vHZX18gFshcm6g1F5WLmDXAQL5uxa2feCO6Edeaz
JczeSHc5sWiDKfMmTCK9omSmm+yDzbLHm6Y5zL6INz/uLM/WkP3gZht8Z2ZQ
TX4bQr7NfHByF9kfk9KKy4PZneTNmJs5FDg73UHmIUNR49Cc10YGZqvqRQ2m
ZAXgWDG0Ubv5J+pboIp3tLMzbqG+BQaq8J/lvq3U+TB5adIxw6iZOh8+s8rK
v+Q/UA+AVe3rosKEGuoBOHe+yCL0dj31QHzxgfNA1nuN1AOhVB7rVljT8Zwg
3I/aIxntrqYeBOcLq+3LT1ZR3wrdipSpv/cXUt+K/lcmB6cOfkk9GJdL3FPO
VB2kHgz3P8abSguTeAs9BKpYX523zb4FK0JwKVf1q05Kx3MEOF399E/1Z3zq
AnxSqXrK3augLsTahpzyFU0Z9P5CBBc6tPHaEqiHYtigrFNUJqd9KMxVCTuu
FhfQ54fBIlb18nZOIfUwyAz3iE96HqEeDr7OZ2r2N9bDkXtDF+exOJW6CNba
PpHIh52/CILsq31lrmROBPxQJ9nXkUk9At2HLiWXjBygHonUpkd8v76UhfNF
JBoH0uZzzwbR8ZHQTDzIbBHELFgTCW93J68H9Zb0/cS46x4qzPTfRXsxrEvS
rhc3HqbrIUbVu/cEzZa5C9aI8aZOeFzdq6S9BLqzU+s1wjTaS9Aw6LXzfnM6
7SXId9lpMjB+gPYSyAJ93Y6YsesfBa+L99oVRam0j8JolNJ3OIDeXxGFJWsa
Gt9PyqN9FMbWrPy0f1UB7aMxbB9aM/+Mfi+IxnOH3wNPd7Dzj8Z466PSa3X5
tI9Gfl/ik9oe9vkxCCvVLrUQF9E+BvlGyvKPBo/SPgba1oqj+epi2sfAz8B5
IC7sG9pLMeTKtbOSkyFFtpHFyJhhBe2liHTT3mpyPUV7KQZuphRou8/QXgYh
TL5KSiRDhiveg2PnvGppL0ONX6fz9zfqaC9D1T6Xolou+39ug21/tPvS136k
/TakGt/pyPpYRXs9a/TMiX3RiMXD6qy5uY10/1LoWaNnjvxFQ88KPWv0zImD
53fau08+p/sj4nDMw9JpwkrT9Q9MWTNv
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91HlUjfkfB/BrRHP8QjHJJLltlhKFsrW8S2nRvt3qtty1WxpFCMPkmhbU
IMtMKhRpjFE0Y+2WukqjjKhMWigpUVI4xhLR+B2fr+ec5zzndd7P+3k/5/nj
0RPF+ki/4nA4NZ/O/1/Zod6Ut9p6zLXyz3puy5FajtH4Yg4K37o9Xq3K/DW0
j0yc5fz2L7I6Lv2SmeTXy/wNss7XqGS3M0+GS+3opJ9uMuvgaNmeHWurmbkw
OyE8vKaQWR8Ba6JiruUzG6I4NvSWRMg8Hdn5l7JTrJhngnctKuvMSGZjzNWp
lti2V5FnY864U9Y7pcxzEBP0sXNgPrMZFvFLfXO+2BzvusxfX/RjnofZFr05
opHM81HC2zZ7W+FV8gJoh/plLn9cSbbAdftFKfGDFWRL3JeW7F7lx7wQrtX1
9gmTleRFSO8M05ukX0ZejNw9WqNCVpeSl2B19c8bv9UoJi9FaV3Y9JRdCrIV
EjObG38oYX1rVM86118Qd5lsA4t7ovO/GbG+LTzKn80YkX2eDLRpijRsNMly
YJLO2JQ+nQLK7VCxQFd3Z1sh5XaIKTI91D9winJ7aC16rCkMyKbcHr3rp78e
SD9E+TIE26jPjKs7QPkyrK1sGd1un065A9J3jDfeJ9xIuQPuKSy3qT3davs5
d8SRJwkeqf77P1vuiN3P1KrUi3MpXw4F73xt2d7jlC/H9sp1CUGJf1DuhPp5
N7QTTc9S7oRN9np7P5YrKHeG1dwDGYd3lVPujL2askzri1cod4G55YdD5u1k
uQuajncm3NG8SrkrJr4pi97wnix3hWPG4lPjUEX5Cng4R4YE8v6ifAUqPOLv
Tl55jXI3HO7UU9y4Uk25G0xzF+PMATLHHQMzXXM4G1nuDpuA8tdzdVnugcZ5
UcqMC/Q8uQdat2aqBYWy3BMOur3DsSY1lHuiorjVbFIvy70wQjt8RMFDyuGF
aP6mod9+Z/d7QSfvuqe909+frfRCv1GyVbktmeONMP276Y8OkeGNj5nvNiWp
36C+N4a0X5Vvm05WeuN1uqI55hXr+8BprmTL5TjW90HDinxP3VVkuQ/y/XMM
NjbQ+yh9kFs5gcv1YH1fhDRdDQ/WqKW+L5QrBTOGXG9S3xfNL7xtnlvVUd8X
Wg+qv3LeR+b44ePN/vDsQTL8MDtkRpP8RD31/eDav6zEdZis9IOO6smgUQUN
1PeHlu2Uyo6q29T3R1XLip+TvyPL/ZEzcZb3uTqy8pObzGVNv/5D/QCo6bWa
Gh8mIwAKg/nXbx0nywOw9o3duaLwRuoH4Lh6flHaczKHhwk/BXpp692hPg9t
qep1fZwm6vNwOa6lT9pHVvLA168wPNNJ5gTi/vQ41TbnZuoHwk6QaiZ4Q5YH
wntd3UKDxS3UD4TypLTo6HYyJwhPfd696dlHRhCW8Sbpmp4my4Ow91GB/ndD
rB+EiQ332xQqrdQPhp1xk2nJCdYPhkp7bfSfkymXB0OYvLXHxIKsDMaH/DxL
qTHr89FzuXrQYj4ZfLytf5KhJWR9PtbGKd6lxrM+H6XfFKQU+7J+CG5HNWdO
zmL9EHhlOZQd/NIPwcv3qc8uFrF+CPKM4h+GRd6lfiheiIcdB8T3qB8KE5Oe
W6dT26gfCu5Wl82vH1CuDIXDYFaipI7MCcOfdkb+IUF0P8LAa+i6tGFpO/XD
EGHfWV+ld5/6YThj9qzVaWoH9cMxb/mWxsqtZIRDraDQyCiLLA9HfgZfrD/2
AfXD0TnmwU59bTJHgCqpd/P7GjJXgGMHh01GFpMhgGfvmkNzWC4QQBRzMU32
iCwXIPmsXXeaZ+dn5woQy928x7SarBSg0rznZNpLcocAbeHfnw2b1EX7wk//
j+Mf3uqQuUKMUVXtaJxFhhDy26LxQzPIAiEC1f3u13iS5UKMdTfu2iUm5wpx
N1x1pWY2WSlE1HCRWUstuUOIPTknW3/sYfsiSBtKDepUHtK+CD+YtVs/1yFD
BL0zobOiuWSBCKG7zmOMDVkuwpVxo6y325NzRTBv0fq9wZasFGH4qucqn7nk
DhG6XY7F9S8kc8RQPg0u6FvA9sXg/zNc6j6O7Yvhanc6+IUB2xdj2r8BXU7z
2L4Y2VZLRk8zYvtiaP799Y6KOWxfjN3r7o5NsWT7YniEjZ9y04LtS+Dn0WU+
sJTtS6CRvCHDyYntSxBlMiMtw5rtS1ARtOXgHUe2L8GJY3+kXF/M9iXY+1QU
+6s725egWls3eBrYvgS2LvIjDiznSDH6Gi95gH0/rhSd/KH+6Ai2L8Uv/RcM
JqSxfSmGzdMkSXK2L0XsiH3OfYlsX4pSaV5NDOsrpfj2wv8an6awfSkWLZz9
ceoVth+Bo253uAk1bD8C3afifVIb2H4E2pYIr3zoZ/sRKB9lVeLwnu1HwLnw
xMEko27aj0BCqSHvoC1ZGYFphs6+FcvIHRE4oDbI3+BL5sgQ4Fb6ag8zV4Zz
WYl5Gj+SIcPUBXcM16WQBTJ0DWY1799Clssg/dfRTjuG7ctQ37D9XnA625dh
ypYnjrVJbF8GwfDYIkU024+EnX05Z5Q/24+EIcr2lwSx/UgsbZAl5Liz/Uh4
3Lbw6g5m+5F4v6pM8XIl249EwsQVG93Ws/1IaL9Y7+DE8o5IqDxyjp+6me1H
wVxl7c71Ed22/wHrKfE8
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zH0sFGAcwPG7NEWnrmnNtYsjXc1anXAujvvdcS/ejtPyXpO3plli2To1
3ZZJxJo1RZ3zEodjhwoZDufcH62iP44sTGdpZGtIZqWX+T3P9uzZZ9/n93NN
yY5O30WhUAL/3f8vOfTJhusB9mbDjr4LWn+2L4voxBRwWt0YLHAg3gvcdVl2
iS0xHaJed9OS1sbQh+DbQOGH0iViJ9DJYi3CGWImjNBEiRsmYhaMTttONbYS
u4GNlsJmFxG7g8a25Qwvn5gNx+MuzkjiiU/C5X21C1pnYg/oWK3rD5owoU9B
SvFnq2Gc+DSwmKaEyVpiDizaMLaj+cSeIOL0PtEMj6LPwubRzk0Gl9gL7jGt
U1tlRrQ3fKXumS90I/aBVt/k+OexxFwwRsWMGUtH0L6QTJNPyHqG0TxoTnzM
93chPgcOnF9SBxtiPzB2SKyW5iG0P7Acv/xuWzeg+aC+EhKjoBIHwMBV8403
FPI/EFYyFOI7bwfRArjpZ1kTew+gAdI+llLt0vp3rAJQKOXlHHUfdiE8U7FN
5uQe7EJw1Dpkyqp7sYtgNvXaXDm/G7sIdvM0nvPKl9iDoIbO8shhdGEPgoUy
Te19vQ57MPBpP/6sm5uxB8NM/YWC5cON2MWgkWft325pwy6GLH3JuzhZNXYJ
ZFZEmQft67BLQFFs1fkEarFLYbzCbiliqAm7FDxeHOvvGKrHLoP3oJfmsRqw
y8BJr45WFj3CHgIpu9oFNQ152EPgxNPyvpx8pWCnh0ITL8klMiMSeyh4Fcet
WB7ewh4GbZ86mZWLuTtWhYHrXNUlxkEu7g+HV9POKvqDXJwPh7JKtU7Yp8Qe
AQcS8qaos+dxPgKOjDtnUMTpuF8OnqlbjQZOFXY53HXvilfdrhP8BTx2MHQ=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90gk41fkeBvAzNGlPpatsHVJKKg4jU+G1hGSX49jP5qCNSNpGZ0JDq4aK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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tIU2Ecx/GjWQ5vzbwt1MzSptJKy5XpbD91zlu6tdnULprSRRPUJIt8
YYdK0BdBrwSJSFPCCDMSFTWdl7yxlZSWuCjLUAnMS0EE3jJ8/kQ7cDh8+D7P
/3mOd1a+5rwlx3GK9ffvlx7hWE1BuM2AfkML8uDZxl9iOzKHB7N3JnNtyQLY
i+Z0PziyEOLPUr+phX5mZ6Tqt1T4T5NF2Byh0rW8JXtg2Ktn6EIfeSdKM/Wf
7CvIu2DdMiR1uEf2gTonZzxJQ94DnyxniyAJ2Q9NzQKPeUtyAAZSshuKevuY
90KkUbe51JP3YXlubaq+jByIym2tU56+5CAkC5wC1WkvmQ/A0s80qnIiH4SV
dYZI+66XORj+E+ncxWSyFONlXjLFC/Ih9Fa19xYMkw/D5Qu/aeYuzQtBx/TM
1hs8+QgmSh1HtgvpPqF49CZcsNRBPQzVBQsrHj7UZTDqtAWPU2h+ONICRo5n
LPYwH4Vgh6Tc0ZMsR727uOhWahczcGJQFlc+q98wD3jLTfmSPGYuAqZ0cXf/
braej0CmozHlpxX1SBT/di1xeEI9EtcEH5DnSvOjUGqyta/61sl6FF4bBdrb
HtQVUFb2d8rc2P14BSJ9R+ccltl6LhpXtfrVno5u1tfNX854msvMKaEprFUm
VLSxroSh1SA2FLWzHoMSuTBN/r6Z9RgsqeyKpZkdrMeiLDrjzCkdMx+L7AT9
K/UE7Y+DbL6hJuRrK+txGHEP3X9zhZ3HxUMa1rOY3kT743F/sArXk+tYT/jf
vJm5Y2bdzFyiWU9E9fc6w8mYZ6wnYeKcwCn59HPWzcypIJxcs/lorGddhbPu
tVdW26mr4VNbPWYsbNww1AjmG/wlD5vYejUs3Hy9hi6x/+/65z9hOU7j
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90Xs41PkeB/Bh6baKbuLsckalLdlq0ipZec9QLo2MW+6MuTBl2/awtdV2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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0H0sFHAcx/HLXOvB6uRWbSeLonSVhzx0OD4ccsjdUVQrPYitJipmlDwV
TXkqnDqFIoksWhEyp8hQG8ZI1sN6wGxhMrakh93390d+22+/vfb+/b5//AyP
hfsGa3E4HPe/+9/JFq+/+LR4WVuTRhNOomt6nlNLmDkQRK+vXMNlXoLDgzaR
Y/OvyDz0jOUIlD+Y+RAHdW27/Yl5LXitN7YJa5n1oX3Btel6LvN63P3VUV18
ltkIyTlh/o5hzBvRPCwubXJkNsF45Yuiw3Ot5M0IMDOoUg0yb0Hs8AmLznTm
rZD526bm7mPejpV21v69Oszm6NmvP/H9awvZAsMdfIH8KrMlni3qPKEYfUne
ge5Cn7KfKmYrNPdFGEuDmK1RNZZv2BXGbANJd3uS2QZmW4TMNRzyk78g70RI
b2svv7CZLEL2t9DYTXvVZDvcG12eNlDVSLZHdk1N5kM1swOqlQOLZ6/Xk8Uw
zYhs9JmvJTvi3dHAgrbyJ2Qn9KpsP9ZXPCIDn6PUPvb6VRonAAkx0ecea1VT
d0bH5GkBt6CCujNaRBb9ulkPqLvAw1dv1Rt5KXUX1JfNqY+Hs/kStLSMm96x
JCdIcFLsdiCxmuZxXHF7VUoKN7WcuitmlNy0856su4EXKGzQGbhP3Q1FuhmJ
k3kq6u4wKV/jOO8QQd0d62ayJcbD15w0fRdWLuJF6bRlaZywC5eyrI2GTPKo
eyBKePl7qPYt6gvMkSI4QPW7X1FEXQrDWfVEP4/M8URnn9Ue/lP23hNnRgJX
fBbepO6Faff9plHjSupe+HAqeals4Ap1b2jZT+W9nUym7o2Y8rqLOd6Z1HfD
Xzkk0v2VRH03ZOl7c0v4cdR9EP+p3UBqHkl9gTmyBV0GZZBr5RFJEP2fHF9E
8QdNfOM0hhy1FSHTXwV+dF+O7J3PO7irUzRdLUf+ivdSg+5ceq/431Ag2qPO
bOR1SdMffERXOQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQMC1xcX2HId3w/hfbCP/7fzog6cz+Bg4bbzahec
z+HwgnGHUYUQjC/goBwTEnlBDMYXcTi6ca5nNQ+ML+EQ/tX6i+KnY1C+jAPn
5WoznzswvoJD9jL5zNR1ML6Sg8RprzULN8H4Kg7m+w/5LMiG8dUcJG/tqysu
h/E1HC7u1nCqCYfxtRxifyx/9sUVxtdxqN6SwzmZDcbXc2jITvuace0olG/g
YNh0+47GRhjf0CHixJ/H2vEwvpFDosd0+5ZtR6B8Y4dw28oj60tgfBOHuN57
50tCYHxTBxd1dikOjcNQvpnDzX2Mn2b+PwTlmzvw3pxYUnEbxrdwmGc9i0m7
D8a3dPjXuiRh0h4Y38rh26qp76cch5ln7aAtfOTFj3KYvI3DxLWsT7XyYXxb
B6WVvJnZnw9C+XYOL/suzZKKhPHtHWoTw5fxsRyA8h0c7NhUFjNPh/IbHBw+
HdJxqXOByTs6iEXc+/7l8A6ovKOD14PElklbYeY5OSj/jIjU44fyG5wcJsl4
bF55CKbf2aH0zLK5c6/DzHd2iAg7yS50ew9U3sVhklXa4SfnoPwGFwfJlYta
Tt+Bhb8rKr/B1UGM1dCz3ujgfgCq790p
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tIk1Ecx/F5ieYl01QKkrwgw9SyeUmbTn+P29x0W6FEhd3MsBARpUwl
fPEU5A0sB9lCaS/KIsc0TW05hUxrSrWgLfJFvbEXKeEsU8rpkorOn8gHDg8f
vodzzj+yuKKgxFMgEGT8Xn/+9AVO3amU+k48+auvWaF6ZYunkCzAFSd3tsOH
LETzG6G6wW1lDkS+l2atwUUOQWnhbHDRGnkbRofshtAv5DBg4Ea7zoPOi8Dd
zgslO2aoR2GTfX5Degc5GoYm14/ydrIIM5xiNe4yOQYLySZTfgU5FvXi4a6E
VHI8Wqwm3fl3z5l3o4nz9dM3kPdgsX6X+5qSLMZYZbO6tvMZcyKul1eduH2O
nISasuYC635yMvpti3E1SeQUPKgTLn+4P868F23Gm2UHtORUVKuXSh3e5DTc
OuTfdjyMvA+qwjTnVCRZAvP29+NddeR0BNnmYnNDyBn46G08k28bY5ZiNlQu
kpym92TCc7D1sFFE82UhpvdFY3c1dcBWmxLQmMXMA2FRKxejf9L5HMK/vzJf
nWLmOfhUFy+X1VLPhtNepNdVUc+G297ToX35lHUZji4k21qjmXkZjDXfuuek
o6zLIeXkl0IGLKzLccqkOXjPMcK6AqoIXW982xDrCow6OMVOs5n1HAT7F/Xp
vR6xnoMRcYAufvNj1pWQNE3KXvux/bwSmsGVSr2rj3UVxMOu+R5rP+sqJFoq
Elo/PWQ9F+G8Y4twiZnPxcZgiSF2ld0nyMOxoMkqxwi7j8/D9OeWIx6WYdbV
SDvps/Ut2Dy8GtOZGrdzgubT/G9+nQXadf2ffwHS/zVd
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdkHtQVFUcx6+UDwxWJIGFgMx0EzKQh0CA7ncVAZF1YZdllwWVeMTw0FSi
1HBYrVZQUBFZUVZiQlEgVxTRyARCRHKShzIgTVpSEoQpDCgDLlgNv9Mf3pk7
dz7zOZ9zfue+FfORNN6I47iUf9//vuwx6yrZsnz2jbopGhQmRfFsxeaMOWTG
/1JgYcF4FtoXV3S+O4OxGR5350dbGjGeh12porG3x5qI+aiJufR308+MbWHp
EGs9q5rxfIh5Ep1dJuMFOBOcc6oxnfFCnLw87jG8n7EAOU+EeZP/r1+MF5+K
T+VtZOwInwcBvvnzGS+Bc7T5WZmAsRMa4izSLY0ZL8W4u1+pUdZ1YhfgjHPz
ZifGrti6LcP+d3PGbpBetM2dtrWR2B2FR8ze5AsYL4OXf3TgHXPGHtj0G2/a
V/6MPZGTMvBd3LNrxF740cvn6OgB5t+Hm/OQKfKZ90Zg9a7W2DLGPnjaX65q
c2bsi49bDmv7bv9AvBzj+gAXk88biFfgpsW5BQX3mBfCZvVrnglejAF1v92J
jgf1U6wGfur5QhSlrSMvgrnD81tzQ66QF+H61Xl/6KMvkF+JHomut8upmvxK
dE+PeVK37Dz5VUjeJK0uNKkkvwopc6wHRJ+dJu8HqVVH88KiE+T9cNXimmbH
zGPkVyM9KpYnqDtEfjX2Spt6t5/cT94f+7d75emyEsn74/6j/heRIweEUz4A
3zrO7mnT5k6xOgC1j3qvCbL3kQ9EbY/hmXVhDvlA7C7kZee1Z5FfA63VxtF9
jvnk12BI32OTHaEjH4RGcTskbUfJB+H2TonmHcNx8mshS0gca1OeIL8Wxnaf
mNhXFZMPRl5Z5N177mfIByM6Z8l7VZpS8mKM+Ovc4taXkBej6mBnY2ZNAfl1
WBGklScLtORfYk7ykpcg63rzlsh+mpcLQRJXbJt1k/ZDCCYiG0tTVxGrQ9A5
XuOe1UtcH4KLpuWduWlF1Idi9GHf06iLX1MfijRdZM1A6mnqQ/FGkLXb0ATd
rz4UdjNEFZKWc9RL8WVl/IbNFpXUSyG0Nz44XltBvRSeGoNpkU059VL8uS19
7dEFtB8ng+Mcz+8XPaTzIMOxItsg8R7WyzCg7y6tuM96GUY/VLjywr6hPgzO
nnu6np8jRhjMjBvHMnawPgyZBcPLS66w+cMwl1uX2LKJPCdHF//4ktl1rJcj
+DC/L6BDT70cdyvShwRSum+9HPe79hzgG9N9uXCMJmleHyim9QjHUoXDr2kd
tF4dDtfqRR3K3VXUh6PaNNch1EDMKeAZNu8kN3mBegVaR6bzPLqI1QqM1O4t
K3al8+oVOPyB71+87vPUKxG1UKlyucX+vxIN+bxpgzLyaiVSDcMbNMvY/EpM
TjcJdhOcpT4Cwf6DM/nJxIhAbevE+soj7P9FwGAld3ysoP3qIyD3Cczwnkvz
cSpcPhTwSozPJepV2Fky3LbyBs2jVqFPr8q/E896FRJS2vte9S4V/gMZZgiH

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zG1Ik1EYxvEHqy2XiqHSkqAyEzOVNKfNtF3TPZsQBTOiBluwZTUlMz/5
UswFRV9UypFjgZqO0BA1na2cuZVlmy1DwqURRVAmo8BB64VQqfDcHTgcfvzv
c283VJWeiuA4Lvvv/ffSiZ21ny8UeT2rCsksqdZA9DoyB5NdEBnHkdejbfBm
yPXfsXhrHL4mFpDjMeftGspNIIvxu+zgfMca8hbUCDVn3MFnzNsQ3NVcsjtE
TkKPtK+InyYnY1r3MWbBRk6B06teG1VHTsXJGstijJGchmZT7RMHT07HT2nD
hwoZOROhyXeb4kDeA8N4ysvETxPMWUj61q5Mf0PORn9nU7dxnrwX2k67//kd
cg4WWoKVbVfJEjTe5U8rN9D+XNzw87B1UM+D62tvRYSOvA9HrJH2+dtPmaXo
utUrqUsk50P46v6hUcc4836Eq4+txJaSCxC9nPHj/WFyIZIfOeqPqskHYGiM
12kUj5llKF/R5nGX3MyAYGbsQrfl4arNwMALy0aTz8O6HCNVrVm1/WOsy6Hf
bFBpJWyeK4J1eCrhSxT9L0JB5RVhtWWU9WJIitXusI96MQIDPpto2cW6AvnH
W40zDmazAvfaT8zuCD5gnYf84kh+eNHJOg/9XJNsapD2K/FZVT7ZIGbzZiUc
rpDo8vch1lUoE2idaTv7WFehJXDudcbZXtZLsJQ54b+up/0l+LV1KUdT3+/5
AyU1/wQ=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zQtUzHkfx/F5Wrm1Jbdkk6aRokeSUC7VRxEZdB1N08U002WyKKd9yoZ2
pjtR61abpHGrSEpaVGjSndguqFZtQ1qkm5xkn2wee3z/z5zzP3Ne5/N7n6++
KNjFX4XFYtV9+f75Z36aLedDrCbXlH3VoI1ZfO3Quf+bhduWmpO0WYwnovy8
02zBp2qyJtrtuqfl9TCeAX5ls9fcbsbaCPz1peVwFeM52JvsHZ/XxZiNSt+I
g9y7jDng8PMTWKmMDaB+YsvDm/sZGyLheOz4jzaMF0AWYZm604ixMbZon9G4
UltFXoRu6eGBknzGi3EkJeLTreOMl4DX8aLgVARjM7T16p7UGa4kL4WOuDtp
Uipjcxj8atR6jMN4Gbi8uJptCRXk5fC88fwnHGe8AkayWHle3z2yBf7rI9cR
DDK2xBWWxf7wgXLySpwrMd81zGH2VZgl1HofYMx4NWp9+p7vzFaQ1wD/zo16
NVZGtkKdrH5Ndwhja5gl6mXEWzC2QUxa8PiqhGIy0Bx/UJCicvOrpYAw1Wh3
Ma+Q9rWwmvD5jJv2NdrXIt9wccSECcxuiwlDL7KWh16n3Rbh5sd03y6i9yw7
dHFVNP3SC2i3w1q7Y6Lonlza18E52EhVtzqL9nVosJ8r6nHPoX095idFD9jE
XaB9PcJGC42MJJdpt0fQJ23bRI1s2u3x59OwwQf9zL4B8VcqF53tO0X7Btxf
sup9u9YJ2jfi6EoTGSsnkfaNeGfcl2R2kdkd8Plfjw/PmpFEuwN28gumWpvK
aN8Eyejpn4+XxtC+CaUd5npXF0bSzoUBe2v+Hp99Nl93Ls6o/NYY3JDw1azN
aLsambg3Pob2zZCUqi0YVk2mfQscbx/5Xmf7Udq3QLarYaFx6RHat6LTOjHs
P9OYfSs4N5oPHVpxgnZHPNt1e2GmhCx1xGWHJaVNBim0O6HlbufQpEO0wwkv
rUyjGrPT6L0TZqtavFuiSu8VTrCMcoqdonGKeme8SlkUKl5HhjNsbY6OnFPS
e6kzVjlEBg1FnabeGa0y3qOW+PPUu0Cmp+Ntffsi9S7gGbqW6l7Pot4FB0Tj
42fcvEy9C8zvzRUEDJFZrlDV61JLq7hKvStS9dtY80LyqXfFuOuOg3drCqh3
xatCjnm+RiH1bhgRCNJLRshwg6rtTF2rqUXUu6HllaugqJuscENyfZhT4/Ib
1PNglft4g+m3t6jn4cLQnb8drxVTz8OzjgyDNa/JCh7MHXlm1R9KqN+GTXXW
MVXsUuq3wdV2xZDanDLqt8H2Yle28zoF9dsQ2Wwiav2hnHp3xAz8aHy3+h71
7ngTHv9gckoF9e5o+zDJQuxeSb07vLp/Gqf+C5nFR7GFZ8hW7Srq+bAKSXkd
nU6W8pFc8tFUf4ys4KMv+fV+i5Fq6j1Qa5bEKrWrod4Dtz5IYtUekaUecEnz
+3PArZZ6D7zV4e5b0VpHvQCn0ht7n6eTIcDu22+6Sqbdp16AbwsvCifvJisE
cCzh6/7exvSekDUZicuWP6DeE4WZuk/S25neExd+qQzPuMP0nkhZql72KZ/e
s7ygqEmqnHO9nnovmFS81ZdFkKVeMG8ZDTVuJyu8MNJb02Aw5SH13sjmhg1E
8snwhm5hY67DjkfUe8OrujheeYms8Ea/W/qbIU4D9T54IR/3s7KCDB/svlSQ
41BGlvog2VE1c0oGWeGDoD6VuHczG6nfDs98y/jRUDK2w/asKCg6lyzdjt+W
F+moqTZRvx2Loy09Nk8ns4RQXk432W1NZn+xIDg9xZcMIcI6InJ23CILhTh4
0qF6VQlZKsS8+ZwblwbIciHOc4MyPceYe0IMWys29+g0f7VSiMx3O4wKtMks
XwhWh5ec6GHu++LQM/a8Xc60wxfLRGsNG5LJQl8MT5zOMTlLlvoid5Vat811
stwXXTefDEZPeUz3fTHH0NjjZRlz3xcqytXVoxeZ+yJw8s5WeTST2SJkRRSb
nQmlHiJMTZv1LjWCLBThVl5af28vWSpC5HBv/2WVJ3RfhOCOJJUlVmSFCMYW
7PT168hKEV6edm7kPyCzxOg/bJcz7j2ZLUbnD0X3NfSf0n0xho5aTdRZSxaK
0VR4P5TbSJaKobks/6RnOVkuRlaSR0Yyv4Xuf3mvmVGQGENWitERZbJBVUhm
+eHSi9PTUE9m++FtbMofnZlk+CH6PLd6Rj9Z6Af3A3+ov5rdSvf9kKVXuHSn
FVnuh7DIoO9GV5IVfmgbf+fBo/lkpR9ec/Z3a/LJLH9k5mr9VXuMzPbH08Fv
LFv/JsMfcXu8G368Shb6I6rb1GJxJ3PfHz3XpjuOmrTRfX+s0aznxa4nK/zR
pz9xhrmMrPQHJ3w078A9MisA5/o4xfsYswPg9fJ56p6HZATAvn6Mq9dCFgYg
RPXoopmbfqf7AfA37+XbHyTLAyAu/6lhLJOsCMCEuM1qdTFkZQCublSfqZFA
ZgWi3FCr+i/mPTsQrIam7+UfyQjExD11Xk2zntH9QOQFRl1YoEqWBmLkyMPj
wSfJ8kBonbZX6RzfTvcD0W79uUi2gqwMhEdCd456MJklwQ1eo8dhOZktwWKt
kW9aGsiQoKLTedmuErJQgtymotLG92SpBIe3cj/tLSPLJcgua0o+eIm5L0GQ
9qOxskrmvgQaet8NFpt20P0gOGvFxkWs7rD5H6nN9lI=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzm1IE1AUxvGlgtaI9kHDUYmbU2NIM3OultPHqZsuiHxbtTJJV4GQmlPB
FWNZVII5DGtZKZUZhZEhZabZxEwnOtAxLSiLzHyBqFlJWokV3uOHLlwuP/7n
wBVk56ce8uBwONK/999Lh/eyvkCxqte2JHfsoHE08NRKMgetPyTG6zyyD1wm
t1LjReaBZ5Bj9fK+LzxzqobD/cj+mAm3FhWvIa/HgLpPUrq8H4ivLb41Wb97
mIWYK2nzjl6eF6HzZHWlfZx6CD7y7nFF7eSNaNrjXGc8QhYjxD9g8ZKWHAbx
iZ0fHseQN8EwW1EnDiOHI8euaJjrf8G8GcIJwUKDjhyBp29W5Eg15C3YUTsy
pt1NjsTCGb4g048sxR3+8eBkWzdzFIqmrp3LMJNlCEhPPVCjI2+FpfrVXft+
8jb0nC5ylnU/Z5bDWy+KdHiQtyM/wfXlJ5ccjezCRb71UxezAvyZCVlaBDkG
eklneZ+ZHAu9TOK0BHcyA9HuvNmS+x1LNgOOjPnp8rpnrMeh0dfOnwxi8+Y4
nHcdrBofo30lRoq/BRw2sXmzEkPfb3Tbp1tZj4eYO9j07tcj1uMR1b7WJ+X9
E9YT4PlWV9DCb2c9AbvS93bIh9tYT0RFZa/YS/iQ9UTsaxzqeq28yroKhf6G
0KO5t1hXoXRDykCzo4V1NUTBk/JmFfuPWY0s3YUrl0Ppf0lQZd48O192m/Uk
pKlNQRctD1hPhtW6qM0dzWP9P3M06B+tF3yeOmb7A3N4Cw4=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9yWtIU3EYx/FzJpGWkIhB0GVnMc2JNpeXLnPbb5djJL2QTMFmIZYvpGQL
WkytNOpF1GZCQkFqlBShhKuWmcM0dc4blCHlaF2WM7qM0hUkFFnh//GBHw8f
vrIyy55yCcdxyn/7/+niXrZaNSt8vYua1Y0uLxUTY8kceKW/sXLJ0ZgKFp12
RZHjoHhVMTMbTU6AQr/+c8GfIeY1mAkXvfPy1NfBWRN/5P00dQFVe12r982R
N8I6csN/PESWIxL4nvf6FjkJ49bhmuBtcjIm2+eC4cPkFPDP+fN8OjkVVYcu
aO2byJux/9e3mItKcjosaSlHtV4vswoxXc6JZwHyFhSebGoobiJnwNCi88t+
kDORVC2/8+YUOQtjiuqsKxnkbAjNefl6kbwVH+qHFsxvB5m3Icfc/HT8AHk7
JAnLEh0HyTvw5VhHn6J9gFmNVVc1slFpP3MO6u6W9Hd4njBrYK/w6ubVZC0+
pYYdtbFkHcwlPfG2KDKQOWVqsTn6Fl0HbOjeVduW/Zh1PdxhXtj9tYd1PSpf
OH0N9cycAZLpgcHOS72sGyA3e85IL3tYN+JE4/zNMbGLdSM+RlpDa1d2s27C
hFsQnKpHrJtwL1+9IHU/ZF3ESOh+qcVFXUShynY98qCT9VwUJNt/nr3mZj0X
v42+yLlAG+s7l/wXJ4fyIQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQMC1xcX2HId3w/hfbDfo3730ANWGJ/BYZY/6y1p
Jhifw6FbMvNcAzuML+AgedJAvxUuL+JwSCXGjO3dMShfwmH6vOnHwg/D+DIO
KRdFVrIuhPEVHDh62/8oNcP4Sg71aWtydiTD+CoOlTrvcnVqYXw1B5lrzyxS
LWF8DYfpby5c5lOD8bUcIhU7o9fZwPg6Dp1SXUnpX45C+XoOC25MEIk6DeMb
OGyZJTCZ/RqMb+hw+KTXhfe3YHwjh9u13qcVK2B8Y4fdNi8b+JfA+CYOLPvn
/A4Sh/FNHQK/yk8OOnEEyjdzYHxY9frT18NQvrnDeoE35hutYHwLB/4Xfxjf
vj8E5Vs6LLZqLnS8AONbOWyb6LziXiDMPGsH1nMHyu88gum3cZA5tEnujS1M
3tahSCayJKkKxrdzMFB57pmSCXOfvUOoBtMzRxmYvIPD+SW2f4SOQM1rcHDI
rFto49gFM9/R4c3vuCsubFD1DY4O638n5GzUhMk7OXyQOHpqkw1M3snBTeXj
7F85MPOdHfwSk2ZeNIaZ7+xw8fI87/Q/B6DyLg5uZT2vk29ug8q7OGQFzuF6
lbYDKu/qkHX90OPGFzuh8mh8BjeHtWd/O9pW74bKuzkUbb3+8/Ki/VB5dwfu
JRw6ysFQfoO7w5QsGdVuZpi8h4Ojba7e0pR9UHk0PoMnmjyCDwAksgZs
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90HtIk1EYBvCtYLhAkBmWFaXRVltTZvtss1w+23QzZkYTBJMpM1waw5JE
jSIXQX8EE2Fi2oUVlZBgDEGovCz1a1lpJVYimYgTbGQXN4rM2Y3O24HD4cdz
Ds/LSS47bi1fJRAI1H/235NW3MTNE7o1j/3/9CXLOTrbOPjfAnyTn67lReQY
jHhHPMvfA8xxiN2ZbaubIa+F/WpXieQpeT1UBS2yTp68CXxyWDLkJidheeVZ
1f1K8laEHf1TaRx5GwLl6iVPDFkGrltV9WPiEfMOpDuUwYbbZAX01dVHLreS
lXDKFam2FHIq5loHSp/IyCqcm5a7Z97wzGnIE3sDDR3kXUgam46fLCOrUbfR
KDTkkTl4X9k0tcNDzOkI3Sqab0+kfDfuvpNre5cHmTXY0ORbqT5M97XgFm3x
ph5yBlocL/M7feQ9UJ68cd28NMC8Fz8d9mYuSs6ERlo8XjJP1sGibZuwyqlv
H9rUb0W2YXIWJsdXW3wfyUDgWjha0cXsAu6IZt3RA5TrYdXP8gsmyvUIa0VS
yWfqM+CFWHExLsTsMsB8zLxucc7PciMaD2259Pors8uIe1PPCyPSXpZnY7GJ
O/+gu4/l2agpDtS3n6L3OfgVPApd/kOW5yDFWRHpK2QWmBAcq7c3J1C/CcLR
oisHa2h+M8TbL7wvELP/dJkR8SV8CGXS/Lk4W5koy4rtZ3kuzixs/lTqof79
4IUZFv94j/83T/UHCg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAmIQDQMC1xcX2HId3w/hfbC/uMXw9llOGJ/BIVlwgVw+
L4zP4fBvzZaMyxwwvoDDWe8jqt2/jkH5Ig6K3cflfz+F8SUcJr/5v0LpPowv
47Ar2ty87jiMr+Aw692lbe5wvpJD9f8J1hETYHwVB5YimYLVtTC+moP07QQx
vkQYX8NhIldfD7MrjK/lIKeySsFXCsbXcZC+cIjH7PJRKF/PQfpPS1F9Hoxv
4NCeH6v/Ug7GN3ToPtMYHyUL4xs5WNenlZ6fcwTKN3aQaLZ70GUG45s4PJ+Z
/myPN4xv6nBvzd344IWHoXwzh4T0SsWoLzC+uQOLqux2tf8wvoVDYmqP36FS
mH5Lh2O1l6ZpTTwE5Vs5/P8eodgfdRDKt3YoyWUzmF64H8q3cfikfsJ9Yes+
KN/WYX2/ClPju71Qvp2DwwK29UbcMPPsHZ5KTtYL4D8A5Ts4hKWF+EQ+hKpv
cHDwSXzv/usqzDxHh3+3ldfXndsFlXd0UFicLzhPdjNU3snh7qnseL7ChfYQ
eTQ+g7OD767EVTJ6MHlnB49d2+4LWkyCyrs4lP3w+iG3YgFUHsEHACiUyxU=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0HtIU2EYx/ExWZh5GSpeQnDWEm+kzfLa5s85p24zzRInRkU0u6iY9oeV
ZAssMZDMVpnaxaT6Iy8p3hDNWVpBpZiBKelGFKlk6iTSZbOi9yHwwMvhwxee
9znH61BuiobL4XAkf87fNz380boTYpsXvf80HzWSrPZvsSVz8HN3GdfZgWyN
luz4SS8+mY9Ku0T9JR7ZGYbSBl3m0nNmN7Q6BVVXGckecDmZbrJ9SRbgUY+u
c6WJvAlvk/sWLJVkIRzUjfrpfLI3fN/lNrcJyT4oCCmxurY6wOwH3vhnTcBl
cgBmZjYv5F0kb4Wui5e2UkAOQuewwm9GTN4GSY0yx76nn1kEnTCLp/YkB6Na
4xzYoHrGvB3zj0tO1+mfMu9AoX/Rq1AFOQTdltj1i0N9zKFQmQvL70nIYVh3
Pd2da9Izh8O9hl+vFpEjUCcInBA19TJHIqJc+lEpo74TWUXNchs/shhvvDek
Csw0X4ICpWn5QTPtEwWbr594Pa9pf2BK6H1wrpRZCzi6utrd/EI9Ghbf7IqN
+ez7tdE4smQeGUui+VJw3t9oyrzP5mul8DzrYsgRUo+BlcuwaH8U9RiE9Bev
Th2mfWUw3Cmb5lZTl6GxLWjLVDvtGwvpsGQ0ba6b9VgYxwQZvrfpf8hhvLBo
v+zD7tPK4VTbOR63j+bHIXXQLVnmzqyNQ5dr4t1ijyesx+N4crV1rY7mx8My
W9U3WdLFegKyqpK+nRF3sp6A8NYJ/71H21lX4OHQB3neFWatAtzQgWMV56gr
ITT9mj1vpK7ErY7IQs0p6ioYfgxmfG+nroK83uy0p7GN9USkOAZfPRDWwfoa
c3at6f/9G5Z1OAg=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10mtIU2Ecx/GTgtioWJK5ZGmrJWJuXXZqW27zp3OXXhhLFI1IYhqFI1Or
F4Fri5JA9IWZaSsjmq6GjWxFZjVv3UYXSZMcVGMLJSK6SFEuKSp6/gcOhw/f
5/m/eJ4jse4v2h3HcZzi7/vvS49w0l2jFTwa/K8vub8+BvwGEZnD6set6XwK
OREH+spr5yeShfiwrEVnjyMvQeGJ+lORTw+ZRYhG69YK3pPFCB5Jzdz2hrwC
+TeM6cor5JWI/Ph8SegiS6EpCSK6k5wB7Tm9vHQHORPnuzzvpBpyFlIWj10o
TiJnY2aqW/Ms/IBZjhc/eysVV8nr8CSl57nATV6PIWuT8oyevAENUu7gy8h9
ZgWeGiQDqY1kHqr60mR7O3kjmg5b0m7G7jFvQmWv0OI5SlaidXm8WlZEVsFh
83bo2keY1Sjf2rJGNEHeDC7mO9Z8ktbnICmvbJ8uQtZA1G27LLtD67Ww+xrM
7hBZh6C9UT09Sc4FbxlzzY2SgYpQ5/dYGbMTkNVxjuTZYdbzUOzxSvWjzM48
VG+freJ0tD8fnuO+veFr1POxKsBH+kJDrOtx/fT46zY/zdcjwbbLVlV7l/UC
iFW/5307O8B6AdI6fF7xeD/rBmT1VCxdcHGQdQM8I3yYlwRYN0LuGJ8y5tB8
IxLmsmsM/XQfJtyaaOBexbP/wWnC7c6ZhW9LqJtRWN22yJ9B+83Y89VqOpRK
57sF8vTmaYdrePAPcSL9zQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzWtI01EYx/F/EZkJu6QyIclrQ13kbd7StZ9z6mZGubRgqyxtWOaNwghH
QwzGSkG7GCnovKTRBdosMLFtZplBbypaMWFpSI2IYqQWmkJG5+lFBw6HD99z
nhNRVqvRr+U4LnV1/zlpCd7118k2Tjr/yievln3XRPiTOSx1S8r8A8gb0Dpq
b1f6kQXwdUx+nAkkByFtSsurFJFDsNdSKR36Nz8UCQXn8mN9z5jDoX51eLBh
nBwJa01t5LSNHI1OedGNpC6yGMJ+j+3OZXIMOj36ks8XyXHIWrH7FVaTt0Fu
NZzuSSdvx9iQ5MTt6QnmBOjfvt7T1EpORHOwUflTTU7C/IV1QlM4ORkhM95g
7b2nzFJE6d2bDy0/YU4B/8vzUw6OeiqWK8DboienYTggTMmTk9MhmRtYmpWS
M3C0vMpc9Ibm7YDvfGlK6QdyJqLjzuyuGyZnwaipt3wdJcsQLS5OVhygeTtR
3NMcov9ElkOwXvzNvZUMRAlfTL0vZ+8bgZZ9+/nXFsZYz0ZLelVHSZOT9Ww4
vSIHb4S6ArcWB8Qr88yNCsQ6TQdzahys52DB0S5zhz1mPQe/0tq8CUHMnBJW
X+jLY4Zx1pXQzZpkgX3sPy4X8WbRQz7vEeu5uGqJr9e1jLCehwaeLdGgu896
HgrzrleoLjFz+XCd7fKoum2s58MzKLwyt+sm6yo8+GHZ5DbdZV0Fida+uGxm
9zk1jrdxqy/6WP/PXAGO2FwnJd5e1guQMbHGZczsdf4GSHAKzw==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxF0AlUzXkfx/FbpgiVJaPFjMhaRKmkRZ/SbddyK623bnevyNakbN0WJjwJ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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11nlYzfkeB/BDmLFENRlaTAdD6doqmSkt70iLymg/bafT2Vplmcod3BzF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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90n1MU1cYx/GuYWarzIlWOnS6MqwC6rrpmIrQ/igVi7yVttg/mGKnzXAO
Zf6BTCu5vlSkKoJ1vjCjYJEXnQypUQQmLSCTdsrUyXSSoMyIU4grQ4eQ2M30
Od7k5uaT733Oubk5wV+s1xj5PB5P8//96smu8b/bsqMFPzf79Lf8Xb8/TY/H
MfNQXP9rdNzr/hbWjZwd6RxtJ49HlzCvHkPMQvAnlQ72epjfQ3WnY57oGvP7
0Fndo6VNzGIEdsJZt5f5Q2T0LQt9lsk8HQpPUqw6jXkGdnaEPS0SM4fCqPve
vG3oMjkcbm+krbqBeTaWu3qt+nrmj+CVRjWUyJg/RtjYzJA1PW3kTzDwS8V6
SwXzXDy5fMxrFTLPg/ZBTrCnu5X8KQqy7KFBHuYIzN9RJjNsYf4MAfwJq0VC
5vmwLF9d50lrIS/Av9nf9Ju/c5IXQiQQtP5jYI7E5k2ma7btDvIi3N1V0LrK
3EyOQkm1xfXXGeZouCt7gloC2fsy6Gv2KadMaSLL0XZKPtj4sIEMBA3nxuTq
L/jMAcXc46aTgnPUY5D0Zdatr6fbqccg4+LaOUNZNdQVOJQ/16bNqaKuwFh9
oTHAU0k9Fs9vzryVN3CSeiz0c65yj6adoK5EiESlaR8tp66EX1Q2J27YT30x
Gn/I3K68U0x9MV6+OeF67RUyLw7ePrH8qzWsx2FheMbmdY+KqC+BZDigSFJL
5pagMitfpks8RF2FdnuruEdygLoKXWWu4AfP9lGPx9TKlA8WZJipxyNCdknq
Qg71pVB2q37a2r+H+lIcHmMKSVtroZ6AsutW08oLZC4BFV6B4cdZtB4vEfHl
B2znT5RQT4R092Rjj7SMehIKB0/fO5zO9k/CsE3dtJHbRD0ZguR7jnFxG+S+
noyVA1bLmGM7fOalYHLQzhfOWgPNp+BS4RGJN81MXQ1+gqWq/P5Gn6FGx6pt
zq4w6pwaW4bb/UXOPJ8daozkHhE2TtpN86lQuPghnnd20XwqDrr9J9bXpNN+
qfDmGJ/+Zsjz2ZGKF7fzFVfte+n7NSjt7eaO3ij1GRq0vB047Y/97DxocCXy
oLTASufLoUH+ohUv3Z9X0LwWfd+Gr0hvpPMILS56ZvpFjNTSvBb+2aLAtjfq
aF4Lu6n7+M3kMzSvw8OqG9YuGf1v6CDoVyk6tpY0/wenl6UY
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw903s41Ikex/GhXLpQ1DnbRZlQUnTjbE1bfAphMrmNy2jwm4sZulHtprSY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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10H8s1HEcx/HvSKmoK/2hkkVIUjqUwrmX+4Fz7pJ+0KzaEhYl/Rj5ta4f
bKG0KYVS5MflR6mlWnHnR9z6ocXookW1GVq1ftH8Tuv9ue2722PP7/e7z+tr
tfdQULgBx3E+09e/f/bj6W/GCubotP/1XegQefHlaR4zB/s/N5q0RszGOJJ/
KmR8uIXMAz/4wOCTEeZF0KxMvmX2i9kcfIV1cscbZgs0X9tZc0DLvByijmsv
EguYrbGv5NJRyyxmG7ipTlTwpcx2yK3dJ4vfymyPylgz5Z+pZrIDxs5kyPn1
zI6YMg8++e4R81oI5p727AxnXoeHB6Pyx6OZ+TisF3/MiWd2xhrvvGMhn56S
XWB47ryk8DazKxy0pSv7FMzrUZCq92oSMm/AzhU2bZFSZjf0+0dcLYtrIm+E
bWiFV8/rRvImJMzJeDAYxuwO3f6vhQO6BrIH4nLU6gZ9PdkToc4G20wMNGQB
glNtm6faHpO94CovGpZE1JKFqHw/Vn/jArsfUPIU1VECsgoY8jqbqTd/Qt0b
Abslx0dH7lH3hrc4bHaKy13qIsxemPJxseYOdRFiimrc5+mqqIvRWW53ta6X
dTGGwnvNFgRVU5dgZNKoMZUjqyT4PFO4Z0LDnpeiR/0qS5ZWSV2KTn77quJS
MucDK5Ps6sml5dR90F7k9DZSWUHdF6tF+mUR11n3xak6bdjFu8XU/fCjputL
zE+yyg+5RZp0dUMJdRmW1sj7TZ+VUpdhu65vQPyokLo/rIz8vjjFqKn7wyU7
PUeUws4nx1BC1MzOQdqjksPuXlUBr/I29QAklNTGjn5g+wPQHa3aYZpJ34tT
IKm7xZU3n+1XQHcn7dtvD7ZPibLyxEW6CbZPiRmWbvGhZ8qob4b7/eiuPiFZ
Ne1LswQdo3ReLhBOS7ocLZ7TXgSiNalZ7biR7Q3E5uFd9sUT1OsDEeJUcrmt
lZ1/C/K6xya7Pel92II6ww/Gv66cFP4Fx59s3Q==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10AlYzPkfB/DJsX8palGKJKVyX7WxZeuti0nXdOqco6mGQmodrb9MRGvZ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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxd1HlIk3Ecx/HHozyytoWVmXmUmIREHpXn/Gib9zE3yaKCFqaJpYZiggaP
XVJmECs7JHFdYiMtZyXmMbWyiYXaMfMPrbRMO0gRO9GKft9KBw/jxfv3fR6e
H8/zOG1Pl+8w5jhO9uv4/U8/oeFiRoBlW9MffQrsm3L8GjmXzGFr+oSfiiOb
Y/TZToeq0fvMQmQUl+VJ+8nW2JujmrB7TraBZGtBlbaFbIfgHKsveY1kR1xQ
GyrmXSYvw1L9QUvNUbIzXu0Tm0hjyC6wGMngZwnIrkgf1HXOuX+PeSXkpuXx
W1LIbii0V2Q3GO4yr8KdRa2tTz3Jq3Ej9Ul1m6GV2R0eudFGDY/JHriadCM5
xIbsicZrvkPi/BZmL3QcDuibyCavgabMI22kkrwW8RaFvsX+5HVwjnxzzz6p
mdkbtpmTQp9bOmYfuDTX14oOkH1hpE8Vl+6h9X5QO/WYLB4m+yNRP3B+59/r
B+B6Qf/EKSeyGOZdq1qjnWl9IAY6taIEVzo/IPDizPQurPOAWXyp+sujJtaD
8FqVb7DVMfNBmL85Zygris4XjLeqqfLvd2k+GHz3uDZJSX09RNbD1VnvqK9H
07O5Lk8/N7Augab4uMZH0ci6BGY3rSfdo5g5KZTrlO5bstj+81LsNk36mKam
+wuZbj4Et5UnxsJy6f5CMe355kMhEp0cn11Bz3MYrP43HwZtyXDJy0Tq4Wgx
GdtjeoR6OHLbegu3ZVKPQPKlJd4RFtQjUPvoQ2b9igesR6KuviP/Sj/1SMw7
rTRKMKf5qOnmZ5iLntFnmIuB9ZBe7b+YegwKRkO/9bpTj8Wh1cvVNYHUY3G0
qigh1Ji6DJWZttk/drH3CTLsLzkz8GITMy9DzVmT8Itqtl4ng6brXPYcAc3H
4WTRQ53AlBlx2Ctubx8h83EIsavLvf6e5uPQk2dT3yakeTlc38RuS6bvDeS4
JBmM4RbQvBzJ5SmzVXQ9nRw5Y50Ll7nR+69A0DFtQrCA7TcUM/brnx0kG7wv
NCow1h29XbhR3/QTW1KS1g==
           "]], 
          
          LineBox[{{79.0352959724766, -0.198}, {80., -0.18723323238954162`}, {
           81., -0.12476958486522736`}, {82., -0.12476958486522736`}, {
           83., -0.1652787148248424}}]}, FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90Q001HseBvDhUnFllKK3K3SVl7ZUkyLxVChuZsb7+5gxZozdQkmtuty5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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQMC1xcX2HId3w/hfbAP5DSQ/MIL4zM4WExdPr2F
G8bncPB7/Yy1gQnGF3AIeNbcd/39MShfxEH+R9Au5jcwvoTDp6klWlxXYXwZ
h2vZUhm/j8P4Cg6Kk9mCXc7C+EoOuxQSMx+egPFVHJaHcuif2QTjqzk8+vCg
uaYMxtdw2M+6ZlWiAoyv5fA6VWrthvNHoXwdB+kfvlx5q2F8PQcrcbVQn0YY
38Bh7nE/+/8zYXxDh1nzbC4vXg/jGzlotQnpa3nC+MYOS8sD7Fy/H4HyTRwY
Folp106H8U0dxEqPvPCMhPHNHA5/WfzpThCMb+6g1X2TLeDWYSjfwsH0zQ6b
Vf9gfEsHcQkGRsGLh6B8K4f03b3aPJ9hfGuHTVOOs007C+PbOKxhKfnPEg3T
b+vgapTcbPkDxrdz+Kk/4dNOIxjf3iE7LPQMSxGM7+DAc+/IlTVVUP81ODiI
nZosufAVLDwdHaTE1V1OR8LkHR2MY6vktIRh8k4OByLLWp7wQvkNTg5iG2+U
LjSAyTs7GJ77FNp5HSbv7HDwzO3vks9g4eni4Pbhv/N2Jmj4NLg41H+5rScg
CNPv6jDL+aDPywkweVeHD6Ymk7R/wsLTzeH+n1zbkEPH95/Z+t5OKdLN4dMl
3ySBiJP7AeZg6Bo=
           "]], 
          
          LineBox[{{45.31678631556981, -0.198}, {
           46., -0.18635571812250906`}, {47., -0.17713725822476448`}, {
           48., -0.15623049539183262`}}]}, FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90HtIk1EYx/G5IK/MdUMtu1guYko4a5uruf2czs211bLssiJjOLpIaDAr
sWLRDP/IFS0yLC2T2TATxkpLQzPLTFEjjCGRdlkuI2JBgZGxis7TC4eXD9/3
OeflJJlL8i1cDocj/rP+vunh+xpLM6Oedv9TUDlmGGtx/DcH1YuCp1LCyRH4
tKXqUnKoj5mPAUdi7bwZ8nyUtN5OcLwhxyPVGCyzd5AT4VoQKdB5ycvgb5pt
MBWTlyPU1+ysLiQnwzS8NetyNnkl7gUD+68kk1ehfU90XM3rJ8xCTLTueltQ
S07FRMHc6UN28mq8z42dpReT0zBzzfrTIyeL8Oy6rn7qyGPmdIQrlNJBKXkN
9F3HZd5fvcxrsfBr3sF3p8liqPbVHytKJ0twyxQtHJeSpZCcXCyfvvGIOQPu
lKJzPh51GZq1/t6RE9TXITE/rOOsnbwe/dwNrpjyHmY5jBHwPM8hZ0LYc7eh
8s5DZgWmk7g36z52MyvhlUQlfE+nDiQFbNvOdzDbgLKX1s8xRtovC0cn1Eta
/NSz4DOOV7bvpK6C2ef4criNugo/Rsr5/RV0XjZ2GwaCS0eZbdmwq1yvBPYu
1nOQUaq++EJP8zkQuQvNPBHNq3GhU2MODbPvbWpsdNvODM6h83Mhu9qwgjfE
bMtFwDNqccrovjTgxH+LamuieQ2U0r2dNUMPWNeicSqsyiKjrkVky2RCheA+
63lQ1B3YtMNK/5eH4rQP2yedtL8OcZuLYvna3u7fZ1oJFg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n9Q03Ucx/GBCGgaWArYDCmoE2gUiiCTH69toLAJ7AcbeCUIRXh0KT+P
SgazvOM3AkGRHPHLoU5BSJI6ZCyQDe8EO+ZZF3JnLn4c1Iml7mwe/bjen/5g
d7vd456f177f3XcvpR+TZ9hzOJy0f97/frKX6w+d2eHrTcP/aTly9rGpXPq/
OfB2Uus2r2N2xitRdjMie2ZXBBWfPJG2aCRvhkPwJePIHWYPbOTfOFk7xrwN
49bglEAdsxeM122/tWiZX0b/5eAN5gZmHzgV8Lj6AuZX4cev7vSTMO+A8MMI
m+naGNkPtU89n0M182uYv3r0yGg8cwAqK/KHDNuZ38A3qqDuqFvXyIF4uMZ+
PH0L6zsxJBL0m/Ws70KN3UTj1BhzEIrr2j4YMDHvxqb81MHy4VFyMKrlFnNp
D3MIJq4vLrV4Mu9Bnwc/aONu5lCkO0y8MKUdIfNxQ525b4Mz816812edtDQb
yGHYFXKF5/o+czh6G4ve5HoxR+CiadliHGCOhE+h/1tP7w+Tgb1zfvNVQ9Q1
wDaXE/mTW76jLsAzRYkrKz+yLsCi1pYzxGXfJ4R6q77vSD3rQuTe3rS9apl1
EbxXJgvlAXrqImiywhwD+wepRyFj+SfF3NTX1KNwPKSi0zI/QD0atsyF8MN5
vdSjUTnDCxC0kzn7YHxb5/f6zvPUV5mzf1Xfj+8lQkkht4t6DJp6W4R1gjPU
Y8ATPx7960EH9Vj4P8o5/UcHWROL5rQ+eacnneeIUf+uu2+RuJ26GNL7bbPK
q6xL0Gh9x0G90EZdgs9DC5qveJA5B2Avr625x85rDqAk8t6dofBz1OPwIHea
O12iox6HxbolfqjPRerxuD35Yp6on/V4dM0laIu9uqknoOauo531EJ3XJCDZ
FPt86pqz1KUQn3JqTd9B14MU4U+MD7mlWjovhbLW5v/sIeoGKe56nG7V7qHr
cWQY+fjT9pv1bC9DrnP5ZGYrux8ZYssiZmRr6foGGcQuTYpO3gXay6EeTL3k
+IQMOZxKvaO/jSNr5Mg6Xpn9ZzI9P4McAsnvzUvu7P4VWNdb39OtY9dXwJpy
E0enqWsUSPnK85eD5+j3GBRwnziolvDYPhGGRx3WnjOttE9E2/n8X5v47Hkm
QpXn1lA1QTYkQuZTN3L4MzJHCS+NW+HgDP0/oETMMfHs5Qy2V+LnsKIUO3Uz
7ZUYH5vr4Zu/pL0KvluXzLbgL2ivgiz/ljFbSdaoIMpRaBsu0P/FoELX+mKL
WltG+yQsuMxk8TpaaJ+EkrKPfM/GfEL7VTYkQZ/sljAaW0r7ZFjMiri1AxXD
fwMukfUd
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10H1I00Ecx/Exw6eyFhk+zdgiV7nZnOWWlu6zzWlFgc7aH6WjJMPE2toM
rAx+JLnByIFCNBKxWUisWHMKM2azbItqFtgjQSUZgpVlEJUUUtF9D47jxft7
cJy4zmyo5/N4PMXf/e+kJXjRZylJvhf+rzl1zdEjD3wCMg+LZKfMzmXkRJz7
tfiMNIEsQPPnyn7dfJQ5FWvz1dK2t+R0PBn0POUiZCG8abKFa0GyCH1ChXHo
Enk1bFVFLyVO8hpIx2ccljayBF/am8VyHXkdsuZbeKF4ci6auvdVL5+IMMsQ
bNc3RLvJG1AbN7VCVEnOR8y73s5XkRUYkX+rin29y1yAGv/s3Hgc9Y3QK1p6
L6ZR34R8fnzS1StjzIVwaa+7lUvJSiSb38gNz+4wq7Arkm3siJI3o352b2bx
BLkIxu11julqcjFWvv+5M8d9m3kLXDt6Pnnto8xb4bjgSjpRSi7Bq4Ef3y2e
MHMp0gOyRK/0FrMaBmvsYYGIDOSZLjf6fOw+B9i7xCMHCum+BkuEPQtKE5vn
NMg9u+e5ZNUw61pkt54PDTXeZF0LaxNS+e+YeTqcfpwgO2airkNWcNqf4Q+y
XoapkwPDM48CrJch0xMN9XYOsq5HR9D6232czXN6jNXWqESWG6yXI8WWE7jf
ysyV42NnSrb9A72vAuH+1137D7L/5CpweHJyt62B/msbMjStzkN5o+E/Pl/v
fg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n9MzHEcx/Fv50cJsVQo0g/90KicfrhOenXdXT8uumr50S8WZq2iLpf8
2Do/QmJSmVp2V5LaUljJj7buKqfJYVqEmA1DorXmR9gu2b0///hsn3322HOf
z3f7fj7OabvjdvA4joucnP9WNuYO1GYHW/ZoTRoNCRyLVWqnM3PQbOrrcPt+
j2yB47wR2dAI81wUfqjLSnnHbIMYxfVfYgPzAvAyiiMcnjIvwnRH9YH5vcxO
KBmwWtjcyewC3sPtA4Ju5qVQB9lZ8IuZ3TFvltvg4zxmT9hbzvQ7I2X2wpQM
87Zse+blkBpl0dWuzN4wDlZ1Vxr1ZF/kKPt1rRLWV0Kd8Fpp/ZF1Ppb7SKWj
3cyrIB9qTy7byuwHUT6XfMH3LtkfTScbPmcUdpMDYN04VfzUmjkQ/b5lswxf
u8irYbBSyWccZhZAte2DfFd4JzkIEu+IusFoHVmInX5J4/7aDvIajHu1T3Dj
t8nB4HnExAd9aSWvxQo3254nrjfIIWixLXqe6c4MaMf4BnvlNZNVQLldZp5H
bj31UIhSR//IjlZTD0Wyj6Lf4X45dRH2bkmcKOorpS7CrdQcszdvWQ/D/oLj
h/ddZD0M50TpRT/fn6MuRv6lzQ6LN+6hLkbf+XZ9QeDeEFOX4NN8PU5OnDJZ
JUHF+VrbFxMl1KUw59tsLfY5TV0KwTLnB+UPSqmHQ3FQ617Rc5Z6OOK+JERl
zSmjHgGhrYvjcGkF9QgEL01x7k2vph6JY8W5WYquOuqTvhWQ9s2rnnoUzF4Z
UjYkXaYeBaWxZUlYcC11GSp+6CW/btJ5Khnc7nRquproe1w0NEMerkf6a6hH
wzFZ19IRqKa+Dryj7h+r2y9SXwfPO+pci8pG6uvhJPAVZJRcpb4eI/o9RfXT
mqjHoPZEFb85rZJ6DPxqvmrkBgX9fzlUJVW84apCkyGHCxL1QmED3YcceZ7v
Dh0wXjFZJ8ezMOGjjW30HrhYzJYuFscXpNP+/6z6z7pY6FOdCmQ1dJ9cHA5a
vfw9VKgJ+Qsu7FmG
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzH8s1HEcx/EvzWasYqKyU8jqFrsdFY6ue4VzTn40ao5cUyY/lmgzRZqv
NCHFSjfTym5XksoVJbfiLhJ/XK2Saor1e5OGqRWzJe0+77a8t/fee+y5vT32
5sSlWXMcFzy/fy+NwytdrtSuz2jRpGz5hH+q8J85aD+FZGRYkW3RU52icpx+
xOwAd76irvw7eRl6awqHbMbJKyA+a84f/kIW4Ee22CgfJLujT7Pmd18H2ROt
ts/zymrIXpiyr27R55DXYrhpduldCVkI5487Yp+IyeuhqVVEf3Mh+yDGp1/k
au5lFuFwaotNsYwshrObG5d36yGzL67f9zYfDCP7wdN0vnPfLvIGSB2enTGq
e5g3YqVkUHPU0M28CV3jWtHqUrI/DpTFzJkWkwPwRt88ljvygDkQOkW5/aXb
1CUoKXlaZ6glB+GD4NoVDzU5GCqh1OyaTd4M24oW8c9V9E+Kuc9t8UUDJuYt
uFifVWklIMvgFZDsuUdqZAaKNVOv+wWdFvPA6KRKnZ7IzG3Fr9OaNrWZ+lZU
GA3H5b4G1kMQ+q4pyKRsZ33eX9+Ppqcxc6Eonl6U62hDPRReDYVJMzF3WA/D
45dF2VMjN1kPQ0rW5VJvJz3rcqyL7XZPFDSyLodQrxVd2J4ks/RwFLRmVnUV
qSzmw6FLTriXrM1nXYF4yWxHZn856woce7H7kJ/TCdYjMGtV6Sw8x8xHoCDg
5H4X63rWlVDyjV2iiausKzEUF6sbiG9nPRJHJsfK3k4w85EL+rb/zS8wFwVR
g1+V/BT1KAzunGkOzGtlPRppxiUJPXY3ZH8A7noh6g==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQMC1xcX2HId3w/hfbD/KTt9FS8PjM/gcHHPhad6
v49B+RwOZQYbX1p+hfEFHL4Y/VrG+QjGF3EQXSms3XgHxpdwMN8xIz9kDYwv
4+BhFS45cTqMr+Dw17fgq0sBjK/kMPWe9dsF6jC+ioPLiZ8nP/87CuWrOeR4
+Wp/vQfjazhs3DG7/cEtGF/LIaZjlfnRpzC+joOdZGs1wyoYX8/h1byY+AVX
YXwDh4VPT5nri8HsM3SI3PFkjvgzmLyRw4bYKTqb7sP4xg68gfUP1q6G8U0c
qhNn3ZrcD+ObOjDP1xJY8/cIlG/mMDmkgzc/DSZv7nDputXPq6dhfAuHnRI8
Zf9vwPiWDu4357lYicH4Vg75bxbrKIcfhvKtHdR1DZXyNA9B+TYODMHq2s2m
ML6twzHtayplvAehfDsHnj3T7AJzYfL2Dr3nHhuvLYPxHRz2FWtH+hZD+Q0O
Dke49M5/OguTd3QITffrSs6A+qfB0aFgxsLpjwNh7nFy8OTxKFU4C7Wvwclh
gtVngWNdMP3ODsd8Ly3KbtgIlXd2sDq2Mqfp6CaovItD048VPsohm6HyLg4h
s/OYnT9uhcq7Ojxxbghz+gNV3+Dq8MC6MdEjAmoeg5sDo61EUtylNVB5N4ev
M/hVH1Svgsq7O9Te1/4ds3U1VB6Nz+AB5wMAfuj4og==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz3lIk3EYwPG3FWXihQSOijGXbN4dHpub00d3uE3NK2utyJg4jArFskuJ
17PEZHkxpCxSUoywIgsyc/NMlKU2KDNQQzzywtQIC7Ki3/OH7ws/Xj58fw/v
87rrMxLTWBRFKf+ef298XD7WZ0rt35r/azl8/mi8KN4BTcGnoWJd+U60HSzJ
lc4TW9AuINZmDvz83Uu8C3QFak7cCpoN3CtZd5z60Hthw9wauNaG5oLgx4p7
TR2aB15fV5fmDWgPqBc/aR7Qo/lwwVm5Va1Ge0LjA/EgV4D2hperkqIGFtoX
8jQsj5pfPcT+MN0xJ5Db0AcgOGmht6AUfRAcn2dpvvijD8Gz8q7CJDd0AOx/
OGmshW7iQLileme7t9RFHAT6bs0OSzc6GEotn6uEN9FCUFQ0pc5koEUQ9H63
ITkPHQK6bKu1sqyTWAzXm520FVVoCWwfXekLsKFDYY2vCu2ZQkth0NWU/W0P
Ogy8dJebwlvQ4eDDetSevthBDGDsrx41DJBOA4z47mPr+/F+BKRItU+T1y2k
R4C+sjL2xvAb0iPhREF15+IsMR0JdvlpQyEj7aTLQDQdtmA9iV0GCj8PPjcF
uxxmjqRPNHiTfWg52Lp4Bl4q7qcA4SVLaVou7qcAt2OccbkndiVss97VGkxm
0pVwPKfEueIxMRUFDmP80xdl2KMgMV9y+5wP+R9KBa4xw415GWQfWgVz52m/
uo020tVwbTzaa80Tv68G49mw4hIpzmtg+Wph7RlhK+kaCPrACXjR+or0aGg5
BSLHsdekRwNvXcDOYRNTMZtNxzDmY2Fy1l4m5+SQHgtTucao+5FFpB/ebJph
Ko7RGabiNxsYphm2MEwlMOYTQDb0XeJQZjL/AasMYPQ=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwsslWEYB/CPnCXO0dmSUU10UWLSzfXI390RznFKY5hp2pnpIhabVftC
yc5WkdRSk6hWCUVH7pc4p5SMNJpSSkNuWRcT1mW9z7d9+/bb//u/z/tY7jus
2K/LcVzg3/fflx5xb1GCm4G28b++ulsLBIgTkzmoLu342m5E1sePvXuMxUKy
GGmV+qU58xpmY6TdqdN2TZFNUWXnPOwwQl4FyafUpde0ZAsIHNd31+SS12BM
d8MpZTx5HS4PeCTnBZCtkDy3aFnsdvJGGHDL/DTjbcybMD1hWGP5jmyL4N7f
TmsWyHZYcdnm2MAg2R6ite+L72nJW9A9VWltHkzeivzlBjPDx8nb4J5lEDrS
2sq8HfMVg1Pz354w74B9qnu1iyPZAZrcIaHyANkRsWM+ruEyshOitU3ma1+R
nRGWHDPcEk92QbHvRHt0P9kVs7/clEdzyBI8VDUtThOT3WArSS8rELUw70Sn
ScWxxKpmZndsshNa6J2jHIiJ6Pg9Hsv6PGAITu2hotwDhQGHhN3+rM97QCzP
PxhoSOd5Iuy2Vt12mnJPhFpKJ3vrKPfC1ZHpVNkM5V6IOq2X4ZTdxHJv7H75
Yi7jHTPvjYS4I6uzaB7ngzJnSeHYfnYf3gfqExYfYjdT3xe1ihJjp0jq++JR
0MfEm0rq++HWxpjJvkHK/dDq0qOTZNrAcn90RJqEpnXVsdwf6S9u95xprmW5
FCfLS57ymTUsl6LhRpZuWwz1AzDpMDuaX1nP8gD4ph+vzjarZvku9PW3vc00
p/4uSCeF5RMXHrM8EAsNcR0RRlUsD4SZNK+96CczF4T6xQJVYxD7nw+CQFTx
+YqS+sFYf/98yVJ9mh+Mb1Gq54kr2T6cDHl341PK69k+vAwD3qMXS/ppPzma
T3U/05ay+0KOahuN7fdRmieHRqKIK5pmbpJjSXlzGS+j+SGQ62bo6SQxIwRW
Mq+zBUO0TwjU+gmvRXrUD8HbNy1dKQ3UV+DBvfBsL3uar0Cnp0jUTvvzCtw/
pF5ieZ36Cnj7Tyx80alv/AN0Aot4
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0A0s1HEcx/F//x5cWbq4WexqSJR0UQrn6ePpOEdKxrS1nshaLaZ24San
2rTUijNhTh4abiXK44auQvRI0dQSC6nmYdqqtbSe5vet7f7bf/+99t5++/z+
1vsTIuJ4juO8/7x/v/QIB8oTvZZ06ec047OuoExb+s8c+vv1Fik8WYCBqQL+
wEKyEHnhQlHfp/vMItRnxYmi3pNXoOeomalVH1kMyUzkWKiObIWH1Y+m7SrJ
NsidUA0+yCTbYjTl25GsDLIdYsQBLw/ZktdCk1S6T/e0k9kBPRYNqxNLyI6Y
jo52GI8lS6Cx7zwuiCc7IX+3ZqNrDNkZx8SyDCcBeRO4iFGLc8bkzTBSFpmn
xXcwu6C8MNyk8Ax5C5Knpvp31pG3omhIF+GUTXaFcmyVzFPfzuyGjy86pt3c
qLtDdVjB182nLsWk1tiu5Pk9Zg/oTLujRtaTPWHWtGNoUnmX2Qsj1/bUtl+/
w+yN2Dyj9AU1emYfcI3F550tqQPbL64R701nVgNtl8NyqqvoPF8kVT4us77A
9qh9MTHyiv/+i/b5YdGVXpU8nLofcp5J5zmepf/lj8+LX79J/MKs9oeJsPdG
bS7tD8DVDyvz3T3Y/dUBEPWm6ZoaaW8gdrloO6RJt1kPRGuLUp6nov0yLO/K
Shh+0sy6DPlt0akSs0bWg3CiGJmxkgbWg3By0Ebzw6Se9WDMCroF0pQ61oOx
7B1f8pavYV2O+IKWg37mlazLoVQ5tBl7M3MhsF86/HVcUsV6CGZvbahI8LzE
ugJhqc3pLa2nWFfgtDjtZrKlwmeuh+KnSGsaWZE9Z7WBuTCDbmBum0H/79+6
lTFB
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zltI02EYx/E/GtpxLg9hZZvVnEv2HznNPE1/7iAEDg8VGsEw26iLwBUj
LML+l80FllAkwwuXeUDChdBSN7dlGVJjEsvoIhluIc4uYhSjuuiA7/PCy8uH
78vDc7iru82SxnGc6t/9/9IRf3xs1ex849/St/pp2dOjzSIyh0fd0YhxL3k7
DPYKxbk9ZDGmrYfW438WmXNR/KX1gjtFzkcXHzkg/0ouwGKr+eax9+RCnHV6
Qk885CN4t7u/4NkLsgxZxW1vE1ayHOmJyt5yNVmB2C4hbtSRS5A1OR7M3k9W
IhLyXU9KyCrY0BPSrr1mPg6x1yKd/0kuxeWpdvuclaxGXXLZ/J0jl6G2zxJw
h18xl+PK6AdT+nPyCfDD6/m/lsgVkMQejtnd5JOQmu+kHLk0rxLLCyKt2Uu9
Cks5G6ulrgXmaqwkTKLOU+QaqCf6Cp3ul8y1iN+vEX9ykTXgR+WZzgdB5jrc
k26appQB5noMN3ErA3fJQElGb1lTi3/LApB9/vQ22+851hsgpFzqa8lZ1htw
Ky9WZPzB/nNajGQqN3Py5lnXgq8ed4zso/k6qHhZUJPGLOgQvuQM+D/7WNdD
vzHoW6tiFvS4HT5oO+OgbsDFG/2KdhXbRzBA0qOPTnq8rDeiOWNox8BVmt+I
4Gy0qKNjxv8XA0LitA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVzglI02EYx/F/Ns0DaaHikeWxPFCJdF45dT/veZYWKUiIkuVRmEGURjLM
0kRFMzMNb8VMNM9cts2jtKA8iqiMoMxQNCyFQGulFXteohdeXj584Xkfq6SM
mGQNjuPw5/592eG/bjrto/t4SK0VcYuG9tclfWYOQVFznLUeszYmkaeny2Pm
I0ESrqpfGycbYuGW7Vj8CrMJrLQqhipnmc0xkzq7KhxjtsTcjKgqrpvZGlfm
7+it9jLvgcAk44R3J7Mtdi25FSpOMduj1mjTaVs4swOyewz4tY7MTrh84WlH
0fIYeS/MG5LLXsmZ96HD8ouvxRlmZ4h5xm/dPz0iu+Bs3T27N8eYhZjMVkkU
mQ/JrnjR7hzn3T9KdsPIYV7XOp/ZHdcVRyuzX46QPbCwVdhqUMHsiYLq/sUm
G+b9WPIVjSYaMXuhWnOsYLhsmCxC+4bXRPz4ENkb547XpEm1mH3w5MfHEEMH
JdkXssGrhQ5mD8hiyJ7FD5j7y8jAtFmPT9bafbWlQJNQZb+9jcz5IS892z8g
aYC6H1KiS787yPuo+0OeOtdiqiRL/WGsk/LNbL2TegCs7gryS07eph4A0/KJ
opotjdQDsenhGbNjto56IJYjMg7FipqpB0GSplyc7qqmHoRkudJEIKynHgzN
iED+TdcW6sGIO5jcNz1I/3Eh0FmXSPQtaJ40BLmXNobLE9uoS9C9uFNj+jPN
k0rwPD0nQexH+3ChKN7tPAW7KuqhkEfK9HLmr1EPg3GW7BdPFUM9DMOxR3zM
rfOphyNWkRJtE1MqVvdw8CaSVjN/FqvNRSDhnZPLDY0S6hFYELTovOdVUI9E
a955cXpvI/VIlDoGxn3IbaUehc2pi/FtimbqUQjwDLFQmTZQP/C/pf/8G1Pr
NOI=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQMC1xcX2HId3w/hfbBfEPcp1ZANxmdwKDivFeLM
DeNzODxd5xFlKwDjCzgk7ri2xRmuXsQhdqXQpQ4hGF/CYUkIi+9ePhhfxkH9
Ouurt5+PQfkKDnLpt7QSb8P4Sg6F/3+dPXMSxldxuC6+1/hoH4yv5sByPFX5
hD+Mr+EgIqA+ZZ06jK/l0Htu30mp30ehfB0H9uXTKgN2wPh6Drd8uqdP7YPx
DRyenhDer6cI4xs6FE+W63KWgPGNHFr6n6VNc4LxjR1UPTTk/9vC+CYOR5//
+dmjBuObOkSWHPnHuPoIlG/mMLc0oZBTGsY3dzCUXLnkc9BhKN/CQXjCQ/fN
TDC+pcNFBo8Xd14egvKtHFrUcrW6NsL41g4CM5l8DonA+DYOXp+eFZZNPAjl
2zrMyKntDVsG49s5sP7mX2k1Fca3d/DUunRr+VUY38Ghwn31jOK7UH6Dg0O5
oC2/4wyY+Y4OD074bNgaDeU3ODp8fhDs8TEF5l4nB1blh9+fX4LJOzkEf7u+
QfUrTL+zg9DmyTy+uTB5Zwev8x1bWI1g8i4OxSIrq+RloOY1uDjovZ/Wt/gB
TN7VwfnajnWH7sL0uzrI/4pnLC2Eybs5fPjr460qd3g/AOB34Gg=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10A1ME3ccxvEOdKOMRFyayJbhHEXEF1DnAIHRPqUF21Khb2CiRoGgDHVS
koVlqONcqbDBBoaKmnVSLEgUY5GxTWy1hTo6mahbacaQZWHAXohsqEAYmrAt
/P6XXC6ffP/PXXKv5xdr9wXweDzdf/f/T3aF/mgzpAR7XYuaEnd/GW0b5DPz
UOeLEwpeZA5CicjYI13CHIpoaZL262e9ZAGCqtJiFE+Zw1A4MXNWMMX8Kg7q
o04e6GJehW9TBbK1N5kjsKFBtOC6yxyJyYp2TU01cxT8313Y4zzGHI3gXyp/
KstnXgfHzhOcIZF5A9pLC+bLVzHHYvcOiVRy4xvyJnSMD/vMLzFvRtLzJ+eG
rLfIb6BmxdhzFZuYt+C3/hD+n/HMb8KUGJZ44gsPOQ7726ThpkjW43Gn37lL
8QPrCeDXLgkxpTNvRfW18La67h5yIqZO5f16dStzEq65NHve/4edT4a+5lnf
5H3W30JIU1H1xmbmFHg9q9dMtDOLsNBkDXPnMIvhfYjRqnpmwPNHTgCmyRwQ
7VsvWGN3U5dgh8wRtkxB5iTIdXBH/DM3qKdivHdcXuskc6lIPjy7YJxnXYqL
qonvt3zSRV2KR+fLJV/VXqcuw0h3Wqe9tIO6DPPH915dOXiBehpWS7JTLBGt
1NPw88jouYg61tORcjqhJVRP5tIh+mizI8H2OfVtOP0km3852Ex9G0Y7Z8KH
Z49SlyNvoDCuPqOYuhxFcx6fg7+LugISv6UhPuEd6gp0lDUONAmN1JXwlCxd
PyhXUVei9AWh1dJbJF7sGXj7lSdzxjYylwF/nmTkiHUvdRVEoWK78rOD1FW4
64mV3QpIpr4dhgr7gfFhJb1/O4p5E32x5aX0/UwMXSqImV5WSD0TQnXU477A
XOpZqMwQHtIqjlHPAq9beOf28g+pq5H0V/7KssnyRUMNsymn88GKKjqvhtFW
2WIr+XTRbjVm333t73vNNbTXQNC69IHfVE97DWzZH1gMs/T/OQ0mX1Y2Gm6T
3RqMHR+YHrp3hvZauLw2+0NnA+21+FgpDgxSkjktnsb0tNzPtdBei6PmrP4m
F5mnQ+ZYZGBDQTPtdVjeITcH26y012Guq8hrPUx267D/iix84+NG2uuxz29R
nc09R3s9Hr3XmuObqqO9Hs6S85GHfq8X/wvEaKmt
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90n0s1HEcB/DfSLu7IqsYVvJQCJGHk4fTvT2ce3AI/cFmrJNslvQgSZZT
NmqJcYlF7nbSQmuSuJnHc11aU0sPZOmPW02qZVnEWA/r9+m3fffba+/v5/v5
7ruPsyIvKcuMYRjhn/X3T5/1G+3xcJ5x8J/mhaUTGUEiSzKDZW0m56QFmQOX
Zb4mjEO2xpj1j42u5uStcJu7lbK48Ii1HRxmc70NY+RtKGK2bPa9TnZCfaaq
M7SQ7IKhFK9iXiB5J8RTaU7lPLIbjq42SlZ1BtYeyOhamNE8IHuif9bGyL1G
9ka4f11LgRvZBypZSttaHnkvCtXlSkUA2Q9l2ZqSAdUoa39cKj3SEdOvZx0A
9VkfSXAfORAWrT28rBEyH1fqXFLHk8lB2H0ov920g7wP8/emn5oNjbAORsSu
tJkztZSHoDtPGnW3g/JQ3FksOlg1TA6D6bBOk7BGFmD7puBvuZPkcAz3psdb
Cei8/ahplOvn3lIuxIGr5slNJjIguM3o+x3Z/Uog+lVj+cwLqo+AuMvwqdaL
fQ9lBD4nLqm731EeifDUY63u66g+EkHanJ+Kh5RHobdqLsfiJuVR0CV2fn85
Tf2jYRpozpiWDrN5NHJFlqFcDmtGBF31xdchUex+pQiTSz1tK2VUH4PRwinF
hydUH4M41Zf0vv/vIcbjzBKurIT6i5Ht5+yptaf7SfCMP3qZ70u5BA5Jdr1N
lZRLkf7xhkKQT7kULVwrvoeY5kOGCwX2rsoGdn6UMpz4Wq+YaqZ5isWG8yaR
23p6v1hUrozvCZFTvRyB5waGNBWUy+FYUyFoMFD/ONQHtOdU21IeB/X75zYe
Q5TH43TspO39X3S/eHAYfrrQnc5PwKli44ReaBz8DY0QPzU=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz1tI02EYBvB/IzKE2bBWjZbMNFsWoUvTrLln7qRrFUoE20XgIUjRMi9a
KKvVJnQgkGyFHag11LZYh10kpTTXtJWOCmGYYRir4YRdSOcQsqLv9WIfvHz8
eC6e982sOVJ1kMdxXOHf+ffTE4y7muWpIf9/zSpersq19S0hcxAITK/r+OSl
kF13G96kkwXYna6y/kghr8DkuNjxM/GceTVuX9VO+SJkMTz2kofhAFmC9pn+
RNcT8jqkDvjaRtzkbJxyKHY1Osg5sFxbJuk+QJYi1JB3Jr6BnIusT4+dh1LI
m9FliAij3cPMW2CIafl7LeQ83BwN+4vayPkINNtEi5vIMqRN889JWshbMVjb
sjLqJRfgc+eoyztGLoRQVvxW0kHeBnuPYvBoNbkIVbGBO1HXEHMxRB8reX3L
yduhOTa7SX6cXILWUPWHmnryDnj04461yiDzTkiNe4aDC5aDP5llNIkDzKUo
Pfx75mv9M2YFriy6JPkuHmQGzHPT385nM1uByFndi7STT1muxP7g5UTsLuVK
eKZ8GROn+1leBturjXM5BazPWgbnhdr89Rl0rwrzonm3WM36rSpcVJXfMutp
XzW6HljuremgXA21tPHdCTvtq0FvnP+L10D9GjgffRG2R2k/Lcq8lZm+sJ/l
Wkxk1w2Z9jFzOsQ739+I9FKug7FpzDdipvvL0Vrhvj+koP4kcxVJeZI5/YL/
AJagD/o=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgdQlHcexvFXs5TTeGgEQ5UizUI10Uh9EJGiUpZet7DsUhRjRw9lD9Qz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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQMC1xcX2HId3w/hfbBX+/Am7h8PjM/gcPKn4wdW
Phifw+HKSc2wIDYYX8BhiU5bpgIDjC/icOGgY6j+n2NQvoTDfxUBdv3fML6M
Q2Lmw1nP38L4Cg4iNU6+t9/B+EoO32asiBF8DuOrONQuaJ1TfBjGV3P4vslI
Og3O13CQP33uFks2jK/lUPvEs1NKFcbXcbghKHDK5c1RKF/PocFFv3ZaIYxv
4LDkYsf9bm4Y39CBSydtq+n3I1C+kYMFT21DhA1M3tjhud+/2eaMML6JQ9mc
Z0Zb1GB8Uwcrn2lHpt+E6TdzYKz27hDogPHNHSSi19fujYXxLRxc//9avS0Y
pt/S4duFXhmDkzB5K4eWOzymjz/D+NYOOiu87668BVNv4/A9P6J6sQ+Mb+tw
ypiv9cKXw1C+ncPp5VO3/6s+COXbO+xbUHpiD9MBKN/B4YzLx/Vebvsh/AYH
B3YrF4HrL2Hyjg42zL9Vn9yG8hscHZbu0bCeNQFmn5PDHIc+VZ9jUPsanBx+
/1Rw51LZDpV3dgjga1lt37IbKu/sUB/2gqP09iGovIvD88LH5aJTT+wHAIP5
zn0=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10Q1Q03Ucx/G/1nzAMggisZpbcTQ1icnDaIF8HJMHQWAPHERdDwPMDHV2
zBtl547SlmAK5wPzhHgQcig348GBsvFHBD3KTruAPIdHpoLTQghnrVOy4/v7
3+3+97r373u/329/sW6LOn82x3GZj3//v9njO1Snj/U53zWje3G2HQ8PPDmP
mYOrVbxz8lEfeR5s3gtasYfZF33SGOsvfzMHIPXISKfhLvMitNx+pa1mmPlF
9GzUv3/UzSyCPb912bSL+WXc/+Lp0Y9amIPxecD8NEEzcwial3qkGQZmCQrz
a4f5XOZlqL8YY46820t+DS+pRFHlDuZQeHy2B34sZw5D14ldq3q6z5Gl4Iez
0oWVzCuxfI6xcbOWORzKk5s+s3t7yBHIupp63NLEHIkzioXm52XMURDkFczK
STlLlqFt37GbFl03ORreD7cGJwuY30BRh+BGnI4ny/HNtYr2jiHmN1EX9mlW
0RhzDBa2Fj84pWWOhaQ04tbECuZVWBI6+6uicOY47PnJ/+uhH51koFdZHOu8
QzYB4pSAX1vqHdRXw7f7gExqZH01gr2iK0Y/1hWIcNeX9Y51UldAIb6f1GE+
TT0e2c/dytHvPkM9HrLcZ0OKxWROiVefWPSnXwmtNykROnA5cuUF1tfgiuIp
+V9TrK9B4eBYWWVFF/UEvOf7yQdRm+h+pgT4Dw0EiWvZ/RLROrjYGpxH5zUl
YlaXe+c9ewf1JLjmF9ve7mfnS0Lhg4eBcyV0Hy4ZI5eiVpSYab0pGfJ/z4+3
X2b3X4sbJetL/c+xvhaPXAnCBv331FOwQ7VcfzXmKPUUPLPE0eaU1VFPxQ85
5Wev5ZZRT4WuYYPdaTxIfR2Evy19PezdcurrMFn0lm5aaqKehs25vwsvTVdQ
T0NoQby8c4LMpWPg8O059rIj1NOxdeqfQ1ZrNfUM+Chv9umqa2eMx67aUNIZ
WEPrM2ByHA+53nR4xnwGXHnXX3CMWmheBaNMI1+fXUnzKrRP2poT3ew8KhS6
t6h3jdN+vAq9g3v5n8dpP06NUW9bwZ1t9TSvRtM71n3OmkaaV6MxaMFi/jvq
vBphEtEfwu30f3IaNETr5dkCMjRIs/hlXcyk/UwamCcM/Tkb6T68Boa5o1Zr
/7c0r0WSyBMdFM7mtVhgsB3a5mHfS4uTVXrhlITtr8XB5hOWUn/6Hlwmvkys
Gjm2vzruP02AuxI=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwlczPkfx/HfpvaPRCgdFlNuinQoV95yVTp0SedMM80RkhytSH6sq9BW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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgk81HkfB/BpK0VaSgcPFa1udyeJT4cUCeMYOWfMjBmWUHlKqUaHQuvq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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlA8wlHkYx1+i68JV196lcpfKRg5XJPZUvv4Uy4b+7lr/dhE1h9QeXcJs
VDpRLSGnxCBdJeS6HSO8I4pKxVSuqy6nZtxU123UVMq5bvZ5b6Z3Z97Z+czn
+b6/53nfed7ZkZtXbzBkGCbn/fXfP/eb3FeRuHTipVY96dyTTzhG/zGFYwYl
yWzPl1M5noCnB/Zd1/1fPxnmkceW5764SCxA8biy2WOGnDfHTQ/P4uIxzlug
o2AFO2TMeUuo/LseKo04noNRk/7OGYNcvRWOqyYN5w5wPA/D5VflhSc5toH8
2ljAxUyObSFMDT53T8axHbzFgdnWCRw74NPewV9LnThegN9VLxvv3+8gXoi0
yFZRfAvHjlCXp53q2cqxE6KfR3TZvW4nXoSyk7OuVjZw7AxtQ8oVi8scL4b9
U7+i/gSOXeAzciPD6c0FYld0TvJY0Dqf8yIsymw+c1bL+W8Q+eqZoWCgjdgN
c7ZEnRg243gJNoZ2pbwuZYmXom3g7kRzCcfLIK3rmHKnqpnYHb89yNSVVTUR
AwMFtUUFpef1rAbe/njtJVveSN7jfUHtV2d6teQ9MMvJhn329Bx5T8QpZbfi
w+rJe8LYRWctya0j74UrVYo9N1wryHuh/nShW6+6irw3CoQbUttTq8l748Ka
fJuZlZXkl+PJrZZFWpdS8ssx1FAda3LoCPkVaJR9qzlpUEh+BRzCYvpSM5LI
++Cg0FDo9o/EXe99EDPe75Hhuz16ZnxRfT+qPkcbRd4XDqtrlsRc2UZeDFuX
gJnmIbPJi5FXZ7q3bGYceT84jPy0dvDSTvJ+0MyvicuW7iXvD4FJ81uRIJu8
P7YPblK2+x4iL4FQtE0jNtpPXoIHYiv/qbJc8ithkC7/eLFZHvmVkMSq2fSk
fPIBsGuzsso/W0A+AAZfv8murywkH4hOi+lzpRlUrw6Efb9qtM+V+mWC8KZn
7HKt8UE9IwjauFTTGEEO1Qchem2NwmM65VkeM6tgaJtz191eQ/lVH3r1KmyU
957u96J+WJ5nVn/I4LGaxyyPmTW8PI/VPGZ5zKzl5Xms5jHLY2YdL89jNY9Z
HjPreXkeq3nM8piR8vJSmHn61bc7x1BeirYdrYOicuj3geUxI4Muu8ViWUWG
niHDvaYm66iEXbRPMqw33lKdVU+elWF03xHV2MJUygcjy+2FqdCX6hEMgzE2
kdFtp3wwapKvH48z2Uv5YBx+293/WEXMyPF97PyLjps0lJdj/Qxp898ZeZSX
48/u8y5p7uRZOaY5Vg3cuVZC84d8yAiBZNeL6pFLJ2j+EDzxPmD1WUolPb8Q
bP7FTT1meJjyobhs1jTX+PFRyociWhVsPec1eXUoKsTtDlrdccqHYrT9zu3b
ycWUD0OfILYoPy2d+g+Ds7koK8kunvoPQ2WM1ye77HdT/2FQauamDJlupXw4
Eloiu1UMt3/hmOZS2qhN4fY9HCkdkloTI9pHNhxJSzrsg8fRvjERMFnjLzLW
0PcMEQicHDOUYMnlIzA83jc67+h3lI/AgvGvtvzVs4OevwI3BbbdX8zbqWdL
Bcz3dS2MP5VP8yjgbit4npt4TM8KBUZvdq0TD5fQfAp8Lnrn/HM4cZkCda5C
yUhQEc2reP/9MeuX+tD9+hUQx5cm/JC5n85XwibTSPfRAXq/lkok3k3c3el5
kM5XIv1I+qMJDQV0vhIPS5xH72UVtf4Lt1ydBg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQMC1xcX2HId3w/hfbBnCnv2gEEYxmdw2PZx1jxh
MRifwyHqx/83fTwwvoBD/VOXB0ffH4PyRRwONN/bp/gUxpdw2P3iyN5uOF/G
wfBPHOuZAzC+gsOvD49TxZthfCUHtyMvzz4shfFVHNrtue2542B8NYejK9bN
PSYC42s4tGzXlerigfG1HO73F6SdhfN1HJiK3uz/sfoolK/nIOVnyZgdAOMb
ONzNOdFsywjjGzocVPtsFDjzCJRv5MAm2CgSpAXjGzv0ZzJnygUdhvJNHJy6
VGdE28D4pg7XljsySRrC+GYOKpdzVhcywPjmDhUKgXslN8P4Fg4rmhartL2A
8S0dftzyXvGtAca3cpgkEeR7fxqMb+3w6eSSac7LYXwbh52NIpoM0jD32TpM
kZ3y//IaGN/OgZvRiXGyPoxv73DlxJKd/b0w/Q4OF5uqMv8wQ/kNDg7H42KD
eCbA1Ds6aDKznapsPgSVd3So9k1/c+HOAai8k8PedYd+reGH8hucHHJcIsUn
qcDknR0mnuVYmbDpIFTe2eFo3t9L/HFQ8xhcHIIkXy5OS4aZ7+JQZjVdU/8e
TN7VwXuPwdKF8jD3uTp4/NPh3jwNFl9uqPwGND6DO5o8gg8A5JbuwQ==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11gs0FPgeB/CplF4sW/RCHq0kvWzvPL6KIeSZ1zDMG7VCV6XuqtFu12uv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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtI01EYx/G/XXSuEGOFs7SLmWil6XLpvO033bxtpgvxEloaSZLGtIEJ
uRpFIVZShIV4KRLLGGG+SJtzm6Y1zGRk6oSEorAoSmcUWiRUdB5f7MDh8OF7
nsPZdkRzoGQFx3HSv/vfScvb0VYRz7dZ/8spzas3aS/xyBziVJpOzbJ5CJPd
evHWjeyNgdKfYwd/P2NejxP81aEJHHUhiueutNyboe4H3Y0+XtkEeSsONxXn
8+zkAKgbahePtZMDcXXO3+LTSA7C8MZrziodORgK38BXiYXknShcNL3JFJJ3
44G3h9C2hRyGOwLPiil3cjiCDfX5udanzBHoMPaMbM8gi1A3HtTuVUDei6Ui
W7m6kxyJ3MaP0nU5ZDG+GU9eHLUPMe/D8zJt9IXvg8xROG2ZPPSknno0umeG
s3+FkiUQTwnNAn9yDDZEtU0uqGk+FiZoBcOvyXFYKQ+JzraR4xFQc6ayfBc5
AZ8W10i018lS+M5Piw0eZMBS3RRzKo5ZD+giBiRNeuoypC7keDaEUJdhaNJs
7Af9LxEz/LHGTVXM+kQctU04g37QfBJKbvqGlmYOsJ6EsODIQK9eC+ty1GSd
u2192ce6HJunWgqK1VbWFRg9O2936oysK+DRr+PZLptYTwYvSzSS49/LejLG
u1R2zYfHrKfA8lmibK3uYT0FS8f3PKxQdbOeiq7B5uZaPr2firr3eY6idHaf
S0PAbEeleyzNp8EvXuQW/oV6OvIFO8Tvkqinw+3++a+z0/S+EoNrfSIdZma9
EnKzaFWrjLoKVsecn+HuI9ZVLj3D5f8u5va7dBdzmcv+Ay1HPHk=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zws0lHkfB/BJkq62TYWtbSK3LsSSjOSbRuTWuF9jzDAzUqHVvpJqosuL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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zwk0lP0eB/BHaZeIqEuiRW5JkRT15mvfxdiNYRgzhDaktGiqEb2tblKR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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxFzWtI01EYx/F/UbQW6EgXGmKZZrLsoptWuulvuv90UlmjTEUKSgmjq/NS
KDFtQ8KWwxkWEVq+sN7YyPKycmbuUvjCaFJomo4Kg0YLs7wE3eg8deBw+PA9
zzkRh09pixZzHJf4e/85aYletZ5WCN19f/U59aO84cP1f+YwESA9eHMZWYCW
M/HHCn+4mEUQ6GYCxYuoB+NopMZ8aYF6CKIuinXPfeQwcEfGQy98I6+F1TVe
GfqUvA5c8fIva5rJUejxhgi/tpGjoXNf8d06QY5BhSC71cSTJchpNzd2B5Nj
0XXVahx772TejHobn2AYJW+FpDZ6qtpAjoNn7/6xbi05HlX9Yv/PNw5mKcoC
Pw1v2UCWoSa/RCLLHWBOQGSeumUuk5yIZi/XImx8wrwNG8/PynZlkbdjxlZa
5nU8Zt4Bq7Mit+4cOQnHJzva346Rk2G5nBXRW0mWw+I1h887yQp09ayYbzKS
UzAxpKlQavuZU5FSbA+L2Un/A9o9t/WD9azrAYGt3DTdQPeV0IjFI3deU1di
n13KJR2i99MwOyxUjGcz69OwRHRy7r6tj/V0NMW/8/AvmfXpmL5bsHSkppd1
FZLTBsL5F8x6FQqrsgfz4qjz8LWt7zT5H7LOQzKpODu66RHratRV77YKDDSv
hnuqw+FX2VnPQECO5ZnyBs1nIEhrLBUV0XwmZq65ywtW03wmvnt094J09L8G
cr4kttb7gHUNVoasGso/0Ml6FhaS+GlXQgfr//0Lj+8S9g==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10AlUjXkfB/DH0kvp2Ec0odFQKIMoKfpG2l2tKrfl3tvdmJpekqV0PDKa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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQMC1xcX2HId3w/hfbCfcOZ1YRwvjM/gMKcvRGwG
C4zP4eDk3XOa5dsxKF/AIYz31JlXT2F8EQcGnfSsqfdgfAkH3eN7fk/bDePL
OARc/aKQtgTGV3BY/MS/8VYtjK/kkKfeytmYCeOrOBiEdUubuMH4ag65lS0i
kyRgfA0HJ0lVHc9/R6F8LYft1wPFltyG8XUcZO0/pDrthfH1HDY9fWtdkwjj
GzhES1y85f7uCJRv6PDrwcEgj+MwvpHDxinvQuRTYHxjh3V9TeoTQ2B8E4fI
+y+zt7bA+KYOLEzej5IOwfhmDknFMyYGVcL45g6lVrfXT9aE8S0cgqbosyyz
PgzlWzronI/raa+G8a0cNKMsZBsSYXxrB9f/wou6PsD4Ng7Rdt97GJ1g5tk6
HBep/jbZEiZv51DmYX78SiyMb+9g0x0VdKMNxndwuJzgu6j82yEIv8HB4TrT
vL4LfVA+g6NDktPrY818UPUNjg43r+rVzl0P0+/kcOP3k/BHD2HyTg77y5Xc
5nXCwtfZ4cCVF496w07u3xnLrpLL6Ozw6ZJvkkDEyf0A9WbK9w==
           "]], 
          
          LineBox[{{39.35831651186642, -0.198}, {
           40., -0.19067792742980258`}, {41., -0.19335739932962737`}, {
           42., -0.19274484042736964`}, {43., -0.18658856280021474`}, {
           44., -0.1794331585548241}, {45., -0.19546039771912493`}, {
           46., -0.18468382533384733`}, {47., -0.14915775138852033`}, {
           48., -0.16282766931059467`}, {49., -0.16806781800454065`}, {
           50., -0.17252597267588501`}, {50.690121254003884`, -0.198}}]}, 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zWtI01EYx/F/GjanwsKVGY3cyGV2UeeytWn7zV1URhgF2l4YNKklBBWs
JhW1LpbN6sUi64WUZL1oy/CyIbmVl3kJb2UoVpPIRYREtZQsU6PC8xw4HD58
z3mO2Hxk94EIjuPk//b/k5ZgrO5oDr+3bVFhdf3hIbMxmsyh0hyYFseSeXB6
FnzSSLIAxgeaaPVsD7MQ1+8muOqD5FWQivhd4n7yGujdg7ZhPzkJw3ydi+cm
S5A8agnhNnkdJuJPG/aZyFL44xxJ94vIKbCEyq/tWUZOBc9+RaCZ6mbehMhC
T+F6J3kLzM7lgSUmcjp+/Br4cMpBzsC7zwrhiiyyDG6lYFz2sYs5EzO2Pt9S
A1kOp2VapNCSt0IuKYoS2gLMWegodQlnmzqZt2FD3NnzmbFkBQQRNVOOYx3M
2/HSOnqoeoKsxBdl2WTJc7IKVbyMykEXORsLM+G5tHhyDpITucsNj9uZd+B7
VbsloY2sBl+tufdTSwZazlXEvOp/umg7oOrf5XDNtbKuwXyP3Niw2ce6BmWy
6tdjFj/ruTBm8H1PAtRzIbG+2Hgwjc3jtFgZ9o7sb2H37Vr0qWZP7B16xroO
A7fmr3aH6X8djhe33rwhofd6/DFIg6t1NF+P2tq3I70PqRsw6bH/jkqh+QZU
jJvWet9Qz0N6eWNJzKCX9Tx8/ZQqsyU2sZ6Pi+rixjs7G1nPx2Rp8FK3tZn1
ApwRZV8IvadegM6T38KPaprb/gKmvAfg
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0gs0VfkeB/AzKj1GN43Q26sZXb2JrjC+kSKSkEde530QDelSmsshxdyS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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQMC1xcX2HId3w/hfbCfcI7x8iZmGJ/B4foFJs+J
/45B+RwOYrOsZlp+g/EFHEJjTS7Kv4XxRRw0gjcdcLkH40s4+NvILeC5BOPL
OKzX51axPgjjKzhM6c3euGYyjK/kEPrgSuyFJhhfxSGj68qjqAQYX83hSgVT
SyQrjK/hkOwVarR501EoX8vBu3TXkkttML6OA2/gdIUrrjC+nkNwwqqJKxNh
fAOHN66uFUmaML6hA99OxvwJDDC+kYOjOt+B2YuPQPnGDt/fTDQN3wbjmzjY
pJYk/XKE8U0dxNMFdR1+H4byzRz+NJqUaTrC+OYOn5rDHn3yh/EtHKZoH392
8wOMb+lwYrajd6QAzDwrhxCLpRcTXWB8a4c05kb+XXB5G4dsXu6QN/mHoHxb
h+s3Dp9zsDsI5ds5WGeLaM86CePbO8zieSpyeD3MPgeHTZe0zYxXQvkNDg6M
tY7cL+1g8o4OztNT9AyzoOY3ODq8eRay/50szDwnhz7X7l2+v/dB5Z0c9shO
Fi97sgsq7+xwyLuskncxlN/g7NATn+R3qBum38Vh3Ye+LbbB0PhscHGYmngk
U0oH5j9XB6azx9OPxO6Hyrs66Pouyr6Uth0q74bKb0DjM7ijySP4AIKu6mY=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1z3tIk1EYBvBpNYbYmmBLc6N5YUbkyjR385vP5r7BnP5jiCEYOGoQFC3b
EIXiI9L+EMroukicxRTEoTIlLda8i1EUDTRZEIFChImOjGQZFZ73wOHw4+F9
eU6281L1uWSRSKT5d/+/dGSLz9xcylxkR+tl+/y+Kr2ELELLSpPXm0qWYOtF
rTK6iywD/8dwz7c1y5yOjM3a9zkb5AwMjYoPDfwiK9DV/N0ZS5BVSL/a2988
T85BH1dwMDxAzoNpKK5VhMlq+O11+ooe8mHIv+VfCTWSj6AyNTez3kU+iljC
Y+aLyBpMWOIKOcjHkZIfULmSyIU45b1w8bWEfALdrurCvAPkInS0P92dvTTD
XAzT+P5V1zL5JMQ6e5I6QC6BxDvj7luYZtZi9OwK3/CVrMPGHptxdXOKWQ+H
uHXp1jrZgLrB9uDDpklmI7KkxoYWboK5FM6gT+1fDjNzkJ6/7Bj2v2Q2ITeo
jFQpx5jL0DtyPVTgIQPakoq2+sDIjgXggfX5fPRGiOVmpG3LnO4atk8w48fe
212yTNpvQammYzrxk/URLNDFP/7e/kJ9yyF/0ul7fIbycjxqXLt530C5FW8+
xzynNcyCFa3X7t55p6b/87B/aKsJRGmeR/Ga6m2WheZt+BQ1CuNS6mcD9+rY
sMM2FvkLCmDh0g==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzwtI00EAx/F/09IZxiq1EgtLsVwy0qllvn7q5pzTZoLkpBIlISNylSSO
pGlllBJFzFrTUBxirWWu5it001VSYZSEkSQ9BO1hqEOjqT3xzvB/cBwfvnfH
3cbcgvQ8DsMwkr/z30oH73W9Mtqt1zKviVjpsEPDd6VmcHX6qa+vM7UrAq31
sgwONQ8ZhcJC55nHxB4YnVhdUr3Q18Lc8SN/zkG7D0T6bA7/A7Uv6uwVVSYL
9SaMnhFnzl6i9oe791uBWEkdgNzM7PLQYuotKOQdnxzbQ82HJsNi0/Kog9Db
MNQqe/+IWIAQN86Yk5F6GyRFbsVKOXUwKvSnQrUTD4lD4NXbXiZYSrsQDY1O
18I6aA/FXkdJRNZN6jDEeXGfXVdQh8N0/k5N5IK3I6XgjZXbYiPeAU14VqWL
ijoCz8erV25e0kO8E34agaND200cCcfgfrtVbiWOgvJlu2iVijoaRw0bmHcu
1DGoMVyo81zeRRyLdScG03VdD4gBRa4u/+uttnmrgVre+CtzD+1xKC3y8qsa
pj0Oa7JiAnTVraTHo6bZLj/dbyY9HlU5BbM+ghbSE2AqHVjmcraZ9ARUHsv8
/P3AfdJFqN2apv+SRLsIv78ZpkfKmkgXQ8INTvUYaCBdjM4p4ROfFfWkJ2Jo
bjLP3mYgPRE5c+sdl382ki7BjV9iW1CikXQJVH2HRnQnb5OehD5T077ooLuk
J0FwxXJVepC+X4q0/mDZzCT9vxTqF1puWWAn6cn4WBQl9DCS/6iT4X5Yrxix
0fMy+Jd7X1RVtJMuw5SOb+luJfcxKbhnNhzxLCf71Skweivk5z6ZSE9dbDXL
zC5WZ5mRszrLTNpig2U1y1aWmd2s8yyr//sPuSNqvA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwtUzHkfBvC/9bq1IsSGVml7sy7VKiXp8pQkqXSZSveZaabJJkKELiZq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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90A0s1HEcx/F/XSVPualMsYaZtYoc6kTch8h5OndabS7conBlYRiLdOmk
prQyjxUqpSn0gM5DOD1YjdKzZEkNZRRt9LCsh/n++m///ffa+//7/b77WUbE
Be+ay3Gc+O/778se/qsL8W56nW2zmhAZv7OdEhowc3g86XgoU5d5IT58LYiL
+nWfzIdh7feZmgHmJXh0JXM0+QGzKX5o3M231TObw+KjYOJqB7MFViQKJF0V
zFZ4aqlVqquYrbHyZGK+Wy6zDcbUWx/sVDCvRFOCSXBVBvMq2JQ+b/zyv69B
14tqj+61zHZQeqYJy2buke0xqRT3q3uZBehKdpkofsLsgIwhA2GkLbMj1JKk
Gm8+sxMMVzh0F6XfJa/DqWqFqDyOeT2GIxRaMw2zEK7j9+Ozddl6ZzgMDr/5
FMa8AWmqnqAQXTavC1LO7L1sb8m6KwznzOXxo9l+G5HnqdSxmL5DdkNq+Hjs
kKSD7A7e0ei6pfrMIrTatzvtr9GSgbcdRV9ymlpmrQI6O7b0tdg1U/dA3fvr
x0OXse4B037DU2cbmqh7ImSXkWm1kYa6J4qOZ1y6kFlPfRNMuQMB0vg66pvQ
WBtuUhvaQN0L5hWSbncNWeWF3GSN7zc1/c95Y6Py/MHSebeoe6NVee+Xzb4b
1DdjMilxXMyj81SbkT6Spf9Zl53vA+fp2BK+lnUfpIeNTucdvkldjIMJgvJC
lyrqYowYp3bFlVRQ98WcepFZT0ohdV/84OlVxiw/Sd0Pw2MucnlsGXU/vNhh
Xa+IKKbuDxtb/7TXgznU/bG9IjcqoiCDegD0ZSeuOfrkUw+AQD72xMsxj3og
Un/uKZafO0M9EIsUetkHODafBLePZGYFRV6kLkHUAo/5VYvJXBCkOeecDZor
qQchRsf+2yILmpeToley20o+XT5rSOGbMzr6coCskqLg4epbe3jkdim01XuF
emoyJ8PUuvm9xeICWi+DVeB+ZacOuw8ZIveJopXP6D7aZfg943a6T+dY2x9E
1mk4
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdkgtQVGUYhg8IQoghhaiBGkQoII7ITcyFd7mvK7DcdtkVERpXIlPWhVFD
wCPNqKEhAjJhkCjiJUHBQQkwWVRW1LyAIKaQkBC5YwVBoqRQjd9vM52ZM2ee
ef/nfJdzbD5MjlDqcxyX/M/975Nd0zrLVAKTK42vaNDnivVw62ZjxhyKVPO3
i4wYG+Puswcvr+sxnoa4rICGTfqMLZBn+naLaERLPBPit7zvm/cztsZstfnT
/a/zdxE0TXmr7x5jW5wb6z+/ppaxHSScy0brg4ztYbbm902CDsbzYfjJ42FB
AWNHjH2mDbwnYbwAfYOtd+WOjBfih4nctt8mM14EO/O6fUYVzcQuOHNjtpmX
M+PF8JQ+2Vp07TKxK6a0+Yx/bsDYDeaDiVldr9kdpV94bYvyYuyBofRiU5eh
S8Se4LVz8r16GS/Bma7xiU49dt4LpqH+2o23Wb4USs52rG4b4w+w+OavxmfL
LxIvw45iXY2lIWMBJnQruyaFNBF7IzWgJdPRneU+mDF174bgZg0xMNIwuanl
wIVXzAMuvh2lLjnnKReiZJ+VevD97ygXwrqmJSdLxXJfvHO1ycnqBPN9cTgx
qHVeP53n/NAsNyxIXMt8P2wuDBqZOZf5/hi9Gbb/5Sxi3h8Z8+Mj11kwPwCJ
Teq514obKA9AkkPZQ93uOsoDIZB0N+8cJuYDkXfBs9htlPlByM75plojoXn5
ICw9FCf382HzB+PNHdd/Sh9leTC6HWRj453MF0GprBGpBxopFyElbo/q9Ema
l1uO5BcFXdu/ZPMth7B2lr86gs5zYmyZuydO/wabT4zbW92f27nVU74Cdab1
5VptLeUr0J2QsmrqYTZfCGaUqM7lHv+W8hCI7iyraLpMzIWi5D3p+oZd9D4+
FJbthg+Sz9C+uDAktekV2texPAyXpouyMu+w+hLMelxZVKum85Dgj9i9X/+V
zvYpwYTc0vFSLNXTSFChSH90JIH65cIhsFlS3yOuIT8cehkDd6frqsgPh640
PuiJ2xHyw1H+7Jp/n8FR8iOQm1qqzXhwnPwIGMdkzBD3nSA/Aurvk3qvPjpN
fgQ2qBrbfYyJuUi0O+icR2cTIxKbB8KyryuI+UgMPdUbeRZyivxIyIIvvlh+
pZL8KHisru3InKAcUbgsNNCk/Uw5HwXx3nbhHBPmR2GeX1VhT/FJ8qOxpbL6
of0t1n80PrI+ULH7df/RUNrsSlrQyuaPRoosb9Fjp8PkSzHlY1eP7FZiSNFj
sdNbeZ+YlyLEZvcb6xYSa6QwqU6KFeYdIl8Gsx/1CroKiSGDg8X6G/mhZeTL
YKH7NMlZ9RX5MqRlGXlm2bH6MXAYSP1zbU4J+THoXGN2NvPYQfJjcMhKfDQt
lfUfg0mGw/eOVjNfDk1RsKWrK9WDHM/PehQLqmgfvBy/FB7sjR6hfWjkMM1T
NeYPHiNfAfeE1RqnoXLyFfA+tWnqqkX0f/AKSApDPdJsK8hXwNVOGVJgyb7f
SsSP5fIVntQf/sf8f/w38F1EMQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1038s1HEcx/GLmR8RrVtKJCfKuamU3Cm8zu8fd6fDiC3Lhf5QuVpKa/iu
CLW6NaJVc8xlQ0WhlLju5FfNzz8YGVq3/Dr6MbJqUs3n892+++6x5/u7fb/f
z+frIEuLTDZgsVg+/87/V3pYDVfIvc061Wv66vu7KEJct56ahV0TJRkCY2oT
jHtN5mlXO4itsPjwYo37PDUbMVszmOoh6i1It/B2YHdS28LJJX+opIh6Bxyz
tHneqdQc6NJmjqRLqXdC17Moq7ajdsaw4sb9X+bUu8GtWl28zLQTcyEptclV
Kal5iPaSRMWfonaDxmrgJz+Jei8SFSHRSRup98GSb7DJ8fRbYnfE3q1WHbvX
RrwfFsc1wbbdWuIDMK03LTcqpvZAZIIhLFuoD8Ijc6mS16Eh9kS6qnVgvvcN
MR8Ty9mTTTbUAtxRNUq5XDWxF8okDwr6slqJD6Ewp1ZottpMfBiKWnX7o/rX
xN6QyfoMrs7S7gPOOpOmysAWYl/8kTcLbO3oPFDS5Turj321Zgbo6+S48ZaI
WUI0zug9R+peki4EM6j7HF9FzPJDi5bTMnqGdj/06i8pTwibSPdHucO7qNHH
z0n3x+hCxPYp4xekByC14Txn7ByZZwJgeW2hq+osmWcFYvxJ6nJFZiPpgZhO
rpnT+z0jPQhzcd/ipvm0B8G8PL8/JaeB9GCUahVllUIyzwTDTulan618SnoI
DNlFPcsnaQ+BZmhMWrtE3y8U1+33iN4n0ucLhTwhSpQbQ9c3DM1O1rrb0+R7
MmHgbihg963Q9QwHb8L5wmQA2T9MOFZGPplcKab7TYRt0s0NClOy3xgR5F8a
boXx6P8mxof+mz+SjIgZMVwl9h4uZfR+CVI+CuoKZ9vU1pFpblMyCb4PimVW
R7vVfwFY5UMk
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90wk4lfkeB/B3NFO4NUV7GVQqbVJybyPLlyxDkn07znH2c2ixTHtxjxpm
rjZadEQTSZfmarTZKg4RokKSEs5EmpK0TPtUd+7T7389j8fzeb7v9/2+myni
KF+ZDsdx9X/9/u8v+xl1KyfaTr+24rOeOqTnj7ws0WPm4Dnparnww2WyLmaN
9Hxn+5J5FDrd1h9dM8A8BturR1u+eMA8Ae8mqAyjmpmNkDf2Q7HBcWZThM31
NM5bzzwVmbOMup6tYTbD5vu5ulo/5hngy3lOky2YzbFZ7abfO555Nm626JSN
H8c8F7runa6NpTVkC7y9bfam6gKzJbY9Ke417WRegLutq7/espN5IYL4XF3+
amYrLNmgThmznnkR7H/pEVXbM1sjKr/PZOYi5r/DaOvgtLXWzP/AuMirMb/r
My+GzbxpKfEB1eRvMXZvsSO6qsg2GPcxJsBfxLwERVZO6cVxzLZY8cHYaP+W
SrIdKuZPFLmZXCLbY2BoaGrKeWYH+CVNtsjjMQMBgwlJGQ/ofCqgN6WlMDqE
nd8Ro//ZFpkx9gLljmgzH3bqbvl5yp0Qc2Cr8tdjJyl3grBfsbPB5SzlS9G9
x33zTEUR5Uvx5tHE8ws7Yih3xtGmb7h5V39y+Jw749V/fLWH3v/7szkXVNgP
YFv9acpd8Fas0rTsJ3Ou2Kzd7hjRnEe5KzyS+fyIpfmUu8H4WO/MAh8V5W54
H3nsvkVRFuXf4cxKk1iPnJ8p/w7CrS/tuRM5lLvDgwueGbPjHOXuMD331ryp
le17YEzNl3dS04oo94DOVVWK6usCypdhZIXr4bKuM5QvQ2Pqwz51K9v3RI6w
9auG7mzKPdE4l683/zIdzy2Hy0p/k1JtCeXLIe/uSUx+W0y5FxY9dekwq2G5
FySySKezmlLKV+DQ+MMpRa5llK/A43rD0O5COp7zhlR+J9lSScfDGwYP987p
HHKRjvcGFxU4uGkmWeONHYMJFe+NzlPfByGLt9dal2io74OkmqOZAdFklQ/6
T5jojplWRX0fRFgutt6USuZ8YZ+m88U2fTJ8YeO9rycnu5L6vpjV4eAoMGZ9
X9zryS0pL6Gc84P1iYhX+ems74cbghdLuswvUd8PRXsKTNcVkDV+mDPYmaQs
JHP+UF5psJgeTYY/9ONzbRQbWd8fR088ONeQyfr+uP+7s+C3I6wfAB1ZvMmB
d6wfgIyEk8N6lNXUD8Ddvcef39QnawIQuD7peWYf6wdiX+YnwYVi1g+EQVy8
TZMZ6wfimlXEzwv/3w+EXog2M2Qn6wfh+/YCu57jrB+EvfW+6SsD2fUHYdLY
x/md9uz6g1CRIU74UZf1gxG8sHJ4YzPrB8Ny+Xufsj9YPxgHpvKOxMWz/WB0
TLYttXevoX4ILEprh14fpBwhCA8dqd8dQbkqBNlzNiRf8iBrQvBc2eZuq6bj
uVCE9fQGTjGnHKHozgl8mHud3X8oJEnfDHMfzvqhKJE+26kpZfs8GK8bNif7
S9bnwenjp6r+g6zPw9u2AEnLfnb9f+XWrySFv7J+GAbuxYe2CS5TPwx71pzW
00TWUj8MXgLe4ddbKdeEwW/+I50ZIHN8OIu/6qpLZ30+Plot01ObsT4f3i+e
bnhhWEd9PpwS7eLH+ZA5AaITfsz/opuOhwC32tvVNxfQ+VQCjOBPFPQNYfcv
wCeDfD+xGbv+cDwwc06pZM8b4YhfdcbR+yG7/3C02HoJRu9m9x+OlLrOXOkT
9vyFSA8dLNxVQzYVQrSgun1JOnufQmyZZVnWtZu+B6EQpdwF/3b2vaiE0IQc
SqsbSsdnCdGlk3g9x4N9b0IcjTOMkG6k/0+tEDYSUWzBevb9ibBowXDb3ex7
NBUhVr3t4Lgo9j2K8DiWZ/XLFrYvgueE52VqC3Z/IqTNu1M3eh7df5YIryCL
DW1hz0uEN+qTiYeG0PPUivAoL4W3NJq9PzFG1GXMflZPNhXjxuztJYY67H2I
4eOiZ897Se9LKMZvS0rSzdrqaV8MnkVS1HKPK7QvRoHR62PnDBtpX4zVjjGK
0+VkrRh2p4z6W3MbaF+CCVbvSuv4lJtKsOH7hv6ktddoX4IfFuie8pzbRPsS
rOsW7Dg4laySoHmOzXjj3ddpX4LaiN5RbhvJGglEVv0GholkrQRTk133L/Wj
PidF3yrV88YfmmlfCljl3SuNI0OKEeFmC3fdZftSnFE/Ov1+LduXQi/b9LBG
Ts6SwmLK2eyXHPU1UhTf2HWxZoByrRRpu3Uzgnwp52SYaLTpwdqf2L4MXM2k
J65ati/DvRF9HThFFspwLbcjuHZoC+3LYPDHnXVXl5GzZKhvejxq8xGyRoam
sBK3Vc03aF8Gs6GxeV4JZE6ORpX47P1PZFM5vOTGH1PvkiEHLyfItTqXLJTj
4u2JioE+skoOu6yDSalWrbQvx9nGyJWvV5M1cnwo3LhF5E7WyhH9aXvRdCmZ
U6DL6OK7RR5kUwWap9VukB8jQ4F/eUZXqsrJQgWSrd+YDzaQVQoM0d/naG1w
k/YVCDHvjAxYRdYo8Kdx4Z2IXrJWAf81swar0sicEvZB7Q4+f2ujfSX4I0ZP
UqwhQwmxQWXlqtBbtK/EdKOSxxHmZJUSi18lWl1XkrOUmKa+UjX9DFmjRPnk
fXHtzu20rwTWvZjx7W0yFwHl5Kr5Dn+2O/wX0+vsjA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zgtUjekeBvBPiCnSyHSZSCklK1KkRDxKTElqt3Vvt2/tvV1mRKgMZjO5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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zgs41Xkex/F/d2Vbl3TjaLFNYpQpoSH5JHcSjtwv5xznOGIqDolQRyOt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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XlMG3QYxvGCSyY3UXALAbayhjGZx6bclj5AuwKjrAdHHaweUGY6kJbJ
xEGgYUxW1B2SdYJx4uhC5Sgkjk5GoURRArHiFmTVcFjnhC1ZxGPiiFg1vD/+
oEnTfPLt07dNuS+Xy9WeHA7n+f+e/7+yR+DNdi3fe8y+piWBx+mx/HRfZg7K
rAPnzD7MD8Plf+O8e/39gTiWa9Zp3V+Sg1BdW55Zfpd5K2oDpgzXbzOHovBC
zKR1ink7ZGovVfhXzBFwJI75ZRiZefCrK+Adq2COxPR0B08jZI6Ck3+P26Fi
fhzqLL6PZjfzbihMloaR6S/IT+Idj4uDUcPMT2Np0fS9W8m8B+oa8Q7lnVHy
Xihs23/Z8QbzMzg4ULlNsu5nwYsd7JQFMccgJLg+Gp7MsXAWT1ZEZDDHYe7R
k0POCeZ48P9xVByRMyfg1WWb0eXNnAjhQ5GCvfnMSbBHKX9eVDE/h4kgy9Qr
vcx8DEUUNj9RxH5PMs4ZJeNn6j4nC9CiLY12jY+QgeP1b7911kXWA6tLR6R3
0uzUU1Ai6r/ffoisT8Fs3+HMPyTD1FPBt1wrjNxko56KR/x/muq+MEg9DWGN
tsDTE9eopyH+sR/D/0phXYilr3vKasIHqAvRzZ/d2pdP5ojwlKa5IHz8U+oi
vOm4lTQw2U99Hyaur5aYPMn6fbgUkqCzqFgXo+1k6Fyp1xXqYgiuzAmEBX3U
0/FnaInF32Ghno5W7lFHfGUX9QwsNq30/51L1mcghputv9trpp6JqhWj6kVD
B/VMtA3PR2sbWN+P+TNFQ1s6e6jvR+V7RePRTezzszBlqvO9Pcp6FkTBezxv
drEuQctwniFMwu5LUBWrSzpoZT0bYbofcNTdTT0b1pe22bQPPqZ+AE2NLQHi
qybqBxAXt/Nq8olL1KXYKXz/22XXR2uGFOpBe4Ddl76/XorNHyothxbo+41I
sSnn3fjEFzppLwOvTXgipIwMGXxGe5slXpdpL4OyJdj63W90b0QG7+P1u856
tNNeDrNg9f5MD7svx/hms0hvaKW9HJ9wuLtMeUbayzH3Wo1TzmugvQJBD4y3
qr/hCdb2CjR21erutYatWa+AO/nGwmzpKdorUNy4fNmPb6B9Drp+LdZVz2jo
fg4WNL9vmR+qp/s56H595uJnSgHtN5iTi5APDieknm+k+7loq1oRO4vY/7nB
IxvMyVv3vyKWyM4=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzWtI03EUxvF/YnbBZMpIp0K2zDJz5X2t2R6nu5gWJaFmC8RLkhZmkqzE
MmRBJasXFSIYkai5hIFOWhe31LYKIqyZG2EmFRiWMctSXGrFfudNBw6HD98X
Z31RZU6pD8dxSX/336XhOVtPpK5+avXKLTtX8KM5bg2Zg6hqnThoBXklYiTx
OZO/7cw8SLMuBjZ+IfOxUP/8s2mRHIKXjV1na2bJ4fBfDG2qdZEjYPCrdA89
IAtRYg1XjnaRI+HRLomideQoRBcc3f+wibwZx+cChqUa8hZcM3//lb+XvBVT
ake8KpYsAj/BrFe4bMzb0XlKJ52cIMfBJb7pdGeR4zFffnjs7dwT5gT0Jcc0
qBXkRARaqhas+8hJWDUiz3nEIydjmzRJcDpjkDkFsbaJvNwwshh75r9VSHzJ
OxBcHuUQ9A4wS1Dl5IJD68g7UZRf+E5U0c8sRe4Hl44vp54K1YSh4f0x6rtw
5sDGAftd6jJc0vqXjYxRB8pkIdcrZh97XQ/0nBzOc3y6z3oaptvaMxPzullP
Q0vxVd8L9h7W5Wg+L9SZio2sy/E6ItJSeoh6Oo5o64oCrL2sp2OtR2gUBJlZ
z0CHMntT26CJ9QwsG9dUX/nYzroCP98UhtXM61lXoLxFoZXYjDJvV6L6hc9U
9g291/VKNI17OnMtHayrYK7dkHJ5+g7rKpTM9H+dczNzaqS3Hrz1ys/AuhrP
NGVLM9OtrGeiz3W7W7pwj/3/z9xujFZ2TC0fMln/AIQzDdo=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zF1I02EUx/G/62KzdGir1NaLzhkzY6U5nabtN51zE7pwdKFNCWYtLJxi
ppWDVvMlwos06CZrgQnZzJfaspk4tWVEZiaBFBFpNErKDC+UVVrhc3rgcPjw
5TwxpnLDUR7Hccl/59+mFzbVVpG59ql3VfOqydP5BZ5gMoeS940jKaFkAZai
Rx7615DDkPcsgOlvo8wbsKlzlu+YI0dCFJH02TlD3oLiW+Li3S/J0WgNtuiL
75AlyLOqeB0OshQ8q892oI68A3V+Q1V3PVmGYyWcJKSNvBMVdqvm+WHyLkjD
P3UsFpLlqDfztsV6yXvQvjFOeLCanAjBu/nUohpyEm73KGOa/ve9KHUf73mT
QE5GTZ/npO/rE2YFAjfvtqcfIadA6ZMONFeRU6GXmCsvKchKDMeVK5YsPuY0
fFyIjz8rJqdjfUPQbHf1Y+Z9GC94NSQKGWHOQGDi2sJk+DBzJmbtxli+doh5
P/IdgcqkqkFmFa62Lrq2yrzMwNta/twv3cCqbUB97VhU4wUP62qcELotrot9
rKsxahOELq48YD0LyzrnikfNbMtCdpTQ6O6nng2jftrJ76L7bBSFpdm7Cpk5
DTqb4x6ZdNQ1+FF2arxJ7mY9B5vHglyR25ltOSg6NPEiI/E+61pMCb6fa2hy
sa7Fmd4yvz2I/s9FafwVsVlPPRevZ/wJpghmTgeNrGW5f7CHdR0+/P45c/2L
k3U9hCLDjXuXqeuhKjm/rkXe6/0Dfh0CXg==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zw0s1HEcx/G/WmZILHmYhzCZjkKewnEfx915ZlaNzWZTZtTtlEJpdbVL
G5UYPeFKaunJojhK4Y7UomZLWCiTq2md0rGRtWp9f37bf7+99v7+fvv9nTNk
yZmrOI4L+fv929kyH67PDTXu6/yv74LDRbU/ZabMHDY+mrbTr3QjjF2PUsUs
PyebI89DvV73m9kSstf6ta56ZhsYX9DdaV1gtsecvZE0aZTZCakefpmbVcwu
cLM90vL5IbMrVKUj3YH7mN3w69vl5pIkZndccExxUJgy81B4nndM2dBL9sQL
603CrCLmrfgQaGj1FszekJg18g7oe8g+kFWENa6+yrwNDyb3a65Naci+KCs8
9aqyndkP1U1e4u4kNu+P2aUgXx8JcwAGb6sSrUOYA1GSY3GpvpB5O5Cfxh9Y
YvcFgX9iR69UxxwMSUpy/q0ZNTkEZRNt6qq7zHwo6jp2aWeZQzGfunhSVcsc
huAq7RkbKbtPAM+xyZz8lfPAxXJHi4lSshzoazMI9t/Aeji0XMJXwZVu6uHo
2hLybkjURV2IdT8WnLwr2XkhWjXZh1yHO6lHQJwoMLEdoHl5BGreW8Yri59R
j0Tk2YK8LztpXh6Jm08GT7cfZ10EodLQ7KOULBfhaL978cA4vYcT4+DLspq9
o/R/cjHOqavlalEHdQnKE9dku4S2UZfgU9OsWNvQQj0KRoq4KY2CLI9CxnwW
fySgmXo09jiO25no7lGPRlPdXMZu90bqMVgeSh+fftNEPQbT/Tdyq61onotF
mtI4QZp3n3osehYNOG0FvYeLAy/9Kc9Z/5h6HLyUMw4Fre3U41f8BwsTMNc=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91nk01XkfB/CbSstEUsyjniJaRSRpiLytRbLvLq7rLmgfUU3KLXqkJ5wW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          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90mtI01EYBvB/ajWtxLAiw3TN6aa55dS51m7PrroVZIX0IYm0tW5CkcJi
fmhULIdDR4ygD4EVFQTLTxHhZLWLA0sW1EyKWYiK4czLMDBCKvy/Hjgcfjy8
h4fD2dd65fi5DIZhpP/2/5NW3ufHV1U5seCaFjTfqjsGL2eTGVQE88dnNpA5
sBacftK4kZyH8dkubSyLvANlur7iLYtDrHfjxKZbo+ZpciFM29Lu80EyF9G5
gj+p12Qe7nuv73XcIfMR88+0O7XkMmTuSbXIjpKF+CDfZREcIFcg0GIWHpmK
sq7E5NdPU9wEWQyu/kK4cYRchY9271j4NlkCWZEkvSomV6PUst9WJCLXoL/k
56lwJMK6FjWDF780DZOlqOM0X+paItdh2vky4GuieRmy1PcmrOt9DkL5KL9H
ICDLUR4Y5SRCNH8IN+0Lzf0+sgK1hhVx+XKYtRJJV6xUwadchXjmi4GUiHI1
tOohVcJE1iAuSWrs8yHWAL/3x+HckbdrdgLFPcc64s8o12LeH17u7WTt1OLG
sH8xmk336TAwy8jFDyjXweZ2e/qq2PsYPbZWclbPpN6wuR6T5nS39CRrxoCl
btdTWwnlBgiVbVYP9WGMeO50bL87Qf2MSMdd4e8Ryk3QGNvmjO8pN2EsN3k2
g0f96vFb4eMhQXk9cgo9Gukrmm9Au9shSj6k/g0QiN91tnrpPc3YqdycNP5i
/7fTDIfg2kpIQf/dsu6/TRELSw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0H8s1HEcx/FvrR92apHo+qUfTFiuU1yX0Mtx3FEcSzZJhQszIh2KckdT
8yOt9ItWuNWm0c4JRZsfUZqFmbKxklqtdqW6tcqPqNbn/Ud9t+++e+z5+bw/
+37WRh0KUc7mOC7g9/vnS4/ZoDbZg/eo5a8+b+/clReZaErmkPxlYb12AdkE
IqcVdQlzyWZYrlXwnk4+ZF6C+PaxsQ4jmY+yXXb6mlfklYjJmHs7p4W8Bhcl
Z2RHy8jr4BGnEX5KJdvikqq4aPow2Q4i8+cOvmFke0gH+NLwILIj4hwEutnf
O5k3IPrAxOtZSWQBflbkRBkDyUKcHU/IeWFPdobJyS6bXFvyJlxIaVh9rbWD
eTNUM6pELpLsgq4ooc3eZw+YXbGv/pu97itZBN39yNrYPPIWrI/Q84pKyWIM
vXaoubSM5m2Fs+GN5dtk6m4QZ49mjX5vY96GjOGGNLkTdXeIsrNXNge0M3sg
pmRxm7Kb7IlwsxsTt+1o/Xb08Kuzyk+SgSNZhzPzp9l6NVD5eXfvFynt98L8
xq0fTJVsvdoL4OcOp5hSl0A4nllgHUpdgoQfKp2rOc33xoimsEjXRd0brh+v
ZlbGNrPugy1jmur3VY2s+2DWCWNq82gd61KUlS6yE9Q1sC6FWJA+FW1Rz7ov
+gaLdBLPO6z7oqLc6JzSSvv9ULAqXSI6R90P1e4ltT1adh4ng8kCfakhoYl1
GSx46U1p/vdYl6N0Y7jc5zrtl2N42PKdQUDz/aEfcXksm6xl3R83Z2oKi+fp
WQ8AX7NnTp8ZzQ+AjWlV4WQe+x9uB24ItQdjaL16B/K9kHQ8jJ3H7UTuJ17e
jwyavxO+ZSpP8RD1QAwaZm4Z8tl9qAPhpppofhNB84Nw/hg31Suk+wvCaZcn
3VZy6gr0W4d2rG5n86DAlaXx8o+dNE+BoYw+bzHH3KqA9Yzg3NpTdH/BqDG3
wnTxXbY/GPwj5RpXH2Z1MCI6Xlo5erH7bA3GeeNUyP5+1rmQf+fhP6tDoFTK
PC8P6Ft+AfTof10=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10QlYjfkeB/BTZCpLZS1CWZMlWoiib+S00Xa0b6ez1EGKMHcy4hSJwq2R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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zglUzXkfBvBbV0TovpHSWEIaL9mSpf1JUqF9X27drVuKElH2K3qnCKNI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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw91Xs4VfkeBvAd6TTVSEn3yyZDJLdSunrlUopib/frZtvbdt0uXTSRzaQ0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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90mtIk1EYB/AhaqnL7UNSgkHGXOZ06OZWqWv/Od3GIjWNFpHQpoGZYA2l
6/CFiuy6lQyMSsqsCUFqRHYZzWWb22isJIyyqZF9mFSasXAEdqH36cDh8ON/
LpyHJ9PUXL0njsPhSP/MvysN/pub+xXJI65/mlMe32VesHHJHEyca3thSyQv
ha0k/Gjgv/lgTlT1e755WS+Hvf/pL/8ieSXCp24UpE6TM5DTKJK0jJBXQ2p9
GRfqJa+Be91tQ81dsgBJ8hQmzU4Wwjj7LvdHGzkbzinXEWM7OQf7eON7L+8k
50LfPS7QlJHF+HQyOBytJecjUnHHpi0mFyAhfCw7GvGwlsAx5LE7pslSCOxF
ooe5tL8QfYsHv0TVlMsQrvSPtY89Zy2HZc7bWtdDXo8qX2V6oJ68ASEHvza+
mbwRy/iTBzqtw6yLYB2wvI9JyMW42mRWXYu6WZdgkleXvplHVmBV4Pt5Tgd5
E64btsrm856xViJxhTqL66QciDW+/Wx+zeYM8CpDWLVQSe+pIF7rbEmpYM2o
0HXoaLBeQ/eVYvth+a2UVMpL0bvkyunuB3RejbNuX95EiP0fo0ZmR/KgMYvq
VQZF0+BFfZDyMtzv4or6lFTfcjypnh2aibL9xpQjPk0901PjY3MNEsSBnxYx
u5/RwGT42lC4m/pTC1OSNqC0UK7FpZzW0YZtlOtw70KnJUb9z+iQLzxj00e9
rscfpj7KIjrMj24x8Xf4Xb8BgsUH6g==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2EYB/CTmVcqb9i64FTEItI2pzlbuv9uTucC8RI4+5CBohRp0oEK
g0U4NDIvE03UbGWGClNzzAqkrFzti5hdHIlYzqSkyz406eKiovMIeeDl5cf/
fZ/3xok6Wp5T7MUwjORP+9vTFzR9oyI14Mn9f3JJl6yb8upXzWClr60lbB3Z
D6I7wuaWLzbOQRhNEn7IcZLDYDs0ZSxdIPMQUDqkareRd2Cw98LgSj85EicS
RwrnLpGjoWF5N7MLyTGo2VkQeVxNjsUc79PLxCTyLmi3nmuql5J3w9Qum/TE
kPdgMXTqbc8WcjxqZ7Zlbbw+zlmAhs6iq4cXyULovFS8iRFyAs632yMEVrII
ivBQ9zuWnIjc7uiaka7HnJNQokh2fDWR94HPWjJDOsjJuKa7OJ35/RFnMcp/
SnpzPeQUeAvyAiUPHnLejyK/6oTYDZRLkO/kl/kGkw9gfZ3mfVwljU+Fse15
sXtmjHMaIvzHSj9eplyKM0utgeZXlAP9yvkWbzNnPRBlSTG4VuvLsLmqJH44
g7Nehns+L0a7z1I9OeqGFxq/xVEux9DJimNLtXReBcymagd/O3f/egXmZ8XP
epX0HkqE+KS16pYpV4I98rrfaaf6KqivNFlvu7l6ehVOV+21Bjvo/tORXdk4
rvxFeTo6CwzLrIHWV6PHGfG5MYEbr1djQNo8YblFecb/1q8xk4k3OsUAG0P5
GjOaNbkG+f68mlk57S8L4R3m+FMNdL4s3PW1TRrF9D9pIbP02V2ip1yuxY8G
T2dZK80/uOrfCdcwMg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0ntI01EYxvGtmxqCMyWai3S5zMJG2c+7c890c1v+oYksykSYMwukhTCo
WLUaRmRgY0aLIpFwWIYVjpWpeJlOJVgXpsaSBUZoUJJGdsF1w/MWHTgcPnw5
8MI5Yr2xtHoFj8dL/73/nLQEk7eOydaO9C3ro7xBx9kcUWQeXhc31Sf87eHw
9J44WBNBFqAzVewJfPIyx2Jd+5YzqbPkDZg15YT9XCBvhEtak2GbJicguif5
qNdP3gzng1XnU+6TJai66ngRcZucBPhlPR1mcjISt45x7iryduyQeorLyskp
eKR3VU6IyFLEyo2J2V+GmXfCLJy5VuEn78JS2/XqrpfkVKx+6n/caiXvxsLZ
0f5eEZmD85JgjXtpiDkNBtPpyz4bOR0DJ8fGvh0gZ2BcbBr/zCdnQpjmkvTV
eZizYLRWmJtyydk4JSt5cldIzsFkQ/RcaRY5F0l8vU7WP8gsw3zAxwU/DDDn
IcIw2h1fQl2O0JHyRWs9dcDZ/KM8St2/bAsQOb9epZlh5ikQKXJ4i75TV+DZ
jbbmCQXdz0ec4f2+bA31fNjbNGKdr5f1AojaG++c4zNbCtC56fDNETt1JeLL
KhvlWV2sK/G2bmUm101dBaX03rs8ex/rKoinj78aHKL5CrFtOjxKG2TzWAoR
G+LirrTQe6tR2+GobZGMsq4G/7nLHVPEzNMg2Bx2ce8F6hpMfZ18OHWIuhYB
5eKc+g377xYt9neEhu0x1Pf8b8s//wKaoRP6
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdy11I01EcxvG/JrZstFlWCyz/aYVYrXK5aXPzcW+66iY1K8ioQUES+EKz
FNLVxSrI3lyRMGVTSKGLysy5lOaaNvLCCKyVRCVZjYakiANxaIXnJ9SBw+HD
9zwbTWUFJ6M5jlP8uX9fOuJAa7kqzu9Z0ETOhoy6mMplZA5rB73jqxYtwJl1
tqv3Y8lilM+l1mdOv2ROgP+hOarxK1mC42+N2599Iyfile3incMDZB7vP682
P/CTk3Gpa+Vk9D3yJpSmVHLXzOQtWCpPb68pIqdCdHCkiteT06BW/Cjzzgww
b0N2lco5NEqW4kPrDnuxm7wTyS3FwpCMvAvLR9sdPo6cjopAbWR2vp9Zhk+T
YY0gSN4NQWTzrKKDnIH8EpfU8Igsx+3u7/aKNrICPkHTWG0aORNZ1eNzhikf
cxaOdVr7b+qo70GheoXodBRZiZh3jSH/ZXI2rKGR9e6PtFdhfvj1Y72RrIZU
OXE08JOcg6EbDTMNUjIQ1ds8lWR5sWALMC9uus5397Gei4QjpuftYS/ruSg9
u1VrC3pY18CceGu4eQmzRYPhN63CXwd6WNfCIYqvqEzrZl2LNVVtYzUXuljX
occk9BTGM1t0yDin8qdIqOtRJ9fbi6y014NzDd4NCt2sGxAJF8T1XaFuwCl9
UqmxjJnLwyFn7Al1B/tvyYO2XhhwyGifD0PNtFTJu1jPR5DnJed1nawbsZ+v
7ywJP2HdCGf1l96xyFPW9/5ry3/m9i36N9rTGdk=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdznlIk3Ecx/HlQWpkUqZl/mFW0mmXlqVzH+fank2d2xK1QaGWYkWHaZbh
cmlm11ZikXQYonklUmrWSJ1XtYxUugwrKrMkskM0j4514O/7Rz3w8PDi/Xye
3zMzZocq1oLH40n/3H+fdDl0Fuzk290xjumLwLBIvqDchsyDfbAiWmdJtoE4
W9ec+v02swNMfKeg1j6yI/IsblilPCdPgyTWpfx2HdkVqlH/wrXVZDfIbaN7
ci6T3RGUrHm4ej95NrQuUTp5ONkD92t6JHb+5LnYZi7KHffqFvN8TA+QpJWY
yQuRVjoc791M9sSRHXfzy1rJS6BTFTZ5xpGXInziW/VlcwvzMvA13qOfGsnL
Mehs2Do4k+yFAYMbp85pZvZG/Iy9BTdE5BXQ/9ggje9uYl6JXwW7404Mk33g
I9CFldmQV8EjZc6ymM4G5tWYcd16kuo92RfbeT6mlt2NzH7Qf2/b55RCnY+8
Lcc2OESR/eFadOZjm4gswIgqYmT+BCMzYDVkmpJpxboWSE7vmmx6RT0ArqO1
6uHX9awH4KtQW5WbUcu6ENEXzaUTzMxaId5z9ReuplIPRJje7VBNEfVAdPjs
6nJ/WMe6CG0JP9Nmydh5WhGOPhZvPv6E/ncNBB9ilbbz6Pw1UDuetvZ1pL0Y
32JLirg+6mJsvNYew79E/y+B068Fuf1O9H0JziYmB8o6DaxzmD7UntegqGGd
g6b6ZlJv/1XWpfAoT+S8DleyLsWjd+NOxz2qYF2GKo2LsEN2hXUZDn1TJw1w
pawHwSOB+1w8WMx6EEKn9r7kxtM+GOIXCccqImgfjOOiw8HG6BLWQzDoaej1
XJfLegi2PPtwynJxButyZDVXNHUlqViXozb75eJ50nTBWA/919r/zFOgLD9/
k8rWccxQwFhqd6/1yl72vgKVS7ZfCLPPHHODAhszu7JCunVsr0TO+uJIS/1J
tldihWZgz9aqLLZXwk/dITzyQM/2SjibDj6tjkxiexUaxAfOvDl33vgbeWRw
+Q==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwlYjPseB/BX6diOlidLuh0NusTRIuSoTF9ClFTTNmmbmpnWq4U4SLy6
6aoslRZdxykkCi3TpVFoFBIeSil1uZU1S47l0G3juo/ff55nnnk+z/f3fb/v
TAuKEsnVOI5r+Pb9/y/7aLcdj14ytr7mu97ZbjX7ONZiPDOHHX15b49pMI9G
cYVkcOPX62RtHCs83Ro1xDwB96doqXd8YNbDm9rHs9xamQ2wPbZv/HolswBn
ChM0H+UzT0fhNMP8dgWzEeYb9po372SeiYLMMn4gkdkYGcdyWtVWMM/BiHP1
1lG6zHNhXTgjXj6G2RTjeyz8TRKvkc2BZDXJ0CnmeThttPYX+03MFihONTpl
PnSVPB+7X53d3K5gXoBOnbg+p+PMCyHIdc+4+SOzJZ6lm06wMmNeBN5yIEI/
oY78CxatOuLb1Me8GGERkXVDWcxWmFlVMMGnoJZsDR3zsIGKbGYbHN/ar28T
pSIvwcT9Bz5Y6VaThagSVRhM+VhJtoXjm81v4rlzZKC3xPiwWjGZB9yGFqyW
5bL7pbBq6ez/+TnLl6JscXbvwEEl5cugntcj9LWie34ZHIxNTBVVZym3Q3Pe
5+2N8cWU28Fjr7A87F0+5csxM02vubUhm/LlUJ52+70j85+Ur4Ak7llqmvkh
ylegZ2lP26GsVMpX4k73pKYbdemUr0TO0NadEXrhlNsj8ZFtZcuSXym3R0yV
pfOd826Ur0Kdt5toRGYc5asg93uyV3pyl+33fDWeXlEYbZm677v51dDdW9Jz
MS6Wcgc8FL/nys0KKHdAiRJ2z2wLKXdErGZ96mSHE5Q7InVYc/VIX7rn1mBX
e5KtSd8pytdguG/kT181yih3wmVX8/X7ZpZT7oSbBlqVSbUKytdC8HL7R8Oc
CsrXYr/dbH5Oy78od4bZ2YFnO2Rk3hkzws3W9p48T7kLKp63S6tFlMMFaXw5
N30Pe54L2q75pHy9QHsqF/jFC+tbuul9OFdsxx+KDGMyXDFNGl2iubWE+q7I
iFXkzhlH/0flistXi6w3bGHvL8I2zeQNm8/RHkSIfP12LFdTSX0RXj+pmMFD
SX0RHr73qo3ZU0V9NySbCzNy1l+kvhv8TKZu1om9TH03cM9dp2fpq6jvBudz
jbq/jb9CfXdoV226sSKZcrhj1jazSTkvyLw7kk1Mhk+8ZH13NFjKhEcdWd8D
/eePHtRTI8MDRh8x+Gk0mffAhpWa78qvsL4HPuwe2VzwN9b3xODy0qeOXC31
PXE1qerK4QYy74mcA/1ekaV11PeEYOh2waIfr1HfC+73azZ0Z12lvhfuphjq
erSQeS+8VL7qdJpB9yovaOwcrRnQxfpi/NqXkua55Dr1xbCfO2bYxJ/Mi1Gk
ELqGJ7O+GClHoj2SuHrqeyNSlbIoqp8Mb3gdNe2PzSLz3hjXcE99muYN6ntj
35bPRQvVG6i/DmH85YWXcinHOjwOeGt49y3rr0Or+/LJ7X2svw6ztHJdo/5y
k/o+mPgfdfGt4VvU94F0rWB+7pfb1PdBeNZh0+iHd6jvA92MERdOht6lvi+u
W0xV+8Gpkfq+sFxhIDCJIvO+2OmYVhicQ1b54llN2rD0Kpnzw5rgWR1cDev7
Ifa3guzaHtb3w+JTY8qadJqo74dZ59dH9DmTOX+Mvumw5lw8Gf7otVD3np1H
5v2Rt5pv6z3B+v74+KJL52UU6wegZVh77rwY1g+AQlwZ153I+gEYLBnXYiy8
R/0AyCcdsa+JI3MSbOgIbP9SShZI0P3KQJTEDAnqZn5ZLB7T/N0SCeKutY5M
sSHzEggv1zdGJ5DzJQgSD6/ZV01WSRBw5r+vwpTkrm9+Wt6RXkbmAqG3ILza
pp4sCMTna0pTY60W2g/EWLNei6ZBth8I+5uWZTtfsf1ALDmbLykNp/v8QFwM
+XKrsZasCoSOsMP536L7tB+IUXbqzZazyVwQDinrzeZFkgVB2F9RcfDBFjKC
4Gh0tJFnuSQIMu+iw4/iyXwQcuv852qw+/wgLPipOCC7k6wKQoRNSPfDDrYf
hLrkC3lqglbal8LXL2P4tTNZIMVKTeWNhCoypOi+d2ZqYhpZIsVmUYm32J3M
S3GoU9/7HU/Ol6LT8tLU1EiySoqMOuWf6SzvkqJUw7WtScT2ZXhUdH6ekwvb
l2H8pr9PHhPD9mXoyCu+lG3F9mXYHa+5J82T7ctgErGxKcGD7cvAZYmfXypg
+zJ8SvVVvJjN9mX4a/EBl/RtbF+OY3repU4qtv/Nots3MuPYvhwG3Z8Oa95i
+3I4K65ru2WyfTlWTW56O24X25dD/8jG3ZkNbF8OK50JoVMG2L4cR2L023PQ
RvvBWDjiufYFe7IgGNqjqnob3pARDP/6BJO4k2RJMPziYvboKsh8MEbJ3ad0
3SPnB+NS+WeTH6rJqmBIdhx/tOsBuSsYdlpZO35n5kLgGj26ulLjAe2HILrx
8ezP3mSEoO7Fyot2QrIkBLr7Ju748wPbD4H5cc8pkx0ozw9BSGOls9KIrArB
E2XKsWAzclcIwvOTzuSZk7lQOA9a3z4tZvuh0PKpXLd8L9sPhbnh4M+FF9h+
KHpqT7S8+YPMh6LPuij9nW077YfCJjRwmZkHWRUKqycW70e5kLtCMWFL7SrX
pWQuDBFNYdX/6Hxg+z8jp/bU
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1z38s1HEcx/FvdP2wCtWWpHJH0Y/51Q+/wuvoLlyOQytrqa6V0uRHskw/
rh0ilh/VQn5U56Kh6MdC53cUpc0qrN/90Q9HWH7Edv2c9+e7ffbdY899frz5
8sjA/Xocx/n8W///7DPqUUW5GTxumNKwR+fYrwTOiJlD7pJna/g85lkwn5Nt
JeCYjbBAFL2ydrSNvBDZ7sGNNa+ZTdDfVe6X1s5shskfhtZ99czm2FSR8fHQ
U2YBdky3ys8oY7bERO6J55/VzCvhKJPa31YwW2OuNmp7vSfzatxyHZr8bsa8
Fm9l+CjsaCXbIOZqfL+hktkOmoNPqky9me2Rnqw/I8ue2QGDBSb6Py2Y12FR
h7Z7MvMReT2KUuNGZTkt5A34Oi26WB3KvBFBFkeVXjxmRzy6sj/ULLWZ7IQY
2wmNKpPZGQgc6S29yeyCkAP7HKvDmV1xfKnwuzyiibwJNUUa56SiRrIbVJ+M
X+uymd1h3GKrRT2zBypfdv5W6JgB42fBEam7G6asAD5ohWdv6NVRF+L5h3vz
5HdqqQvBaxmwvCvRUPfEcp9joqr2h9Q9ERmeL/HWsu6FV4nDu3gVNdS9UD6+
18X9RjX1zRg80pZYKCUrNuPNnlyXAhGdx4lgPydUoDZnXYRzqve2dW4PqIvx
xyZooOtAOXUxWlu1PZ1NVdS3wGT9ztHgEnb/FsQWz9/2rpLm5bxxNCRIp7nI
5vdGc+G22R6CCuo+4N+qsmsdTKHug7gB6YrkjIvUfZHzJjYrR6+Yui980Rsh
EGdSl+D8he7T0jEldQlOlRh8uV+SRH0rDvPb50eKC6hvRXOU8EzxsjLqfrjs
sFjWZMHm84OtcXdjRvx16lKoE87LayXZ1KUoGgt8q7pE7+H8oZypC/HMoXkU
/pCXlNWftKLzuACcHIkw7XcsnTICECtPsTJxovsVAQhtH7r3ooLe1xiAzw66
tIT3ebRfhlU1Yq3Chu6DDLV9E3mVrtdovwzjvMG6b+5q2i9DmPpOX086mQtE
WNYO38VcdcNfkbV69A==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQMC1xcX2HId3w/hfbC3jL6w9zucz+Dw/JAPpxUn
jM/hEFtaeePPz2NQvoBDgfK2e15PYXwRhz0/Nnx+cxLGl3AQMXT+1b0Lxpdx
0DO4+/L6DhhfwWH+yutFi6fB+EoOa2qy60WXwfgqDhs2lpxeWwPjqzm8kvqX
56kL42s4SN+zblrIBeNrOUj0pWufFofxdRwUIgVkw61hfD0HprrTMueEYXwD
B7bARKv+k0ehfEOHB5ubeI6nwPhGDmpb9s198vsIlG/sEHCvxVHNCSZv4hDh
ER5Qsx/GN3VoaQhjkc+HqTdz8Pt8U9+9CMY3d7hz2EryYxWMb+Fw9eNuxbUX
YXxLh+M3o6IKXxyG8q0c4n26vr95fwjKt3YwdpaeaZ0E49s4vAjSu6OeexDK
t3V4E/XyVhk/jG/nsPHOnIUXj8D49g6bj0/2yQiB6XdwENlzbpqTAZTf4OBw
58mrCfNYYO5xdAiMkmkz+AnlNzg6rH7fOqmPB+ZfJ4eFVlNu726B8hucHL4s
3DL5fiBM3tnBKXSPzNKNUP80ODtYfvvWf7ITZr+Lw74J8ocVu6Dua3BxiNu3
sLyKC+ZeVwfDCXJJG9ph9rs6PHQ4VJjpdWA/AEpH4xs=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1zwk4lfkeB/BzIu1S15SMdBgVLa4QSvS1K+HYd46zOJRouYlB99BENc0k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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdkwlYzHkYx8cRbdpMh0JkJFLJkRgJfTUdpqS76ZozuZYkYpEasXYr5Mij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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90H9MzHEcx/GvivVLDsXpl6Jf01HqFOrqdVepS3ddyc8mnGVmKYnSj3Fp
XeVHpB8KXfpBYwyhnwiVMJtp+oGFiz9MkklisrB7f3y27z577Pl9f/b5fu2V
CZGxehzHBf99/u1s8Xqrd4mMO1t1+uKvFGZMHzVi5uBrnmDz9L8NsXX7HeOL
Bsw8zC6wTVNPYjZH+SP7nOThB2Q+ePXN/acHma2RPZNn0a1ltoNUmC416WOe
h7K0jldzNMwOiBg9sNvxKLMThH2fdozLmF0w32xOdZM78wIoTV0sugyZBXDX
pvbm6jEvwhRFqupOTwfZHfHiensnX+bFcB4p4re1t5M9UOvRUizWtpE9Ydan
GDQoZRbCqdYtO5fPvAT+qidGSdbMXqhV6QsalczeeB/oEzu+gXkpPKMdHL1+
3Ccvg2ao6P25VOblsDhidj72JLMPtkR9s0pV3CP7Inlsev3A77tkEQ5MNLrF
2LHuh+ev8m0rBlj3xw1JtDyxppUMhIZURao/N+usAi5bbm7k+9yiLsZoo2Fy
oayBuhg5gvtl+gVN1CUojx/s7Depoy7BuOzwxMRkMheAyHuS7uNVV6kHoOSK
4O1rgwvUA/GzW3m44mYN9UCkRA7zs1yqqQdhLFHskO+qoR6EDwE3isrqiqmv
QK58aJX1qbPUV0C1v9yj8nsJ9WDkCNevjRJk+et6MNoyNtdElcVRD0Fh/M5J
Sel7aT4EcWumDqgXpeje56R4sVEjaukpoXkpErWmmV7Vh6iHItvjmLqlvph6
KPQlJo5WMYXUVyI+mbv2zDyb+kqMlaudrd5spB4G84fyhut+cdTD4K4KWL+6
IIO6DAcLOqSSX9uoy2Ct31+5TpRG95cj8KmXqdnC1dTluKTWTtNabqEejlkv
Jw7FZuyj7wvHY36dUVdeIp2vwLWPruEuvBO6DgW83+VxC1bR/1cpMMg1JAiD
q3S+q4Ao03tk7m0yF4Gvgk3aGdFnaD4C727blKbbnKT5COTrlV5avkfT+gee
CFA8
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw90Ak41YkexvFD5mZJV10Zd6Ro0qpuo+zRG9l3co7dcTaMSaTNqOagbSyV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          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[{
          LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQMC1xcX2HId3w/hfbD359t8yp4XxmdwmHfpik0q
G4zP4XAySMR1CiuML+Bwsyt10/6Xx6B8EYdZNRtP73gL40s47ItL/sF4A8aX
cSjnn/zJaBuMr+BQlanb9G8ijK/k8FL41jPdBhhfxSF4VULiDAUYX81hydvA
uMOMML6GQ/JZg9ZfT45C+VoOmYw1ckXHYXwdB+Y7Z/pb4mF8PYc6+cM2xxVh
fAOHL59fz9flgfENHXpy4w+f33MEyjdyWKlx7vWhOBjf2KE8fsP7OxMPQ/km
DlPErk3p94bxTR2+lAofmbX2EJRv5rBlTWn9/jAY39zhzOXinb/NYHwLh/0x
wpdvvD0I5Vs6vFsVJe2vBeNbORTOmXAu88x+KN/aITbCdWHiZxjfxkH6lPuB
25P3Qvm2DgVJf8vPR+2B8u0cEpLPTWDZDZO3d0jnbOhUXbgTyndwSFS44MW+
axeE3+DgwDQh/KQ5O0y/o0N1Kue/ezy7ofKODvtm3j99+wJUPYOTw1P29rN7
a7dD5Z0c0o/q8kzg2AKVd3ZYnpaavm0x1L4GZwceJvk9dguh6hlcHBbmTdj7
3wYm7+Jw/cWEr1xLNkHlXR3W7WpNkdDdCJV3dah9kVZrawKz383he+jbD+sX
QcOzwc0h4E1mnf8DWPp0d/CQbXvd13xiv7vsj/Z2A3eHT5d8kwQiTu4HAOk8
+5Y=
           "]], 
          
          LineBox[{{47.52481710134089, -0.198}, {
           48., -0.18838443485050577`}, {49., -0.1865550422537676}, {
           50., -0.18719053664185797`}, {51., -0.18750843534501185`}, {
           52., -0.1865550422537676}}]}, FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQMC1xcX2HId3w/hfbD3O9UrEsIN4zM4MF3jXa7M
BuNzOHw6+kHwIieML+Dgc3bi6rT/x6B8EYdshuWZDn9hfAmH/eyblndehPFl
HJb+Wfyq4CSMr+AQ4HBUasJeGF/J4VHi3tVFa2B8FYetu+4/vLcExldzeLb3
ivjhfBhfw6HLX0LipjOMr+WwRVZV7bUKjK/j0Bknu3GlPYyv5+Dv8YjrrASM
b+DQwjet4MHjo1C+ocOjGWoxVvIweSOHtSumVjU8gskbO3hd+e/KLgvjmziw
Of3cUf7wCJRv6nBYTPBb2QsY38xh/72UkvbNML65Q8crqfzUKYehfAuHO3N2
RvlEw/iWDsv26Oc33DwE5Vs5nDts4tShAONbO7zadzjfYepBKN/G4WWqa9oZ
zf1Qvq1DoeiCl89uw/h2DmaaFS43smDq7R3mPd6RMGX9ASjfwSG84MucM8eg
6hscHIr/7nR4/GsvVN7R4QVLT41/zj6ovKPDsVNvFhyX2AOVdwJqYI9UN4Kq
b3BykKq99bFYCma+swOHB4fDyxaYfmeHrtqa92XyMHkXhwuHRH9dPgPT7+Kw
3uOeT2gsVD2Dq4NYW3W9lMG2/QDQbtz1
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n8s1HEcx/Gbthg2J0LGrYSTTBe5kzu8zq+78+u+RZclf5TRSpbShbZy
+oeZJlIdXSTVLZus+bGInAtlrdFOQ5p/ZNRWl25+tES1vu+1+m7ffffY8/t9
f7+fz77bjp7an2XF4XDifp2/r3Rwx5vywm2f9/3Rl0jL5rbBJBsyBxuU3Ha+
HdkGU5F2tpVrQ6y5uKZe9HzynuyMWlOlTjJCdsOMS+vNuTayBw6IJR/qG8hb
UZX2aNW3nOyFhghlq1RH9ob75IQu5jTZFypvR4PLQbIfxE9TVFM8sj8q3WZC
XdoHWQdAyHe6XFZBDkROs3HgipAswAQMBTfiyLsh8GOsJKsDrIPgETBv3fKC
HAx1xYrYJ568B6YJwZ0QDjkE6xmVpVlNz1gLUdZSw5v1JIuQPaLruh1NDkXn
7IOu4FDyXqhTIvhvH5LD4FZq7z3EJ4tR3LRr7RtDluDlvHah+3E/63AoX6sL
p88aWUdgYVp6ouI83R+JMZFDd5qFDAiH7/NabVlrAONFfW6xL3UpDnWMSaaV
1KXguL7xSv1K86OgTe3bMjfMWhOFniW982I29Wiobq1Xu2mpR+Odk8ndx4l6
DBx6HEVBrtRjkFcncLV+ReuJRZDwLr+1ibUmFpv6O4/rjtDzcajdHiDXH6bv
i4P2k70hX0RdhryCsWbTJeoyXLcxL/bWUJdjldfxWZRJXY4Cf/P3ERmtXwFv
QwXT6EXfp0Ca2ryxREw9HqvI+JGzTD0eF/JWwtIXaH4CsqaG5hoD2f9Dk4Cu
5epAVRH9L4ko4k4eiy+hngiHqxmj6WaanwRLRyfnXD3NT8K9XkUVdwf1ZIzX
WSJtZ2l/ktGbK89sGKP9U2JUunNC8dHA9v/MYVAiyzeb+ex8MFg7aW0slNH7
GKjL87P1etYGBswZp6W5YXr/vn+Nv/4JCxhpig==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9zgtUjekeBvCP6FRKMaNSLiUzGaUro2TqSSlF96uu+9reciLXiFMfE7ZL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          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQMC1xcX2HId3w/hfbCfuk5Gt5sdxmdwmLTx2ldb
bhifw6Guw/ZQMA+ML+BwZEkqmz4DjC/icHzud61MDhhfwsHnoL5k2u9jUL6M
g8rsJ+s+fYTxFRxqrs85evQCjK/k8HdTePDkehhfxeH+BTbJkBwYX82hQ8Aw
55UpjK/hME3goYSPAoyv5WAZmP35lC2Mr+PQycf4fgYnjK/noH7wmXPnyqNQ
voHDj8TPMb0+ML6hw7zlYjO4ZsP4Rg5XbjXfUsqB8Y0dEtbYOJ0/ewTKN3G4
eEM7r/cRjG/q8I+pOGXfKhjfzEHcyHHWp1QY39zB1Do4WXv/YSjfwuHP5/mr
/qbA+JYO3XIic9dtOQTlWzn4ddfoMZ2H8a0dmoM+9srPh/FtHOSDdTgMeWB8
WwerabmZwqcPQvl2DpFvUx+X8R+A8u0dzt2WjXx2HMZ3cIhJvKaxJB7Kb3Bw
uLAi53SwDUze0eFxtPG0UEmo+xocHU7/37n4dBfMPieHl58D3a7NgfIbnBw0
UydZftkN84+zQ+m9P/LG7FD/Nzg7+Cl9W3o9Eybv4lCVtaHX5SvMfBeHhZZ6
k5rWwMLL1SFJqm9PvCBMv6sDz/mfRh7+sPhwc9g57bHEO4eTUHk3h6iv7XsY
HGHuc3cIC3ry96/gtv0Atrbsvw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XlUzeseBvDfTrpFhpLxumxOMqWkVNLWI5qINGge9twWXQ2iMu0MHdEg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          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxFz21Ik1EYxvGHNJQRJmWRzaStOUbJszWtae7l2stjX4ZBQQ0z0+YsP6RW
ixFhTFFki2KEE0qCrMCgIJKphLrlylYJtiVSgVBtWjlJtAT7oFDhuenA4fDj
z83NkZxqOOxYx3Gc6u/999LJfH+vUSeKhNa0YKiyxqyRDDIHz7uheG8WOR29
2eUWkYSciW7nVEibS85C1HVLsiAmb0OedFLp2EjOwaEMz4bY75fMO1Ge7Kh8
/IkshT4qbpL9IMtQ6L/bnvhKliMyXzcsHSEr0B33nfS3kndDrhv2JSrJ+dDZ
Z0UmNZmHNqBczT9LViGWdnSpZnqUeS+atz/8FX5CVoP3FleluMgFMOgnFNle
ciGKJh/ZUq+Q9yHFXs0b28j7MeBK1G0WyBo8kGp8qwpyEfxtDZ93BF4wF0O4
XZDb5SEfQOJ14LJDIJdgXGldaZ1/zqzFx2u7eqaU1HUILg+eaf5AXY/74rmm
nxepG/B266tB9XXqwLFoeFZzJ7xmN2C7cH6mvmyEdSOW34xV+BzMbiPsY96b
i+upm3CkOj1oa3zGugnmvNG+b2XMnBlz0/V9LnmQdTNOpAUX40+HWLdg/HR7
UrMnxLoFtbVfavhUmhewxSnuWjlH8wJinc5L3/upl6Ilp+TGVZ72lyJ5PCRT
TbD/cAdhqOiZ2SRj+9z//QdRQPIq
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0W1IU1Ecx/HLEjITWyVoYrZNCzWzNM1yOn/qnDo3myvSAhOskGymRkw0
yGkuyhUpZlnUC2dZhhFZm1Y+Zw18kwtmD249EJKWTglrJBIVnvPCc+Fw+fDl
f8/hHmF+sfoIj+M4+b/1/00f/puWkngPS9+iZhMkn0S2rZ7UHCRXG83nV1C7
o+9Dz4TUnZqPPGe47+Vl1N7IjvWqqZx4SeyL1+0ni0NGqP1hlLuN5rRRC9Ar
c/ze0kAtQklp3J/AC9RB0DaeyLJWUW9CuTMyv0JJHYxLe4KUEgV1KKbTWzzG
o6jDMCgotXfHUIfDNlm41+37C+JtKHEo1h3fTx2BYz45NX651JFYqK+Y915O
vR13eAULmw1DxFFodzUZ7muoo3HR6lq97wr1DngZIhYMYXQ+BiL9RmtAMO07
wfvc/TZ3JfUutA5rIvna58SxOKhfW5srpBajSd9175d1kDgOUwM/a8qrqePh
I+y1fxRTSxDQMWzUjlMnoFZSp4wWDhADrsLDeQ5F/6J1QPftTsWpmaekJyJA
3N6T3dlDeiIOOK1xXBExl4RV49fH6su7SE/C6KGxM988n5CeDLO1QTfbRKxL
Rpl0LqzAZiJdCvGNm/ZndY9Jl2LSMu8ylplJT4H8fcNds55Yl4LTI1lnM6V0
XoaKjletvJFHpMvAL8LRGTudT8WoTLDe2Em/n4rA6jG1qZnOp0F7zVT8zvmQ
9DQoNf5fRN4dpKcjyPlVPeR4QDpjTs50xlwGjJUqi5+M7KfLgHTN0A/NBnJe
TsHMM+aUTGfMZTKdMbeb6Yw51VKDsU4FjW4upGqa/J9+FWAJbRPN0vNnLTUY
6xj3M+bUqLo11RJ1jtwP1EiNsIU0C0x9fwGe14nH
          "]], FontFamily -> 
         "Arial"]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, {
        RGBColor[0, 0, 1], 
        PointSize[0.009166666666666668], 
        Thickness[Large], 
        StyleBox[
         LineBox[CompressedData["
1:eJw11nk81Ikfx/FBpcRGUel0/YrsytHhqnk7cmxG7vuYw5iRtJayUWkSOWIV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          "]], FontFamily -> "Arial"]}}, {}, {}, {{}, {}}, {{}, {}}}}, 
    AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
    Axes -> {True, True}, AxesLabel -> {
      FormBox[
       StyleBox["\"t\"", Bold, StripOnInput -> False], TraditionalForm], 
      FormBox[
       StyleBox[
       "\"\\!\\(\\*SubscriptBox[OverscriptBox[\\(r\\), \\(_\\)], \
\\(t\\)]\\)\"", Bold, StripOnInput -> False], TraditionalForm]}, 
    AxesOrigin -> {0, 0}, AxesStyle -> Thickness[Large], 
    BaseStyle -> {FontFamily -> "Arial"}, DisplayFunction -> Identity, 
    Frame -> {{False, False}, {False, False}}, 
    FrameLabel -> {{None, None}, {None, None}}, 
    FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
    GridLines -> {None, None}, GridLinesStyle -> Directive[
      GrayLevel[0.5, 0.4]], ImagePadding -> All, LabelStyle -> 
    Directive[Background -> None], 
    Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& )}}, PlotRange -> {{0, 200}, {-0.198, 1}}, 
    PlotRangeClipping -> True, PlotRangePadding -> {{0, 0}, {0, 0}}, 
    Ticks -> {Automatic, Automatic}],FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{"\"All replicates\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], FontFamily -> "Arial", 
                    RGBColor[1, 0.5, 0], 
                    Opacity[0.2]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], FontFamily -> "Arial", 
                    RGBColor[1, 0.5, 0], 
                    Opacity[0.2]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             Directive[Background -> None], FontFamily -> "Arial"}, 
            Background -> Automatic, StripOnInput -> False]& ), Editable -> 
          True, InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}]}], "}"}], 
               ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}], ",", 
               
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   
                   RowBox[{
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True"}], "}"}]}], 
               ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"Directive", "[", 
                   RowBox[{"Background", "\[Rule]", "None"}], "]"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )],
          TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Mean of the replicates\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.16500000000000004`], 
                    AbsoluteThickness[1.6], FontFamily -> "Arial", 
                    RGBColor[0, 0, 1], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.16500000000000004`], 
                    AbsoluteThickness[1.6], FontFamily -> "Arial", 
                    RGBColor[0, 0, 1], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), Editable -> True, 
          InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.009166666666666668`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], "}"}], 
               ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}], ",", 
               
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", "True", "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )],
          TraditionalForm]}}, AutoDelete -> False, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.702030141207961*^9, 3.702030175836627*^9, 3.7020302378821487`*^9, 
   3.702030404975274*^9, 3.7020306630798283`*^9, 3.702030767795496*^9, {
   3.702030806322263*^9, 3.702030849085206*^9}, {3.702030920292411*^9, 
   3.7020309411688843`*^9}, 3.702031248885127*^9, 3.702031312736662*^9},
 ExpressionUUID -> "b9f9446b-d5c9-4912-85eb-cd1adb5caf23"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {{}, {}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz1tIE1Acx/EpIZVGpmtaOXUWS0XHbNXMZvvNXZyz0hoDkS10OIMM2rSL
Uk5JQgqDSJpEWdiS1UNEDC3aQmgYWVGi5AqllMbUXtpcyOgiFZ3/gx44HD58
OTeB+cRhSyyHw5H+nf9WGjzDgOdRQxb+KySfFMor6pPJHATbspU3BwXMq/Fm
bGrEoycnYuhJun5pPpOZi612RV9uLzkVCe1ll8yF5DQcT6iSe9wZzJk45amU
FUbTmbMwWW180aomb0M+L+zsOc1nFsI32tobCKYxZ+Nb5OFdcWQLcy7WLz7V
hhrIeRBPfzUZBjYzi+Brdthv88hiuK/aRVdubGIuQIU/v2ZNNJV5BzKcl89v
P0CWILRosU/3pTDvRP/UzPj7KI95F+LHv9uW7OTd8GkjtwTejcxS+OM6/fwF
LnMhxKYO17N75D345VwlmB0lFyGx01b3+Q55Lw42JZ51DJNlOHot9uQ6CbkY
b2urwpGPycz74LY2RaqbyXIEjuUU/e4kA+XusO6QlLkdmHc0Kh7IqSswm7PQ
UlBJXYHXgwP3G63US5af116CkRaVrE5IXQl1ceDcux9JrCvRbQl1G13MHBWM
HZLqD3PUVcvv46gRZ4hxh3zU1eiZ6Yr5FKb9mhX7Negvkrx09VIvxVpn9Ihm
eAPrpbBORJ7XCqhrUWMz/Xw1R12L60OuM4Y86mUrzi/Dfmnb4y8iep8O+omL
XWN8+r8OSfEp3qCXejmcgQtmZT0XfwDBUeNG
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1XtM01cUB/AfjylMQOaAITApuAcg6QZsKC3IlwLlzWh5tjzakpAYcCFR
Nzd8/cYQ/AM6EeI2NYhmyxxoDTjmFEx+sMCWbWB8RBODDoWRZcaBIVHsFLeF
c/+4t0nTfHLuOef+7v313rDqemONqyRJHf99//9ln4DigcG+unAsaz45KvaP
1iIPZgmBdXvPHj0ZRvZAUNPt2c/0zL4I/E6j9ppXkf2waCua3GpnDsT4p9rD
n0Qxh2B2dVTcoa9DySoM7L7sMCysI4fjwaJb800d82uIOfXV8f11r5LfwCPX
e+rE8RByBD4yt++dS2OOglOe6NaUBpOjcex+W1VbaxBZjfapO6lr760lv42s
oOtXxtKYY/Db5hm9cTyQHIsvhrvcWkqY42DJGcLQyCvkd/Bxn2ExooH5XSw4
x0YnbwWQ4+G51OmpjWfeiC/tXbUjH/qTNyHM/fbUwlM/cgICLUNX7XpmDWZq
IzXPWl4ma+HImDPu9GJORIz+yIXs8TXkJNTuWPzepZR5M9b8qYz0Gl8iJyMx
NrfFx8oMLCxdNDWu9F22DPQmhm+J+HE1xVNwNvj0+as5ZDkF+aft6TUD3hTX
4Yb3gS1P8smyDuuzD98wn3qR4qlo2OccrutZQfFU7Om6NhRw143iaSg1xzq2
hT9PXo6nwVUV5VzV+3TZUjq292qT+09KlJ/Oj5f0QlyPVW5nGv7qcKH6Gcjd
uO/8tJr6yRlCPFPon4m5BOeSTj1L9bN4y1mIa3vwOEV5QvFsqveQ4tlCfo4Q
FyzlCvFcoX6eML88YX3y+eeRBUvv8eNlwVIBPx6C5QJ+/ZQCLJ8XrlTfwK8/
DDC0xmxw3+9O+QYh34BvBm8G/BLyAuUb+fcBRj4uG4V8I19fKuTjKERze51m
V+hKyi9E+/T2XbrHZEWIS0X4eTRp546LHpRfRPvH3tci/v1VhLhUzBvFiD7n
viLezvoX8/2UYuH5S/j1RInwvpbw9ZUSfr5SKV8fpcL8BSvCeKlMyC/j5yOX
8fujlPHzk0z8fkCwLFgx8espmXlDsGwW+puF/S8X8suF/S9Hn6O+U11O66WU
I3Rp/NdN8+x8qsDBJrcffq8ko4L+f56UX8GPVyqE862SNyr5fnIlv9+KYKmK
74cqzJ+78myPP+tfxddXquj/60X5Flz6SfN3xDQZFnhvi9Vea2TnsRBXLNiq
O3jJ54QP5VuR9a2j5/VjdL6rrDAdOXPCP5ruA1j5+8BqRZ5+bHQmid0XVnwQ
2dlxqJ/cbcX9yTeb3mokK1YkTAx2j02Rp4T6kg2R+ev90t+n+0hlw/WaR54R
F8iwwTc6JnjiOdlq4+872YbP77a63HlI7rYhPWlm92UnWRE8ZYPJMpJpLmP3
ZzV0w4XrNoTSfauqRmZ2661+ExnVqHf5p7lH649/AQZyaL4=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02lIFGEYB/DJtVwzdfPYzLwrWTyW1Exdj/27Hq3nuleF+iEErXBBSiux
zIkwKpUSpQ8pUWkHhaIdtGYeSXRJhZUlGQQZEcaWhlmIbQf7vB92Bobhx3+e
ed55j+CSCl2pA8dxun/3/ye7pMZb/b3lIbBpRpnSdLY9S8LMoXTe/W1uTzBZ
DM8hq5O7kVmC4NQdx/dag8hesIyU73K/xOwD011vLTTMfjgxYjp5500gOQh/
vluONngwh2CP6fHrFGMAeR2Mcq+H1ef8yaHI3DLq32rxI8tQLxYvdlUwh6En
xawwF68hRyBxbKgyvcyXLEd7h++2Jw9WkzegxNyTMDLpQ46C+1y33hLNHI1G
hbUsbf8qcgxq6hbulV+VkjeC36ucU4QyxyItYvy5qN6bvAm1RcqkmwbmOKju
6QPCA73I8Whouri+S+RJTsCHtk2xky0eZAVelc47y/pWkhMRuVI2e2ZMQk6C
q8njy7HdzMkCp8CkOjXgdt6NrIRDUNiCy7UVZGDMPD438cvFZh5Ym336deGV
5ZSnYubG2O9ab2fKU9HbXdEqLxJTrsK3hAWrSr6MchVy4+puT8lFlKeh8lqi
8voFjvI0XO5/I33it5TydLiIumqmW5ZQnk7jW1Ta8gzKZ23mBeYyqf8nyjPp
u+zabG9+s/37nBpbC6O794T8oXo1bOfBgeqyEKjOS5BepfHyWdA2RoU71jtS
ni34/2w0T1UeUP10ojzHfj75HJQ/Mg++7KP55nIF85uLp74z060SNv95GHio
+CqbovXi81AY3qx+Vs3q8zHv2nd4MZbl+eh83LHPpYqtt8a+H68R1Bcg0Pp0
NH6G+kFgvsC+fliQc1r7/tAK+mkRmSw3DH1ypXqtYD/qUGAKG/2xmvYrdGiI
Ln3Xtp3M6+z3/7AOVTsvD2qk7Hzo8avT6dDHVDL09ueH16P4SEzhxGfysB4Z
yR8PPl9g9QY03XAOH3zP6g1wCnA03H/hib/TUkvu
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQNioVt3b8xWcoDwPtiH79pmGikF4zM46K1gKL69
RRHK53AIlJ4k/TYCxhdwCO3NnMD8UQHKF3EIef705K7JML6Eg1+1v5q1BYwv
42C04vTG3EPyUL6Cw7Mux9JQXhhfyaEpNzpDMFAOyldxyJg5hd1oiSyUr+aw
/8CZ6y8fyED5Gg6rVv1elPZeGsrXcph9jfvnMlMYX8dhU9XSubaTpaB8PYeQ
zxtzdl+WhPINHK6+beB4/VgCyjd0kF/c26TuC+MbOUx8XFzt9F0cyjd2mCs3
dd9sOxjfxGFqg+1iQScxKN/U4XGjkEZBsiiUb+ag3e92zum0CJRv7pA+lamE
1xjGt3D4mVj8t3GrMJRv6cAuxxJy5BKMb+XAFsq4+cNhISjf2kHTT1nENVcQ
yrdxWG2jlKFxmB/Kt3XQtdUL2f+MF8q3c+AtMrK+3ATj2ztMaGHecT+WC8p3
cIjSnuhxroIbwm9wcPjGu7PxjykPVN4RVX2Do8PGdflT9KI5oPJODvIevpZi
q1ih8k4Oxaut7TctYoDKOzsY97797njgpz1E3tmBm3lt1avJHyF8BheH95a/
/jnpfYPKw/jPoPKuUHMYGAAydqNz
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtMU1ccB/CLRMBVHEgFCgxo8dEyI9pORYH5pdKCUEqfUFAiIWmika0z
wnCO6ZUZ3YIYhUZNcMnMpvgADb6FLasQxEmIDxSNMRqCbuDmds3coKA4l/3O
H/c2aZpPvud3es/vnHuU5R6bewrHce633/9+2SfSeb6jbYMK/0tYkdZrr/NG
MXNY/cPgpohOJTkExiv6f7SlzGH4/ZBm6cRkIlkOPvTrrFNHmaOhdFQdeZ3N
HIe0lqZ+4W4CORE/qV0jgwpmFW4mB504Vx5Png1/0+jxpOPvkediRKvsiRyP
I6sRXhF0+ZCaORkv4/u9D3bHkudDke9xd4YzL8CvbTWbX26JIS/EgfVR3OE4
5kXw93uCs6oVZC1qK57XNd+LJutw0DTbFlLP/AGWZd/BmdNR5MXYuehi/D0L
8xIov90uz+yLJC/FvEfWw1VTmVPhCZjYeSJtFnkZZrbeXS9slZOXo/yaql3H
R5DTUFd/ZE5rIHM6gpwBZ4WumeQMrPlSV3J/mPlDHBjcHfDoBfMKNLqFxjXN
zMCPPbsej20j80DZxtKJ68PhlGdCFti65VkjmZeY06MjxvvN5T/DKNejSuNt
bDhD5lbiDWd9U1b5LuUSc1n4a7K9uDaY1WdhIPSrdX5zKOUGTElMHpednE65
AU0DMv/RxTLKjdDVPx/N9E2j3Aj//Iaa5goyl419Q5s+148GU56Na90Z1ZXt
IZTniMfzORDO3nr9xSxWv0pSv0pSnysez+eiL0Z45g17h/I8JEz29aYKZD5P
kpvE6+FNaDvl8S5YzebPx94dgZcel7L6fPF6OTOScvcPlBxjufntfi7/Qz1E
/eIKJP0rwLHMru6rCtZfC8wtewzu82RYsNLxaslU4wwab8EFYW9KTB/ZZ8Hp
2JaLt/PY/llR1WFJTx2jHFbx/LwV3//83aeySlZvley/DfnGq91PMmj/YcNv
D+ftSKll58GGOq37YVMZ2WdDbPTQ8L4Gdr7sSNeads0oo/MIOzTmJLnhI3Ze
7fglRaX7WEP22SXn04GT6ap16i56HjjE6+Ed4ufxOWCpSO79W8HqnZJ6p3g9
vFPSP6e4H1yheL9QKOl/IaZHdFZ/MkLz+wrxmabH7y5g/18kXg+KJO9rEcby
noZsN9H77ZOYc4nvB7jE9w3vgiHjSc2NcVbvQvHazpwSF7t/iqG/Yo9/P0GO
fwGVu59l
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlWlMVFcYhi/UVg0CAsMm0gI6FMRSwQrI0nnZRnZmZRaWAu0EY0mYDp0o
mthb2gSNSlrB2MQarDZGhWKQIIFRezsI2vKnoaZNiqVR6II1LYgFbArUxvP9
OHeSyeTJc97znXvOPd9E1jbobJ6CIDQ9/f7/S58gY5+r5+0oPKMZVU1I7cFr
CmIB9Y0nf9vfE8l4De4ogrdvMhOvR0q/JszwOIKxAudiXQtJnxCHYM/ecb3n
NuKNqN78QXaT6yXGEYj+2Gya9SWOwoS64Ymu7kXGm3FhT3uyb3c442h4SM6J
ursbGcdgsuP27ZVVxFtQF37M8W1lGOOtsLn7NR1XNzCOR3X2TKo4H8p4G0bH
dq4MvEmcgHxXQ/CcB3EivKQI1asHQhhvxzdVlx/dSCZ+DbvPBitbAol34F6c
ze21NZhxEub+GRm++2MQ42ScEDPO+WURp2DZsaBcOxzIeCe+2vRhjBBFnIpW
u/NSuV7BOA2WN9x5VnMA43T02hvnrPuIMzB6te+iw078Or5uykl/K5pYheu3
Wn5efM+fMTB5bUmMS2YsAvdPJe0YbyOfibjwoNC6GvKZsH8/566JJJ8ly2fh
jm1+bcyAH/PZPIvZaJ6qPTbVRT4HjZ1pqitn1zOfgxVBu1L9ri/zuVgX4N5r
n2Ys5iL/Yvcl5afk1ehMj9odM0ReDadLk56y6MP8LjTF3npiK6X5ZSzk4XJY
V/9YIeXz4F3v/8ehd8jn8+sR8/nxQgHqsz667vMZqycW4ELm0PBIqDfzhfB7
qAiaCSJfCG9HYtp3zeSL+PWKRdDUbxn9O5TqF/PjxWKYrIndjiiqX8KvVyyB
M7a97fgVypeiWD0yPJVBvlSW1/D7CQ3mlgctzatpvMxLGv48BC2/P9DK8lq+
vqTlz0vQ8fNBx9cTdXglI97w5a/s+SUZC3rZ+vWy90WPbMO/Sc+r2f5Ketn5
GJ7eh9Q/YybXsbwBJV2tubY+2m8Dv1+SQVbfyI+HUfb8Rv59k4xwbWg/PfAX
nU8ZIjPrDjuXGaMMOeK+pYQWui9l/H2RyjCmOr4q+Ce6PybewyTLy1gyQWV6
XFESRnkz/H+X3J06ypvh9dwX+x+0Ud4M2+nzngfOUN7MzydYeA8LFgt/WfN+
EfUDCxIGw16+72QsWfDs/4b6hxWLn68+OJXJGFbei1a+f0lWnLx31GNilvLl
fD9DOW5qpFPiIOXL8TDAYps/TPXL8YLRo3dmiPIV6Left8QHsvlRgcLe2QJt
MmOxAieUSxahg+rLWKhE1SH1dMZNylfC+mg8SblE+Ur0LLZOh4D1b6kSeQ9+
uOFzhPp5FSbMrS1HFxT4D7vU7Sk=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HlI02Ecx/Ffuk4znceaV851qS27rKlp+3ikzmuXOhUrsQSpVZSWNZF+
SEWCXWoQUnQYRUqaShQdti6jO/ujP6IgEiLs2ux03bHv88eewRgv3nt+z/P8
9uwXUb7eWOEhCMLKf+//n+wlKzh3qXuNEi7ZNb7am0tG/JgFyL13itv6Isjj
0BJ69UNDMbMvyq31P6yjmAMASVW/9ISCLIfnwbq6njTmUKR3XPuy9kU4WQFn
rVA2Q8KsxJ0wtb7TNIU8DY2yYa/Lh8LIMzBBr7u/wp85EhnY5RDWhZKjEbdl
wPPs3RCyCsuGLK8++jHH4FlF9ZRVkmDyXLx/5LAkzQ0iz4O+W6EtvCAnz8fd
5V3DfWrmBTi9+rBcdW4yORbXG/dK25TMC9HgfNwe9CuQvAiKwcADbcXMasQ+
2V0z/WIAOQ7O76nHa1TM8egeDj5irfQnJ8D0tKHxSRjzYlRXnurTyfzIiZyT
oDF/Ls0LkZKXYGvU7ZEKnS9Zg7fPZ26fU88MhMgH3+xvIovgejLXk1HceuZY
oIr1FGhPd7ZPP+RDPQV/BMOfsmqykArpuwCZXTaJeipO3Gnb7FVNFtJgSdl3
ZdIx1tPQkaisjLzBxi91X7+4FFUdizU9x9n86fC2+L3dtYH1dG59GdBbou99
CWI9g+uZ2BTV0tzUw3omTk7NehZ7nXUtt38tdz+zYC6Z37lRyfafhSu3Ez5E
Dk6kno1bn3xMJRvIYjYeBNuHWnwnUM/Bzv1rEmrDx1LnLOTC0DhvlmSHhHou
XP9XD+p5XM9Djnrb+cEYT+o6eHmesQ41j6Kuo/snUNe7fx+cRb37eJseHopo
p1fHT41rvAELdr//lmwbcRkGfIx3/k6J+eqyaKDxDpdtXBeM7teDkZvfiPDM
3HhZ+2ia38it38TNz1nkbDNx6893vx44i/nc/vO536cAql7JmEV7yOAsFsDe
O/CrLnA8jecsFLqfB3AWCxH++8G9ODvZVojZSTH5V19703iz+/mGGfEPLx3t
f8nOqxmzpZGO1gGyjbNQhKrurga9lZ4XKEJzhb259BQ9T8QiZPc6sgxqf/wF
zX2MwQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtI01EYx/E/Q2wXtZXXSnMbYrLWMFdutuV+uzgzw8JIWalpl1ls4Iw0
6MVaLyKiTAmJLi/ECxYtzFWmIdFmFIUEWZhBRnRhUFATFjbGmBV7zot24HD4
8IWH58WRHmirPczjOE799/572cnaMzbptcsQ14J+5e7RrnkRMwfhm9eOK7el
ZD60QdlEt5lZjKqDfS3nP0vIGdAVLgUcl5lz8NjrS7quZc5FavN6fe1wPlkC
m8sWuPFhLVmGvl7p2Fwsj1wARVTLHy1nLoRg/n73QE8uuQjB0J2h4tAashzr
3LKjdWZmBTpT9r+3uVeTlQh9OtNfN7uKXAxnk8tfsIN5I3bObWgWhHPIJRAY
n3+vsTOroLx6N9gYzSZvwlT1TflMA/NmuPkqV+hrFrkUPxv94y3PmNV4OG19
UG9l1qDVHjD5UpnLcCH71aXF9kzyFojPth/6OJBB1uJazenIFyGzDuPOYasy
M528FcLBcJPl6QpyOfI80bcNamY9pIbWcx0xMRlISZ864fy2PG430DG5S6cJ
p1E3JHQDHMaeR2n9rBvh0cmOFD1h3YihF4OdouOsmzAzMfvrXVhE3YT82Mtp
zYKQuhmqrh+/DT4BdTMU95KSSy8uo16Bk6cifvutZOoVCd0C70hbr3Ifn7oF
8f/Mo16J+r0lI8dkS/p4r0SwLBIzKhfj5rYl9ARzVeBJ5BGRJ0o9wdz2/+e5
mQPUq2kPjvsDXH7bJw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQNioVt3b8xWcoDwPthHHXPJmSsC4zM4lNVs2tW3
XRHK53DoYFmxJDMKxhdw4Gn4NOnqJwUoX8ShxWCt4flpML6Ew/vcj+9uuMD4
Mg5/AoXf52yXh/IVHG7uYD32SB7GV3L492u1t0WyHJSv4rAyOMxN574slK/m
8F4p13aWN4yv4eC8Jf7csfUyUL6Ww+HaFdrLz0hD+ToO6g1KmWEuML6ew8L3
8fwvJkpB+QYOnx+2Lgy7KgnlGzr8WyVrHi0J4xs5bJV8dv/LfXEo39gh2JCD
4WYwjG/ikK33+/6lk2JQvqnD1+2tO7/dEoXyzRw2rW+Tk7gjAuWbOwT2GGqz
tML4Fg5OeglTihKEoXxLB7ZQxs0fDgtB+VYOJRnL9/mLwfjWDtzMa6teTRaE
8m0cnukrGedpwvi2Dp4r161SncMP5ds5XNxx9cuNH9xQvr3Dh80X/9aKckL5
Dg7Ld18XOyXDCuE3ODj4mNdvf6zHDJV3hLqXBSrv6CDv4WsptgqqnsEJVX2D
kwMkPTFB5Z3R5J0dwqOM1hUp/beHyLtA/fMRwm9wcXhv+eufk94zqLwrlP8N
Ku/qYNz79rvjgZ9QeTc0eTQ+gzua+Wh8Bg80/R5o9ntC/QEFDQg+ANo909c=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwA2IQDQNioVt3b8xWcoDwPtjv5RV11RKA8RkcLDODi5N3
KUL5HA4zOyrcZTJgfAEHvwC59568ML6Ig87FXwHzDipA+RIOcx4F9L8KgvFl
HC6apT1/dUEeyldwEODeIOXBBeMrOWS3vzFemygH5as43D351Pd6pyyUr+YQ
V3dt7cqHMlC+hoPlp5MGAU4wvpbDpXULwrevkobydRxyj523amWG8fUczkp9
eDVFQArKN3Co3Xh9ql+6JJRv6CBy9s7Jfy8loHwjh9h+nZn38mF8YwdVznMR
ek/FoXwTh498oYc19WF8U4cF/ExSf1zFoHwzh5NXWlpLT4pC+eYOy3dfFzsl
A+NbODQdD4/95SMC5Vs6OOklTClKEIbyrRyi3fdz/dogBOVbOxwJODC7YReM
b+PQ9CSp98kaQSjf1kFXUOPjrIsCUL6dg7TE4xcTJ8H49g6Vmsd/pvrD+A4O
vEVG1pebeCH8BgeHKO2JHucquKHyjtDw4oLKOzr4mNdvf6zHDJV3cihebW2/
aREDVN7Jwbj37XfHAz/tIfLODu8tf/1z0vsG4Tc4Q/XBgIsDN/PaqleTP0Ll
XVDVM7hC+c+g8q5o+t3Q5N1QzWNwR3VPg7sDk4LWL+7Vf6DyHmjyHmjynqj8
Bk80+71Q+Q0IPgArAs+Z
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H1ME2ccB/DzZRbFCkWoCghIfEFEVBDKwI4v1iIolpa+QpwaHJMEMidC
rJW4G5MJbr6BxogYE6MSFDHVULbhoEtwaIguiqJmSqY0LAtkgSkbJU7dwu/5
455LLpdPvs/vfnfP3fMsyN+ZUzBZEIQd/53/X9mhNLe0OYsiMaHh1HCnvbRm
OrOAyqAQV33jArIPAvZOu2xPZ/ZH64lDU9oGI8iB+MpR6dp2iHku2p+d0n8Z
xxyK3wxlI6Gnw8kROHjxxWc//xNGjoSP57ZsewrzQnSa4mu8+fPJizF6LPBw
1PNQchT6ss5dPwrmaLhSSj55nBpCjsHvznL7a0cwORZpsm+e+9+YR16J9pth
pilDc8mrUP2mp9epYY5DkO5T1UDrHHI8ZtmjLX21zKsh+sTvf+VRkhNQ1/iT
ZvQqcyJ2FA1o3HJmFS6e3K34HkHkJGx93LKlxx5I/hAVXdaPx7OYk2EUku45
FcwpOCs+cvg1zyavgfOv4HOOQmY1ul0tjSWfM3+Eodm5BX9XB5BTMf/Km97N
KgUZWK6IGqm77z9hEShbeqK25jpZSMM7wfBuW6kf5WlYro41dQzIKV+LyRHR
475XZlLOWdDAG1NT3lA8nXINYm5MnZZ4REb5Onx9vCh5XzhZXMflWoS/vdud
NDyDci3ylh3PuGf3pTwdiqFA5bByFuXp+LEr+c+oftZ/PZevh2v42Irgu2Qh
g8szIC+JS+mpYO+XiV55VaFXRxYzUdamX5M0xuo3SC1uQGZj8+VF9TRfwkZp
P5GzkMXlnIVNXP9NuPXKz5i3i72fTvq8og7WvLjmkkjWP5v7Ptm4/92j10/G
2PzpcabX13spgQw9bt9S7yn9wYfG66X93Xru/gapYZD+H6IB10KaWh9spNxt
4OYvB7qmI9qCFhqPHO575Eif182NF4zS+8GIwWdLDqyoYP+zkevPjRdM2Lu0
y1uQTeNh4taDCZtl5+tCtLRe3FwumCEvDhis2sXqzdAXR3ePzmP1Zul6c5tx
uqNhjzmGrUcLKjz5hz1NlMOC/pv/istUlIsWjF2Q7fekkd0WTOzXrN6K0sKG
9mwlGVa8PJOY8Gstq7dCq/aU/zLO6q049eLbSX0jrN6GLNUXrf2xtF/Ahi1V
6X+oO8miDbKwqabOB2S3DQcdnfaxerYf5cKWcdT/ZQcZuTA//aC6ah/tb2Iu
7jw8UFl2JwjvAXi0oVQ=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n1MzHEcB/DfdIg6iusUUhJLpRFduXDvrroepXvKdmSY20w29EDk4ccI
i4jyl8Zou7Y8LBylcB6Sh13TWnnaMGGTp2seCtc8rM/3j9/3tt9ur72/730+
+/2+k1euM1iHCIJg+ff8/2c/pdneVJ8XgkG5NDUth76fUTALuDVV691sn0z2
xNPskBSVldkHWnujLWAUswL24hVtJ68Gk/3hUx1qu5nLPBGbneXO30OZg/Ei
yf+DkBFEDkHriePN1spJ5FDICorUyT7M01Coe6A8awwkh8FdbU/64phIDken
h/Ohr4w5Ev3LzlsfpU4gRyHxcs+RmLLx5JmoePUiMeB1AHkWdq39VGZ77E+O
hrO3dHtoPvNsDNwJKrv0bBx5Dla9Lbi0P545Bk0HDttK6pVkFWqf366q7vIj
x8Kl7zhUpWKOQ0nnZrmwXEGeizdrpqsH9o4lq9HdPCBGxI4hxyOwzt21NNaX
PA/eY29tWv9+NHk+au6f3uhVOIq8gLMGefcarnc0epGBw7s9Gl7mjhy0CFR0
F5Ro+4ZTnoCfkUe22taOoDxBel7QYvbBT30JDpZrUX9uXWXUEk/KE7mcs5CE
0oo8dUkQzROTEHlRNkxVzuYnw3WxfWCbH+snwxJRkdpWzPbXwTne1VPpw/bX
YUr6sS5LLdsvBe0Nnd+e9NN5MQVd8n2rf2bJKU+F70eF0qWk9yNyFtJQ1JQ9
L66f5WmQ50fHd+xi/XSun87tl4Ef8sad7hhvyjOk+wiZXJ6Jlq+jjZYNZGEh
ahNut9wNoHniQm7/LCSa3KqhOjY/i8sXcfsvwoz5UaYb71ieLe0jW5qLnB2c
BT2utao/h3XTvtBL54t6ZJ0pT7baWZ87Lxi4voH7Xgbp+3EYMCQ4/JdXHesb
pYaRu89G6fdwGKX3STBJ7x9M0vsrmqT30cHlghn6A7MiZHtk1DejoC5ec+GU
QH0zMmN3XOmO8qC+mfZ1awb7OVhsiT6XH/Jn0MiBl8fZLT1HezV/AWhUcVI=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlX9M1HUYx78CgXmekOiBQt5xWTKl0wM5QUPe/JBOfhzccb9/wBeaw+10
/hiWsZxfmVkb6NRc80drNG0alIyoxc/41jQtOzeiqDWaJItKV9IskkugGs/3
j8/nu91ur72f5/k8z/P5fJ5PSu0u27YIQRCa//v9/698GseHvR1BPeZoIndP
bd2Zq2qFBbhNp+8621OI56Mj1I8bdoXj0PRzyz+tkzriJWg69pd/99sKJ8Ii
przh2axwMkZzEqIuDWuJdXDfXj+880mF9ZgJt5VkPbeCeCXWBi0/ff3u48RP
YTZ8aOWX95KJU1GfV6Y9sk/h1YjPFLd3vpNEnIbBuivmZTEKG3BLXzjWU76c
eB1M4Z0D/e3LiI0YWDdP2xarcDqaHQvMX7UnEmdg+oq26YPvE4jX48UO64PU
BoUz0XAw/EmwVUNsQl1wvEBWK7wB1aac6B9CS4mz8H77kRWJI0uIs9F4zRUI
lyq8EYtVCX3jffHEm2AsOttdHFpM/AyMPUmrbu9TOAeF0v5p4yuPEW9GU/q2
kXNiHHEux8DdkVWH1zYSS0BS4tgvJ04qeh7uz/R4GmMUPQ8ub/rlvfpY0vMx
K1hnxXpiKR/D6le3T1nUpBdAvTd901AjsVQA7UzoRtbEAtILkdYZFW06FkN6
ITou7zpl8M0nfQv1M5r0LbiXHZ7JNxALRSxLRSjdcPCjMUMk6c9SvrO5czrH
ghkRutVhVdtD0s1QRb7XcOe1P0jfSvEnSd/K6cWcXszGE0o4vYTTS7n8SpFx
9Le/8+Qp0sswdz8jqL4yWJuNa6JejqL6LFz9Fhx4c6hP86NSfznLUjnXnwp2
PVRw+VRQvfPm7GXOXrCy9rCy8SUr52/l8rexDBuXr42NL9u4/lVy61dSP8Yp
/0pahz6Z0wU7Gw92rn47l7+d3Q/BwdYLB2svOdh6ZAfn7+Tqd7LnX3LiieLX
h72X6L7ITkx0Dk4fWPoo+bsw2PXNn989UJG/C8cPR3bdCpC9xLHs4vzdmEo7
+dLFHcTgWHLDu+aE+eZ+ii+7Ebze9fFQN7HgwaS6+9DDzIXk70H/tY2/p44R
Sx7syD/ev+itReTvwYXPzz+vqicWvGx+8HLn2cvmK3sRWj5x51ScMj98nL+P
7ZfkY+uRfXR+lfr9bL/hx8XebzVfJD9C/n5u//3c/Alw+xfg8g+w+y0HuPtZ
xZ2fKm7eVbH5yFXQmsuyNa3EQjXbD3AsVbPx5GpuvopsP3QiO58hsvNbFLn9
FXH1fmyldw9xC2cvi3g6x2AfGCceFbEw/tMXdv+qvB81yL7Z2/LZKL0vuhrq
N71fqKH+0fsm1qD2ur4nQ4rHv7P6Uvk=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQNioVt3b8xWcoDwPtgvu2QSEs4L4zM4TG7z/my5
QRHK53CofvhmiWAMjC/gcHnHAUdOZhhfxEF5eWO89RoFKF/CYUnLkQkzA2F8
GYczM/b7FHyQh/IVHPKqY6rv+cL4Sg6HLxtpTmmXg/JVHDSN18yQ2C8L5as5
TFz6+VUsH4yv4dAmpnTVMEkGytdy8ChK2ntxqzSUr+NQqxa3+yY3jK/nsPF2
792LrVJQvoHDy/2es2f9lITyDR1uibGuPOcP4xs5nP3YVqdSJAHlGzvILMh9
HrJXHMo3cXgXe3B74jExKN/UQf1e4MJSVhjfzEHmdoSDwEQRKN/cIa7D7aXt
EWEo38LhXe6Rr8bfYHxLh6QTSruMG2B8K4dHs81Mb08WgvKtHVLnLmOqXiAI
5dug8W0ddktNmbvzvQCUb+fAmyP0uqMQxrd3KN0dYGPxgw/Kd3CQ/3f2tMUH
Lgi/wcHhveWvf056bFB5RwcmBa1f3Kv/2EPkHR3Co4zWFSn9h/AZnBx8zOu3
P9ZjhupH4zM4o8mj8RlcUM1rQOMzuDoY97797njgJ1TeFdU9DG5o8m5o8u5Q
/zyDyrtD7WVgAAAMUb/q
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2Ecx/HjTNNmaOammemcIV7GqJVOl7mf082teZlClFYElhGTMgoz
DPNQFvRCyUsYCCJIRGojFTFxC+eILqRg0o0i0UV0gba9CEGyG/s/wc4Dh8OH
7+85r05yTX1lrYjjOP3f59+bHen+8amROjn88mo9yz5luoSZQ0jjQXS6kslh
sPZKMh1W5ii8+/DTtiJmjkFE3MSwY0hGjkNFT9bzlFrmBNhCIqOvhTHL4JJH
Xk/JSyLLUTVZlF9+K5G8HY5vN+svL20jp2LlmOZGiow5DT8Wl8/HHkkgZ8D0
Qvq2oXUrWYEZg310bi6erIRlQ1Db4nHmHXCMmhONs1vIO/H0peGUU82sQpLp
UWJXXxx5F46a7bDPxJJ3w+m6LXpVxZwFTer9N8NtUnI2Limaek97JWQ1rrS6
3vdMM+cgOz58wNfPnIu7Z2bnT7Yza5Bj1araYpn3YODj1ZrCEzHkPByuWXYr
Pm8m74Wt2FPZGMGcD7d9jc9UR5O1MDi+WDG/iQw0pHd3dY5G+c0DZcPt+trx
jdQL4His+Z7mjqBegOrMDuPcBTF1HeqePHi4MEnmdRDJMlbFQ7TnCgP3fCE6
3Ocu6lbWUy9CU8uqs24wlHoRFGPrQrPbWddjxFbfrTwURl0P79j8WrMknLoh
cM8LzBUjyViaKx0MoV4M//8uom7EnanX0mcJrBvR3Ldgly4FUzcJ7psC99y+
wD0vMGdGibplwq1k3Qxx8L2mr11B1EsCzQvMlQrul+JAtcp2Vv5b6+9lgebL
6L6Pejl9hw4vMGeBJ3f1l075yb+HRbAXeFqw5yr+9z8cOgD5
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1Ecx/G5EC9T09Ll3Myplaa20lzpvOznfZs6xQrRstJYiQoiGgoj
mWYOJMSF+qIwgvCCxmDlbWpCiSmYgmYSXQjTF2JWA1M0ml3of17kgYfDhy8c
znPO8S0ozdJwORyO/M/3d2aDf65v2FTsh3+yyD00AQ02jswcLN8TF7Z0+5Lt
MVBpMi6lMrvi9XbGjnRVTHaH/vBo25SB2RO2vf1SpYRZhN4PhV1VvT5kMRad
vqeX7Bwk+yGEX3e2KJz5ECRCobjnkjf5CMrmX2Y71ovIgYgy5rw51iIkB2FR
Wb355ZcXOQQTmV1z1bHMEtyPm21QqwTkE3AMvpnnYPEkh2Im5SJvQ8Qchq0B
XrZo8gD5JJ6NtXMXcpjDMXy7qVNr4pOlWGuceSyf8yCfQntLuZsZzKehLnfV
to67kyOwnV9urenbT45EaPJds2p6H1mGYG++4Fo+cxTmNZsOgWY3cjQSdVXW
UD1zDKLD0vQul5lj0eGvehv+3JUsx+f3AXXHa5mB9Z2hnFo7sg7oihsbfyFw
ph6H4snB0VdmHvU45AYbFDNVZE48mur2DH7Mc6QeD8uTWesNDwfqCfBRpEfy
u22pJ8BkLG2WnLennoh6Q7FM62NHPRGT4zGVFUOsJ2Hay7La7MrWT4K/qnUh
t4vMSf5/P7pkjK/vPZNb5kQ9BU8nZF8Dl8i6FGw6m2t+SllXgCsO+sHrYV2x
6/+VuD6cGR2x5UJduauroH7UmKTpI+tUyCwJmtoQsPNNhdBzacVwh51vKjRt
HVztA3Y/aSiq2Oq3yab71aXBmPItq9KJvYd0LBcdlVn1ZN0uc9S4UPBpKWSF
dTUeLt8qSLjK3lcGrrwbGelcc8dv6dr6FQ==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlHtMk1cYxj8B8dKpbNF6AQXKdARqtVVQROThXi4qvUBpC8QYXRZZQoSq
WEU/jUb/8AIKxjBmjIzJ6CRxzogC+qlBUYMRidWoyUYwupk46pyiRMUZ3vPH
OU1I88tznvNynvOchq8uNa/1kyRp6/9/n7/ZR513tu10iQYj5Es01m7xtasY
Sxiofhwa7AknHou6roBHqzIYB6Fi8NFZw2AY8WRYfty0Qa5iPA2vGvLdm8E4
BCn7H2YGXQklDoO2+PdtHQOziDXoG21w3c1m/DW6y/71K22cSTwH84LrusoC
GUfC22evbV8TQhyFiLpRRw/dCSbWwun+NuavbxjrMJCx40+LdwbxfLw1BF5P
S2Wsh7bx+NSofdOJDWhqvrB3fDjjBXiqaXi9tn4a8UKU17RUjlOmEsfA7Yoo
9SQxjsXRuLYjL66oiRfh5TmzJWIZ48UINS6PUzdPIY6Dz9R7sDaW8RK4N0c/
886eTBwPfXrd+azur4iXIkirD749/CVxAtI7/l6HHsbLsPPJ6v1PfmWcKDCQ
Kld80O8hlgHPUs13kVcnkZ6EzF9ammfXE8tJ+OlGw0aVayLpyRiWTMOrXExP
xoQyQ3zvzgmkp8AvLGpI5fmC9BREZB3xOprGk56Kql3+rX8UEcupeKc9tPXk
9+NIT0P3DN/zmiCmp6GrM2GT68JY0tMFPR2hH7tvLfax/TPgiK423q5QkZ4B
35meD5VT2P5Gfj/ZCO2ZgMDYA2NIz+RZzhTmZwn+LLrP0aRn8/PkbJxuKa3R
OZk/R9g/R9CXw7196HJJcyDpAksrhPkrhPxW8iyvFM6fy+eDXCHPXN6v5OIH
r+rdzzG0XjLxOkwYiBv6mKxj/6+Jz0MxIWfR9nP9On/ym2FzGFrKNMOJI36B
ZTPKPfGJv52QyG/m95csvA4LRn7P/Gi+hc9LsQjnt/L5wYrq/vItyYPsPqx8
HooVPa33/nvwlp0/j+83BJbz+Pei5KEp6WrntensfeSjpKv1Yu95lr/Acj6/
XsnH3ASd9dJT5reh4/qSfyL72Xyb0HcbOl9NsjjWk67YhH4U8HmgQDh/gXD/
BcL7sAv52YW+2fn3rtiF/B38/cCBymO97eo+6ofsgMr/lPv54VHkdwj9ccK0
Tx8dsDuA/ALLTqF/Tr4fUqHgLxTeYyFOtt1X3wxhfmG9VCT0r4ju/z31V2Cl
iPr7ZoSlYjrfS+q/wHIxv14pprmS9AnnDwFJ
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1Ecx/FHHV5IQ0vnJTNnZU7FXDY1L/nzMue8zGlaLilMFO1GIyQv
TXk0ihBDSipELQtzBKWMtDLTiQwyCkMJiUTRtZD1prwkEhoVnf+L+cDh4cP3
ec45HI6o+EJuqS3HcUl/x783PcL8/kH92QD8148EqalVHetM5lD7JrrrTr+I
2REzmvA5YRnZFfNql2uf7cnuMCi9F3S9/sxeqAiWbzTKyb6wqGMm3n/axeyP
Ud9hcR/IAbA91mZ0veTHvAdFDVqxoncncyBiQ7mhfCdyENzO2Q+0B/kyB+NK
tqlwqHIHcyi0I3V7x73IYbjXKVUXSXyYw7Fus1T28rg3swQyR7v1Fb0X8wEM
PvRr1/qQI7C1KvjobIsn80EUD88t/e4TMktRbxEZTApyJGoLE+L68jyYo3C6
5GfV/n3kaOQ0SUIEV92ZD6Hstm2FSwQ5Bievp1rijduZY6Ff8rlfU06OQ4/8
e26lMzkeb6tT4koCyYfxKCZiTNexjTkBprZI6XQLGWg16CrzQ5l5YLWxx/PE
ihvriVjL+OpYn0k90fp7LgmaqeXRUyLqSago1w1nC6knQ6zc7S47z+bjk9Fg
Lr5hfkLzp6C0o9v2cif1FHwsXXUKGqAuQ+qQ5QwmqMswmXBL4DlDPRVfXm/w
IVG0fiq22D2t+dZCXY61Loc6cyJ1OYyqkTb+Fe0vzfp8+DS80HSrwzzo/BR4
0DXm0TxFXYGMZ4vpOVHU0yGLN2s//KKejrvzTTazizR/hvV58xlw8BPkGSfp
/0y8e97/+KKGmc+0Xo/LwoJ4qVqiop61aX9K6/V45ab7ko0jXPS43o3dJz4b
vtMFcL1J90uFgrRmV5OBGSqIBDNzy+vu+AMRiQHB
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtI01EYx/G/dpmXplvZvM0216rlRObMbTrXftt0zjkNkpKNsiEIoVCt
wAqypnSZlNIFQQgkozSwF9nFWjeSmAWSWsLwZdkKpIuCYU5iVPgcoj1wOHz4
wnNOdv3BnQ2xHMcV/zl/bzaiXQ+eDDbJsKw5Y/P5evd7ITOH/oGWL81D2eQ4
1NQdaNy3l1mAwbMaZUZYSk7Bjf7ZaXQwp6HTNx0c38IsBp/XJ1HflJClsBj1
m9qSmWWwKzLjA/YNZDlCqmAotTeLvBljjizDvF9MVsCnXRBUKZlzIFHd6fU0
ZJJzIf+esJjvzyDn4Ux7j0GczazCobqTw3JHOjkfMRffRWZa08hqtHeVr5JM
pJIL4JTprk3tZt6GqS636/aEiFwI/6hzqNbJrMGF1InLC571ZC2GN55WcDJm
HfSNh7vd91PIRZAfjbmimV1HLkaZIXRifGktWY/Fyk9xrQ7mElifzTTirZBs
QInacS7Jzbwdxtofe6ozmY2oso4EQgYBGTi+9VW4YQfZC8xHHjvbeKybEOT7
9oer+dRNCMwn17g8a6ib0fT60fNJfyJ1M4RfU0RzoiTqFriUl2xjx1i34Jbp
ZWAknfZxpbgaTAz3FbJeCknkzahuLoF6GQo6vv00vYinXobceytXazp51K1o
6Zl8KvqwgroVDu2phx/zyFw5jgzojXevc9SjzNkwW7QUMectGJe7jd4LL5ur
+N/eCsRKc5YSB35Rt0f1KHOVtP8z9ShzDvoHjfeffwNh7OMR
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzV1Ik1EYwPHjB7kyv8q9c0trmxGmazRtNmdzz96pm9uFzCGxVSyFKDBY
uVG4ImYYEbQ+bC1IunHaJqmxSMqECmKGF9qdd9mFFrQINySXZVvFnnOxHTgc
fvyfc46o295xKpsQovi3/590MZ1TM6EeMaQUVYcjo7bRPGoCyvedPZtjIjQH
OG+G/RYjdTGwjFIZjAnRpVCoC4x7fNRlMPZNZlpSU5eDiu0a8E7tQQvhADPC
LDHUYjBPDyaGruxG74U/WY7V44sV6H3wQCoJfNZTV4H2uW1h9mk5uhrafz/s
s0R3oSXQL7/xQ15NLQWXgZcQOAXog/Dh1rqHfcRHy6Btxs5by6KuBdFc7Lpi
fxm6DvpCpp9VLh76EMRedJgrmxi0HGz1qi0f57noehAuc+/7LdSH4dU5Sdyc
Ta0AM1EshEpK0Q1wkTtEbj/eiVbCV1+vZkJN3Qg1FQz/dNcO9BFwngm8bmeo
VRm9Ca6udHtWxkvQakgSU/KkswgNMDLnv5DvLEzZDRDUvAvP8guwayC8VmS2
nt+OXQPzgmjEW7wNOwsbksHLgbNbsbOwXjDdvynHeaJNn3dr4e6y4xIbz8Pe
nG53M9wZyHn56QR9vyXjfgtUGnyL1iDtrRCatHulxzjYW8F0U1aTey0Xuw7q
PN/jmrcb6lTXgeNJo/rZMMGuh6PW2slecRK7HvJzJlyRe7GUSVu63RkmBlht
+JVgpV+wZ5gYM+4b8V9C/gKyH9um
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2EYB/DTnGZect6mzZkXQlKH5Synae5x3uZluptFpimBEBmsLPKO
p+iGpmQKokFofTAUB8tMw7ApfihFaUnah5BCKhPKaaK5lqvY8wbnHBjjx/99
3+d53nNCTuvUpRyKovL//v79k4efPzhiKAsFu8zSx0Pt5U0exBR4/gg68UIf
gnaG8CnfNytqYh54jWTVWFaD0T7wqlSV/KSd2B9aY5IKuhXEQrDqKhxrV4PQ
wRBqavD6ICUOhU6X3rmAK3vR+8Ag14k7+wLRYXBjqThBbBOi98Na57GMT9nE
EXCNq+p+PRqAFkFK5oLweyZxFHg/NHYYJgTogzA28GDCIYI4Gro64sNuFu5B
i8G1UVLVP+qPjoGWxYs1sk0/9CEYz34UYSokPgzNl+uvJi7w0bHQ5cERWNOI
JRB3Vipu8vNFx0Hx/OCp2UofdDx8CV+rilZ6o49AjqR+aDGKOAHs78sLnQg8
UXTAjM0TfRQ2GvR+RevESVByoejX5BKxFAL7rHOFEmKARnHp+3slPLtpADfv
8YrzXz0wTwYbpbKVXELTyfDUfOeAYHo35jKYc791ZivXHXMZFES2yGcqXTFP
AdPw2/V3P9F0CkwLzMttPBfMU/E+d2KeCluiu7U953ZhngYGva4t6qQz5mkQ
JFfE83sdMU+H6nrLWFmvE+bpIBrgOsU243lUBqzEW7ZlUSTPYOVyMA+Yftf5
Yj1aDkHb01NxZtJfJnCCIyyufW6YZ0LZy+HR2WdkviyIafq2mWwk+7NY/Wez
5s9mrqdymOvpHOgZmedPCsl8ClDdjo7kXudirsB+rFJ7nss0zTKVB8cLxPry
UBvmefj9cPB8JdTdn33O/+hgNyiZ90srmfdrVOL3iOspFbMeqHC+LazHyo0q
cHXor15uXcX+1HgOPqDG9/UZ9xNv4H41az4Nq38Ncz5ag/V2YP8a1n4ts1/Q
MuvRWlb/WmZ/VP7//v8ALzpc+w==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0H9MzHEcx/FPSW7utK6uk5OuHyR13aTkSunVqbvr9y+GiM0kNMuyFuXH
V/MPm7YoWYwV4xa1HaMUFbOykokW6w9s0aaNQhOZ82O9P7M+n+2zzx57fj7v
fff13V6YlefIGDP/3f9OvtTrb7fZCvwwrfHYR7LzQVBxM+xuPd3s3+JLlqHA
dkrpkM/tCu3JowHhv3zIKuSec3OXW7k9sWfw1fVeE7cX7IYrz/xfa8k+2Nr8
u3qpnNsPQ3tTs2syvcmLMXEorWPi5iJyAGKydjzc+d6LHAhDmZvLWz13ENRD
DeXJxxaSdXAKtobK3mjIetQn/HxScpx7OS5c1mzs6VpADkWiZqC/K557BZqU
PSMf6j3JYVBH+RQpDs8nh+OiouaOakBNXglJFnbk6zvuCNRcrbP6eXOvQus+
3WS2owfZgPLuDblTKSpyJDy33XteYeKOQmew8eONIu7Vwv1o2L5oLpXucifH
oMk8llWi4F6D9i1LHnjL3cixkM9qLB09oyRjpiUgRBn4ubbflXocfOPyTxTb
yVIcNtU21nnoeDfi4LLuH3npvBtR3JYRbfjuQn0tQmL06zpG5lEXzOJxvzvq
U+Cwgno8Ch63tL+4K6eeAN0tJ+eIijnUE1A5vL/MOElmJvRpxkerXOdSN0Fr
7+s1jJOZGTnBlZanB2ieZBa6Bf5JZwdzrPy9ZeY8lghbU2GVfrOMeiK0ltRI
dcNs6kkYi5yyG/XO1JNwre2luseL92T6vw7Uk+n+t9jpnkIembYkmKXSHFqS
YJYmdMEsXeiCWcZMI0P4HqF3CmaZwnvB0n//Ac2o9IE=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0X1IE3EYB/DLmY0tc11zmW1urhnLauXMl+nmnk3d5txWliZUQhSCMWSl
jWCSnuUKKgpZJBXOP4QCZeGoYWRk9oLWPwWWwf4qRgsKzCQIL+mNPb/g7gfH
8eH7vPyOyz/i29uaRlGU5e/z702OrCk2EfWqIaUFc9KviMcyiSl4JmGuyaP5
aCEY9a7zaw4TS8Cn6bz3REAshXBT1Q79sAqdA33zZwfGSonl4F1s/xicVqJV
8MopHZTTxGqIt7v3DTTkoTVwwUO3hoYV6M0w+J6W9EmItRAUCpcjPjm6ELI7
7oZn729Eb4OZcv9FyetctA4uV17d0isi3gkFV97Ylk5sQBcB7W2MZ8znoPWw
ye3fz7QQF0NxSBHtvr4evQvGH4vsQ19k6BK4oYplJT9lo0sh0Utrjx8lLgM6
8vbYQrcUXQ4Nl4q2pgeJDXBmurmFdRFXQHQxdyjQtg5dCQftkyJ2jEYb4dGh
gqk8MbEJXsxpvv9cvRZdBaNGdZv2aRbaDNtNusbJZCYa4OaceOlWiThlBiDQ
w055RzIwt8Dp8OxD2QcB5haYeW46dfKBEHMrnOv3VnQpV2Fuhf5EZ5f1B5qq
5tYz1bz5NeAq6xlP6Mj8Gu4+qpa3v5ZbT9m48xgb3J54J3spX4m5HZoP6O90
qH+bU7kd0lSFrHh0OWXKwTXjALEgEvgcWoH9dVwzdbz5TlA63AbZCJpxwlcD
+8uqI99Xj/83HfN6Xr+L1+/i7Xejv+H9eKY8WIeH8fDy3XifJPbzTO357z+O
9/y/
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/GTl6mtlbdNnfNaWekwN29Z6n7TeUunSxLpQprkm4SECixN
OxVChaaR9a6LFFZqWVnmjZzGTAWDMsrqVU1ShHCFzBLNivN/XmwHDocP3/85
z8MDJ6SkPL/UgeM43b/7/5NdsoJnfY/LQiHIojFVXD3Xv46ZQ+GRd+JNj0LI
rlg/WjCtTmN2x83IjvIlazDZG8lzk1PmRmZfHF4offVLzayAtEU5lGgMIgej
WVK8b2AlkByKn7cGJdITzBsgirKaTs0EkMNQezuQN5Qwb0bq06LXwx0Kcjie
xHsEfBYxKzEfONH0qc6fHAmvK82996fl5CjkDLh1texhVmHy2qRmi8mPrEae
org7JoA5GiOmpIrjvb7kGEw/b1epdjPHwujd5nJw1occB9eaBv+xIuZ4GPKt
/h1nZeRtuFhzwKd9XkpOQMFH5wvnq5i3I+ZtfcXGXm/yDuwv+WpWzniREzF6
Upd4KIw5Cc13RqQN7z3JyTD3L/MR8cwaeM4Yh9ryPchAn7zpes+cu2Ae0KcP
m6aSyJwWXZbGrfLxtdS1cAgOXxS3raGegnval6ZhPwl1O3OpsEp6zizF0jyf
irKR7hcTPWLqOozLLbNN7qup62DpfLNcLXWjnkbn7Uo9zXaeS0d0/fcFrZHm
+XTbeS4Dl83HqlIWXKhn2L2fCWWnkyjuEuuZCMrUJ8hanalnQfg/HKhnofrG
RL/siyP1ndhVp4pwqnWibmcu23aez4bY8UHl7JVV1HNQeXpxsKxVRD3Hbn09
7vZ9kI0pyLzedj9crt33c1G4V/3waOiKRuh5dD6/BfN5dt2AuYTFPymRVsEw
0P5+0Dzr3wQbDbQux/0FH2EVAg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03lIFGEYBvDJDnR1U1PHM68yvJJ001KzfdZ7La9dLTIsCqxIJdysRJK2
A0yzTDMNtP4J0ow0DUtTdMMDUTQ8MqELMaJCa7vMRLvw/YKZgWH48XzHy3zv
57L/iCrNgOM49d/335c9fHJTa0O6Kxall1d+iUjdY8rMoctMW+7Q4EI2hGuG
pvCmktkMv7MksuPTzmRLFDt6z6sLmG1wNHNHZY8dswMkfar35uVOZGdI3MuC
DUcdya6wNXnuFuDEvBbpHbMmYdrV5HWY1ixUmDxwILtjqPnpt/FZe7Inxrum
5KYezN44PDeZ9kttR/bBNX66d1+1LXkDipIl0cP1NmRfFMyPjDWEMfshMGoU
jfXWZBmqHn68sNqIeSOqnrgpVxTyZH+cPdf5okJnRQ6AV3HkYGi/JXkTbPa2
DV+KZN6MN4c9ghbyLciBqJgoWvLq8ypyEHZHdUjm7jEHI/tQdXs8z7wF4dqc
Bd98c3IIjjbUFyTkMm/FMY+yK6WNZmQ57G0m35WUMgPK23W1blWmi9YCO1P8
6jSuZE6BGWnL6Xl/E8oVMHD2nDO+Q+ZCUaPo7O6xlVIeCqnGL3jkDJkLw5j0
/KGfcSwPg/mUJa/nV1IejvUhPkkdb1kuMhchyiNE8yOF+2kjhftxUUjvbW4f
aTGmPAqVY8Y/b/mTuWgM2Ok/lJlJKBeZU0J2cfqHQmdEuRJO0bGBfO1yymOQ
e2rucXrtCspjUN36jO9zYPk26O8PLeRZsfnbsCamfCylhq2/HSleJdGDOay+
7cL9uFg4/Rro36xn9cWK6o8TrR+H3u6QE9mPDCmPF+6njUf3V1N1ShY7vwRc
Pre0+XUq5UgQjU8Q/g+dyFyisD4kivolUXheukTR+aqE/QaVsF+1KrTalV1v
+UTWqTAsL11m/ZL1txpTFrvSZgroPkCN9+UaxV053SetGnk3Rtr4CbJOjYNX
DbKlMnb/ktAkPzB7MoOMJHzM7Poum2Hzk/6P/wP9nE/U
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQNioVt3b8xWcoDwPtir7pfPsOOG8RkcFlnnrp22
XBHK53CwU2QOL/WE8QUc1r7VsxR4pgDlizgkvxRP8+6G8SUcImetXSiqA+PL
OPzmk/L7uEIeyldwsP31OnHZJTkoX8khdO2WqT1uML6Kw/Hrcm93b5SF8tUc
Lq+YlX+MC8bXcJisf3Kl2HIZKF/LoZ3Jv3z3cWkoX8eBZU/BDXM+GF/PYeXR
u4m2EVJQvoHD71WvLrTXSEL5hg5X3zZwvH4sAeUbOTzfvsbQMATGN3ZYmTVX
QmerOJRv4tDAYVz3+YkYlG/q0FBq/8VKDcY3c1B4LDp1caQolG/u8CHwcv9U
MxjfwmHjj76XEg4iUL6lw8tpRY5r7YWhfCsHw13S6o9KhaB8awe3vS+zHC4K
Qvk2Dpbndi849kAAyrd1KNWcMnnSJhjfzoFH+FB5wUt+KN/egTdH6HVHIUze
wSE8ymhdkRJUvsHBgUlB6xf3ah6ovCMqv8HR4cPmi39rRTmh8k6o/AYnB3kP
X0uxVaxQeWeHwB5DbZZWFqi8swM389qqV5MZofIuUPv/20PkXaD2/YHwGVwd
3lv++uek9w0qD+M/swcAjI6rRQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n8s1HEcx/Fv8vvCKUV+HynpQsnvH/c6Pw85nKwfsyUblaLmxxiqqzVl
sVKtH8pWMqRohPVjumuStqK0qE2j5ZalX1drHDPSvD9/uO/23XePPT+ffe++
n7cg7ZAsXYfjOOn8/f/JrlXJ7Y9bDjhhQWrReLYwY0KPmUNzvdOZr3UCsiF2
6spyX8cw89E6rDL2H3YkW6AwymOupYTZCkdSQhIHLJltkftnolxQ4EB2hEMN
L26oxZ7shKYu926TFcxrcPNyuZXisB15LWaq28N/KW3Jrnj1qW1IZMrsht2a
q25W2TZkIQ7lqF5n1VqT3fF9T92NZ97MnvCZzlJ03ltN3oRhG90R4wkr8mao
1/XY6+1n9sLJuY8yfSPmLfjWVj3i2WhJ9kZWbZpBaTazD0orDwQUOzD7ojLK
0r3o/SqyHzJ9s03lycz+qHJsN/sytpIcAL9M0eYKS+ZAzNzSFYy9sSAHYYfk
LP+zgjkY7aIMTclB5hBUSY9Pjxozi5A0WFb+1m4FGdDUGhxViZcvWA4szAOZ
E6Oz59SI5hjrYjxJcXlqz2M9FJl5mo4l21kPxVVFfUGykPUw8IWbbPrmzKmH
4YQqrUJ1l8yFg7e0qWj8AuvhyL0TKGqt4VOPwEZz199V/WR5BAZNTu+bkppQ
j8SuDZWSvkIe9Ug4x1wa3NVgTD0Kvdbq8Yt8sjwKL7qDC/IeGVKXwKvix6RY
aURdsng9F63VtczF0PkaUI/BlPB8Sf1B1mNROZpbHDrJeqzW+7fCYbb3pZ+a
/b6t6H8w8PeDhv4PFwcdR7dp3p1l1ONwbZA3VefNunTxerkUDeKu7uer2feJ
nz+/gJ+uo2x/vFZPQNi2GR+9SNMFIwEd6nMe1r1kuZaVWuu5ROQ/Tgjy07D9
iYi+3dzoct2M9idCIN5blj9L56fUMifDeqmzRUQWnT9keJc+YeT6kM2DbPH8
KWXQT15yX93F5isJoe6pF3NSaZ6RhBRDa/kVfwv8A546PeE=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0GtI01EYx/G1mdkUnWv+c87LLhalssrpbF623zYvaxDZoqy9iBFJL3QU
WxAOYkN8IYQVdIEMgq7qZoHZhWbUlEIRRCJyEJQ0osSaTRrWRkTFnhP4wOHw
4QuHw6M4ctzWzufxeJq/59/Nhtv/cGykQ4mUYoah5YEHcT4zDz1Papw9NxXk
DBxKs7lnrcwi9B97s3Q7LidL4LAXfew8w5yP2vr37xarmQsR5a53t86UkOWQ
TZmn3VJmJfj6Lwdk3cXkUkyGi6NjI0XkzfB6+uc7VwrJWxB3moQnjMxliCRu
CfZekZErID6cnTetZVajbXzBmDVQQN6OSO/PsCiHeQcG/cFeoUJKroR5aeiS
82g+WQOX1BmOejeSq7D82LZPpefI1Xg1PPu91JlH1uKg5Zwo8lxCroGnq/zz
3CbmnTCpHRddjg1kHV60hq76gmJyLfpG15c/m2euQ6bgrmfxQi65HndU1rdV
EyJyA8QLoYmAjXU93IE6w/0brBvQtXUy0b6HGXgUO7+tYCY7ZR+Q+1XCxTgy
z7jaPiPa7JX3XMoc6ibw5WXJzEAWdRNU1stz9kEhdTMqRtPStWfXUTdj6mXD
qZPBDOqN8HiT4x3+dOqNKLHs1nH+tdSbVtvXhNPXXj/lPgioN9M+1lBvpv/8
MqR6CzR90R/GUCJlXwu+6ZK/TeoV6hbyJ+oWepfNrv/+AwupwRU=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03lIk3Ecx/HHo0jX0rydOo9KPGo5zTvzo85566ZIIBYaaIZCpRC6MCeU
WWlUiiFm0OG5Wh45KwumYEQiYuKEsD/KwBCqdWBqqRX7/v7YHnh4ePF+fhc8
j/exk9lF5hzHJf+7/z/Z5ZQ7NNJf6gOD9LFB9rUfGh2YOfxWFJ931XiTt+H4
/Vzzt/nMtrC4fkcUaMbsgHyNarS91YvsApukJolAzOyOluqprLnHnmQv6BZK
Ix74M/ugzq64xey0kLwbo338H89uepB9MVBS/mJz0p3shzJV8rCvgDkAV1c2
u4Xn3Mh7Uf/lxJOZGQFZBPVUlTwqnDkIJTph32CHK1mM9WJFZdGUCzkYZ/qF
N3LfOZNDMJbWHTCdz3wAOa2bCzJ35lBYbTRbRYc5kcMw61dW2DnsSA5H18ic
02t35ggMPKoTusw7kCNxdraKzxUwR2HfopvS2pI5GquFFeu1Q/bkg1j0/14l
ljHHIEd3qeGNB/MhTGiGespPMceiIyrkVVe7HRlYvqx2PvJzp8FKQKKsXBdf
JHNxsL63clQ6znoc7D5px1TZrMfjSnDRfFuBLfV4ZEhfjn+MIXMJSOlR9+65
ZUM9AYfzgtXlPmROAo3+2n7B5A7qEuj49SWrmXzqiZgU6Jeaba2pJyKk8fOv
OK0VdSk8NyYnIvSsS7HMf1r7J3Q79SSYewWs8VRkZRLadLzVzlAe9WTsSm3R
5XWz8cnQD06vVzuy+VOgqFkbLe3dSj0F8gZxoOUFS+qpqL4989zpvQX1VPAs
HiqWmsyop6FCFR07cJejnmYyPt1kfDoM/6M59Qzj95UZdP7VWEPPNF5PmWm8
HpdlPJ8yy3g9TmbcIUN6eM3wgojtR0bf6xaDtTKT88nxNXJtI160bNgP5NS/
Gaw06Vo5jeO4v50+IfE=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdk3tIU3EUx2/OzJympk5N84VKmq3UtLZSv5uPqXNzDyUqBBGEyMpspTUr
Z/RAyFJ7UH8ovTUtn4UrC5cxM4PCIooeRBiVUTQysswko/P74+7C5fLhc865
5/f7nV9oUamu2IHjON3M++/LHlH+9b6ukjD8J1tK/lJBda2QMYe6jaNbBJdD
iZ0RlPYp+VIqYw8IrnU3PhgPIfbGyK2p9poWxn6IFxRmPFIzDsRFqeaccjqY
OAS/QiNuqxWMw+AhOrTZ2RBEHA7vu04K4Y2FxJFoO73Td+x1IPEiSLNG7plC
GEdD51k4Vd4UQByD3Za9EQ/9GIsx+Cqy+MOJBcTLkDUv1ayr9yeORZG5UzLw
0o84DsbVZ5PzwxnHI6bH0SnxiC/xcpyS9J38MiAiTkDTjpYXy8IYJ+J32Zkq
1QYf4hUoUke1TLsyXokY25H23qNexBJ8iPq2K1bDWIr1in6Xyc75xKtm9i9+
qLmR8WoUlhX8Hv7oSZyE4sZLDpVnGCdDlTFofZfkQZwCV6+Biq1j7sSA52dv
kU007z+bgI6AK72PlczL7LwMP9xuVE8luJKXY8T89Pvzn0LycrTI7loH/d3I
p8IhJHpS2EbxplR+PJdm59P4/+PSsWZdXPu2MOrHlG7nM+zyM+z6U8A67q5f
V8a8AraekT97fOaSz0T9qKFSPjGHfCaMVZN3SlqdyGchOFMlEbXOJp9F50/x
XDYO1pdIK4NZfrZdfSW/nkmJ5r5nouFAqsflQHs4drHjAUfyOXZehT1NT26J
3grIq2BoW5XSfY4jr0bOiqreUTHzaggFV42fjs0in8uvZ8rFV8nktFzM1qfB
r5iG3c2bqF9o0NVeely83pniNfz+LRrE136ZkFnY+rT8eGhRt19gflPgQvla
fn2LFkPWpIrtNyme0/H3Fzq+N+n452fRYUmSOK//PZsvPS7cP18u3E7zAD3G
p2+u3TeH5t2k58+/RY8dUcePNXSz+5AHQ1dHjcZI9wV5+Oy1tvhHzXz8Bb1Q
Rn0=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQNioVt3b8xWcoDwPtj/1ZroJsEL4zM4PKvXcJ6z
TRHK53BQn31QuD0FxhdwUHRM7yz9pwDlizgo39f982EJjC/hkHCnc9PMKBhf
xuHa0ec3GBlgfAUHg+u6CeZ28lC+ksPP1VdTmgvloHwVB9buSdOczstC+WoO
75VybWd5w/gaDqarxXUjN8pA+VoO7z+vX2LwWRrK13EI6Th0psQGxtdzuHfn
eXr/DCko38Ah5rwn597bklC+ocPb8x9zbA1gfCOH59vXGBqGSED5xg4BX7ac
3OEiDuWbOOhsXRz6Z7cYlG/qUDlB5KonI4xv5vCUddq37dNFoXxzB0WWuw8+
/xGB8i0cfv1wXlSuA+NbOtTOu7xH7KEwlG/lsLmg+HNUBYxv7eBjXr/9sR6M
b+NguEta/VGpEJRv61Bw7fOhREUY387hmb6ScZ6mIJRv77DaRilD4zA/lO/g
EJCjdfqrpACE3+DgULo7wMbiBx9U3tGBt8jI+nITL1Te0WGF4+GjxyShfAYn
ByYFrV/cq3mg8k4OE1qYd9yP5YLKO0P9wwyVd3YI7DHUZmllgcq7OEDSHxNU
3sXBuPftd8cDP+0h8q4O7y1//XPS+wbhN7g6cDOvrXo1+SNU3g1N3g1qLgy4
w/kAzHm26Q==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GlIlFsYB/CTS0W2WNroLSu1hczwamVp2/w1s1FTR8dpnDFnbpFgRGZJ
OBXVW9SHNtOK6UNQVB+K1KLCMpN62yMwUbu3G9ENC9oXu5ottDPPIc4zMAw/
/uc5y3PedyIWLsst8hFCbPz5/fUrPwZr3fmTSyLhVYfx2PuXxU/8pQXe3PI0
7T0cQe6NrktikTtFOhBfaw6WBL8MJwdjU2xtXLNHOhTbRt9vjpghHYbD0Qua
HtwZQQ5H7KP4I7UDpSMRdfF/T3nJcPIoVC589jCpYRh5DBYPvrnYECw9Ft/K
i68nmMPI49BiWP7fmS1DyeNR9bR00Yb2IeQYXHF71h0wSMfCvXRnwkrLH+Q4
bLf2MbWeCCVPgCujEY2XQ8gT8dZYktbuLz0JFxoG9e7YYyDHY+s6Z0hN12Dy
ZLTUNHeOWio9BVllgWs814LJCXDdrXO2uaUTEepqbK1IlZ6K2wvy33XeCyJP
w+nSsk6HW3o6rpr1fVrDIPIMvAqyF3VvkZ6JVuMuv5AHA8lGrIzas3vXqUAy
UD09snjslQFea0DfoMvlpc/JIglnOir/HNLUn/IkrIq68akoW9Ynw+aYcHxF
pKxPhk/4uM8B1X0pn4WW+r+7/v0YQPksLLlZf6HtHFmk4FrnAItjOY3XUuCI
rjLddst8Nkame/5xHO1DObNIRVZNxeyiun6Up6K737kNX+Ll+nPY/HNQucm3
/mGhrDep+9FM6niRhqrHZWuSP/SiPA0BvrWrX+zuQXk65k5Zf/ZxjC/l6SzP
QFn1NOOpQ4LyDOrXd6M3n6taYxaZbP5MvE38/C05ppvyLEzc8fpDkv6J6rNY
ns3ybNrfO8rNNP6J1zCz8Wa6zy9e62b1PCJHPS+YtRx1vJ6jnkfkYvxpv56T
K6i/yMXa/W2NhnZ53lwcOX/XcCvMn+pZLizqfLDA+3/mQ/UWtZ+6hdXnYYQp
M9FwjOZHHut3njpeZ+OFVc1hVfulWdn52XgxT90vmLV5aj91ZmFj/bex/dvU
+9Rt7PnIV418dv/57P6ZhZ2tb0fO9rhov81+tL5dPY9uZ+d3sHoH2z+z7lCf
B1Gg9hcFrJ5ZL1DfZzGfPT/M2nx2/8yikN0fs8asF7L7c6rPJ5g1J9u/U70f
4VLfZ7jU91lz0Tr00ZnFX6rDf/sH6WgeXg==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0WtI01EcxvG1CW3MhdY0nbdNs1LWdLOmbtkenXNeVlF0gdErYS90xWDL
hGn1T0e9KbpM6dVGRjpNDbtalmFIYIkvRLKLQYSSoIhLostoWrHfCXbgcPjw
5ZzD4ShqHQdtfB6PV/h3/lvZSDz88OldeyYiChpG7KO+pWRmHpaHBf4fQwqy
EA11b4VfapnjUG8MLCQImaVY7NakrHTIyUlwDozXGWuYUxHb5pnjQhlkOfbH
Xur/kM2ciQPNhrEmRzp5C5YsfT0D42nkrbgfs/a+cTWVvB2t7nMuwxHmXFxM
l4xMDqeQldjh6DozoWJWwTpvMae1ysj5mM16UeB/nkxWw97plp1SMmswP9in
Vh9KIhdg8YHvU/7tzeSdCDsVexuKmHdBtNom0msTyVp0z4y2+6YTyIXobHfF
PwFzETwxr14Lr0vJxbCuzGizw5vIOszV5+jCF5j18NqC3mOBjeTd6Lg1lnB5
mrkEkf9k3oOcfVlS04l4sgE2Xxe/6QYzsPhxmyevJS5iDngUvJInm9hAvRQS
p0Y/1SKhXorJx2++vfsppl6GX8przYHjIuplGHtZ0nhySEjdGG3OiPNX7bqm
jPXUy6PNleO0f+pZ4mcBdRMshWcHZ1VkzgSxoN+94F1HvYLey6degaNWzR1n
5poh0s3R5sxw9eoN927yaH8l+PLckLj3N/VKLBeHVstU32l/VbS5Krr/K/Xq
aHPVdC4bNf/9Byj82L4=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H9MlHUcB/BLwaQD4jccEL8qRby4hCAQ9d53wPFL4H5inrHUSaSwNNC8
Lf94MkRh/QGumXC2VMww8kTTBAl3ooLEYKELnWXUcO5YDk85mJBiNT+fP+55
ttuz197f9/e+z/fu+8Ru3KovmyeRSMz/ff6/8xViOtd1uiIOz+VUVk5WtFsD
2BJIC7IvvdcZS16I4EcK150NbD9saJkK/dqLHYS6ivaesZ9iyGF4lHrH07Ce
HYkHur6J9/3YMVjw9LNPHBujyXHw2rnroKwmivwanLapPVW/vEJehOZWpe+J
AHY8ziS3WWu/iiQnQF7cMlnuzZYj8mLT3VpzBDkRc+vqy5e0h5PfxO2y7VGb
PNjLcLgpfdHed2XkJIy/M2iZsISRk3FOdm/UNRpKfgta19n+jix2CkqOW5PW
eLNT8Vvf2ds3q0PIb2Ng1lFf+00wOQ2bN01ZFIvZ6VBfMkQtjQ4iL8cP26on
zZZAcgbGD1SpTirZK/DlX5+/8MfDAPJK+MmXRQw98yevQqyqvG7HnB9ZiTf8
4x82D7OB9KGuw71/kgXg798X1yh2c65CgMPe06an+QSVKFcjImzM0bif+2pU
t2UozxzlPNN9vJApyrNE/SzR/NnQViYMTMk4z8ax/paPpdt9KdegUNN79e5K
zjVY23zySLCc+znwDuzZuW38ZcpzsKNLuyLtMfdz4X8/KMQZQhZykWl8kuqp
4TwPeSds371+iPt5qFQ3dPse4TwfIz77Ppgp8qE8H8Mdv7puPZZSXuBuoQDT
Pp2fPknxpnw1Kq51XLzRyflqvJp/YMTc+hLlhaJ+Ibr7lk/Ej3G/SJQXwby0
MXfIwt9fDOuIdOZ4CufFaKiZ3zFayvNrET03OJDmJEOLeTEJs9I2ml8Q2a4V
Pb8Oa8xJtqo42h/o0Kq6fLVXxvuhw4/OBkX4II2360S/nx4+VUkZN3bTeOjd
1yfo8SB9dk6duID6epy2bf0icd1C6hswI9+/69tKL+obRPthcH9+uwGnIr4/
f72A1isxup8HGHFPEZf84RL+vxsxXW8LLXWR7UY8f1/yeTPhitZuFS6QYcL9
wLVl03VkwYT1H5X+87OD+yZouse3YJjPZ4moX4IXozyMV64H4l9xKXuO
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0mtI01EYx/E1LTe029z+uelyW3b9j6WbptPmfpuXLWOI2gVsQUoXV4Qk
imZUoytEEpkXCrKIXkTaYkZqF2Jks9ULiUm9sqQLMQK7jMK2JCv2HMIDh8OH
Lzw8L466tr5yl1AgEGT/vf9edrjNdx9492kQ01dz2eno0N4kZgHyK8pzfnrU
ZBF4ifrzlgrmRUhyh9tfhlVkKV63Z0bKLjOnYCQyEOwyMadhkF8w3v8snaxC
WNU1Xa5g1sBpGBInNy8lZ6DuYkeC/rqSvAIuWcDFSZlXodHiSD/VlEZeg2NH
Rjs131PJWtR0bBqwL2PWYexFpKegW0HOxMGqM9rAjJychZb95/Kaqpj1KOSW
90WfpJANMN47OiHTMWfjaqdI9DS4hJyDukNvdl8TMq+Dpl90ye/gyLk4fmJ4
vNsnI+fBtfNHy9qVzEb4eOtkX4OUnA9n7bv32lAyuQDesOJKax3zeqzOSPgw
ZWM2oe2OmH80ISEXgldy8j01zGbsOLD91/PQYjIgCfke91aS3YCyd/qVM5d1
C26n9g0GNy6kbsENy7B/RD6fuhXV/Hn7aEsidSsMbZNTFp+YehG8nvoO3TYR
9SIE/KbmxvtkQTG+GKO/rbp51IsR+49C6iWz7S5BYtyt1k8X5lAvRcXZLD7+
ZDz1UqTbHUbu5lzqNhzuGXvIvY2jbsPWar2nQTNjjnU7zfsWs9tO+3ykvmG2
3f/9B0uLziA=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxF0XtIU2EYx/HjRKwt77qcs5pj1LZKbdZspu23zU2NnEuMSsGyGAhKSem6
0KAsIglNXdBfFbGwUHOsWBdqEMi0dRVEQ7qAKRKiNVNLh2WFz0sHDocPX973
eeCkHDxSbOVxHKf++/77ske42/PEXSXFkgLaSNu74fdRzBx2jssyZx6nkJeh
8ap9xF3BHA2PetIbzmeOR5X5M3+9S0JOxPOBiNkpE3MyJG0l9ZqBNWQJLmmH
WsUqZinOzxQe+t20mizDp7kwe/ubVeS14FuKXu2PY5ZD892fbtEnk5W4zavx
22+IyRvAc1bYGj8kkVNxuaUs9lyfiJyOjWeHygUzieRNaFjoH3QbmFWoC65z
+V+sJGdg+oJxr1HFvBmW4h9iV72QvAUNwb520a8EshrqibGPneHMmbj2KLvM
0RVP3grZ8RCH+lscWYP7NcemS08wZ+FhTdu+1ATmbTDmjJ5+G4wlZ2Pp/zHn
gO+cKzf5YsjbMZYmzTisYNZCnDjypaU1mgwUmnp8oznkM0BHtrRS3h1FXYcH
gea0pNeR1HW45XfaBLVkTg9DyYI6zMS6HntKVV1Hpey8AYMRFyvnzRHUDTB3
NhmtHjKXC55EGRR0rKCei2p9szfyJrvfCEu18uWsiO1nRJ3iiqP1HtvfhJOK
3nlrEesmLHK7Fg/Usvl5iJmIFwaEbL883NF1+3pEbH4+vL1ZX+UjbH4+Mhon
f+qeLadeAPv1/qfC4VDqBRCE3j017gihvoM8pV3q//0HWj7Vgg==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzF9Ik2EUx/Gn6VvW1Ga5d7PNdLqyWkg6ly3L/ZxOVzFFIykrKGkKSoiY
QY3i7SLxIho2si40HYlFZbJAbCkGQWCQQYkDY0ViSO4mSxih/WfnCdaBw8OH
7+HR1TZVOWWMMeOf/fvyEQ8NjfgaMxDRguX+SH/Qm8jN0KL/8NU0piPHwatr
WvLUcSswc2pxtGE1dzKaD9e/uzGUTlZj/pFlNlDBrYXQ4Xh28FcaOR2q3GnV
0SruDLwKDA4En2wk65EXb2qbCKWSN0PrqwmyQu4tyFq1dbn2qZa8DQbV65dC
WEPejvaJ02Kznjsbbn1FV4F7A3kH0BV6+9CfQs5Bw5RN6E7izkWmo7VaOq4m
G6Esr8ufG1aR8yDFGS8ufhTJJmS9r/S2Ctw7IbvZs2yXlOR8lLcoXJ3Pk8m7
4Pt2dV4NbjNcU+cS2Anu3bi+6ccR1rOeXABv37jSHVhH3gOPc8Fz7A73XhhS
xZT6k9yFcHb3y1y9SWQLNOrZTx3XFGRgUPNg+M2BtRFLQN+L22flZxKpF0Vb
KkLj+OOxSb+cuhXhBP+l76Z46lZk7u8M1NxdQ70YaXaHWbwnUC9G5ZUcQ+zl
WOol0ZZKou+ZDZ/NSz+t2Sup23Dh1uSoOBNDvRTymIHzIc8K6qV0H7ZEehl5
LmKpjO6/ULfTPzTSf2b7/vk3jRu7jw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tI01EYx/E/w/DWSuec1+WcZmqmecm1zdrPqXNzZiJJOYvQiGoVmpMo
6fL3VUaEiSIkW4mGeKHZKkcyghm9iSiywiIIErsQOXVCmaLd2HNe2IHD4cP3
POfdia+tqzgs4DhO+Xf/O9mSVI64HMfl8GlOU9UebuoUMnOovSiyqUbjyQF4
0+N0VtUwh6Cm93vEzUBmMTxN3iBzv4wciesmS5i7mjkWitw1rnYBswwh55QV
dw7EkeWomfywYOrcQE5EpXPTY+VLKTkJN7rz/F8pmJNhTcfr8X2x5FTsGoyx
vrgfQ07DpOHCD8/vaHI6WhN3W9WtzFvh//6K495MFDkT871V7rgs5iy8PdJR
Z78dSc7GwTE+KiiMOQcSlaxh7fkI8jYM7/Hz885IyLnoW+mPS7IyK9AmPTbd
NRVO3g7/sQRr2jSzElPNouT6Q8wq2B7kVbfbxWQ1yjO65Y2RzHl46hwZaKgP
I+/AR3OKauUS8058SZk/m1nOrMFP46eA5lIRGdA9/GrGeKjPPCAdWp7YryBz
+UgpSxAXnWQ9H67oDtvobAh1LbaEJnu7xsm8FhbH8OXyJjZfgL6Eknc5j1gv
gPCE6FvLKTZfCMOAfXCjdT31QoROiyVzknXUi+Ccu5YR/YzMF+HWk97TwY2s
67DXlGVvkLN5HSaELUcXy4TUi1ff54th2tymf34mmLoe2Vc9C/nuQOp6+P6D
gLphtXkDLENqzd0ejnrJavMl/80b6f1Fja8bIZClLgUPLfvMlWJWufRLm/5Z
8weOgN2Z
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0G1IU1Ecx/GLC7PmNjWzuZnO2WqYrtxK25ben3M+a2RUxhoRkS/CILor
CCG8+UKCGrhCewJfSNGDpCTZiKw0EKGsXmhpGbFhiGilRWQtth7Y/wTzwOXy
4XvP/xxu+oEjO+qiOI6z/n3+vdlK2tX74E69FmHN8+kXsgt+KZg58MnD7uqu
dHIM9MasdlslcxyC0a1FupCGnAjBqWh9cplZiWB2sElSw5yCvfvemrr9aWQN
nooJGZLdzFrYZ1u63d5U8hpYZpbo236sJq9F7/s3H3oEZj18LuMx1VAKORPD
vrsTvJw5C0tH1x0/KKjJBpx95pf7+lXkjUgbbH41NpVMzsHNKcP49B5mI/rM
cxA8SrIJ1ztHxxc+riJvQnOON3VsO/NmOF7KDl3yJ5Fz0XEqtudqDXMeQsKC
btngSvIWXGt1xd8HsxnOGJV40ZxItsDxdSJXF1xBtqIqr9E7aWDeikdO3UCq
NIGcD772m3ObOp5cALVyctpzLo7M44yx7t2V/cyA7HDC7OmjZBG4N9+yQfVc
Tr0QtQ5jl6BVUC9ElCYzIO2MpW5Ddr5h5+MpGXVb5PdcUeQ8cZE5O2SC0TrS
xPbb8XDI8lk/yeYXw7HeU/bihJR6MTIq2l47biynXoKGxsBA/a1o6iU42T7S
l+SXUC+l/0UWS+l+v/lwL4PJ/WmhsP9n2GIZ5syBkM3wnXp5pMVySCW3G2bO
f6FesahXwNVp5Xs6ODq/MtJiZeR5XFXkPLGK9rFV/d9/AAuL6JQ=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0mtIk1Ecx/GZ0sRba6VptqUz01TykrXKbL/pnHOZbpnYTMlLIqVUdpN8
Mca0y8guZBCrpJTKwApTUpzXqUkklk1apUEjpftlXdHsTuf/ogceHj58z3MO
5zmPf972dQXTOByO/M/990mXV/qNtutFIvyTXdLTGBz5yI3Mwee0r8OGJn9m
Z0yNzlCmZZJ5mLwokxyY9GOeDZeRm9v3nyF7wxhmOpoiJs+DbG/0yYhj85n9
YBBYHJ9+EzKLYI49JxcpyAsQ3iJt0zcImBei2sbnVfDIwXAY0z4rUsxjDkGF
k7pmqNOXOQzVzjn7LA/nMi+G8aNbkTefHIH498ogfbkPcyTe3v1QHBtBjsIO
47bUW93ezEtg/1qgtdXMYY7Gu2xzS26/F/NStA5omjM05GWon/nOe2GTJ7MY
Q1c6DOXW2czLwRU6re+zzGJegWuJ79eVupFXIlTg5VOYy2eOwfR0hyZ7L3kV
9ON5R8avzGSOxaUA5Uh0D495NdyL+a8PlZAleP04qCJcTwY+/TRp9FxmHfCL
o/6Vs3sG61I024+Hzx30YF2Ky9Lem/0+7qzHwX1nVMywnlkX9/94TjxUxSED
X3xo/njsWXSy6kQjrS/Dijtt5/tt1GXYVR8jaaylngBB/XdrlpjtT5cAScbn
rBRf2q8cro5Xy15VUZdjrP2HLlRM3ycRxq660vQwZl0iNiZ2uXxroK5ApMk3
6Oke6grklGRP3X5B8yehT9V9RmeinoSJC1ztuJTeV0Le8XIr7tH6SmzdPdHs
kEF9DTqzAs1CV3p/DSLlp1uVg9STkWY1VFoE7Lx1ydBs6lFkbqDzX4uiDVx1
/inqa1G2L/S5NZD+nxQolJUjjRpm3R+/etDpcZh6KuLMacLQ+dRTEW05Uhpo
oq4C/+r9LXYtM1TgHSzZ/KSWxquQP9reXveGuVsFc0BFMEdE/7MaUx6FEnMC
M9SQnbXxWw2e+A17eBZ5
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAmIQDQNioVt3b8xWcoDwPthf/7T78hp+GJ/B4b/4FAnh
NYpQPofD271xq9KDYHwBB6Wb2noX3ihA+SIOTWv/HUlqhPElHAJytE5/lYTx
ZRxuarDNl2qXh/IVHA4eedxw6poclK/kkOz71uGEJYyv4sDzR2rb2zRZKF/N
IfQAs23DUhkoX8Nh3VePOm1+GF/LQd5gw8LCVGkoX8ch58FEf7VDUlC+noPr
0bzqSaowvoGD83sv9aZmSSjf0OH2/PTCztUSUL6RQ8v/O0FsnDC+sUMD//eW
OFNxKN/EoXKCyFVPRjEo39Qhv7dSUniyKJRv5qDIcvfB5z8iUL65w1b7tB81
OTC+hUP89a1xlytgfEuHXz+cF5XrwPhWDqe3bV1ZVCAM5Vs7JJ1Q2mXcAOPb
oMnbOvRu5tTed18IyrdzWLjkhGj/NRjf3mH6wx7Gex9hfAcHtlDGzR8OQ/kN
Dg57j7ff/1EPk3d0MNwlrf6oFCbv6PDD+ylHow9M3skBkn5g8mh8BmeH7QXL
IvVEoe5rcHZw0kuYUpQAc6+Lwyy/xl+PuaD+bXBx2LS+TU7ijogDAMinpoo=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAGIQDQNioVt3b8xWcoDwPth3yfaaPhOA8RkcJHbkzORa
qwjlczi0a+22jvOE8QUcXCcn3339RgHKF3H4ZcJxgacBxpdwiOGy+r7TEMaX
cUhQaXau3C0P5Ss4SDFNecDGA+MrOVT/WZublyMH5as4rOZdP8v3pCyUr+bw
brn29DpuGF/DQevxocONVTJQvpaDaZRE2Ysn0lC+jkPh1PWLXgfD+HoOC9/H
87+YKAXlGzgYnlPZwftDEso3dPDkc94RNBHGN3LYdv2zidBxCSjf2OHTDO5/
Pe/FoXwTh0gliwU3wmB8U4dsvd/3L50Ug/LNHConiFz1ZITxzR3MJh/J8BQS
hfItHPyKBaqnHRWB8i0dfiYW/23cKgzlWzlsL1gWqScK41s7/PB+ytHoIwTl
2zg83vO3Qdscxrd10PRTFnHNFYTy7RxKNadMnrRJAMq3d4hhXzRL2hUm7+DQ
bZR6Z3YCVL7BwSFy1tqFojow9Y4OnivXrVKdww+Vd3RYL71m+yVvKJ/ByWHb
hwn6Umf5oPJOaPqdHVY4Hj56TJIXKu/swKSg9Yt7NQ9U3sXh4o6rX2784IbK
o/EZXB3k/509bfGBCyqPxmdwc1D2mnYtagVM3s3hveWvf056bFB5d1R+g7tD
eJTRuiKl//YQeQ8HSPpngsqj8Rk8oe79A1Hf4Imm3wtN3gtq3zOovLcDN/Pa
qleTP0LlEXwAxK3gxQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdyV1I03EUxvE1Wa5sZdPWSk0dZdsaK5tubWp7dPu7dZGVYYGtMGOQU5LQ
pYgXu8kFtSK3oBJU7CJolm2waOtFI8KrGhVFlEEvK0EjRxStofbCzq8LDxwO
n/MtbGyttfN5PJ7m7/67bCR1oTuBZhlSihsbvjgc0ixmHnSD0ZvvgoVkIWq7
Ho/EDjJnwsvZdvctZ86Gsi1qHg4XkKX4pn0r2NvAnAun5lPnKJ+5APPqqcBI
TT5ZhrFH139MhdeR16PHMzq3K525CM3T9o2CnjyyHBOT2WH5z1yyEpN3wwNH
6phVqN903vqkM4esBv/K4ROeibXkLfi99GRjfz5zMQYFY7XjXWvIW2Hh2pvS
ZqVkDS4+6E9z72MuwZnIzOtDp1eTS+HUFdlDdmYt6qOipkvvJWQd7kfEwriP
eRvyrTv1kmuryHrE9zw/d0HLbEDJM0/Hhkg2uQzJhGmoQ8VcjphDYZhzZ5Er
8KFPW/rGKyZvB1cR644mmY1wtCduLdrPDNjShy7ncCtTdgFmV+dcsZvMq1zQ
K5Hnn31p07Fehc+bZZpjCtar4FT4vL3BTOomiFrE06eOk12mBd0Mf7nsqPzh
Cupm1Ayf5ewhEXUOT2+/+P4qkUGdw71xw1f5x2XUq/FL1dt9tWUJ9WoEbrT6
1AeE1C2Y0Sfnq9SLqVvQ5i8zBod41K3gFyiTGf5ZY6pb6c9mx3//AYiuwxk=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H9MzHEcx/GvCx1HLipXkn6Q5IYuFUX3qnT6caqr7o7bmda02a6yEZmo
b5b6g+ZXiBPCZPKzZkrDVxvl1x+xYtOWiX/y62yk2lnYvT9/fL+33W6PPb8/
Pt/P9/O5oPyt2QUyjuPy/n3//7KPj/FOx21bMFxyaFXPtkTUyZk5WIt6/1ib
gshy3Bz2/cGvY1aifKry1aHhQLIXCk8W63bVM6vg7lTH/Ypn9sf4IctI8ZN5
5EBUeoSFbpYxB8NytfOsvTKAPB+eC86Zel7NJYciQ9859CaQOQyd+1H7ptif
HI4aWWZpR9ccshr+ynb3Oh3zEgTN1/SkvvAjL0Nr+aTHexczR6Bq89KusWpf
sgabim6fq+9VkSNxZHB7WeLv2eTlcAwXlL9vZI5CQ8DxB/Z45mjEht56e63W
hxyDgc9NO8xnvMkr0HKzOkDV70VeCavcj69fyRyL/O7ge5H8LHIc7nfVDIxU
zCSvwkj6J3mlnnk1FG7Xdw8d8yTHo6DhsqzsPLMWqzT6Go88ZmBRRohXchGZ
B/Z9zK/9eI31BPH1+ATMbXb2WWNYT0SHX11D+3cl9UQc0BT02/PIXBKyCsOf
//JlPQlJuc7oSToP6mv+PU/st7DBadTX4NLTizsVJawnY3h6e6UzivVkvPRz
DNUpp1LXYVR9dE9T4RTqOnQ/Xl1ack9OfS0crT1/9nqzvha7K8Ye2a5Opp6C
6iO22LJ57tRT4NoPMuqp9PwTqKdCH1Nxd3CJG/U0bG+O07Zc4KiniY/n0iU9
HZG1X38nCKNaV9fDbNHc2BY87jKvhywwfEzR7KS+TjweXmIuQzweXmIuU3L9
TPF4uCwYDkYsnrh/osuQmJdYyJLMn0E8vzDQ/mDzacDhKre2gY30vgSD+H1x
2QhJO9FnuUId2bB1tz143a6g87PR09b78+0IWZCYyxEbOTR/bL3k0HzT/YQc
8f24XMn4cyXjzxU/ryA5njPC3qcYvRzF7m+E5xcvH4cPrV/eKF7vglGyvk0Y
5wzjeSUz6HyTZL+Y8Ll/YdXSfWTBhA2nrzd6q9n+MkNr/mnNmEP7EWacethU
alTT/wFvxgd7dNS7Y2TBjA2bOlMs62fhLxzKjI8=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03lIk3Ecx/HHI9JUNI9lOUtHeORaTTNzHvvMa+axmVmxREFBNFa41LCD
5LG0w1YUBUJRpFEmpqmxmfMojND8J0pKkDBU0CzMK5RV2sG+vz/0gYeHF+/v
7/jn8c0tTM+z5jgO/97/X/YIDhg6WrQiWDQjPzqvbb7jysyh3FBRVN3uS7bD
YK3RqMlhdsGFX22oMfuQ3THVoz3i/IjZE35h0A0qmYXweaf2PvhmC9kH6c4a
Y4I7swgZvlWjbsrN5K24nvvls8LkTfZDZ9Dl+uFJITkAYvWD+XxH5m3Iyqsf
i9Z5kcVYzqzKD2zeRJagN+3x+7Jo5p1oe1YpyzFuJEuxLuh8lv2MJzkY/dlP
57rDmEMgvH9sIqNrA3kX9KbpoewrzKFwGPhxfLlMQN6NWPGHtzaVHuQwmHTi
xf3WzHuQmKQfatW4k8NhzileKje4kWWYCJw7JU1jjkD1iN5qeNaVHAmpyct/
9ARzFB7KQvrq7jJHr+pylBTUdasFzEAcf3JJenG9xTzw7ZN/xY5zLtQV0Nxu
rPEQk3kFGiJFBQGvnKnHwNGtp1Q3SeZjsD1KkvFi3Il6LFRPrsXnGch8LLp6
Zd8Dxhypx+Gj06UCs4r1OGj7nncPtDtQj8eCU3v571Ca5+PR0lR4S5JpRz1h
pfkE9L2OKi0xsa5EyNWpRcVLe+pK3BgrPhOzuJZ6Is7eG+gUjNhQT0Rdx6Cg
X7iG+l5Y/g9r6qvMJWGfXhpkW2lLPQmHDgc3FYn+yC09GQ42jae/3rSinozi
hgh5ay1H61NWmk/BdPjP5RjJAq1PpfubLeZTab9Z6qqV87xqVVdTH6eupnM5
7i+stQSJ
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd039MjHEcB/BHLp1qOtGJSnXKj0r0w1XCvburS7/vuTtLZUnGHzJJ+VH+
8KxhaystalmU8iMc3YRmy8oxjTJCwwzDslKYo8Y6/cD6fP/onu327LX3Pd/n
e/d5f72zc7XbbDiO0/37/L+zS7qh5XZzjgyTMit8uz5kCfbMHE78vH//zQVv
shh1SyzB8THMEkzcOuXz4rsXeS4SvTRKv2PMrrDo60q2yJndoerOypIYPMle
UPhlqkNnMcvw0Ta44HnCQrIPin0zMt/WeJAXI9dF5PqyzZ28FH0dAU8kH93I
fnhw82FnoQdzAIzdhfzqsAXkQJyUfnu45eJ88kr093VIhmXMQYgRTx8dbnYl
B6NktOdls4o5BF9u1r5faZhHDsXYHu+kveHMq+CT9+z1iIuULEfutD9HDZEu
5DBsftWS2XNgLjkcVb5jadyZOeQI1AovipyMzKtRdmOmf/t7Z3Ik+lbIQnYt
m01eg6Hx1rRiOwl5LeIuGw2+p53I62Dj5WdxuOJIVsBz/PGjcLM9GXi8wDxY
KSELQEVv/kHlbzvKo1B0yHI3xzCDcitzSniuT4qQGmwpV2KyTzaUq5B/JVJx
/SxHuQoO05uKBk9Mozya9jeqmMyjEVL27XeUaWTSXMzU7wtW5tRWuZW5WFy8
/Ura5c72Fzt1P9x6pKYHG/fIJuj9VubirNa3MhcPvjTIX3RERHk8vkdYxpWB
7P9JQLMxtzIwQ0x5AjqGnHTpeWweiTjfeW6fQ8EsyhOh0o/KbdVkLglpNU0N
LgE0XyEJbq69nyuOs3knw3HOvf27B2jeQjL9PpanQJE6vCnZjfoipEDdNrAD
z1h/NNhW22hzsJ4MDTJi79hbrlHfBA0SbvyI58OojyYN+pf9LAzSsH7yyNlo
x2+tJoPH8n43wV5E/RZ4nPt0JFu1nWzicVjU2SWuZv3Xwr9c/UT5iAwtzYvO
i6CFme8pr5KTTVqUznt6/FceO0863F10eCknI0MH+de+d1ft2PO6qeuZdKjp
cm6tN7Ln9ahubLgkW0jnFXq0bCrKSt1JFvRob3UWmyul+AuW3EpK
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1IU2Ecx/Gjkc00U9umOfN1hZZUMzUt1/lt6ubLnDKJRYmEUEMrypYo
EnGK1Kyl0UWZFljiLgQnpkYpmsu0KLAkzFowKrrQXg3MrCgrfP4X24HD4cP3
PJzD838iiw8b9nlyHId/9/8nXdKdvf1dB6KwqBn+ZHE31yMic3BIH3oPWyOZ
Rei8YbrO68j+aDJNfG6bjWAWw6G1vXVeIQcjdqn5WQlPDoWsOvmucSScOQJD
VxO95BJyFFZUWqvLdocxyyEe9tL63FnDvA7GekfVx4VQ5hgkyfJMvkryelgT
DM9/NciY46C8qZ660BHCvBG3+z2fmJeRN+PFTEvrgHk1swKbFhTdH5aQ49Go
kxtE54OZt+BTjXd79Zkg5gS8etDjmDRLmRPR9Ciwr8UmYU6CJejpxbky8lY4
d9XXWr6LmZMR2DFRMnOCnIICLnmsK4C8DdeEiaqVtlXM21EhaeYarORUTF86
qurgyUrYtF8MFb7kHbifP9Qs9AUy8xgsXGsP8yEDmoHpUowHLFoAlrfOF2lG
mDkVzF2ddflV1FXgjbOFehl1NVLG+ltGX/uzroY1OtuRcI+ZS3PraYhUmerK
/1BPd31fSEeuZnTknZJ6BlLjdbV+e+n7GW7rNa4WNG7/p0WsPlqccYjWa916
JtKFyt+KWuqZ8I9TyMYWqGeh9Nj8LQ8j2y8hC5ffWDycX2n/sl3nI2RDbS8I
2xBO88txna+Qg0JRiNCYQl2HXn7//PGD1HWoP1LevqeAei4y308O+p2jngt7
9OkYLorOkx6p3+xOSxGzoMfjn1Nna9qo50FeNv7yh4SdTyEP+YY5WecpKf4C
E4n6xw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H1MU1cYBvArVFE6FC0WBBToRBERJ6wICPbhU6BCSz8oVDBqdCGpmeKy
RdnQ6pwaBYNs0QSyOYJfAT9CmBNF4RICOidGJKIzM7jAjCFT6zTaErRieM8f
9zRpml+ec3vOfc97TtiGLYZNHoIg2Ma/H3/ZR2m+2NZsU2FCDk17cXjnPDmz
gJ6C/RaPU2HkqbiVfDC6OIfZF8nfK7qGn4WS/RAe71YM1TIHYGtzy/FDOuZg
rH1c3/rVUAg5FNUm7YVXWcwq/NW+0F27Zx55PhL//vdw2IO55AW41+TePsnI
HAFXWXZp+sVgciTU1oBvng4HkaOwpvwL9dOFzNH4zfnu5dyGQPJnMCc93Dj/
4RzyMpxpvHLAO4w5Boqt2s4vKwLIsRD9mrzWj/iTP0etzjW4zq0kq/G8pPPS
+h7mOJTvGu20NTIvR0dIXcDP05jjUel/p+ZN2WxyAvbK/rg59ZgfORHN/wce
Ly9VkFdgww3VlVg7cxKuXd8/6Nw1i5zMeSXuampk/o9mkjXQWF4X5wUxAzsW
XXdt0vlO2A5sTq2+Nr1+OuUp+LpNnxTvJNtTMPM/P6VDyfJUdL+aYbSWfUJ5
KkLe9/4Z7/CmPA3Vez1bB0vI9jQ4WvreVcyeRnk6YquevU0RyfZ06XghA7Yb
re39l+WUZ0jnEzLhsy1mRf8eH8ozYV18JOv2dhovrEJvoGPkJ182/ypEtcim
xB32ojwLp9vuK28GT6acs5BN63NpJvJseIRGjsqbxiYs5MBijTm/TeWmnLOg
xYuE0fep0U8o10Luea585MeXlK/mnl+Nil/6ryr/8aT5c5FfuWyx7AcZrS+X
+mkK5XlS2/NoPpbruFzH1V8vrQ/0+DTn6ID1DKuXHm98Lu8eU1O9Rf14fyU+
jxhi9c+X7jfyuefzpfUWx8dn5SYoG1l9DVLDwK3XIN0P0cC9n1FqGLl6GaX/
J3LjBRP2HbElfhtC64OJ60eT9P1EEwZ8DpS68qjfBLO0H8HZbkZf673XD5zU
j6KZ+ofVr0Da7yiAK6rmu9Ob2fycxQLUDchdp9Ssvy3SesPCnReLdD7Rwq2/
ULqfKESaaSxuciY774VYkhxt6nhC48VC7vwX4XdH9dLAXjKKcCHo7KW72hn0
fBGaklSlEV1ksQgJt9t+7XlM941ghXeDc21mN91HsMJ5wmvncArdX3YrDlWd
DD/nqcAHGtTDHA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQNioVt3b8xWcoDwPthvMtgwZSMfjM/g8HDmGaHD
uxWhfA6HHbcDeS4kwfgCDstX+4XeZoDxRRzktlnbXVqkAOVLOMy7o+eZGwDj
yzg8sBVnWXFNHspXcHDw7bwS7QTjKzlE7nSx858hB+WrONw10FR1eScL5as5
uK6dobXIBsbXcLj56uf2ST0yUL6WQ/k+Y+fz+6WhfB2HxCkh2zyUYXw9hy0/
/n6UXSwF5Rs4MExu75qpBOMbOsQ9TyjhnCwJ5Rs5bHLsbPr5XwLKN3aQNW6/
Kp8E45s4LJjKwXH8kjiUb+pwcuqawNcaML6Zg5H4/MSYNjEo39zBRZVP574g
jG/hsF9+tsRcThjf0qFOp2p23gdRKN/KIfQma2dHNYxv7aAVbXF0nz+Mb+MQ
oL9AqURCBMq3dXiu+anSMEAYyrdzuJL6jVNjpyCUb+8Qw75olrQrjO/g4Lly
3SrVOfwQfoODQ+nuABuLH3xQeUeHb7w7G/+Y8kDlHR10bfVC9j/jhco7OWSf
2LHv8k5uqLyTw97jVu80HkPVMzg7TGhh3nE/lgsq7+wg7+FrKbaKFSrv4uBj
Xr/9sR4zVN7FoXbe5T1iD6F8BleH8CijdUVK/+0h8mh8BjcH49633x0P/LQH
AKlWrEg=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1I01EYx/H/NlLLUre2ta21F19qrFjNpW5q7bctXxYTZLaLXohoLMIu
zCKhRaXQhWRBtjBIuvFm5ZKoVRJbKhMrDKO6KKUiaNQytP5QUEmuF/acmx04
HD58L8458Oj3t3kDQo7jKv7t/ydbct/d2K1DxciIt/dViqY1EmYOLZc7BNNx
PTkPivZTi+8OMhfhpufsh1wxsxQCXuAtHdSRFbD4TnhUPmY1nhWO9Aaeask6
RKWpvW/TGnIxSs70zwR3M5dixHk1Jzq6hrwWeXxP2Tk9swGJSMG6cY+abISr
eaBk55XV5A1QNrUFEmJmE3IP3J+c6VCRN+HSfPCi9oWSbIb4TkzZa2QuR2r4
htm8Q0G24E+rv/txahV5MzTdrde/y5gr0DWrH33vlpMrkeySGA77ZeQq+F/H
4+E5KdmK4PH1qZdlzDbM9h1xDNlXkqsRCvChPWEJuQaST2OJiFdMrkVPeeBN
/74i8hYcizXXWn8WkLfiHn9ho2qK2Q7xnFTOy5mBB4+qvxiSyzPuBIQ640J+
hMw5cM0xPvFQuYK6AxPfClt2tbPuhDY99cTKL6OeZc4FPvp88aRsKXUXvtoW
0k5TDvVtCMdeySfVS6hnmauDtrHJJh9kvQ6eqtPDSZOIej3yRUPBzyEB9Xpk
5llIvQFHIzX22wMc9Qb63297pjfCcn7+h2PsV8adWebcWd1N7/9IfTvdw3F/
AaiI0YM=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlntQ1FUUx38CKkYoJK68kvUNSiT4Ak35AoKogIDy2F2QH7APJ3DMV5pm
/IpMKjVRJh0qXanMR9hgkfigftigFKMTMdlDyyUcpxgznFERMqmGc/84d2d2
dj7zvfece8895+wZW7Q60+amKErTf9//f8XHkFV/tq5kHAaoO7atZXvNAk/B
CvZGWw7frh1L7InBN25VjM8U7INNPVfro3qMxH5IbWz9bNUBwf6IKB1j+TJR
cDBuVtRMfOt6CLERW8vvvpgyWvA4eIWFtPyzegzxBNQvnH/w8OkniSch1H7t
YPQ0waG4Mey9SdN3BRNPgenbgBEfdgURh+Nc1dNvlM8QHIG6qzt/adsWSDwN
/oF1k8tdAcSRaL8Y7P7zUMFRcPU1KLVl/sTT0X3f9pLr0GjiGeiYajvvFS54
JqqPNiXcqzUQz8KENW0/9Y4SPBtu+w/+nayNIo7GR2d/MHwTLDgGPtvXWK/X
+BHPQZ5noLY/RvBc9D1IqNkYLvgZlOQOzSjeN5J4HiLPBE3+bcMTxPPhEx4Z
dLnflzgWsTl389KCBANj4xyvb3jkM8AaEOTf+XvlHmIlDk/5ht6pbhN6HDaE
Ve3dc1Lo8Vh09MSxie+OID0enwR9fOq7JcRKAlKTLjTfmCf2J+CDr99/3mv9
cNIXoDR+d+PwQ8TaAvje8jN0G4SeCO+1UXPbX/EmPRGNF+fcDu18nPQkmKdW
Jl/e5EV6Ena/6t5wPf8x0hdi+s4/e+L0YaQvREvzvI3rz3iSnsxZS0Zl57ot
8T1DSV+EzWV9TSXHhpC+CK9VlszZEiL0xbgU2N1V5UP+NImVJdyetoTeezDp
KfByr93ctXcQ6SkYqEc30lOx9UD7OUOHO+mp+Cum71F8BJ1HSZP0NMn+UmTs
iJzqsc2D9KWS/XTuH+lwM07p8zr+MHZgfTpyzFEn1o7rH2A9HSmzy051RpA/
JYP7RwZCklNjDMfIvybpega3p2RyRibWHZ8be7JGof2Z/Lx6Jj+vsoyvxzJ+
Pk1ifZkUn+U8nljOdU1iXVqvZPH7Iovnh5bF80fPkvIvG+GfegyZtYvWI1vK
12ye33o2xi9++4r5iMivHJ7vyEFbw/d3f3wg6kFiPQchjy61RneL/bk4EvdV
84UAqi/k0vtTfWmSruciYfnDWYOTRH2aeD3ChJKWhi/aTwv/Ju5PN0nxM0vx
N0vxM0v5Y5bez8IZFm5Ps6DuxOqqCAvFW7fweCt5UvzzpPfP4+fR8/h7K/nS
/nyp3vOl/MmX6meFlP8rpH4g6foKut99qp8Cziig/Oml+i2Q9hdI8VP5fYwq
7xdQef2pqtRvJHaqUr2p/D4ulderUsjXGwu5PxTy86iSrkm6U7KnF/J+5iqU
4ldE57szwEaJUcT3q0U8nloRj7eziNvXJXsuod8k/8UUB/oYi7mOYr5flXSt
mPtzSut1SXdJumLl9oxW6f5Wvl+VWLPy+DitPB66lb+Xy8r7oWLj9WK08f4H
G++Xqk36v7Xx/ua0Sf3Ghvvep19+OJP6k0tixY4r3hUre9Oovxnt9L40v8CO
fiWjX11PrNrxQtjFXttSMc/Y+bzktMNUXXtoVDixbkd66ZTWewHELokVB96M
sl17RyU2OhCWNt4vcRXNZ3Dw+Ux1IKnxj2fRRrrmoPcidjr4/Kc7YCo4n2zO
pfnQ5cC+jh2Dfr0j5sOVaP28/uja50biX+zcQ1g=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03lIk3Ecx/GfWprNK4+lznNF2pRpHnlV+0zdNJ1zWWGYVBqRqZBLI7Ki
dUAhFpFgoEUooUtJW4eSB9lhIVKgf4xAI8gouzwSLI9cxb6/YHtgPLx4f5/v
73n+WHDh4ZwDtoyx1L+/f3d+CXc+7DaUiGHWlKw88viORkduhqPVs4IiQzB5
BUqqbpyrV3G7YbnE6N7EuD3RskwxPtgRRPbG6Bv13Sd7uP2gcxUbcuy5g3DL
pdPmRH4gWYwYkb5d/jyAvBYRH64fUnpxr0NLiLZ94oI/ORQhDusXCh/7kSWI
HlBcKTWKyOHwqGnouv3JlyxF2OtxR7WaOxLCt7Kuilof8gY4SDqqhQ+8yVHI
bK7aJXDhjsaISdS9u2I1OQZlF+umtVruWJRIF94NDwjJG3GtqUEvDuCOw/6R
np7mb57keHjv7Rm+rOROQH7h+7HwcQ9yIgw/fG9WFnEnoS1tMueYE/cmhPkL
fQ4WuJM3o8w487QgmHsLiit+ddjkcsuQ79BYJ1KsIgPK3s/FGCLrgK+jIecj
zrpRl8PEtpn2VbhSl6P3ZeJE6JgT9WQELr0ajJ9aST0Z/TOu2/O0vKdg6v7Q
71NejtRTsCaj1pinp3mWinqjYK4pVkA9FXr5s/4XPs7UFZh1fnRmMZb26RSW
80xp9bwS0Ze+/5T30XksDXPhV082l/Lz06zOT8dkwvxSstSeejpUcac7x6R2
1LfC/P+wpW5lloHcvKi2I2KTzNwzILC7U/mlZtpslkn7P1LPhG2QZF7Qukhd
hfLWJNm9Rkb7VZb7WJblvC7Lar+avneOupq6Db1fttXz2ZbzTGN5HjRW8xp6
/1mz+zT/v+cP8CIXVA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H9MjHEcB/BHRfLol3Ip0Q8/Rp1DKEnufZWrruLuuh86tTDNpiblx3L5
8ayNZirCmNXMykRHFuOswsNifqyGthr+SGMMNbchSvJjfb5/PPdst2evvT/f
732e5/t9vmGbCvV5LhzH5f77/b+zS2a80dqcH44xOZSlvOt2hxczB0NJnt2j
OYw8EWdafet35TD7oL92fsyv0VCyPyyujzaG2pinIdX/xt7nGuZg9CbVvS57
F0IOxctvuarTPHM4+q5/ETtNM8mzoXslBBVfmUGei35ZVrPL72DyPNw/iMqe
bcwRaPGsWtVln06WIyDu1vlHA0FkBbL5O+tq/JgXoTMsXpVsDCQvRlnBwJGG
nmnkKKB3/3pfNfMSWHfOKrSpAshLEX1Jn6MplZGX4fDws8bA31PJ0ej93LDL
XMscg0MdpwPXyZmXw6e8aHNvnT85FnJHVZP9qB95BdS3P27Fc19yHFZGpZd7
bWBeiRm2ke7sGOZ4xHa2nnv4xoe8Cl9HW7LK3JmVWBCvMNx970mG1ALw4Kt3
pqVoMuUq1HTzQxeW8ZSrMEtzqttycRLlCRiSH9/bUOBBuZO5RHyJHR5NUEyg
PBFmS1RTcfgf5VieBN71ivXTiXGUJ8ElNGKYt41QvlpqwcmcGksqB36oxCHK
1U7zJ0stJEvruRTqb5DyFKf5U7HDFqe8VsdRf6nSfjkN9p3tapP1uVKukdZz
adBVLI50O+hGeRoOVeevKA1xpzwd1gPD9/Ib2ftJl9ZzGZBfd5sQXUX1Qgaa
mwpPKtZPpHwNOoIcn0760HoIa1D9dkdpwg82/1qEpGTEyhrHU77W6f+1SI85
YH+roP6hxdh54EL1WjS09sieBNN4USt9Xk4nNXROz6OT9iPqnPrX03rQfoEe
lsjqlM4Stt/00npRj5DRjqfLHWz/ZcKzOCquq4z2LzJx/nH9bn6nF43PxE3H
sYVBHWTRyZwBvv3+MoeMDAMSDSPR49VsvAFXp1+2v0jzpvEGpF5qapxTS+aM
0BZEPP0eSN8XjLT+ZMEo/T5FI73fKTTehH6/rLzBw2SY0K4Va4QWsmDCFD6g
7X0bnQeiCdY9kR+657Dzwoxya3vJz1oyzPjltUV5bzWdL4IZFQHPjg8WTcVf
vnmFEA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2Ecx/HHS26hU1M7Wt4lnOUQ5/KyNPfzfrxfQsoVacKgi12n0Upy
GsEKDdQXoimGgcIqw8LMJJDeKBG9qFAJwkgpsMvMQFs3K/Z/XuwcOBw+fP/P
8/DAiaw9WWFwZYyl/3v/f/kjVI5OjByLgkPLup/vp177+HAzzIuyxum7kWQ5
murFSU0pty+SLDHWZVsEOQC98wfnSju4g3DU26W+Kow7BDfXAx639oeTI2Bd
UQba5sPIURC8nvXPfgklb4PRdLXmpYk7GtXxyjXhVQg5Bv4GQ/keDfcOPJha
XtV1BZNV6JPXmF7MbSXH4XhF91hEEHc8llouRfsPbyGrcar7ROn0ZBA5AWdH
wjoq3wSSNTDLNRe/LQrknWgPPfKpZ2EzORHZvW/9xq9wJ6HvYdr+zuEAcjLs
h4y/m0f9ySmoqn4i6vdxa/Fh+4pJXca9C+pHwcp3DX7kVLQs1rYt3t5EToOh
b9D1wg3u3TggG+gJzuFOh6LO76PltC9Zh4aJsrSU795kONsMzCgsh+0lCuoZ
0Me2i8/PeVLPgF3V0ThUt5F6JlYV482/Er2oZ+L6jKd9MJHmWRZU9909kq7J
qGchXCzWCtYN1LMxNDErPA0hmyVmObBpf/zJjPOgniNZn4ui5KaxhTg36rko
b1XHul92p54HT7c755c6XajnwfG/u1IXJeslZvnO8+Z85/1YgfN55gIYb6Xq
7g0w6oWS+xVK1hdhrz5h+EzUus7Ri+i+qw6zYpr/Sr0YmrbPaxmTduolkl5C
+zL2F8w371k=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlQ1MlVUYx4+ASuFVJL2gUFzQHCmRQCAgxJ/vT/m4fF0uXrhchrmBkQEz
RMfbJo5NYmDh3DRHEmFCNGwmBLjXMQIq1BLJrTZxOLcyE8spl92k2n3O2jnv
dnf32+95nnOe9z3P+/pYqvTlDoyx0//+/vvnlzbv4lB/hS/sNB/9qOlvk587
ZwbrVNUVnxEfYmdcj9N8v2UPZ1eMjD6+2a/hvA7htcvuRPbriD1w0nZbsWVy
9kKd8+n2CJs3sQ7jFTnXHeI5+2Ihd9+ZU4dfIt6MTfOzl6d/eZF4C5znj73c
7MPZD/dvdRpijnsRb8W1yemuKdWT2B8Nry79nuLMOQDN67dvfjtgI/F2nNQ+
mCjt3kAciD87C1XvIM5B6J021P1s8CAOxgV2Vjnmyvl17PvEsvLoW+7EIQj9
TG9KrdcSh2Jy+khj7eR64h3oaq9eOwjOYciodq0/MbaOOByddxstcXs4R+DN
docaTTDnnehfaPnVA5wj4ebiPnxv+AXiKCRE3T10bdGN+A30JT3UH1jFfTS6
IoInuj/iHnD1D/S8urTWzgrg4vj5wd8+IGYx0FS63W/a70o+BnWvjFvLM4lZ
LJZY9pK5Zg35WNQOZUWGLawmH4cCY1DfO77cx2FG07TXmqEhH4+4XFvo8kSK
V+LxhWfvpR/TKJ4lSD4BX823vrZxitdPlNZPlHwSeiJ99/qNcp+EkfGIP/zm
VpFPhnFbW/LVd13IJ2PsrzU5xv3cp0g+RfKpOBczOvbNBupHSZXqp8FBt3XR
pYdYScMPAzcf31qgeiwdFRMDl28M8vrpeKIZfM8WwvN3YVPqiRnjuefJS8wy
YPU/fqi78jnyGQh+/8HTGJWYZYqsZIrxLAttc9X1sU9X2hlZONpWEVHvTaxk
wf9LpxWhLcSq5Fm2yMgW6ynZ8E7eFa49v5zys3GwYfFKxfkVlK8XPfTIbg7c
5tToRPl6HD5zY1h7x5Hy9dL6OWI95KB76Cftt15UT8nBw/DFZ7EB5FWJWa7U
f67Uf67Uv8QsD/19VR8GFDlTfp5YX8kT96fmif2xfKTvaLg0F0D9IV/af74Y
r+ZL969A9CgQ76dSINZTJc8MUr5B7E8xiP2pBkyMRR2o+ZqYFUr3rxCtRxwH
bpv4eS0U50ctlM6/UWQYURnbOrL6Yz7vRnGeVKM0f0XivKBIjFeK4P1s6ruw
edqPWoRTMy7WT0P4+rvF+cVuZPS2JJRf5PMseVViZhLrwyT1bxLnTzVJ57dY
PN8opvfvMsovFs+HKnlWIp0fiZUS2L/vDpRfIj1/s/j8dGZpns3i+8IsecUs
9tchedWM6p6d0RfOMjvPmul9aIu2r19K34clO+tKqZ7Vziilfh/Z2SyxIsV3
SPVUiWdLxfvDLCLrLGI8LOJ+zRaa7ye0vsQdnO/R+hZxv7MSszIxXlcmepTR
Puky/8//AHkliVw=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0FtIk3EYx/G3iOFhlFs7paZTWrQaQ93MMud+O7iDSMgsbLJqLZKaQrkL
h2AwOiCEOoJWkUWZzbrQQGhKtYiEQLNYBVl40UUb5sBKgnCJswP9nwt74eXl
w/f9H3iKPCcdx9ZyHFf+5/37pUeyP/J4pKUY/7Sgn/c9sFmlZA7J8LCrf6yI
OQMv8xdzQg5yDqZEWXl9P+TMIpxuK7zVeJUsw7vGg94yCzkfgoWOWO/rQmY5
NhTUh6sF5GJoDx05WmIvYN4C/nLu6Jfmzcxb8bPNftwcyWfehvPdDZNTz/KY
t+O9jtfesJzLrELd08zRQSdZjaxfGu/8x03MJRC27JvhfZUxl0JiiLcOtZPL
MGybmfWtIWtwYlqhzr4oZdZivDsoGCgml+N6TGHnXZAw78SKb1GR+VzMXAF5
XBwacJJ3/efd8OxV3lvhkytxbt3ki4wrIuY9iOibU52t5Cq4PJ/iqrmNzDp8
Vn7vKK0nVyNcqZm4e0PIrMeZhKcnMSRgBuLRdGBHBesBoKqsrmu9m7ph9f8B
AyxPkl68oW5EqeXaw9pXtN6I/jsT4uA0nWeC8/C4rekAu0/ABGG2NDobpfuZ
4Rf3ccFB6mYY1e5LPjf1GiQv+wzDeuo1cJ3VNH2Yo/0tqNElOmNLdL4FY6cG
nWoxrbeunkfAivvWbw4/n7oNCa+yMt1F3YaQIu3kblK3YyTVm5SBzTtgx1LK
dNuvovnXQvu2x694JMJv4sXMbA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2EcBvCDSmWauuk2da68kdO0cplaanu8zTmnbpMuRh9E2AdRKGsa
huVBoyWJ4bI+CAmWFKRWGhHqgmWUSVipMEtKqcQUDa/ZvJAVvS+xc+Bw+PGc
55w/f96A/JM6vQPDMOo/998nvYSHH3e3Fwbin+bkM+8vzQ84UzNYylkeqn4U
QLwFxVJN0AcdtQfajDxB46w/sRcmEsfWJFXU3tjVLjJcCKH2g6713cJo3Q5i
f/THVcsWvm8nDkSBY4FeH0EdjDdr+SNTtRLinSh2fGgLHvEjlsJmmLoRHUQd
BvflLuVcoZg4HMMJm0pz1n2Jd8PBuSq2Wkq9FyvhpvK7RT7EkQi8giPD172J
ZShr19qk50TE+3CuYvVZ4T0hcRSeKxcbA8wC4v0YPVZrrPnpRRyNiG9idqsT
dQwiFQ2dqn4+cSwG5SYn0Sce8QHwJy09LTrqg+izBi+tuVLHQdKybj0RQx3P
cQKnfwjdvvU3O2c9iOUQe3+drDNRA7kNbU2CcGIW0BSFvf7hQ/NETH8Mubin
kuaJyFS8fDGeQPMke7NJaO67XepicCN5Mh6IW58MZriTPBnbivjTl4tpPwUb
jHYjz0DzFLh69pw9NUXMpNq/z3LMKLD4qyu3cjPNFfbzMmmc+dM48yk5fSXK
QntX9Nm0n44zLXHyjls0T0dJaP01UwfNVfb7ZFW4E6QaieqheQZnvxmc/ak5
fTVn/kzwZryEc0IyL5uJkm5NfKyNzp9lvy82C0ePy+6fDqT7y+b8PxsRPOl8
wwD9vsb+fEFjf15YDeJlaqNbHsktHDNaRHaJQ76UkPMMLZ72GsdsFcSsFk3N
rwRXrcQWLXKs1TWDEk/S1yE1Ybz87Srt68B3EZknzCRndTjfOGQWfia2/Pdv
u+Y1RA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd019Ik1EYx/E3t5y5tGG61My5kTHmGv7JpXP6/jY3nU4HiiKuBIvChheF
UYEiLdAg0MiUJIMKhUQlo5YUSOlSCC2LbuyiCyVJUGithMotZ8Wec/MeOBw+
fM/DuTrKk2erT0dwHFf0b/8/2ZLXTkw+blYhLD9f35vgvBXDzKEmNi4xyaMk
R8H1vt1ndDLLcGp5e9a1lUaOR0Zm/e/uu8yJ6JI0BR8ZmFOwPr0gqRpRkNMw
B2twZiOVrIKvs3/ArWI+CKNGlHzMeYB8CDUr47q1oRSyGm+Xn37iY5k1CLjf
3TfU7Sdrsbm2FbQsJ5N18HoGZ0Ua5kz4JLO990qSyFnITNsMFQwnkrPxJeLZ
xZuf95Fz4FpM10l7mI9AOzFU+2dSTs6FfqS6obyNWQ/9D6favpRAPopgbBPv
tTLnoUM8Nx/VH0/Ox4DjSmAlmtkAs66xr6VxL7kAt6eGL9Vq48hGnFvceHVC
yVyIl8fTvalS5iIoTU3XLoRkZB5jRtUZ9cweMnC4UFcztRoTtht48drgU6/s
pm6CIrTwJs8fTd2EhWT/ep+MzJmR0/31l2l6F3Uz7ixKNx/kSqkXw+/5sNWe
wHoxbnSIni81sHkLtB5xpP66hLoFrZcD3ubRSOpWKGyV+fLRndStgl6C4cmP
8vkU1gXmSlHVlZUh7hRTLxV0G672NBvaFOx9m6CXCebLIBU9bF3v3UG9HOfH
Cvgngxz1ckG3I/y/IqjbUefMHm9RbfPhXkH3v4ftrsC3/EDIrPtJvVLQBeYc
gu6g+VX+L/JW+Qk=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n8s1GEcwPFvKAqRH5cf1zk3IXFycYdz7nPnt7vjUKGNydZm02Iu3abM
zTS1SYo6K6utrYRxk8ROW0mnVpO4UZmxaFeoHFqh3Prh8/zBsz179tr7+Tx/
PZ65BanHzSiKivm7/51k0Q539rTns2BdRuEgI1Lau5OYgnB1MPvbA0+0Fewb
Z3jdSSO2h9xb3hrpIhPtBKPCbKNzLbELuE5du5QdQUwHdZpD4NURDzQTBjQ1
niUBxCxosqtnNJQx0F4gym4eztPvQXsDp6utlcUj9oWvRWtqm4d0tB80fcks
iVx0R/uDs0YxeFpBzIaZE7TQAoMb+gDUVJh3T2YRBwFfS7UKTK5oDvxqnn1T
eZb4IOif083HLImDwbFQ0nuy1AUdAov11qaq+d1oLuRkHllR5xPzgPFsYnlY
RhwKS6v9uvExGjoMuE2pWYlniMPhOrPTzvDJGc2HybnG4vQG4giYyKiurPrp
hBZA8PBF5V4tcSR4KbfUcucd0UJ4fSxjYek9MYCYnVNXlINWAUh5ZV3TbNJF
IOlYSEzhkS6CIK27z1SxA3YxKNo1F+Qlu7CLYW7cpyKw3B57FLi7TH++fAWt
igJZbL/uo4D0aLBxfKosnLHDHg0tEaw83z40FQPpRzltRSzSYyBAwD702GCL
PRZGbc/nrSShVbFwT9Sn63clPQ5sizh8fTnpcTDUPfL93bI19ngYcDPO1tnv
wB4PHqaBV6FGNJWw0aoEuDFqvXI3hMwn4v8hPRGMHUNrpc7bsUvghU6gPKW1
wi4B/w6LbdxqS+xSSKkK2m9xzgK7FEpv6h/RPphjl23qMmjseUt7Sd+KPQk8
4mVhtGa0apOpZJgPWzWJ2duwJ298j5JvNMhB0cIX3r9N4X05zv8Q/vcTOZgx
/VatW36vm0rBbhD+ASX7FDs=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0GtIk1Ecx/HTwnINc5vukpems6Iyhs1Lm5ft52U6nYpaIShRSII4QojF
LCHHwAhpWG10W5KvhpgJSkVOCMuGQgxKYoGvRy+G4fJFshlasf954R54ePjw
Ped/Dk9+z0BHr4AxVvHv/f/lj/zim4VZqxoJRY1Li2GxWMnNILKYPlyezyen
YvDl45tzzdxiCJXtG9HNPHImPNll598/5VYioyM2rTVw5yDwZfTtyJKKnIdt
W+BqXMqthvNad5+k/Sj5GA4MPvt2wZ1LPoExrTZX9T2HfBL968P2zXbu0xh/
fX/3ijebfAYrRQu2e8EssgbLbZOrtw3cRcDzyNrM/BHyWWxJ9fI8FbcWlf7Q
yNdRJbkYwpqVSKuVuwQyRWlh0KkglyLFlls4/E5OLsNEuiDrj4n7HARPXmyb
HTKyDrp+o9al4NajZNVlP+7PJJfDudx5Kd7MXQG7zMvGfBnkSnxqW/Q6/FJy
FXrHfYKhCQnZAGe4xxWe5jbCV9C0VvJRTAZunPK4H86RHUBnl3bmujqdejUk
65nyqPww9WqE0u72xVrTqNegoOlRqGvyEPUks1qsBKrsNn8q9VqozC16+VQK
9TrceWAtH1IdpF6H2ZkBj6ab1jMTVDvBz7oon29CMCsa8Yj5/HoUu35uVS8K
qdcnnd8Ab0gU85WKqDfsPY+ZIdr/6lbEvY96klkjzY8ZE72R/s9uwqwJG/r4
To3mB3Xu39QtNO8Xdcve9aw5aX+SWQvdg7G/2hTodQ==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1EYB/Bpd03T5Wzz1ra8LDHNad4223+bm5uXOW9JtiALYZRhmCaV
o+WlBBEECTEEyUyrlaGmUqIul4GFmFQjQoIuqOSHhmbY8FLhOR/cCy8vP/7n
OTznOS/vdHFWoTODwVD+e/9/6eOd2zfYfY6PDdkkNSeXKn94UzPAs9+saeng
Ee+E/NhMm0pF7YFiYXzUgy9cYi/0dUXmcwzUbFydMHdbBNR+aBnrcyvp3E/M
RULFurp9NoCYD8/m4LfzIupApPbcqPOr8ycORjFrK9s65EcsQP0ZCXv1qy9x
KMoXpGnZIuowZN9SNHUZfIjDMZzB/Dz4kEN8GLbeqVUDizoSVSzuteZaNrEQ
ZfaQJ+Ov9xFHYcDsktw6700cjZ/x9jVZOPURVFVbppvMLOIYfBAUFXQMUMdi
6tHkYuB56jjENL7Uq5nU8TCckIif5lAn4Lbmuv2bixexCLMHFy5HavcSi3G2
dLnfKY9JnIgL1sXRAh71UTDnzKOmLE9iCeanQ6ojKj2IgX5bQ4TPhPuGjQ5m
SFE2qBXHLdNcCrcSoehdpRvJZbC61er/aIiNMhxKDM8ZmaG5HHn5wq4S/h6S
y9E+fveSayndP2nzemPS5v0YCodcAWduqN3VtJvkStyXWsZecWiudOgvGUWy
hiH3O7T/ZKwzMtdPlZJ+GCp0HEj5FD1K5mFUwd+0YtXF0nmpN8/LqIZJzNcL
LLQ+xWE+KZDnrMRsU9LzpUJbFPpmiUPrU7G49vx45Q46/zRcNIkkPW00T3O4
n3RI8n7pNL6kH2M63hf+3iV4RvvTYFgX9CLAldy3UeNw/xloHukszw2jeQa2
5zr12iw016Ku/l7Q4y3kf4IWjYW2Rl0nXa+Frioq/+McsVkLReL3ikk7rc9E
94JP6xU9rc+EfVneVh7mhb885hXi
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0m1IE0Acx/HDgYq6svnQ2tR05UoxU5e12XQ/p5vOhzWkDNNCykEa9jxW
kjLD0ApLmg+FBIJYRNpQ0lrzRQRWEoZQSa/qRRA9u95YrtUq9r8X28FxfPje
wR1cyv4jVeYQxlj+v/l/5SN+16Rr/JAMfrk1kvqw6eoYboa+gXFP1HQKORz1
olbdhn3c0XjSYFAdC+WOhddYvallNJksxunGftNgLXcC5rvEFSyMOxnulgu/
jAfWkmWocRYX7LiaRF6P0KylmTMfEslyiE/lpToU3BsR0fa4KXE4gZyOsET5
3PnfUnIGFuyCifkq7ky01+vvDRyWkLMQ4VM0fXmzhpyNoWsqeWcddw5GJmaG
u16IyQoUfbvV19zAvQV5n9/ZHP2rybmokSmHXldzb4WpaknqOBtP3obZlx3n
LLNxZCVaazXquzu5VRCNvWp0t8WS85DkPDHV+SyGvB3WuEF2+Qa3Ghe7R1LH
BNz5sJvd9rqbInIBojOypc99q8gapBnXxeqauQGXpPe6czHabxtgSeu1X5kg
s0JExTyyHv24knohLC6TWvlzBXUtptw9myVzZJsWu/fk3Dkuo/2sCMbRSzrz
pJB6ERaEXQeXjWRWjCWhs92bG0W9GD0dgvtv90ZQ1+HpTL715INw6josqjx/
tJmh1PWBtunh/88h1EsQkpzuibzt1fh7CRTdX38UPlz2m5XSfX3US4O6IdA2
Q+B+VhbUyxApGGv5ZP9OvTzQtnK673vqFUE9yKwyqFcGnTfSOxn7C+FQ9O0=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlX1MlVUcx58AXwguEMHlBsSrhgkxLwrIW/cLyAV5k/cLFy73RmuYsJHi
XaUxHlMRXVEoc5rmqjV0vAbGAFH3YLPIRk2Y5EzmxLXS1iBjCIRQ7f7OH+fc
7dndZ9/zO7+X55zvE1hRk/eGnSRJh/57/v9nP3Vh31BPVRBsNKOzTt6aqnZn
LCH4q1emD/YFEq+F3nDMtaKCsRscR1ytBx8HEHugdzJ18a3PGGvgWK79fn0K
Y19ooiLrboz7EwegJOT9xV+dGQdh+OTw0OEEP+J1ONWfaspSXiR+CQ2/m+Mi
VnyJN6Axes4tK5TxRjh3hHSE1vgQh+H1nM6BuTZv4nC0Xrvy7a6RF4g3wedo
bPfddYy1uF3ZUtPVqSGOQPOD2v1JT7yIN0M1e/ZhxlnGW2D8SfXm6ftq4kic
s164symIcRT+canUDad4EkcjbteeU5avPYi3QmO+PNakZxyD315+/K4253ni
WGj1nwymj7oTx2HuWJeXafY54njER2QecbEwTkBgYuVR67Ib8avo9unoH8tw
JdbBLmDjolO7MzFwZsJpoTXSycYyEJx+csJ44VnSE7H5wz+fJCqOpCfSPNaQ
noSerpqW8NK1pCcJejLqzo1fVt+3Jz0Zte1xut4vJNK3wXb+7EjfhtwPtKEO
hx1ITxHiU5AZXd//IJxY0sM/LStG3baKdD1mLt58WudJ9Uqp+PiQ/cA9E/Uj
CyylwRjanPbjO6z/NFSNDFwdHySWtgv6diyEHX/vfDXbPx0NzVWx+/2pXzmd
r0fKEOrPEPrPhMEY0bUnaEVn0zNp3gs2lrJ4lrOE+GxhftnCfHbg/NDP6hu+
bD474GTfue/RiWdIz+H3Qw6mYxaXk8LnKF8OnZclGysCS7n8euTyuizoSq6Q
P4/vH3lCfB7fv5In9J9P+/1F8flC/flC/fl8PqlA6L+Ar08u4OenFAjvt5Cf
PwqF9ymwIqyXioT4Iv78y0XYV784XNW2mvILLBkQdtFhdVQTnT8YhPtgEOo3
8OdVKsao98yjFje6DyjGnGrwwFIk+YNcjJsDt2Zvz9P5V4oFfyjh7wtKeF0u
4e+jUsLnk4wYuZ7w9t5L5B8wCn5i5PdTjLj+t2u+cTfzr1Lez1Aq3NdSfr1S
Cv/l0R+2zrD8ZTyjjN9PLsOEqnHnQraK4suQXLAUtUrvQvEmtMcH7dzwDfkr
TFiRclcse4llE1qD0+9suUZ+rJigqnb/o3E38+dy3r9RjiHvlk8Hp0mXy3G1
bP2wnxP5v1KOMd1xB69J5vdmXPnuyL35etJhxudfjnh+NEEsmzF1JirylxMs
3gztJZ+QKSv7nlj49QEWLLxW+/RAH31/YEHPfNNDDej7ZLGgt7vBT3PXA/8C
JnAnXw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H1ME3cYB/ALG4IFlDpAoG5SRLGs01GgVinjWyotlLe+d4DGsoWYCJnC
ZI6wjYO4bMxMI7hpRDGjC4ogOhcjotsusjqRqAED2YbGBF/mpjgmOl4kZFv2
/P7oXdJcPnnu29/97rnn5G9ttZb6cRzn/vf335kdEY4z578pi8X/Gk+fTfXT
/ylh5iCVTD/WtsvJgajdniUkFTCHYjE3ONTyJIYchujWE/17jjBH4tloca8j
j3kJBta9vyH59lJyDFxFqq7KWOZYfNhq+HZPwyvkOMxVfKRaNPIyeQUGd+V/
pohnXgmPN+yxR7OEnABPeWjJvL0yshKSrffqay9Hk1ehrnpsh1zG/DquydN0
RkcUOREjRzZXNHREklXQeGtrWnoWk5PgbGtWuYKZk6Fut2401USQU/AFn+aR
ZjCr0Zs10SK/EE5eg50v9l0J3B9G1qBmqDqEczOvxdltbYWrwl8ir0Ox8QfJ
zKlF5FSMNqtTRpqYtbi/OjbpHYWUnAZZ5J0HextDyW/gNenKvw4OMKdDb59V
+xsWkIGq82atZorMA8d0vd5LUSFU1+GkrPPsYM5CquvwdZ/nvaDtLJ8B78RC
W1FFMNUzUHa5+/sb54KorsdA99DTn6fIvB5Xo8f/2Bcqofp6LDN9OVx0jMyv
R9LnY5M6YT7VM32v5zMxrWz84Gg5qxtE6xvgF5MwE9RB5oz4O+Rc3WwKqxt9
r+eyROtnYenc1X7NOLu/bFE+G9JHYRHjEWz/Jt/98ibf/XI5onyO6PnmIr9z
d2bpGTKfK3q+eTCXJ/Q/i6L+8XloW2b6Nfki62c+8gyXvHfTWD0f2e1dx5cf
on5xBTRfrH8Fovs3o1rx03RpAeVhxsRcT2F9APs/s2//BbPvepwFu1SlN5vd
LG8R5S0oPHjiq3AlWbCgbzju6fNg9r5aUaXY19R4muWteHgzfufqepa34t2O
1PTTrSxvFb3vNmhVuZ8scJNhg7ti4/MrD8i8DYbvft+CAbJgw7bhiYslcjY/
dkzl3AusyyXDjsQeWfxoFZm340ez0Mz3kAU7flM8qU40s/l0QBEXcHfSSIYD
ZW8GWN7eT+YdmJnSt+5Q0nwLDkRuujC428Dm3YkNgdH8gbVkOHG4W1vc1EXm
nRBezRjrrGR5J9SP7t/qDGDfExduPzxa5TpEhgtzlZPL53vJvAt65dD1Fz4m
Cy44fvFv+LQmHP8AVCaHCg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtMU1ccB/CLbpTxUJgWQUAestmwShSFWrT2W6BYS8FCKX1EIs6RLCvJ
puA6p8arczIdcQONi7LodFtBGSOQbfLw0eFAwOjmiB1zU8E6h5sRFpyWythc
+J0/epvcNJ987+93Ts6558S//HpB6TSO42xPn///2S/c+HVHsy0BUxpVvtA3
WMIHMnM46Ja8m1YXTw7A4IXaqt065lBEHRtKXfRnHHk2Pt5ivf15LXMEJvbt
Kv43izkaK482nTo7EkuOg1wVeHPAzJyAxJDg5J8d88iJKL3o1zsvkPlFuELe
e3U8L4YswVdXhr79YXs0OQktsrCYX/yZpVBvyFT7G6PIyThpE0/Wn5xLXoTq
t35fdzySeTEeiL47cCw7kpyCoPdlWxrPRZCXYLN3QVNv3xzyUoztUZvVKcyp
6C/7ta3nlXByGq5JytY7TovJMtw076+sejybvAzNnv33IsAsh80syt/w0Sxy
OtSKO9u+9z5PXo6p/WJeIcgVWNweteD2ZuaVOHy+zm6UMivhPvMP/5KMGeh1
JT58Ehw2ZR5wzNdeX9oZSrkKURHu4eoaMq+C5UjjcbGU5Rn4rPfTN4MqZlCe
gfnaQy5rfSDlmRiX1myrK3uO8kx8uHt6661ilmdhT7UtfWusiPIs1HX8FN4X
/Szlamw/2n8mfGg65WroZDtOu5PJXDZG5N7JjGR/yrMF9avQ06WwV7QHUC4w
pxGMr/Htx60WjL8asZpcefgp1l/ra16Lanf51ozH1I/L8Z0PnyMYX4fYycuX
lo3SevA6XG299nDAE0R5LqbFJXmDGoIpz4XJmvLlpoSZlOdhbLLdskvE9icP
Zy+mP5C46X1uDWw9ref626gfv8a3H6fHo5C2nROpZAjM69E1NtNg3Uh26lGv
utDVHRlC9fmC+nzB95CPWlfQuCOVxnfm4/Lc0T8OhrL9L/DNUSCYr8BOwfuc
wXe9YBDUG7BQkVx4/i7N12mAvizp0t+R7PstxMIwyV9HrpJRiPKG5cqWE2w9
C33X1ynIOSNys7u77ihYvRHyKx2fdA+yeiN+VNY8M+cGnS+nEZ6c3wJ26tj5
K0J5c9Ne/duUowgrUnSVM0rYeSxCTMOEa62M1RehZGPxk75hMmfyvQ9gerr/
lbc8O8i8CfdnWUof7SU7TYLxzb6GGW+4xjrXx7N6M16r8HzjZ2L1Zqx9Z4l1
YJjVW3Dv0CZVo5LuK1hgWdepsZrJvAV2cS33gYPstCDR7ncgbYTdb1ZotFXX
Wyx0/8EKryfzhF1K5q1Iu3/3xhciMf4DJF/E4Q==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XlI02Ecx/FfeTctM13zaroudWN55LzbR+fmNZ2FkVkklZVk0SUFpfXL
dJSUECsJ0v4oy6vEA7HSIrqgxKMEJbDDsvLoWATJ5lXh9/lDH/jx8OL9fZ7f
H4/3jgMbds3nOE717/u/syXc2NzakCPBjIzKfqnZUGDHzGG7/kxhVY032Rb7
6urtrXXMjpC8kcq7v3mRnVH5vqp2wsAsQmP+yPh0KLMHxpqK/A1tYrIXxnOf
ZZmdmCWQ55W969q9jLwC/Qp7u7f3PcmrYHje0iK1YfZBw6HPo7c3e5D9cC79
wdbyTneyDI/17hlp6cxymIYnx2M/uJH9MbWleI9vPXMAJMeGKvoCmQOhvQu1
7xVXchCmS+/t/DggIq+F6kf15f1ZzMGo3lsukjUvJSvA2wad/D0oJIfgdHl3
putB5lC0m4eK9TddyGGo8+yR+H11JodDlNn2ukTDHIFtZzXDUU+XkCOhjhrM
6zI7kaMw857M6+AoC3DvnF5MViI3u/KhTsg6ILC4c3zEQJ0HjtRGKBuvO1KP
xmj/6sI1BWQ+GpsyAusOSxZRj0FtpCTb5wmZj5k9z6mQUF1Xs7KMdRUqXtw4
KshdSD0WqrQJhZWGzMei1+FstinFgboaV3sFplvBAupqLE8s7c2oWkBdA/FU
R3uokcxr0OFmHLnkyHrcnB4353w8jE2vJvNd7KjHQxyfHCassaKegPxrPW3C
AQvqCahs7RO+9GA9EdqQUy2f5Kwnzp7nkvAzzDwVI7emngRZk6W1osSGuhb6
iznhJ8RkXjt7nkuecz4Z688HSC2LLKmn0PvNo56CoAvfx6IfmZQzXUf914x5
Hd33h3rq7I5U6l9oPpX+w3F/Ad7vErQ=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/Fna7oNu5oua8u5ZWFq81Zzumw/53Rzc97QIi2CwIj2QkrB
aKQrMQjMiIwoIsIgRW2yTARFMDJIqRca3ZBuFKJQpEQJ3rqw/0Oc88Dh8Dnf
c/7P8+bojlaXVkkZY/a/1787X6ryvsGAR4+gZi1rR7fr7odxM/Tcnq5NCujI
CpyOUBgryrjX40Vth8S/FEOOgKXz1eDkVe4o6GdM3iYntwZmzXJ941stOQbe
kYSsqCJuPbRtYe7JQDQ5FuHttjm2tJW8A6UDX23bDNxxOF++/15lkYYcD7P/
4Jtd19TkRPSEPM+fDuE2QKpsNF2M20JORsuNl946x2ZyCqb0d39W3Yoip+Jc
zcOkZ07uNDRnrhzLqdtE3g1F/WX12BHuPfAYFj9MjKrIRihXWpVmI3c6Fk/e
aXAfjySboJO9+/hjKYKcgeTDje1DHdyZkEfLykYmNpLN2Bkr/zJv596L0HJJ
7+zjcHIWrn9qlryf496HvKGZExjfQLbgkLztpjqXG+hRd/dPuNYF7ROZZaOw
uyW3qm8N9WxIY+IXwrpWU7fi6ZOsutoBBXUrZnvHl89GKqnnIOCvbjVU8p6D
tEvf5rOHebfhe8bCitUQSt2GMw0LjzydZJaLC1c8mV6tnLrILE+4ny9P1O2i
+XYk9spCjS28O0TdgfbB16oxTQj1fOF5fPkI/i9S6k4UpDf0fzasou6E1uHO
UHXy710oaU5JkDXJqLuE77MC4TyfyMyNAxWp/lP635Zgd6Omy2x50MaoF9L5
f1EvpOd8FQntE5kVC41imjdF80QeFpmVCI0S0X7//Qe3nAeT
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03lIk2EcB/C3tCZdulLzmGszjyyxZodmml815zXntneSZpQFVlRUlAat
a0kG0gGxDjM7KOnwKisx84+WR1D5T/4xKo0i7SDFjpUtOqzo9/tje2G8fPg+
3+3h2e9Rrt5sKBotCELu38+/Nz++uU2tjRuC8V8fE3OH7dFdnmwBltiCS0P1
SrIHng5LTKp0thfkllHZ1+0Ksjfgvu2+tJrthwGDhyNMw5YhziPDohqYRlYg
SpkwpAhnB2N3z4vBtflycghuixfc7h4MIofBMq965aMOGXkGbsRIg3rGsmei
y/Rw1YWpgeRIdC3GlfmnA8hRKCs/myBTsudAm7dT9cnmT1bB3/NY3PmF7Gi0
X75VFVPpR56LKmni2Mffp5LnQTw10qeTsecjtajv5qEKX/ICxIVdf1J3mB2D
r81lLcPPfMix2Hx4h/8UC3shlO7PX9p/epPjoN3mtfNEJ3sRZD158DrKjodp
x6y3tlB2ApavftUX+W4KeTEkcndjRzc7EZqYvc19UWxAtJUf6g4im4EtNnvb
KuVkypPwwBby5ccEKeVJGBH0I4XFnpQno/rBxe3jiydRngxt3ZHUoqaJlKcg
xfhzwRg15ynO64Ul0G2c+eirvxflS5Ctvt/Zn0AWUl2+PxXSQW/fj77cV7vk
auffE9JQ0qqLj3Vwnoaly6Ibtgbz/tORcbWhJrSKbE7HtcC65u4szjNwMLqo
93Qh7y/DZX+ZLnmmy/lkwf77Tn6phPMsDPSG759dyn0NlElry0t+c65Ba8Cx
My0fOM/G5HfWtloDn3823swOnrspgixoMd6t3vTewrnWeb2Q49LPwbiLjhXq
Ts51cFRL9vQn0f+Nv8567bFPQzbroLoTGP6qhGzVISJE0v8tjedH7zw/0CN/
ZVv6sjyeJ73zeqsejZ8DzpnWcd+A46G/8oVz3Dcg+Z4onzWN5tlswJEtJTUF
ItlqQFPiGseujTzvovN9gIhF67dWFN7ivogzt+MLLA3cF3Hj2gG5Xy/3jShu
aVO0Z9L9gxGvx5wYbj5JNhtRKx3yC7tJthpRqWjyfPOW72suJPemV0UO+uAP
tspP2A==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU3EYBvCTLbQ028zpcivdUlO30tldrT3TOe/X5SVzYaUlKKiVmRk4
E6GoMF0hTiEvHxZ4gSYqmlqhIl2klCgiJFApG1EGUZaVFf3fD3bgcPjxnIdz
zvse6dGC5BwbjuPUf86/VzpcUrrv3M6T4Z/mVf0DfXVmPpnDqq6WNoFFymwH
c0N7nTyGzMfwFMqm33kwO0P3oXqF10WyCLID8qjhnWQJGpozPmdMujN7YDZ7
qkCjJMvA/1LeW164idkT7jX61J7RjczeWHwke3bIk+yDAiFP9HxQwuyHsgqf
GqsXWYHqtdZ6j1Qx8zbcfOLgaJx0Yw7A7I2Ryjl/shK9XVVBR3o2MAfirEFQ
VzIhYt4OF/VMfvsZ8g40yxolhRZX5p3QKe24lzryLkibKpzV4y7MuyGz2JlG
48h78Him9Sf8yHuxWNRUHpcrZA7Cj1ae9O1TZ+ZgRFpfDDleJocg6YpSzqsi
78OFsTT991jyfnSrji+czyerkJdum3Ssbj0z8KBUE5LtzWwARhLvNRj6nViu
hjFn3phpZjaooewXb5kupjwUWUX6xYdzApaHQqo+can4F5/lYdgq8PlkmmA2
hCHTtsUkDmf3cxqIRTNzNbWUa5CWEdh5UraO5eFY4pKWsk4zG8LRM3/N323c
keVaHDR1NAsV1Nei1HfsW04CPT8CbSGyXJ9h6v9nLhKn2oJVlhbqR6LY97qx
1kL9KNiv7DhnNdL3RWFN68Jh7Si9f/RyG6IxqarluU5RHoP6u+aSFAXNLwZX
u1bLh17T/GLRGfExucSB5h+7fN5cHJRaU1/0OPXj4GTvOvBmgPYXv3zfhnhI
XqWDX0P7TkCAvtI8eIvyBPQXKr7qbOj/SoTt/c2NivdC/AZ+1fqZ
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ltIk2Ecx/EnFRVHZZ7Lmfouwzwsp3na1P2cuukOmpWIiQVFIBipOUs0
cFjphaaYhYiFYVI6S9IQL7xIjegwlaiLqO4KvSgtjShczQ7s/1zsfeHl5cP3
eXj+PLyRJ6oPnXJjjOHf+//Ln6CSyenxKgFOram/q74d1HpyM9QOLUkTb0aS
vWExtS7Uq7h9sR7ad8F/KYIcgBfHw4qMrdwhKBtsCuoN5Zaig1kTnl0KJ0fg
yfDV7tKXu8kC5ipk8e+U3HvwRfo2P6QmjLwXtqWRk44xKTka02vmXpk7dwwa
YgLqJotDyXGYz8Jwcv8ushwPNvw6hdWd5ARcvDfnX3KMW4GW06vtd9+EkBNR
ORgc1RbInYSu177t8/pg8gFMzfjoBj4HkZNhto8ICiV3CrxmZTfiVgLJqVjp
XJxQv+JOw6/aW82mSu50xHZpFzW2ALISnTX11vLD3Cq0PC2tsBu5M3A9ylHG
BvzJmTgf2M+67nBnwfBwXV+cyq3Gh/6U5Pc9fmQg19LgULTtcNoCLO8Xks7s
I7NsjGYIldGPt1PPxtDz2+ck5m3UNYjPlB95tLyVugbhmwu2tDUf6jkYH6u+
Ji/3pp6D4g5FrMdlD+q5aO2uUjaFe1HPRWOzfbbK6kk9T9Tz4Pxf3ahrIXG/
3/ipZ13t7Fp8TbdvauQ/nGY6uEXE2CWjv6nrXNezfNF+kVmBqBcg6crqz+yZ
Dep61/MselE3oG5UpZ4YZDS/QTS/EaVHE8fOCn9ovxHG1Oapj3J36iY6fwvt
N4l6oet9Wgpd17Mi0fxFNO+y+i9g7wBL
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU1EAx/Gr/WE602UqPpZvp9YS3y1f+003nfOxpUk6TMOQJCuzNDU0
ho2kh00jxBeUlko+pzHUxGdUmpigYX8UBCYhYaEppJb2wHP+2C5cLh++5x7O
Pec6Z+YmZhkyDCP+d/9/0ss6WTvYk+OCXa0IshKDNKUsaga16aUzgW3OxHvx
Z2K1iqugZuOc4QcPjQG1JYq5xQaaZidiG1yW+Xh9iKXmQCh61R6+7EjshI/a
ietn+NQuMC4sqbFVORC7QaIUh2u3DxJz8exN+8b9GGpPmN6oru4s5hAfggfX
MUn1yJ6YB9XCkvzSqh2xN3I4uQE1IdQ+cFe/i9rMsyX2xd1kE8lstw2xH3qZ
JuUdNrU/prwuaji/rYkDYDTm2sBbtiIOxNTW0u2bzdRByB8Yd3ohpT6KFIma
vTBiScxHxntt+lwR9THwVu519akPEAcjNWNcokihDkGhVT2jbqEORc8Pu4fX
sqnD4BtVNyCdtiAOx3Ca+5gDi1qA/OzWYZk1NRDqF1dudnr/rpWASFm07VtO
zAjhleBqKb5AuxBX2kMEvU1s0iN0rYzA+YjKIbNGM9IjMfQ6+LvnZ1PSI/Fy
zTxJkUfMiJAz0T88N8AiXYT6edZmSyAxI9a1UgzF4SrJ2yLao+C4Mz3FXzEh
PUp3PiZar0ejUrWn/9MpYkYC/4pvP4WjxqRLMG238vUBm/YYvR6jtz4pjoR5
nxj5so90KZ5MPr7KyqffH6trpZ6ZOMQ87WpzbzAnPQ5rO89Ty4zo/sYjta6z
0YpH9zce3fYdfbOxZDyTgIJBeSh/g86fAGfh2VsFO/R9GSbn3dZ/mdLzk+me
NyOH4OR6WoI9MeQoW8ysWOyg4/U8KkftSGthMo/+P8chDlssmdmywF/8hhOh

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz1tI02EYx/G1ObRN00ynbcsdjBXq1mY5N3Xbz23qZmQHljFxYVIQCB2U
Lkqqf2rSRWAmrMJJh4u1sgKDNTJMqKsKb4eXuZksKVwUhscO7HlvfOHh4cP3
uXlV7WePnOLzeLyKf/N/syc5Gn4z1qFGSkmb3yiYLspl5iHyVV/8K6wiZyAt
PPzn6nHmHHD74777a0pyHoqv1D4sGWEuRFObKuC1MsvxzlPJOV8ryErMfy6Y
DQuY1eBfnvEJDxWRd0I70AZ5YAdZg28S7xh/TU7ejWf3TH3fLcwlEPW/D0qH
ZOQyZA5YOiZiUrIOb5ujs5qV7WQ9+qwntNlPmA0Qlfb6NicLyeXoiU92XjvI
vBdetenBdHMBeR8WbGfcM0LmCgTXQgpNQEI24ovQvxi5k0+uhN7X+3gilEc2
oTVDyt01M5vR2h6LlyW2kavw4aKz5qSGuRqRc0GvLp+5BoZx2a7YhVyyBW3n
fSsfE1vJVsgK44nB2zlkG36uj3t70pmBV8lbe6RTW1LmgGMt5S861dnUa+Hw
rBqF9azXQmvReSbnsqjbEc26cXqpiczZwVeWLItHM6k7MBwVLwUrxNQdKG70
R1tCIupOKNanPpmSZM6J/sGOqm5FOvU6DMa7uu2/yVwdFK4DZslTIfV6HL5p
KE27nka9Hl2j1baXj3jUGyAWPL80P7SJesOG7sKCeXndrpuzpbqL7n+kzHNT
X6Tu3tAb6b+rtr+2Hcpv
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H1MTWEcB/Cn8lqkUlclSm+rlovKpVu3++3WreT2fm+3hRabMeVlaUve
OhvTGEJ3l2EabdVSxpBCnFiYZvPO+MMII295S0WR3d/zxzlnuzv77Pv8fufu
95znzFi2Nnu5PWNs2cjv/51fCtP5S2eK/GFTr/ZKaG0Qm8TNcH+ltWlz8wzy
OLweVVfWkc7tAo214aDujx/ZHW9KVcFuJ7g9sdsO+vcx3D7Q6JZut5z3Jfth
2NC4s2w0tz/6He4m9CVOJwciq6dmoHzXNHIwvt2Pqzbd8CGHoOXcmkMaL+4w
nI5rVbcunkoOR1VgxtGYKm+yEk4ej0qvWrzIs7GuYGtHoIF7DlqefI9yu+lJ
jkCtfY01SM0die879Hn6iCnkKFwQHZNrPijIc6EOPv20aQ+3Cru2Fkxp+uFB
nocti7Sx54zc8/HbeYW2Q88djdlLttW3N7iT1dj0qHwiK+SOwfS29S2VXZPJ
sXhvLYlv1nJr0H6z8kV/hRs5Dk4OzRt7ql3JWryd5R+5JpQbmOka8vXwPReb
BZlZPKZ6dr/bf4DnMjMdMovDun568VxmloCG+OudN7wmUp6AolutVx60OVGe
iIHwA5vri8dTLjPT41anpqz04jjK9djfvX6T7tdYypPgm5IWrWgcTXkSws+O
GqPay/NkbDn24LLipQPlyfgSPTisU46hPEVWn4KNFYMdRY08X4D6S08Ut314
vgCGeRUXupXUj6XC3i9s0OnkH60tT4U5P+JUif9fm9lCmr8d1cvMDPR/+qje
IKtPo/VfKU9D5J5Pv+LFAcrTpeuFdGk/liHrnyHtxzKlhsxCJtW/tVnMlD0/
S9ofMgtZ0vmIWbL5ZUvnj2zp/gjZOHNqrUW5iPZflK1nOdL9Ro7sfcqRvj9i
Du549/ZYXByp3gjf4Ttd83vJMCIg1fo4v4EsGEfOk/pzSPcEqjfC9aO7olfh
TPUmFOv2tTsfJ8MkOw8m1AWkPou6RhZNSBQ2DM2p5OcvF7ERhkrnQjJy4Vjb
X5DUSRZy8XB53/iQNrKYi9D0AHf9al5vxqsjqrnPq+m8w4xVpf0tdmayYKZ5
0/dBNEOnLLSUFPLvRR7KPI6wqjoy8pD/7bkqaGgy/gE5dpHq
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtIk2EUwPHXtLTNeZnbdNO8rqisqfOydOrOplN3dbOGZBgzkgIVy76U
JU7JCiowlPygBFqQlzLUNEsjyVS6iAxNw6QosQ+auJilrbQLO8+HbfAyfvx3
4OV5Dgs7VppTuIWiKMW/5/83+XAMvQNdReFgl0ViLljT9roTU1DDDuxragtD
e8DZjoZz3WpiH3jNogU2fg9Fs+BMh1jS3UIcAJfp2WE0DXEQ5LDHqYWlEHQo
GBX0gPEU4nDgPG8/NXE3GM0H23uvRZVtB3oXPDyYKo7KIN4NU0veY9yGIPRe
WLE+uBNtDUTvgzflrwpa/IkFIEiVf2g9wUNHgyF59jh/louOgb4ZaxxzLAAt
hIGW4KYLPOJYKOOWzCxX+qPjwGobHZmb5aDj4XPzlMGHR5wA5nsTVn4JGy2C
hLoXJxVM4gNQPZabb1Oz0IlQcWtykPPJD50Eqp5vSr2IWAzzgxumSBETnQx7
tBEseYkvOgWuCgvnGo0+6FR4Oc1f/eVJugSsm08OV7uTDqBo62zf2eRttwmg
z1IbxRv3wi6F/SmCQ8++MLBLoVU6PDLKRVMyYJQJxZPVpMvA9yuLY+GQ+TSI
UN6czmulYU+D2ouu/R/z0VS6o03pEJKlSeS0b8Uuh9w8YWdZ+B+Jvcsh9vry
mnTop91UBtBd75cv1rngfAbor8VEutW44Xym03wm7ieFPQvP2xXnnUwpHN/H
pICVRNumTLANuxLUospH8wIyr3R6f5XTvAosPeaNCvZ27Gq4dKMo6XyIO3Y1
dHWW1guOeGDXwA/G46rf8Z7YNWDuf7v6bp2OXet0P1ooltU+9Wom55/teJ+m
bKf70Tn+HnRO+6ADRjFz6cpp3JchHZ432Sc90G6vH80YQYMe1lULHlVq3E+T
Huz/L+ghPWwzuPRYhsn+5oBMYKwvM/rBX2E8Hw4=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIU3EYx/Flli57sbzM6TZzQ8XUJFs6my1/U+duQioYFrNMGEkhlgSh
BR3SkHAaNCzRCkfEEsowM2HGtJoii8zsYpIQqDQVMi2y7EIX+j8v5oHD4cP3
ec7hnCMrqyy0+PF4PNXf89+VDmFRT1/XUTn+azGzpKbFOyQg89DfEdB02ylj
DsTA4Ni5tfvIAoTzxl5d+xTNHIoV0a06tJJFeHr4gPMDyBJYbXZj+/vNzNE4
uKF1blpFlkOvn3cFWqOYY8DdvVR/+aWUOQ72X49OOaPI8ZiYX+m9aJUwJ6DO
v8A+6hIzJ2HpuSfy5lZyMoYm4yze5kjmbfDj16afjyenYESm1uiKIpi3Y/JB
vWrFK2JWQN6AvePN5B1YVxmkqBgMZ07Fld6FBimfnIb8wmXxnbNCZiUqG6sj
QmxhzOko1l8QTPWHMu9E17emORHIKpQNy50KLoQ5A1r1zOln34OZd8HUvWQs
UFJXI095pnc6mbwb5lrF/jezNJ+Jqba01Lc2MuAyxz6MCmLmgBsqxbDjKnUN
bJZFm9lBXYP1RWu6Fx9Tz0JjNz/R9Y56lu88L9v3eVw2So+X/PDMbmI9B4Kk
FPHIb2YuByfKHa49QtrXrrq/Fu78gTbOST13Vc/FlpiAma86en+drzkdOnUf
C09upK7Hk/s9HVXHqOtRU53ofR1L39+AkUPFS58nqBuwUOH+olimfaPvPGfE
z+v+Mu8o7ZuQcaSqpfQedRPSbO5yQzD9/zx0Sl/IE7zU8+DoGxd6JGH4A/t4
6z0=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H9MlHUcB/BHsRCOUzBAQIlf4joFSn5cR0C8D45f53n8uDsgTGMUja1M
JZADLB5YdbXkrCBaA6dLMyVwnexWwIobmeRcbOqCqcvjD7LhcpxYevzsx/x8
/rjn2W7PXns/n8/n2ff5fi+qan9J9WpBEF7+7/f/na9gk33Y9lo0HsmVebs+
/IZdzhZwtaar73B/FHktFm+u1xoq2P6Ir1O/2f1PJDkQH1r/fvHAl+wQRM+o
mt/Vsjfjs+tZZstcBDkSoV84L1RlsKNx0D/WldzzJHkLvL1v3fv093DyVuh1
o3cmI9lP4Zbu+Pmj2EzehiWvlYHLtk3kOMzPLC9qpsLICfjxytDDx/3Yz2Bj
86yqtT6UvAPxrdf3yv4KIScidbDFGZTATkJt6L7Juy0bycm4eGS04dBIMDkF
IxHdIcd82ErsX7X4Xm9aEPlZWJoumN09gWQVrAfqe3cb2KmIc1nPfXv0CfJz
MEx8cORqODsN7lPeb0+rN5DTcfvp6KQ3FAHkDKSOD5+4OOVPfh6NirH56kJ2
Ju6vDL3Q5s0GTl06eUhWt+6RRSDbuKR8LJcsqD0tSixkSeqzsDpy24Lsaz/K
szEhf79mXi+nPBvdE7L50ykyyjWI0XZNVJzxpVyDn3/KaKgbWkt5DpLa7z5U
O3woz8FH73h959xDzwu5kvpcz+eFPLgGriy/FcT1eZI8X9I/X/J+BajY/nH+
uJksFiBi5ZfLKhfP10pyreT9dnr2E3figXywdSmF10fnuV6iDvo+a061ndZL
2AV5bWLatTZev10I+DMw2BXM669HwdlzvbE96ynXe34PoVCSF6Je0dnxyXn+
/kWQefU33emg/YMipCfqLOsqyaLEjiK0TVe1T/fxfiuGQh8TmLOP64s9+4nF
OB2jvZE8SvMcxRgO6zw2OMvzS6ARzcs7LFxf4tlPlOSOEnw+8lWDKY73vwHf
j1mc7hYyDNidN+K78A1ZNCArobKztpLOj8MgOU9GXGrUpL+ylQwj2gd8tv/g
5HojZrpq1f2ZXG+EbS7seFMN15tgEFTjtgA6vzDhpUn73mtmsmiCPfNV9+HX
yQ4TbG7rTAj4vJeibaxsz4KO60s9+4mlqJi7qYxd5vml2NKwqkM5y/PLPHOU
If6PTaLvGq6X2FGG5l8b5UIlzy9H1Jrfpu4v8fxyVOkVZ1b86P9KLIcyzOfk
vRNB+BcTKpBa
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2EYB/CTlzmb2grd5ryvC+ZlNc2ZM90zr/Myd7XA1DKIPlgZaRle
2CAskCymfuiDiVlppC1MSmoGM12FXV0frA8FNTQblgrhDcuKPe+Hcw4cDj/+
7/M+z/tyoo5U6Y56UBS1/9/7/0seXvED60ClCNyal0/ZraxXgcQUsD/6Gast
UWg2DEtOzt1SE3Nh59nsmrK1SHQg8EvjAxzXiQXQ8VVzxaUjDoVU+6nvPE/i
SGha57w7o4pAi4DNEgpbmsPR28Bf8lRtHA9D74ARZf3VHoo4Gsp1rpsvy0PR
MSCrje50PAxBx8Eh7sQ3ak6IFsNsRU/XWBLxblhPOtF4cTQYLQH1ZPxh32UB
OgHaIqdmNAriRLB2h3c0CIn3QPjY52WHio9OAnMuX1w3yUNLoePt9jxWM3Ey
LAzp9FvTifeCVOh7Y6ErCJ0C0tnpT/0+xDLQ7OoS1QgC0alQej6x5MPMFvQ+
iA3jBR+rIE6DxWYLv+zXZnQ6WIXt1x7NcdFyCBE4Z8ytxAD3QvqHHAWb3DYB
ZBrWpN45AZgr4LZi1P4s2B9zBTx5LvsZ7fTDPIO+3pQBJbFm5ZtzHMwzweys
rs9Y8sGcYSqLkWfB/ODE78YgX8yz4bVw3tXO3Yh5NlwwV8rqI0h9DsylrP7J
ELMwz2Hsnwt1xtWRyjskz2XUK0F7SRLr1eSFuRKq+1Ll97spzPPgQEmC5bRo
Xe7O86Cx8/0w74sn5vnA8bxb52rbgPX59PVUARQmG4ecYlxvKoC4QS+W9DLp
X0i3qRAGLFXt4oNszFWM86kY/YsY/YsY51fDSlxrQ+9xvE+TGl7Y02prHpP9
NfR+oIFe6yRvPNQb12vo92fT0OehtPTzgZYxjxYSW34sKWwr7vuwaRn3o6Pn
wLBJBx6RMaucvjWs1+H+C1ivZ9Trcb5FrNfT+9kYpgx0g4Exv4H+P9gM9H5U
MX0eKMb+0/K/MlBjZA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tIU3EUB/Cb+Jg0a1rT6SpXmEiOlZUrNd13s81X6p6SPUgi6aH00GSR
ZSssKWxmSi97irnKUswsLKplrFIoCDMoekAZGEEaidp89KDz+8N74XL58L3n
/uCec2av32bM9eA4btXf+9+TXYGW1nvNeXPwX/2qovfdn/IDmDnMLbiw+XL7
bLIANbsc+U0bmUUY2vque8CbeTpUypC6fIeMLIFEp/451cQ8A8Lq0h6bO5Qs
Q9rM1vSuCOY58Ej4liU9MIschsHOdeNfmmaSw1Hqt1K25+cMcgRuvbl9tszM
PA9dC6pObjorJcvhU283lo2FkBU4fzE6OyeKeQGuFr1V1VQEk6OwpVvrdc6f
eSFCU1yzqs5LyIugq/H94YhkXgxBSYW0c10QORqHKvNii0OZlXhwN0DQXx1I
XoLd+9yP8q4xL4WtSDUQG84cA49TF0aSbWJyLD6stJeVD00nx0FUtmPDx1rm
ZXAPJ9Za5czxSE4tf3szmzkBpZ4dnYKTzCo0D9u/SsAMWMU1XEX9tP+2AXe2
12crxGROjeE6n5IedQDlagweaQxaO+BPuQavcgd9I9rINg0Cep3tDUaWJyJd
98TVEy+iPBG3+4/ND3k+hfLl8CtYGNd1wI/y5Rj0a9s/Gi2kXItf8uN7HPm+
lGvxzBVv3XlXQLmOl+sgb/H0Vtp9KE9Cf8vLsb1ilifx6pNR+bmwWDNE79t4
5lLQF+Me1yi8KU+h/pG5VF6eyjs/Dc2N26oVq+k8WxqvfsXE920reOen877P
M5eB0OT0mMBrXpRn8Oozed/PhKE8KtLzoCfl+on/A3re/9Tjivqx60kw9cep
x/2nsd8jPrP+GOAhm+ee3ECGARnX7drcVtZPAxLNo0ovHfXbaeD134jsMzcu
ieU0HzBCOK3duv3rVKo3TpwfpxEdr8MGRoRsvkwobG46rN9NhglrfGrPSLVs
Hk3I2bF2pLOX7DRBJI+SvvjN6s04/dBhtchpvmHmzbsZR1t8Ix98JDvNaEzq
M1qFbD8s0ChyqgtyyLAgzDqpStnH9skycR+dFmQUiopPuNj+ZWFnW7vscSrt
O7LQ4P9dEt4ixh+6K2n8
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU2EcxvGh4bybplOc6ZzOVCxzM7to7ZmXuc05ZxQ2s2aCIhiFhmQR
doq0qDQ1SjDDexE6QsNm08gkQiUJLymtRKpVNqRmRpmSXeh9/5gHDocPX97D
e877C8w5ujvXhsViSf/e/5704uzt7u0s4OO/LOIufW1RhRs1CzOZPWeWegOJ
7SHs14/cyaNeC5Xa/4vchdoT2r7jCz0dPGIfdHKzr6jSqf0wY/uqxGIMIOYh
zblCZxRQ81HrWD7JLfUnDoZN68v9jqPriUOgUg6Yp3jUoTA53AwRVfoRh4O3
1P1s+j2XOALDj1aqRwKoNyHW+bf5VKMv8WbcY489XbKnjoJHwR6j3WcfYiEc
4gfNqgJqERb1Thl+g97E0Wh7/Wb8xSKHeAvqnwvkdhepYzA0ca6seMiLeCtu
905xhv2ot6HFVJaTkOdJvB0+2r6xSin1Dmi0A7LMfeuIY/Ex7OuJKDV1HMKC
2aYfydQ78UTdf4MxeBDvQpSBu+FtMbUY2YUHlodn3YkBJ1vdSfNVYga4FaQw
Rg+sJV0CTZ2uySuCmJFgYcWgOcumPR6H46seuja5kh6P+5aqSN8RYlbCqp6A
u9wO/ViKG+mJmHS5kP9T5UJ6Imx44UtO7c6kJ1mbSYL7nCfHwqHvl1q/j5Fa
75eVDK7Pu9nqGrr/ZGx0D52vG6VdBnHGtywVl36/DHFC5XnXbPp/5DjWHivu
aqbr5fgQyRcdCaNdgSx2cx03ia5XrOopmMj97hD6gPYUjIlr1nhP067EYiu7
1CQh58MocamiTaCzpeeZik/XiyQ6MTGTumoeVMgZ5BtEDO0qXBP80rAaaE+D
THHZ2KUh88SkQTvVfXC8hM6X2tpQW88no8ZyYePp1HzifjVifB1a5hvp/KaD
/TioPmKOGOkQejccyirn4A+FDBIm
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQNioVt3b8xWcoDwPth7F8reKOOF8Rkc3u9lnvd9
lyKUz+Fg3LyrNzYexhdwiMsLVOFnh/FFHHQr53xJW6kA5Us4tPDY7Z8fBOPL
OHy7cXXv6v/yUL6Cg37V6o3emTC+kkOXVs8enTNyUL6KA0txqZWrAIyv5vCg
55aOg5cslK/hcKjVofd6ngyUr+Vg8JR3WcNlaShfx4FlT8ENcz4YX88hzHiT
ZlWyFJRv4HDjw4LFe4sloXxDB9f1D9om7pGA8o0c+L+sC35rBOMbO4Qtm20U
ziMO5Zs4ZJnn8TWEikH5pg4z++ZlHSoThfLNHJqOh8f+8hGB8s0dIuMPeURF
CEP5Fg5LrYxPLJ8rBOVbOvzwfsrR6APjWzl861onHvtFEMq3dtCWFZNMT4TJ
2zhMTv0wOWY5jG/r0PQkqffJGph6O4cY9kWzpF1hfHuH4tXW9psWCUD5Dg6+
bseOPrGF8hscHFY4Hj56TJIXKu/o4LemzzV1K5Tf4OiQfWLHvss7uaHyTg46
m1nYzPrYofJofAZnB3kPX0uxVaxQeWeHwB5DbZZWFqi8i8Py3dfFTsnA5F0c
uJnXVr2azAiVd3VgUtD6xb36jz1E3hUqzsAAAEQboO0=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0HtIU2EYx/FjVrNsuPK+vE6NLjZqZm4t3W+bznkrNCIbJsNIiEHiBQxL
O1oEpl0kayH9kwRJmmIjvISixEIqTRP8JzJKiRCqzUxBbKvY8xI7Bw6HD9/z
vuc9T2xJWcGZdRzH4e/978mukOPPnvdaZPDIoWlRhDpVEmYO7Y/OlvTYYsl+
ePA1Kn2kkFkCXZMorng1hhyEBKU7cK6NOQy7Sj9LF/XMEeDWV78fnYgmx0Cv
USc0BDDLIL94f/ZtaRQ5Hr3GMkVbZyR5B5z2+XiDM4K8EyFK3veqink3mqPE
I1ND28mJsO59+G7QJSXLUW829FnPMe+DVtT0QWILJ+/Hm7R5Q8F4GFmBV8U9
i8MpzElovJO5IXoylHwAJ2u/ZzT/CiEnw396qdxVx3wQ1+qKQ7uWgskpmOwa
arw8E0RWoshPyt9TMaugk5tbK8yB5EOwFIryT1uZ1Uh03Ojuu8l8GNZPzT6z
zm3kVER2rs0UpWwlp8HN5bvNVQFkDSxj/cPTA/5koEP7wv4yXOwxD9h/Bhwz
lW+hrkW0a/y10rGZuhZx2XdnTB1kTuf9Pq9D0vVvK9qRTdT1GJc6FlolbL0e
DtvU79pg1tO99+PTYdrTYpw4z86X4X1ePkPQDRizp1ZXDfpRN3h/j8sUrBeY
Mwr+z+g9Dy4L4gqFerqBzScLy+KB+rVkNp9s3Lri2//xFFsvMJcj6Dlomau8
oFsRUc9FzaXVUcvjjdRzUdmp1jxt56jnwd/3Sc3CbR/qeThhUnRXyNwaTz+C
H6pVl06+7DHP/IX6UUH/7z+YWwtN
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1Ik1Ecx/GHbc1KKTN9mrXXpxymMl+2tNlsv625tgsvNC2yMpZKF170
4lWGbVExA4tkF2qMkQSas4Qyi7AXR6lk6E3Q6kIiJl0IrRTKOcIy9j8E+8Ph
8OEL55yLozl1pqZZxHGcYW3929nwdaNjD1sEJPTDXH/ZeUm8gZlDb3er8dyo
hrwesz6kBWqZ06Hh78jmY2pyJlZk96/iNrMMhbrmrg4LsxwL4zMp1YMqshq3
lCeXwlElWYChwdVY5GTeBZvYwf3yKchahBwXe/o55lz0+Ds/Rhrl5DwEMHX0
8Kcd5AJMv1rtmlEx6zA7N3Jo7vp2chEiO0P6wMtscjF+Ziw3vdEyl+BKltrd
2yEj69En+OVnH20jG7C4qe717kLmPYieCD11TfLkUnT3990TlMxlaD9mNj2u
zSLvRVjqDSuWMslGKJ+1PvG+20oux9sLNlOTlnkfXkx5P8fcGWQT8hV89mkX
cwU23o012Ce2kPdDMfT7w/EyZjOq7JMT8xXpZMA5OBzM8W9O2IO188ujuZE0
6haI1Hnx1CGyx4KCEYm09GYKdSva3PFQS1BK3YrqzuJ8yTUJ9QP4boyvWnWs
J5mzQeWoMvLBddRtaA+8f85/EVOvxMBYmJ+Ws16Z1O1I/F8RdTuO1JcMnxf+
mBP9IPQ3vi1bxlcS9iSZc9B7vlJ3IFX8oG3Bt0jdSffQeP77L1hhyAw=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQNioVt3b8xWcoDwPtgbKK9s3CgI4zM4+LxSMf+y
UxHK53B4kKR4cl4GjC/g0J9y5GabAIwv4tA9aaJz0y4FKF/CYbnkL6uYPBhf
xqE2xi7wqjiMr+CwQPrHOsEl8lC+kkPTiWi9yFdyUL6Kw/wpiluv/5OF8tUc
3ivl2s7yhvE1HP6VZxyzCJCB8rUcvshdnnKrRxrK13GQc/y3xeubFJSv57D9
h0HER3sY38Bh0oL7v+5nSUL5hg6356cXdq6WgPKNHK56H4p6qAjjGzv0Xxbo
PuMlDuWbOCxq5Nm0JFAMyjd1MJPiXPxxgSiUb+aQfHvPnuVvRKB8c4et9mk/
anJgfAuHqkrt59dUYXxLh3LR2Qz9y4ShfCuHk5UuNilqML61g+EuafVHpUJQ
vo2D0IsDh1YHCUL5tg6Vmsd/pvoLQPl2Dn5r+lxTt/JC+fYO13g7Mn76wfgO
Duul12y/5M0P4Tc4ODiH/DFjdeODyjui8hscHXRt9UL2P4Ppd3IQfCMi9kEM
Ju/ksOTk4jLuEph+Z4dtHyboS52FyTs78AgfKi94CbWPwcUhIEfr9FdJqHsb
XBy6jVLvzE6Aud/VQVdQ4+OsizB5V4emJ0m9T9bA/Ovm8K1rnXjsFyi/wc1h
cuqHyTHLYeHj7hDTbBx14wWU34DGZ/BwiPp020z1r7ADAIZUwo0=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdznks13Ecx/Fv7pij8CM3xSIjlDP9Xr+fHD+3n2yuLbOsGYulliPrN3/Y
MIbUH+hgbUoy/BxNpZ8u2m80dC3pwGyZ8jMtMXTs9/6s/X6f7bPPHnt+LsfM
PHGWBsdx0X/nv5UNXlLf/e4cJyil4Ms1rsSaGTFzcM2Qn7nc40jWw9TJ6YmK
E8wm2JC7uOlwzGaYsEoZXmhyIFuitTxy6zmYbeC4vTzbP2lPdkBVS9Kkqyez
Ez6t9dcKG+3I+zAkvKojfWRLdkG2+Wg2z4x5P3gfB66vVNqQ3fA9U2um66s1
2R0jvaMvimyZPSAV6BrX11qRD6IosdJ99PceshduaMvEI8XM3hgRdOnPPrYk
+6DjVXLRdDLzIWw9ta/qfW9BPoyOt7af224y+0LuerrLZpNH9kPzS2eRTiWz
P07lLITIDJkDsFQz3sOfNCcHIrG5wbrYizkINtPJMKkzIx9BTf659rRE5mBI
8wtWUwtNyUehk7RDqniym8zHkmlK1s8KZmAo3XnYzoAsASb59VoWM7uoC1A2
n1k930GWCJCu29poHcq6EFXeWR+aMkyoq5kLwer2YEqZLushEN3ubHduNqZ+
DLnC2odGLUbU1cyFIuT4pq92GOuhiO2oCc3qM6Qehn5FrafVGOthqvu5cEzc
e/3j3S8D6uFIPVAXMV5I5iJULYnAunv9hbbcndRFsN8ek/sr9KmLoJBObJWa
sx6JMSvFYoMJ65EYfRZ8/uygHvUo1M0VlAjXdKlHobwuJ7DEnsxFo7szr8Ej
jfZLotX+F6P2/xjsjbzyJvUWvcfFqr4niUW038WBOQ9N6nEovTb1gPeFLIlT
6/GqHfGqXRKPgjtB/J5WTmmZmrkEVSMBPtXf1gSydb7yfAIMNO8WL15aUVqW
gOWAjW2hx4LSnFjVENO9NCRqlv33HwlNMsk=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQNioVt3b8xWcoDwPtjX9GzvK2WH8RkckpOl9Lcu
VYTyORx4lG7oaNjD+AIOZ5hv3m17ogDlizgcMa/d4tYB40s4JJjJxgcZwPgy
DnINuvIPN8pD+QoOk7L/VbIqwfhKDk+qDc2OhMpB+SoO9hN3y8WvkoXy1RwK
g0pbn7DD+BoOTPKfTb0aZKB8LQeFX1vP3H0qDeXrOPyIW596wQPG13M4d3dz
8N1OKSjfwMHQaZnq0gWSUL6hA6NIx+d/fyWgfCMHy53190X1YHxjh1JztdSt
qeJQvomDztbFoX92i0H5pg4qhRdv/hSF8c0c1sleVtJ6LgLlmzsE9hhqs7TC
+BYOzzU/VRoGCEP5lg4F1z4fSlQUgvKtHEoylu/zF4PxrR2aniT1PlkjCOXb
oPFtHbgW/4hzOwrj2zkoOqZ3lv4TgPLtHZYpe90yOQTjOziERxmtK1Lih/Ab
HBw8V65bpToHymdwdFjhePjoMUleqLyjQ5T2RI9zFdxQeSeHD5sv/q0V5YTK
OzlMfFxc7fSdHSrvjMpvcHbQ2czCZtYHk3eBhgcLVN7FoXi1tf2mRQxQeVdU
foOrg495/fbHesxQeTeH95a//jnpfbOHyLs5cDOvrXo1+SOEz+COJo/GZ/CA
mgMFDR5o+j1R+Q2ecPUAGvvHeA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQNioVt3b8xWcoDwPtifZprmJ8IH4zM4ZJUFv3q2
TRHK53BQDLzrER8N4ws4/LVw+dvMCuOLOBzzi504c40ClC/hMFs5zVrCHcaX
cVgS9iBg/gN5KF/B4f8Z+bfzTWB8JQcONimp3i45KF/F4ZiIb5nlK1koX83h
llHuvtAgGF/DwWbu15rgeTJQvpaDjv/iz+k8ML6OQ4GbS2V7mjSUr+dwwmB3
Sc9ZKSjfwKG1c56tjCKMb+jwh/FT+o4oSSjfyMGVg/nPl40SUL6xg+LJj+0W
mjC+iYPwYUVd8fniUL6pQwOHcd3nJ2JQvpnD7eNbbl0vhvHNHQ57fJ6nuEcU
yrdwkPfwtRRbBeNbOvwuXFDvmwHjWznci+hr7/kuAuVbO7zLPfLV+JswlG/j
IMQtvufZHhjf1mF7wbJIPVEY384h+FpnzyVZGN/eQUDHUPrcf0Eo38Hh5DWV
L795oPwGB4fXd9Rb9JsEoPKODuul12y/5M0PlXd0WHJycRl3CR9U3skhx2nC
Xr6FUH6Dk4Pfmj7X1K28UHlnh4s7rn658YMbKu/sMPFxcbXTd3aovItDYI+h
NksrC1TexQGSHpmg8q4OtfMu7xF7yAyVd0WTd3PgZl5b9WoyI1TezcG49+13
xwM/7SHy7g7vLX/9c9J7BuE3uEPVf4TKe6DyGzxQ1TN4oulH8AESm9M8
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0V1IU2Ecx/GDxkxnNXPq1rTmdOFyrtycNZ2d347OLY0uRhFYQQSJYWIl
pU3L9WKFkDVnVJdJ3ShaaoZUYC+XiUVRgxKNimnhsCJarqEV+z9dnAceDh++
53mBJ3NfvWt/DMdxlr/z35eN1B3DDwZqNYjqKy9UzM4ulzJzMPrz2tvuZJKX
Ynqs83TfbmYZDihUaf7farIcEzNTV5JuMCugffjCn+VkTkcwUnDz6tgashoT
9wJanYJZA9dLycAJ82pyNt6ODN2N9GSQ10LRVKS9bWLOQdu79bpdx9LJ68Cf
SlBee64i6zF633epS8ZsgC7Sws/XryJvgPf9ZKnyg5Kcj3in1RwUmI04k6Ju
vX5BQTahI7TXWfc6jVyAmubJ6u4YZjOkr34cXjiZSi7Es/BM+7lbKeSN8EvO
+zO+y8mbMMxX/2o5yGyB+3ju9BstcxF02XGfQo5kcjH6HXOuxkRmK6Lvt5Jc
Apk+XzW+mETeDN22LLm9jpnHUV2Xr3NQRgYSk580Hvq8ImoP0GvV1OQ8JXM2
NPQW84Pd9L/HhrwSw/bRwDLqAqpyvc7xJil1AZfPxo5M7UmgXgrTxWDI9iie
ushcmaiXQT+0RFLYEUfdDu/HhmYhRPbY4W4NP67tkVAvp/tx1Muxs8rYf0Sz
yEe7A3OW8IJgCETtYf5J3Unnz1N3ivoW0XqRuQq6Bw2PyFwlpLF97i++b7S+
UrT/1v/9Dz6h5Mo=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2EYB/CjUliZuXk3W3OImFnaVi0va3/n5l3RRGKFMUoxSsqmIfmh
TlQfVlJSeEkzmDbWhc3GSgizyFGkURChEWgYRmRgzTQJIqzoeT64A4fDj//z
f+F93xO3/+iuan9BEDR/339ffiIq7g+4DivwX15ttzneaVrJFhD4LuhUvTOO
HIhJT1fz2SJ2CFyycsH5U04Og6pGgVInOwojM22Xb5WwY6FIMwxL36wny1Hm
cMy3F7AVqNW1DAZbZeR4WEej1QHz68gJMDg6knoy2YlYMX7vUk9LLDkJ3+b6
bqTOrSUnoz/DXPVWy96MVxPu8glLDDkV5yzXNbFx7C04OCa767ZFk5U4NGpY
1i1hqzCyr+/7I3UUeSu8C9UnJ62R5G144rH5jxnZ29GRNtA2MxRBVqNV1PRK
dOwduCP5GpXgDienQX9tUvrAwk6HfCq8tdfIzsDUaWli3QF2JlIrz9gHb4aR
NbhYd/z23nL2Tgyf0GdWJYSStWj/0Oz3flZKxtJc9LGQBVu66rm9m+bFLJiO
Vf4a+SyhXIeF887IynmyqFs6L2RjeYWf2+vhfjamHv4WN6o51+PqY3tjRTLn
etS7+iylTby+AZskibOdr0MoN8DY6bCGJ5OFHOzeo3SaFWsoz8GiULZoaiAL
uUvnxVxcUFaPd5m4n+fTz6P/L5jyfJTWJr34Ec39fJ/1C9DvbUmJeUnzYgGC
Qoca66Y5L0RxzrOnHzXcL8SnFIXqyAbeXxFWBTiavlzh8yvy2X+xz/kVY7rN
nOXQ8v2UoKbVv2G1Kgx/AEs97NY=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H1MzHEcB/CfElGR1CkhnYdFOSoPJbn3XU93V3fdU0WJNE0W03rwcIbT
8tBQjNk8TItQSRxL5Ok8JDQZyTCbh7aGeag85Boddp/vH7+77XZ77f19f74P
f5x/5mptlgPHcYv/ff//so8gqf6KKUcIm7rElU1lP2o9mTkYOsrejGvwJzvD
2ePpDHk6szssJ6LF2yzjyZ7YVOTS/fUAszf2hc5PrVAyj8H2nNnuRU/9yOMR
P7Ze2RbALIReU35hV/o48kQ8EqnvyE+NJU9G+7mfS1a8G0MOQFVUptfuOOap
6GsMS7Nu8CUHocfH7FRoGk0W4WCPa463B/MMFC+b3ty3zYccDCcH69VJxd7k
EJT2ZshWtY8ih8J5U5nvgyXMM1EbUXlX8V5AnoXq8s5zgenMs/GptPW8+IkX
eQ4ac4N6dQ7MYSjNLaxJ03mSw9G6dEH3txcjyXPRcrG+Oi+XOQKmntHlhmzm
eci8J2wMNTJHIjj20GXFQw/yfBRkn7qeKGAWI990tkRtGEEG/CXLSwr73W02
AvmnI8Tnj5E5CXaGZL06nMFyCcQp3xepfFlfipMTFC9n3mK5FGd9axuexA+n
PAoLD52p8ApieRRcR95am/uB5dF286OhXjm15YcP2z8G8uq6mklHaL0xBuun
NFuyElkei2duO7ItKjfKY3Gtee6XgA5XyuMw4pOnoEswjPI4VN4/vsalgMzJ
cHqeMDvgNpsvw0rpnmvDKlgu59/HKIeV01gzCtj5FZgWKdLf6GT7K/D4Uvv3
579cKI+HW15IRFsRy+MxQXHgWWrVUMoTYKpbvV+U5kx5ArouPP6z0WsI5Urs
7cjfIO0dTLmSv55T4V5T5NqCRtZXITVwr6x1Hds/kW9jIqokt5vu+tB5ODX/
fFDbvZea/55mNX66Xd7yexZ7Xw1UtaUxWfWsr7G7r4a/3qyBX//DlrAudn8t
9hQ7XnqdTobW7j5afA3v65eKBlFfC8Pmvps5NWROBz+ZMlxQ40R9HRLmbG7o
EDlSXwfb/5sD9XVISQ2pyxNaxba+Hi6OZwwf9w2gvp6/3qjHxqNtVwVvaZ5Z
D82u4MCBWwfS/kn8eUiy6yfx55vtzCXz5yGZP8+YjNDdn3slZovN5mTqd9P5
U+h9Omn/FJrLcX8BGPJ8Iw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1Ecx/GnZatNaXNtXtLlrbwlS1et3Wq/2TN1C2OIEQjZBYUgQ9Ak
HUgPEYSCvtARBIuoN9XEha5B0wqLhaUQqaQvUoyELhplgSHWtGL/Q7gDh8OH
7zmH8+JknKmvqBVxHKf/O/+tbCQcCwz2nctERIsW6Y8xo0zBzCG+cvB6ji+D
vAVvfz+N1TiY5Rjaenrgy1I6WYmO8Ing6B3mJJwqWdHesjOnQl1n/vhiJo2c
jve653GTPHMmhm96HtW6d5B3wlrtHT87oSZno138WVWfxpwLQTQ9L+NTyfkY
eWIcCIVSyAUoN3X6A8vbyRo4pRs6ZmuYC/Er+FombkkmF8FwsXJOvJJE1mLq
TetIu5l5LxYe3Jgt9CaS9yHckFHepGfej00X1LsvPUwg6yBZdUtMOuYD4D3v
FME2FVmPq65Q87JHSTbg5FSgeqKZ2YiXLby5Jnsb2QR5QVHKq7V4shnjlq6Y
xBnmg8g7mqW0nWc+BMWnoWc9FcwWNOW5u7v65WSgse9+m9NFXQAWpnOu7LnM
uhXOuvzRpWSyYIX9ns+7yyOjXozjVVpfQyZZiDJ3OKpHmePxeNj4NXcujjqP
LMe1yaq7Uuo2LPrHwq0qCXUbvhlWVos1YuolKPDHiHWdm6lHmStdv18oReS/
i6iXobHHZOm/zVEvo/etWSLdTud/RizYEbux1zXf/Z26g/oH6g66l40j6y38
9x9TU9GY
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQNioVt3b8xWcoDwPtiLnG0+XCYK4zM4hL842nt1
tyKUz+EgVfjht2QujC/gwM5pc2ifKIwv4vAk/UHcp7UKUL6EQ8Kdzk0zo2B8
GYfL19v0VnyVh/IVHARqLIM2xML4Sg7v+Kas8NgsB+WrOHx4v+yQ1ydZKF/N
QUAhLN7YEsbXcJiXIup4qFsGytdy8ChK2ntxqzSUr+OQe+y8VSszjK/nsCHB
x3ybqxSUb+Dgs8PBVXOGJJRv6MAo0vH5318JKN/IIZzty50wUxjf2IGvQivs
3mRxKN/EQe7IvR+XfGF8U4dsvd/3L50Ug/LNHAQn+DE4GsH45g75jL/bVlmL
QvkWDvHXt8ZdrhCB8i0daudd3iP2UBjKt3KIaTaOuvFCCMq3dngjHJn6rRPG
t3Fw2/syy+GiIJRv62Bj5NPOlwDj2znEsC+aJe0K49s7fP63K7KJXQDKd3DY
9mGCvtRZPgi/wcHBc+W6Vapz+KHyjmjyjg7GvW+/Ox7ghMo7OUx8XFzt9J0d
Ku/koLOZhc2sD8pncHZYvvu62CkZVqi8s0NV/a+D2avYoPIuDoE9htosrSxQ
eTQ+g6sDJH0yQeVdHcKjjNYVKf23h8i7OTApaP3iXv0Hwm9wc+BmXlv1avJH
qLy7w3vLX/+c9J5B5dH4DB5QexgYAL+Fvqg=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tIU1EcB/CrRUvnTNPNcj6mWamth9Nsacuvj5lTm26zxEoZgRQaaU+b
RN0eoBmapEKYQTbLUltPeyil9jQogkqhKCJ8UCa1KGqO7EW/84e7cLl8+J7f
Ob977zlB64v0+c4cx+n/3v+e7JKsau+8VBiM/7LGnXkWlZUtYubg+TUwp8sS
RJ4K4aV6CFYze2CeLfzLi3EZ2RvXLg42hVxknoEhcYrqJJj9oNfWKaWdgWQZ
alwsNk8n5mCopYI+uTKAHIJtpgrjc5M/eQ6ezr1tftfsRw6FzN7++M2QlByO
EanypTmAWY49g+c0khBf8gK4zjuQ62KdQV4El4TeEW0hcwRs14XZfr0+ZAXa
YpsepL6XkCNhqvbu0zgxR8HQUCstjRCTF6OjWP7D4MwcDbst8VSJ3Ju8BIMF
YTHjZV5kJRqbesVH+qeTl+LWw7K3tr3MMfheYfHJ/eZJjoVw0vnSkRrmZbi9
bnZPgJCNVyGJ3zUeUcby5fj6qyNnv8CDHAfNOUvL7IZpZEDbVqXObxf9Nw/0
i8o3jmnJXPzffmI+hQ64UR6Ps/F37z+YyfIEh/oEPPG1jtR6uFKeiDH50d3N
m1woT4T8yuQp0VUCypNQutfeU9gyhXIHc2pUH5x0420uzcer8V10c9/PxdQP
lwxnWbhd2Mr6S8Z81YKsrmHW3wp4jnpLrBJ3yldAtGn6x/It7HukIKf+fKNY
TuZTcEHadv1ZGvs+GhxW5L8+bmS5BtlrFJatwSxPnTieT0XTI/NO4XZaj0vD
NWv1Qt8nbP00uHndKSn+wOrTJ/4fPt0hX4nfnO63cTubf6VDf1qH/rXY1hob
d/kUe78MmMIejuVnsDwDQfEbDu34xfJMuJptecn3ab8gE8MLgyM3h5H5TJyZ
lfoq6g6N7850mF+HZYr0Mncjq9fBv/Vn/7olrF43cf9263A6JrK3+QTbr3qo
VYO7n9rJ0COvPPmD6h6dD16PkBKnmujP5G49qop3tKw1sPNkwKLcA823zpJh
QGzB1mPGq2TeAGVBnKLSh85jtwGyAXGdOYedzyxEjw6/aROQkYWiStNMrxox
/gDiK0Mf
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2EYwPGTytSmZuY15+amlphoXuY127N52cU5N8Ui09BAMDYRkkDT
YppdQCqnoh8MY4rLEgUd5lZoalGKdJFwlAh+kKiMbOTKZmYXfN7Ac+Bw+PF/
z8vDOS/3dGVemQNFUeK/978nuXwLRh4OqXmwLatguH6Ta97goim4bB/qVncR
u4BCfopTkk7sCQvi0Y7od8Fob+hdmvrKaib2h4kiY7WcT8wC35kKdaWegw6G
kbqXg6o1NpoHk2m3s3gS4lCw1Ske2YaD0AdA17u2UuxBHA7e0zXHLipY6Ajo
0XiWMnSB6EgwXdJ2Ba3sR0dBxxk/Ss8iPgzVFTeTzuUHoGOA2ZRYMzDuj46F
xt+LeQxX4jjIj3Gh3ub7oeNhtXhytPSpL5oPHQZ9H49NnADz4ZpSw6gPOhES
Wp+US72Ik2Czx4n7/pU3OhnY5qr7V2f3oVPgY/tZ4YCAOBUYBbuM1sde6CMw
XhQ2yWYSpwHTceD8Sute9FEQHLcVKQKJBTBjCbX9dCMGaIotW+ws8dy2FsAQ
IluIn0JTQqjqTxUMd5MuhE+LBxujG0gXwdrWgxMNzqSLQHp38F7YrT3Y08Hi
fq3crnDHng7f3c31m3w37Bkw9ixlNXwZrc0Aztbz2STrbuyZ0NzoaFoqRmsz
wWqc+3XBxxV7FuiWq2pF687Ys2BosLIt6qQLdjFc0alTajmki+FL8saWKIqB
XQL2yJa6OxrcTyuh7S+FuOuf14UTpEtp+8sgRNZuKewj88l2zktl0+bLpr0v
p80nh0ijEyPhBprKgU4L027gM7HnQOEhneRFNZpS0LoC5kzztjc/SM+lfd/c
nespJainTeOvzWhQgkNwxAazn6xXgkbUPOah99j2BM2UCpSaiNlvAfj/QQWB
/ssfdC3kPKj+n8c/O9kf7g==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQNioVt3b8xWcoDwPthfimjO3ywO4zM4mFqx7o7a
pwjlczg835RtIhAF4ws4/FzqYt/2UwHKF3FY1DZrf94yGF/CwXWtmY9eDIwv
42DGkuR185c8lK/g8FNRda+fO4yv5FC4cKtK6CY5KF/F4cP7ZYe8PslC+WoO
r/Mnmai6wPgaDgdUL1fenywD5Ws5GDzlXdZwWRrK13Go0BIp3hoI4+s5fJI8
wFq6UQrKN3Coe7LSU0wFxjd0mOd4scvPSxLKN3LgdDrxyi9bAso3dnjKtL1s
0iNxKN/EoapEOX+1I4xv6jCPZ/o2kStiUL6Zw1nnCMmnP0ShfHOH62zt12U/
iUD5Fg5OB4PltOVhfEs0vpXDyUoXmxQ1YSjf2kFThf3Jd3cY38bhh/dTjkYf
ISjf1sE+/EuMn7QglG/nYHlu94JjDwSgfHuHZcpet0wOwfgODktOLi7jLuGD
8BscHPYet3qn8ZgHKu/o8FNnUs3yHE6ovKPDhBbmHfdjuaDyTg4njtqWl+zi
gMo7OehsZmEz62OHyjujyTs7yHv4WoqtYoXKuzj4mNdvf6zHDJV3cShebW2/
aREDVN7VgUlB6xf36j/2EHlXB27mtVWvJn+E8BncHN5b/vrnpPcMKu+GJu+O
ym9wh6sHANZGuj4=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0nsslWEAx/H31IwV5XZwXIojdXCikMuh/HAcznF7mTOjy7DpoiO3Iylb
J0k0zNAfjD9KqeSSa3FmGaWZmsuGVv1lUk2KiZ0Wqdbz/OG827t3n33f53mf
931eu+T0mJRtDMOI/57/rvQwk3er28/z8V9L/m+dGysceNQMJm8Nzxb22hHr
IefcjN58MrUhWIfjn6v0qU0RWzQqnW+zJbZAKaffis9SW6PuNdcuiUNtC8N8
n5gnJ/cS83FBuKgjrdlDvA+T1R11nwZsiPcjpu+r2N6FWoAJZjNoI9+a2Ale
8rGWkUErYiHShsdEN7ZTu6B8NrPLhmtJfAhj5WtlgfU84sNQ+oiKTe5bELsh
i5c2s3jVnNgd7I+ukWdiag8Iuxvk62oz4iN4+H7odv00l9gTUwJFUuNTai+U
mo9XrmVSeyOd86uoyZfaB+PN/SXXp02JRbgylWfAJFL7Yi7VUbRx04TYD2Gd
y7JoL+qj0IR91LsWbkx8DDXPH+TKhdT+2NGgOSV5aUQMZLe3lbCXiVWAgcJ4
oTjTkPQA5DhWV1V2EKsCkOf46mdKFO2BWPndF1+gS3sg7o00XNyp3EV6EOIS
3Fqz+LtJ1zIjRqO97J3HIB0vxiYTvZmopD0YOWrWz1tD5lMFQ99kMDfjC+0S
rS5BfG3LHa6Qri9k63yqkK33M6F47Mc/KxiiPVRrfVJIH7U2OdTRLkVQ7Lqn
joSOl6FnqcLV8g19vkxrfJjW+4dtnY8J1/q+4Vj4cKDQtYCuPwKswml0lUd7
BA4aCZZrJ2iPhNqyur73O+2ROKF7t9YqmO5vFArmksvmmun+RiFVqenhxNH/
gYWzjRnvTBIxWHRmZK8kXCL/k4rFt7QXq+5rxAMsuv1Pa/IVpvgDnYAK/A==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0GtIU2Ecx/Enh7Faec9mTp1LYkqtNst77Xc2p3MuuympYZpYBEpR2Rst
NqIrESy1CF8E9cqa3USZUlZqZmi9ELEMAgkpbSapL0znmBX7P8E8cDh8+D7/
5znnxJaf3H/UjzGW/vf+9+RXeEHb82eVCng1rRWN66ovhXIzvNk6O5DbFksW
wyHf+7PvCHcQFobdXeNi7jCU3AkJlTTJyVKoqqIPvTJwy/CjKG3w/UgMWY7F
6t4KVwi3Apc7hKjG2mhyHOb6Sz3fnkSRNyHP3O38JOdWwur3xRmYKSMnoHUP
K49riCRvRrTgaTXNbSCrcOBw2PVbRu5tePBdNTJRGEFWY3jKKp4ck5I1GHc0
q9X53ImYrGi5MNu8nrwdA/Ennsrc4eQdCLblMUHDnYSCz/7XrtauIyejTXts
/lxVGDkFRaXdxuLCUHIqOvuujM5bQshpKDtVstg/EUxOx5Zg5UzjYBA5A2fj
G+rrWrh3IlI6NnGzjnsXlti+pbLqQLIW9gzFcWUPN1Cls3UG3Avw2gro891J
/llkJsBPnuCS2NdQF9Ak9PS+jVhLXYfKd+0vhzok1HW+65keiTemfguvV1HX
w3ZR1D5aspp6Jjaabn8sbiJbl5kZEOP5MJAyzbsBNRZXV+XDldSzfG3Nwvm7
Qy/Cv4qoZ+NgsebxacWS1tuzYU62OMZUvBtxxp6ubbnPaN4IiehRjbN+xrue
5eBXqsujU83RfA59zwJ1k6+tJt/9WO6ynkv/x03zZjpvBZ1vXtZ3/3+fPxUQ
9Ak=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0W1IU2EYxvFjvoXOsqlTU9tcUepsuulWarrLvWs6nZlQpIkwiMwK/aJG
Mc2KMqSQCLSEKEvSQRKGYtEahFhElJVpgpUwohczDFNbUrH7+bA9cDj8+J/7
PgdOfNWREssqjuMM/67/d3YEuweG+6vFcGtONZOlcsTwmDnYNFVdcbZ48mpM
LAQ2yozMoTgwMfvVOS8ih+ONqmIuop05CmElS33yHOZYyHue9tc4hGQRRJHd
wppUZjHalvgdlxs2kDehXGeT+NyLI2/GfOWNq0oecwJONjbVqcpiyUl4Pvqq
+5k9hpyMO12HyvZJmKU4uDxjWdm1npwK9bDrnOFENFkGfnXpZMBsFFkOcSvK
xi8xp2H/I2t0UBhzOqxrf7VUKCLJClRLf0+/HBWQldBeec8fOhtB3oYqU2LP
Co95O+wS9be+2nByBu4erZvfWx9GzsTHTqXiXTufnIWg64sV+sfryDvgTBGn
HU5kzkawr63xcztzDvif7I7eEmYVtNb6P7IzzMCXqS0tKc2hblu9zOWiVW6Z
6qxkPRc3N+ZPpjtYV3t1NfZ02K5FJLOuQUPiyJKliHUNNKUupb9+DXUttmZL
Sx86Q6hrvboOIbXyrLFm1nVYCBlqcil41PUw9bXpLAOs6z2f5wx4Mfj659vF
YOoGrBIlLQf3snkjHoxkzibMkK1Gz31cnlfP85rPx4UW38Hp8iDq+Th9sTrz
mDCQ+k7cGh4XPIn1p+5lrgDm8zKJ3yk/6gX4nrG8opYGUC+E0FiYIbjN5gtx
vGvsvuCDL3WT17yJ/r8P9SL6XpfK3Yto/4LbXLFnR7FntxbTvh9u273MmT0N
M72XjtVM+5yqv1rWFuA=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1EYB/B3SpZMvN/SqXOaeIlZmk636f5Ozduc9wITw9IwbWRmCUX4
GmVftCz1k/RFQ4NZlGY3cUwjLKNAAhcECu2TgZeULopd2XOI9z1wePnxP+d5
ngNv+LHTpXVOHMfl/t3/vmz5V4xPPGxUwKE1nV2jmw52Y+Zwu93YMTcSTt4F
Vc1KXc0hZk9gUllavSEn++KsWaMbHWAORJSp+0SKkVmGT01HcGo2jCzH3cSj
tucBzAq0PBhU1zaEkiMx2bJg8H4XQo5C+/HBO+sa5mjIvEoi++pk5Fhc7Sx7
/WYqmLwX9enlFrmEWYnhCtujJFMQeR+u1MbPbHXsJu+HfGls/MNiIDkBHyMa
BmaimBNx0v1HuWk4gHwA18+3XdYu+JOT0MenDXrpmZOh/Tq10FntR1bB5nLN
FrLuS06BNU6/PNLMnIrIVklP8qoPWY1Wv37uxhCzBl1jrnGWRW+yFpaqPVOh
UuY0xBgjfLNNXuR0hJi356tUzDqci+ntuTXqSQbcfKZbm5Y8HOaBx2vd8UFv
3SnPgFmrqI9+wfIMOMljt6RmN8r1aHz11PL+mZRyPSZn1CvRdpZn4uWGR1nl
GTKfKTzPZaF/Xro5lMTuZ2FtbO7nJT9XyrOR2LX8PcNK5rPRcbNRfTFsJ+UH
sZq69UuvdKGc+ZvOkefQvNsO8zmiPFdoPpf6bVKeR/8zR/XzIHW+d+Fzj4T6
52N4wuY/K9tBeT4MqrYndqUz5QXC83wBDlcm3G9W/Kb6BtF8BmE/rlBYjy8U
5UbRfEZhPa5IVL9I9L5i4X2IzBcL71uLRfOX0Pu+OIwSmosWL7L1v/8AQhQa
AA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwB2IQDQNioVt3b8xWcoDwPtgLBW/ovcMN4zM4XDrzdVv/
ekUon8PhweHZPS0+ML6AQ6aEtPj13wpQvojDzY/HzHSXw/gSDkUbTmc6e8P4
Mg58Z/R4rG7JQ/kKDmzy6nP5rGB8JQcH1dAXAp1yUL6Kwz6nuWyb98tC+WoO
zjJTwxpdYXwNB5u5X2uC58lA+VoOzz7OfHHpmTSUr+OwwW6H1Y4YGF/PQXjx
gZkbj0hB+QYOrx5f+CEvB+MbOgTv+GPAaCIJ5Rs5HHfcwPXokASUb+zQ+efy
tY3OML6Jg85mFjazPnEo39Rhoru4XtV1MSjfzOHM48V/HbRgfHOHp6zTvm2f
LgrlWzjci+hr7/kuAuVbOiT5aa74xwOTt3IQWns180MdTN7aYXNB8eeoCmEo
38bBx7x++2M9GN/WwdBt1k6vs0JQvp3Dt6514rFfBKF8e4dlyl63TA4JQPkO
DjlOE/byLeSD8BscHATfiIh9EIPyGRwdjn7mD44q5IHKOzoY97797niAEyrv
5KDsNe1a1AouqLyTw+xr3D+XmXJD5Z3R5J0d3lv++uekxwaVd3HgZl5b9Woy
I1TeBWr+T3uIvCtU/iOE3+AK1QcDblDznkHlYfxvUP3uaPrdUdUzeKDJe6DJ
e6Ka1+CJZr8Xmv1eaPZ7w9UDAJ4x3f0=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0mtIU2Ecx/FTaUpCLtN5mXmjRk27zGVqzvx52+ZUTEvzMrUkQTJTsBIX
xLGcmRld7IWJopY2jLxVZhd1IpM2TEhJC6UX1hCNEAsqk4yKnv8LDxwOH76H
85yH/+OdU5iUu5bjuJC/978nXcLknhfd+T74r8Ww03n6gQQhmUPKTtOT90+9
mW0xojd9LkkhC7A8Ipas58iOKDNViO61eTG7QLI0UyiNJLtDIaivqDd5Mnvh
Zv7vUmsfsg/O/WovOHXSg3kranuVmfGDW5jFkE25LgxtI2+Hbnr3joyz7swS
jHc0Hem9L2L2Q1Ha8MSgmLwL/Z3m1tFmN+Y9+FC59FZgT5aiyXow6aXWldkf
BkunYSaALIP8+aRurMqFeS9WjJ5XHk85MweAt/9RnhVA3oeyhtfZrkVC5kCM
LM9VVbQ6MQfhUP0tkVZKDkZitdTXSufIvB8aWze+NpgcAhsPq8PG8c3Mcvw8
VrxS1kMOhbk0Sn5cTD4AqaLumXrUgTkMzS0mp2uTZCBDadiw3MXMA0stNuct
4dTDUdzdefmgdhPr4bBb1679VMPMRUBjc6dOFE09AhcsOVctD6hHQtE/fwJj
1CMh94+7tPEo9ajV7/NRqMldrNHoaf1o3DboS5L96P+iobkoS383R12BtOwh
VXoq2y+vQPdXt0ZtHu1fiQZ+QmvfQV2J2Edf1ImB1FVwsHPum+2jrlr9PS4G
WZWK+VAj9RgsFBi/yb5TV0Olrp56mMbmw6vhPp0KwQ2aVywkGUHDAwlsvnws
zG/KdWfMNO84lF53nIhZw84HH4dXH++uQELnJR5tjbNdvplC/AHMguy4
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd011IU2Ecx/GTLkuHpnMeX2tuqWiapObLTN1v8226uTQ0qKCwGGheFJlR
hroC0SANXyDIEYoXTZtYmmhpYYZSlIZaGXSjGF6I0bxI05hU7P9c7Bx4OHz4
PofnBY78/KUTRheO43L/jf9v9vAlQ6NPKxRwyKaKu1GqOSdl5lD+onX44Iic
vBcLZQpL/Blmbyx6dPpfdGGWQsdJPor7Q8kBMM/NV9tPMocgvNgsn1mWkUPh
33Pt9lIiswJuUyUyv4YD5DBwzR2S++37yRHQp9dVWS0h5EjYo+/Jev8Ekw+h
uHHiw9U05hgkxj/mxM+CyLGo/d6Tx4cxH4Hrp66FjPpAchxWFN2/jOYAcjzk
79YbUqKYE9ClMIdcHvAnH8W4V/LLCQlzIlIjnny1NvHkJOxc2Qx3n/QjJ+PC
t7GxR2tScgokfZ/LbbXMSmyVVtpvDfmSU7Hme8q4cUdCPgaP7t9ncyZ9yGk4
7BO5/mDWm5wO5cxo59QicwaqotrbWgeYVegPtg7P6faRAYO1Ods45OmwCfBZ
k/I23ou6WtDVqHg78mr+uZi6Bl88G8u2DKxrYFG/mZwKJHOZmA6yrbZ7e1DP
RMygyC2peQ/1LGebsmAbnLXX+LlTzxb0bMi0BUq+dzf1HFTXbb+u6HWjnoOf
yu0dTSyZyxX0XLQsV97UbLL1tUho+rGpHqf1TFpBz3O2KQ+no1u0M9fZ+fMh
25l+n2Jj58sX7F8nWF8n2L/e2SY9iu7GRYvqRdQLBN8XQJ9cN7wc60rdAMf/
60LdgJqH82P8EuvHIXbtq15t20VdYK7Q2Sik+9hSOeYLPM7mrzvMFdF9bzgM
gU3MK6q/hN4gmw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtIU2Ecx/FDWWl5mZct79NVIjoszZy39Oe8zkvOOStXSQZRohDZiyIV
R2BCGGUXpTBIDV1Zo4uZYdZBscJKUbHbi8oGqZWpXUirRcb+z4udwRgfvs9z
ONvzP/PftU+zexHHcZsX3v8/2UuSd7vrRrEMFs3E558W6+ocmDkoLg5ef3fT
n2yL6mVVw0UFzCKMR57L6fjhR3aDb0dM3HATsztKrz8pSsxg9ka0rep06Ccp
2Q8dvjXjfSpmGcofTx7aedaXvBrasWPnXg/6kAPQnhsXszaFORDD4bqv4/Xe
5CB86JMPiMa8yHK4FDiK+yOYQxASl/zGsMeTvA5Puwve21zyIIfia3M+Lw1j
DoPRuf/DZJM7eT0anOOXDs2vJIcjoPzFUG8q8wa0mA3SgAYJOQL1LY0GmS+z
AhGeds2zF8XkSFRsi49t1zJHYWvaCdH7B27kaPDByqmrpcwxuKAfPexkdCXH
IlNReccUwrwRwT4Sjz2FLuQ4dD+qfjtXyRwP0z2zPljBDLhM8D1tGmeL9cDO
/Tt+90+QuQT4tP15vl3BegKWN88VpPSxrkTLqvTX4T0i6kqoS4Ke/PAgc4lo
i5XtDex1op4IQ0Jv30MPB+pJGOoc/f5ybgX1JMzLT5W3lthRT8Yzz5mPZ0TL
qSdjVXrdc52BzKVYWy8wl4qjtcXRZdJl1FMxc2vIXCFm109DrelAmfIn62nW
6zkVpGlZUZIrS6irMB31668yZCn1dOTUhAbbVNlQT7dez2UI9mdYr+cy0dr1
QtLvzXomnedi6lmCniW4v02C+98k6NlYf3zqZwJP31efLfh91NaGGsWPO++P
3GXnoV6Yn+gvgSZ7i3k1FvkF/VrRRuZy4FAaFjNyhM4TOShRnux2bHSk/YLO
C8xprK8PjWC/xnqeeA3yz19rFMvZfOVad+TC+bObZEbC9udiiy7MWCqj+eMF
5rRQXTZeWdNAhhZe7qaJ2lNsnrVI0h8yh1bTvPNaWP4v2fOTB2PqtOagPT1/
yMNA4dbZb69c8Q+u+FQD
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU1EcwPEZmOVczpzzWepScTbM9zItf742N3W7ShJqmgiDoZaZq+ly
eNUo/afwQYYpRMUkI810Cj19RWUoxMogqEDLVKyGkrqJrsLf+WNeuFw+fPlx
Duce38LSTMUOBoOR/O/9/yUPN0v/pLeYB1syxp18WWQ2cYkZcIPfnxug90Xv
grpxw0J1FjEbHvwMjmbP+qA5MCbU9ovqid3g0q+61odRxF6Qn/H5y+qQN9oH
vto/q1i2IeYBk+/9eqN0P9oPOFTeqOv0PnQA5FyuEutYxIFQONWnGxZ6oYPA
ENLcqmz3RAugx3ZCMmdLHAwaqeumh8oDHQKWyNPaK6Pu6FDwv/ZeZCojDoOn
5dnrUQNu6HAY46grfZZc0RGgb9PFX3UkjoSaed8X0xIuOgq+215fGWx1QQtB
mxsX23+c+DCc+qjPN1Rw0NHQJqsxz9gTH4E0YfXgTLAzOgaKVGsDNif2omNB
0aHbcfGWE/oonOe3NDc9YqOPge6A9FPECHEcWBgZlgKVIxrAaZHDNXL3bJkG
kNzr7vJvJz0eKvmvTAo5ztPxcD+WpwwcJT0BqJKgt3/cSU8AB+cR9dl50hOt
TSdum0+Cu2/uXGCqyPpJMMWqV5pkLOzJwDoXFmOoRdPJkHOwMWWygoldBDen
mCZdJJoWgbHv3YbWZTd2sbVpMUx4GBda2PbYU0BTbR4u7tqJPQVMgqaqzhIy
L7E2LbFejyG13i8ttT5PRiosbz7OrrUj55NqfZ6MNPB0m5lrbCI9Dcp7exoo
Dfmf6TB7iBd+ho+m04EtCPWctJAuA5Wy87mci/eBlkFBWd76+Bzpclh0zlas
NJAu33afKOD72X1bFaOBgm7x70y1A5qm4Ad/qTKUQg9R0EF/0Dh2k/kMMK8l
3lYLOPAXud0UhA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n8s1HEcx/HvVBPFkXOO8+sORa7D+XU47nW4HzjnhPk5yWba+qWLNW3W
N9nKWg1JS1pkoiJd8yOMitEfRptaf6Q2zdb4J0pFS9eP+Xz+4Lt9991jz8/e
388+36+w8OTBIguGYTT/7v9PevEyeodMR0XY0LJCeONAzC8ONYOqlbGmZpOQ
eCf83rt7t6VR28FN2lgxZ/Yk5uKd1Xd+x3VqPlRrgTKThtoVsinPmLjfHsSe
+Cn0GdZrqEXwjijX3up0J/ZGOY+pUpvdiPfCWWC4FFJN7YtX+0ZaP7a7Eu9H
/YSiK5OhFqNgxqPvTq6AWIKWpUOchVoX4kB0+7vL4pediYNwoXPUISOfWorC
p48jRmf5xMHofJNVPptFHYLS4Inosikn4lDYfGtaTGqiDgPLWa3KD6UOR+HI
3FdzD49YBg9tcgTvgSNxBMJcrFq/NFNHoiJXIe9Jp47CYIl4Nc2CWo40RjZt
sucSR2Oyr/e+scSBOAaXr7T5dG2jVqC/5F62xJEasBMHCab/2G+YBW4+az+T
Id5DuhJyqe6ibQHtSpT51V+re2JHeiwE/PmF2jpiNhbZjV0tjmLa47BiHsyu
tKQ9Dn3LNQEuU7akx6NsyCCXrRGz8Rhf4aTlnNpNugoe5qlJ2bI16Sp4JTa8
zekgZtT4YTNwfj2UrGfVsDFKo15X2pCu2WxWA33nVVVRL+1axKWvh+1Q0/dr
cSy2Zti2he4vAcMvIz/7ztP5CVv2l7jZbOKW+UnIzJE+Moo4pCfhoVx0xHeM
mNFtPi9WhyGX+tsDS/T8kuGn9+KqjtPzT8ZpU3e14Swxo4d161q+epx2PUby
fF6476LfLwUzirrtTh9oT4FQWVxdZqbzDfgUIAo+4Uc6DMizvNsoUNH1Bvi7
8ZyLD5N5zw3QhZ/rn5fQ/ycViw1GZZeCGKmIlRTUGwuI2VQYAppFpXwu/gKI
zgls
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1Ecx/EnHbXYzEqdLrWmaCwvS2epm5f9nM7bpm6znJhFRhHoCyUD
sQutTC3oQqgEGSkVlEmCRnTPB0O0XlQgVC+iKEXUsHyhmcvswv6H2HlgjA/f
nf85z2Fhe6rt+7wEQbD+/fz7Zo9i+91HvVXhcGvGEPviw3hOKLMAtd1nLkkM
I0uhbHQ1RVYyr8ZcTKfzWiCzPwayWtpf96nIQRjca55pLWUOQb30cpt+cQNZ
BfPmAMfLZOZwSKcmGmqurydHIEwt95P8CCVvRGZIW8lxE7MaYuRI/ceWEHIU
4r4kqybmg8kxSH/bu6svh1mDrqqApZtd68hxmOzPa7+0oCTHQ+nbqu/UMWsR
p1pYSrkRRE6AriS747SMeQumm1beajwVSN4KbWBHRXmTgpyIhpPP3l8UA8hJ
KM09v/pzvz85GSeGHDtdFmYdxio36X81+5H1KG9IKHs3sZacAlPa2JFXLuZU
RIcqlPsrmNOQqrU0r9q9hpwOg2O2vDCY2YDnbyJmf8qZAbnfQF3NpK/bTiA2
TbOtf9yHegaeDOm/qkfl1DNQNXz/6cgDGXUjhgfT6g4+lFI34sJo7WHj/Arq
mejtqW7V7GA9EzF3JMsTz7GeBUvSsXujGm/qnAUTartTDH1XBeomOMq0PQfC
fxvcPRvu/68X9WwcvTLyWPGJrc+B7Ux8tKRRQp2zkAuZ9+1DUy3LqOd67ifk
cfvn4ZvOtWTUfKf98+GlinLJuhfdduYj4ez0fIa4QN3MzTdz8y3cfM5CATe/
gHv/Qm4+Z6GI60XcfKvnfcPK3afV8/ci1wWb5/lg8zyf0+Z5HyJnwc6tt3Pr
uS7a6f7HaX2xp1FM56LHyVn87z9D8jeK
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzV1I01EYx/F/OZwp1DKdL1u+rDfRIU1NXWv9f5tuurlptsSwUShElMYg
JaPCdmM3TcMKkqiLtjGtcFi21CKMlbZevCiwC4UkHF1I4rIXy4tZ4XMCd+Bw
+PA9zzmZDbb9R9dyHKf6u/+dbIlrfE/uN8qwohDPT06XjgmYOfApbzvM3kxy
DKxC5w2JjlkEx+Flg2Ihg5yA4eDF9jMO5mR4JL5FtZxZCt8tl5cPpJMz8LCu
0W0TM8swedJsuV6dRt6KIYszauTSZvJ27BMOO0OvpeQsyBzHph/tYM5G54mU
qqR6CVmOVu4I//FbKjkXjVJbQbeKeSe6xXOB+p4UsgINQ/1K/1QyOQ8L3XFh
x3wSOR/+it7sd1bmAjz9YqmsconJuzCR1VTvGUwkFyLnZfIP96cEchGkUwch
6mIuRnzfxPFQG7MSwjTBgRfvN5F3w1R0YXAml1mF2+5A4uUP8eQ9OFQ2ErvU
z6xGdM2agdBz5r345Ra2BTXMPPja79ZKyUYy4NlinCzwi1ZsB8z6sdGgmsxp
YLjjvbvt5gbqGrhfuU7HtaynrkV6ePxNcSiWuhbjqaHZayIyV4LAqLq15XEM
9RL8ll8539O0jnop8jvmFjXPyPbSiHkdumaaz2kXhdR1kA8Iogs7yZwe1Q5F
jqBdQF2P2ro87ynZMr/Sy1bbHmGuHM33VPwDJ0fz5ZhXLoW1uT+pG8ifad5A
/7JlXG27cfV9rgJxUX1nZ69+pfkIc6aIbop43/zffwAE3eGt
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1Ecx/GVRLaJeL+0pW6azIpMV5Zp7bfpnk2dF2alqSsrB2FazguB
L2qUWGphuSCS6EVSUyRNYZJm2kbRxXwRxgwqBEtZUmalNhShovN/0R54ePjw
PX8OnPOIj57SGVbzeLzkP+/fLz1B+60Pe05I8E9zcvtjx4LAi8zDjetViUar
mNkTrQcGBkR6sg+6tY1Ta33JAfjSniqsbItgDoEiMunTPh1ZhOYwl2f+bDhz
BPxzLxmmOLIEws6DDWsuhzFHgW/vsJV+2MAcDX5O9qvD/mQpRpprQs8Wi5g3
wSYaujU2IGTegslRwTHTr/XMW3GlzuPBhJ68DXUlsc+W6kOZ43Cu7GuTZTyE
OR6YOFPoy5FlqLjY+t1oDGbejrsr7eHRN4OYd2Cs7H3/8xJyAkaWnI31dwKZ
dyJf0+wzORzAvAuz5U8WZIv+zIkY6bN2VFaQd6PovKzgrdOPOQld6m+6017U
k2E2zJmLLNT3oFA9zF+6T94L7tHnUrz2ZZYjOV57wbuYDLwxLK6T9jOb4NYV
qOrpbsippa4Av811iHtKXYnq45ah7CC2n0n5/3peCgQe92pnzDSfgulYiexk
DPVUvHBEzS97UU9FVWeSvPe2D+sqt/1VbvMcamKumVt62XoT5zavhjxvvihL
SPNqCEM+Oq+2UNcgJisyQFVOXeN2XmlYbOwK1s9TT0OF46f9iJjONx3FRv3y
Syf1dJRWu/pW5VHPQBzX2p8+SueTAT9B8OD0IN2fFkpbbtjmcPY/mLQo+PEu
YeMK9UxoZsaHvJuoZ8IWWSflSQLxG7DQ658=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlH1MlVUcx5+omUogIFx5VbgG8XLDAEsSiC8ICAiX+8LbvdzLyO1uDJAM
UBG1PSM2zNDkxZYgGVhggTi0DELwGYagLqdjQhGbNhg5SaUEA5Oo1vn9cZ67
Pbv77HO+5zzP75zf8dr+js5iJQjCvn+f//7pp0j7pqczX4n/aSbS9qq31xlr
YgEXs3t9fNq9GC9H/qHG9xuSiO2Qp+pXL931ZOyIkHV3Hx2vInZG853w+iMq
YncUhlZdUx9bx9gT+oGO9LH+tYyVsD/uc3M6jPhl5JTv90s468HYB9VfPL5v
tiX2xe8/mY9kvu3O2B8VL2ibbva5MVZhNGLZbv0zV8aByHs6YflbT/waLnVu
q1p5zYVxEBZUNftbC4iDMaU8NWc54cw4BBVL47plK4g3otvdsGPIew3j1/Hz
4Ndjo8UKxm/gPVVZQ+GME+NNsPrk5F/xInEoRpdVjnr84cj4TZTtDfh1xJt4
Mw58OnxR8ctqxmGQAqIftBeRD8fDHd/PhTwhH4G13cUXKq8Tv4VG8XbZqg7i
SBzzXjQIJ4mB8zuLHxtLGYvAtztbDIFO5KNQa5mpNbU6MB+FJ4c61phn7ZmP
Rklua1+Kgnw07FRBbjeWyG9BcefZDzRljMUt8Gh7NmLaRD4Gu/zqamvO2TEf
g4QvO77yPrGK+Vh8fvXUbusSW+ZjURB9tNe2ibEQx48X45Acd2VgMoLNJ2xF
hjG4o0hJfita1ieObewnH4/itrDIc820fjxsChymD75LPgEfBlvGG3LIJ8DN
eeJedQ35ROz1G1ywpJBPhKH+TJOTivw2frwoYyEJPa51jd2PyCfJ3i8ZlsYW
q32fUf2S4XBP6m/TUf3UML3YXO8WS16NGLF0MaiSfIrMpyA8OKnSNoe8hvfQ
oC1cmet7meql4eshafh6CVpoCvyvz7kwhhZLgnYpp4TyWtj/5qiYUbD9krQ4
HXV54IqLDcvrYAyojr9Ras3yOhyteL7rjnkly+twq+v27I/zzEs6jNgczF1Q
U17Pzw89rDz9n1q3vcTyevQObn7oO8FY0vPzCan8eKQif6irb7ibeTGVfz9J
xkIahgYi9pR8t5zl0zBz/tbiAacVLC9jSTZeSMf6xI9HjKfZ90LGYjpCDj/4
M0qifDp+cJ25X2fHvJDBfw8y8GpEYOqlKVYfUcZSBmyKgsOGy6l+mTwjk6+n
mMnvp5Qp6y8Df15gkK1vwK4eTXjoPO2/jAUj398w8vsrGvl+koz8eROy+PsD
WZjaoAwp9KPznoXyye2HJ9sZSzIvmBCZMWtSu9H5N/H9I5r4/pBMmB5/pWJD
Oa1v5vsRZn4+0czfl5IZeSXzF57LYPelkM3ft5CxmI09Tg3CRy2r8Q/XP/d9

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlXtMU1ccxy8wEcdzKDDEyWMwiVacdaI8+6WMR6FU6IO2t21GSLq4lASV
GRbU7ErULXsw0G0kKltwCcOKTRxzQRnzuon6h5IQhC2LmUE2pzMTHAQBBbaF
3/njnps0zSef8zvn3N85v99NrK41uv0FQaj/7/f/P3uiLed7z3mSsEQTGtWj
8hvJQYwFXMWM/o2uROIgdN1f6PjWzDgCG/fmHI3wY7wKdWeyNN+cSiB+EYaq
xJP2XMZrsN+jGbh7LZ44Ad5/1sWM31lLnITutuODycmMkzHwtPrXB00vEb8C
0b/k1MHeNcSpmN/wSbz3aRzxerjcp8dydzFWob4tZbFicDVxGoa6/rwR8hbj
VxFwq/3n3MOxxJuh662NmfRjrMawYzTjwUIM8RbIYdv6foxk/BoCJ8JHWnZG
E29Fa0d7Z9Jaxuk4crM11qaKIt6G9GNXduoiGW/HV78frs5/cxVxBpzVd8dU
91cSZ+KzlHm78CXjLLRJww3hPsbZ6N5VNym+wzgHraMf+f32OJI4F7fc0ytS
L7xArEG2Wv9eWBVj4EO1+/aJqoglloDQmsiH7+8mFvI4n4fvJpo3rb4ZRl4L
Q1dTgft8KHkt/BPWzwWfCSGfD8/1nh+GLgSTz0fzoYCeO67nyb+OWdXR/V/X
rCDPsVCAie7B+QNRzBfgen9O/dsXg8gXKlkqxDlf7adpDuaLuPmL0DJWt0/7
ZDn5YjS8O3fZ4w0kXwxV93OB6U3M67Dl47+f5MksXsfNX4IDXwx9Hz0aQL4E
wQFnG/465ke+FFZR7duTtKhZ8qUYz5hb0KZNL7Ggp/lnyesp/jH5Ms6Xcd5A
69AjGWj+e+R3KFnawcWXKz04lsqV42XOCxVKjwounvMyx4KRizcq8yMZ6T49
o3ijMh+CSZlfmJT5l0w0H52vbOLO36w8f5gRX1yWEe1dRvFmHGnxZO6Lp/Ey
x4JFOR4W7r5ZlPddtiB0jzprqJHqRahE37XMR6ljVC+oxImR4NmOraxeKtE/
GW4Sd5OXK9GZ91P/1VgWb8XGnDTzpXvEsFI+wineqqxX2YoabXNfWDurXxu3
vg2DPcNTv8yw9W3K+pNtynwJdrxc8vmI2EnvBzu3fzu3fzvXH0Rl/4CIfPOz
9GWFtD9JxN7e8uztM2z/IuzHz7ZHqVh/cmBy4aK9cTkxHNCd9nlTTrL3dyj7
meyg7xOLd+Lh7XWHNjWyeCc01imnIY76o+TE9Ae+GNcUsexEhGpz3MAi658u
JcOFmdI/gg7qqf9KLviKxo31ISvxL8AN+zY=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzl1I02EUx/F/bqOasdxaS5s2N6LExnBO57Zm/9823QtOsXwj08JAvEio
BCEqarAipIQwkrqopAVBYDVhKBpkra5GRUS2CPKi6NVy2tK5bFbsPEQdeDh8
+F48R713/472DI7jSn6/P5uNoiE0FtynQVox/v5Qgf7lKmYOsoNi/+6QmrwC
ZW1f29sambMQ9qS4W8l8shxVEatRFmDOxit+4LalnjkXbsm7mgtTKnI+HrQu
K01uZtbgoUf3wt+7gbwRotN9/fYneeRNuBSauXh3NpdcgKqJ2UBOKXMhkqOm
XUtHlGQtmt97XXn+9WQdwl75noarOeQivFYKJ8Vz2WQ9ehafTQQdzMWYLrJU
D8XXkQ3YqTENRBuZSzA8LnZd+awgl+K8rzwgtTMbEXZ/u6y+s5Zchh+SDv5e
JbMJowe083UZzGbUcabHQamcbMHH/i7bIL+GvBUtfkNz9IOMbEXi2vJjb23M
5ajwHfqpPyUlb4Pa1tHTncoi8+Cb4i01StaB2s7CyPcc6j6gqbn4ZpdmNXUb
pFNyRUwhoW5D91it1ZQgc3Y46heNIifrdjwdeR6PJjKpO6BKPYqYYmLqDpw9
IRiZbCVzFVjQ9h293rmSegVU7mqz4oaIeiW8ZceH3+gE1Cux/Yx+i/CkkLqT
7l3i090JQ++Xedv4Qtqc61/7/jPnxrQ5mbLr5qi7kSkYPPzp3Ax1D/1D4/vr
Xwj8x8o=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tI01EYx/E/23KKhteW1XTOyjY1L1nLqXO//7zNyzIVSwqERPGFUViK
aJgjEYxcQSpIaERJ0pxhrkiyQAOp+SIaUhYi2AUFZeVYFxOTij0nmAcOhw/f
57w6HHnF2eIqAcdxmr/738mWpPTR2IOaSLi1ohUu6uragpk5tB+LDx4bkZO9
0To1vdRSyhyAnrjX48Mi5hBUSh1DCbciyKFQqLSzBQXMUlwLX/Uu+yIjR+Dt
p5pki5I5Ehbuu7q7PJy8B33Hh3NsD8PIUZjQX+i5yzErcDTZb7E6RUqORmvh
x5PPGnaRY9G7bCo3dewkx4EXX5kLsO4gJ6BidFj9fDaUnAjZHdOlfQbmA7DM
hM0P9G8nJ8HWbSlaVjAfhPNxccnudAn5EHw2unxSVcwqyEVz8671EPJhjMfo
HJZzzMl4darM6XofTFbD1piZVhnFnILVfvHFz3wQORW+wqGmpc5Achr2Byqc
N+wBZA0W4iOTzihZT0e9sqvz+gjrWpwfTNWO3GYG5Hz15foNshFoVL74VVXI
Ou9538hj6+mg5fZa1nXIvXffvLfXn7oOky7/khO1ftQzYB998+3dqi/1DCSZ
HD/5cR/qmYi1irxUV8XUM7Fitf9u3sZ6Fl5OahrqnnhTz4JMb1BLzFuoZ6Oo
IzFG1Cainr2p52BgbEYyJSUbczznOT2ab04/lXwQUtd7znO5m3oumlrWJmrM
XtTz8FW9tqGLIxvz4P5PAur5EEREr/kOrmvdPZ/mf7jNFXjayLxA3bCpG+j9
ndSP/J//AzWD9l0=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2EYB/CTVmpe8jJXpqWF1by0SlPndX+nm855mVs3TMsiSZqUaWaQ
0ewKCZZZFIoflqblIvASeWk1Mk2NBOke0hfLtKRGrTLTqPB5P8wDh8OP/3nP
ec7zPmf5rv2qHCuO45T/zv9XdvA33e5s0qzAjEziMz07L9e5MXMYn8ivkRmW
k21h81U00ryb2RmFt4p2lzox86DRVe+X3PchL0aBTqM/to/ZC/1lb29WODH7
oEotvZRb4E1eAV9HB+Hr+mVkX1y64ScQ/FpKXgVnn807gsOZBVi5ryPghd6L
7A/Fi6+1HiHMgSjJmuvQddaTLIRbpa7jxocl5HVQRJbIebuY18P6me5lzCkP
chDWlL7ebm9eTA6G1NZ6ytzEvAEr7Qa2Ct8vIodAaW7ta4tnDsW3yZ7uoTd8
chj2aEbijI7MIoRWPsyVu7qTwxG5t+BKdiuPHAE1JxpocmGORLF7NXeu3o0c
hcwTwRmvRl3J0cg+kPW7f9SFHINnOT/sBO3MYmTaXK3ylDIDKbKe7nfRzjPW
Aso8/8ffPchcLPIk5w1OOifKY1HXV3vI/iCZk2BNtHDj/RFHyiUwtQxOH3W3
ozwOFcOFRyQ/bSiPQ293dPHBDlvK4xHYMnd+aDnL49HQ+ZLf7zWPcim8E1PC
+Y1krRTJYcfuDAutKZdZWiuDlY//pL1+SjyTJ2Bmvq0oT8DpCk3EEW96H5do
Wa82Eb8CL5Q05LH65XiyxPTxovMCyuXw/vPkschE5pKQEVCROHDYnvIkDLY9
N7+aIHMKXI/t6u7xYP1RWPaLS57Vv2QYHkV8Fgw7UJ6CH47tpVMhZG2K5fO4
VPpelqda3s+lQdPbdu9pO6svbdZ6pWX9UM6qVwmXcR7fxKf9NipR1KmMEk2w
/U+Hg9uD4vyxhbQ+HWVBOUPV2Wye0vFpaPXJtcfJxnQU6iPFzVfZfKkg3mLO
TPWkeYQKrqPGB3oVWauCzDC2F4NkowrDd6e1AWFs3tW4FhHc21BDhhp+vjbv
fibQ/6FVw7d4TmXoF7JRjfL8osZtah7+AsR5P1A=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0m9IE2EcwPFzm7HUZKt5Tl252R+mjuFaaZu5+23OOdsfaiUGaqtAqBmJ
SUZBtKzoRRaaa0JQUGIDtUhDV45hGG2WFEEvejV6sZEgVhNq0VhRsd9D7B44
jg/fe37PHZzsaJejg0NRlO7v9e9OFt08HZjsLIO04sz5Iz7HYBExBVV98uHH
ARmaD/sPnXQ524kFMNt2LFyZRyyCEXGsWzItRYvB6y241ttKLAFns74vQhFL
wXn30t7ug6XoMlAcb/n+6sUm9BYQrojoOE28DRyzK8bNyo1oOXS+Vaw9NShB
V8BMOJ5ghkvQCngfmUvw1xErYTVimfGeLUZXwYP5YMi1UIRWQcdWVZZuUYze
Dkv+CZXqALEaFE94a6pvFKJ3QKh//kzvHI3eCf7FwuzUYeJqGL3VI3wGBega
SI3wZEvvROhdcNt+MRnNIdZAzFWu/XV1A1oLo1r1gu/OenQtMC3f2uwlQvRu
OF3uGbo5JUDXsawDmyn0MlZHzMAJw0Aw/14+GiAY1n6RR/PSdgMMXOY+/die
g10Pk4+6PMpWPnY9vCmOL3sEpBug1GzT0GPZ2A3gC3ygX0vQVD30jNcyU/cp
7PWQy314bnkoC7sRrDUX/FElF7uR1Rsg/X9ysDdkPk+ZYF+/qpJ3hYfdBF81
yd8GZYJJ98ZMuxtx/ip2M3CkFcnc8RR2M6s34f5P2JtYfQ9rPsuUhTXfAurr
n3/on//EbmXtt2aeR9nwO3G5WabsrPf77z85V/jl
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQNioVt3b8xWcoDwPti77jYXvCUE4zM4VD3ufyC3
XRHK53DYEL2ybkc0jC/g8Nx3KnscO4wv4iDftvmr9BoFKF/CocVxj7a1I4wv
43Cm4dfGunvyUL6Cg4L4UvlcAxhfyUHvkzJ/XIQclK/icLnpdnTNbFkoX81h
4oG9B1WfyUD5Gg53G1KyVgfD+FoO38SamDOapaF8HYfG33uXvfopBeXrOUxo
Yd5xPxbGN3A47CMSH7pIEso3dPCXSdhhIgvjGznE9uvMvJcvAeUbO3z4llr3
YKE4lG/iwLPSPHDPfDEo39Qhv7dSUniyKJRv5tAjfmHSt0IY39whM+Vrhb46
jG/hcJ2t/brsJxEo39IhyU9zxT8emLyVQ9Px8NhfPjB5aweJ+D2X+txgfBuH
xU9ak5zTYHxbh76C0lXRwTC+nYNKOeNks/fCUL69wyy/xl+PuWDyDg6R8Yc8
oiKg8g0ODt29S1XXMsPUO6LJOzpMTv0wOWa5EFTeyeHRbDPT25Oh/AYnh6yS
H9sYw2HyzqjqG5wdEgpjf596IQiVd3GQXf3nWow5lN/g4qDppyzimguTd3Uo
3ri+M6AKJu/qoC0rJpmeCDPfzWHhkhOi/ddg5rs5xDQbR914AZN3R3O/u4MQ
t/ieZ3tg/vNwcDoYLKctDw2PBg+HCI9+gUf7RRwA7Qe+eA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIU2Ecx/GjZomRWFNb3jc2ySk1W7m2rP120U3n3QS3FWZeClNUskSI
mAiNSAch1ouIQBIvUcvEyKwMizBIQiJIvGTlDfKFFqTOhhU9/xeeA4fDh+95
/jwPj+h0VW6pN8dx+Pv++9ITkt830HNOjP9a0sgFDV+bg8gcrC/ycyYGRcx+
MMD8brySHIjEOZXkfQA5COX7K+ZDB6KZhbh7b051o5gcjsK247HF28nRUOgM
7mVtFLMY043TZUU9kcwSjEV8L6haj2COQZLMJ9RmJe/F+prscmBLOLMMi3UC
paszjDkeLt+R1AVf8j4UPc6rj3OEMsvhv6EoX5zaw5yA1AD9k9zr5AMQCYs8
I5NCZgVaomcXsrXkg3CunDJVftzNfAjjG2EDtlpyIvrDLZXDUrISb5qG6i4O
hjAfRq27S5ygJqsgqRkdWwsmqxFlylCFdAczH0FX9cjoWSc5CY9cVyKFE0HM
R+Fe1bfVxZOPYaY8Vu1xCJg1sBkH/d0PdzED15rbpfd9WLfzzGmxNd+rd+kV
+9+uRaxk28yKkboON780eU0tU9fh2zOPPU5J8/U40aiwflqgroe5dzktR0nr
DZvn2Q1YFFhKf12l9clYNc/6NaTT+mTe/BS0qxXDHbepp+B19stb9qfUjXhb
b0gqiaH5xs3n4Uy8/fPMpfLOzzOXBkvhkMlaQPPT0Cr1WLg7dD4zzrR61+5Q
sPuwm2H9MZ4o9VBPh2jL5PTP39TTefeZgQcRH8SyeeoZ6NOUrV6qoJ6JQEdN
yec26plwVl/otuVRz4L8ZGPH807qWWhvPb+zH8H4A9/F++M=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU3EYBvDjppXN29TWVlPnSjGzUbOcl9meeb+7DSuwgrJMaUShaWGR
Kyy6qaQkFBWRhcHUUBEtdQ6lMC0IBPtQQWjZBSuzyBSxC3v/H3YOHA4/nvf5
H94DJ7jgsKlQwHFc5r/7/5Ndkm2dPW1mJRya1tnWNYZw3swchqsaTv1oDyYv
wzP5rM9VE7MPBo6/HspfVJD98eZnnXtzE7MUXgcn+tzVzHLccmvaX2wLIitQ
7976W+zCrMSLXm1V+vZA8lpclsyIem8EkEORX7dP2h/BHIaR2jJZ5R45ORwn
d7t6DF5cTY6AR228uW98FVmF8pqO2xVlzBtxyHStSyFl3oTTNQ2vipplZDVs
vYF5wikpORJv57u5lkrmzXgv6CqvG19J3oIyTWhhZyFzFKKxRoAZCVmD64pO
78kPK8jRsIq/SkM7mGNws1u7s77VnxyLxndnCxIPMMehYEj5KNLiR9biUvW9
kBYhczzWB0hkRXt9yVvh+9E+YDWJyTqUtj24YKhgBgKsC2O7NGQL4OE3cOzI
J2/K9fAsUceNnvGkXI+7TxvLRUe9KE/AhnhVXv8kyxNg1SqLwwZZPxE78tWt
JUqyJZHXT4J4yl8yLSFbknBfP/j4iYzO45JhHuq2jT4UUZ6MoMXnI9HTyylP
4fVTMOZ5vnguh/VTnectqYjocF0SVbOU8jRnW9LQ1PNSMix3ozwd566YY08E
sTwdWZrKrgmVkPIM2u+PzpFnwPE/CSjPRKk1Ttd+h6M+z1wWr5/Fy7MRWf1l
Vm+fozwb32LmFxNUkw5zORAJWyo+13+nPIeX5zrbkus8zxmcz4eB5n/RvMG5
bzfw+kYIFOHzIusC9Y2Uu9C+RufvZTc678uZeO838fYx0XfguL+5Jy0M
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H1QFGUcB/BN7QQJIt5CAXkxGSU1QQQSiS/v3PHicXvccafOkHW9eDcD
KYpA6uY4IiPSodbYAJWpWAdaiiido24MNqjjTOLcWQ4Tf9gYls3cmJWYSDX9
fn/s3szOzWd++31+z7O7zxO/rsZgmyYIwvp/r//++RdR2X/upD0B/8uX7Uk8
UHo7nC2gV56xY7c7nuwH99E4j76aHQzNgzRjnx87DNvPeBYvOBtHjsS9iHR3
/Rp2NK7s+bG3PYgdh9H+4W2vZcSSE/BdksZ1et1c8gso720rsPXHkBPR3NJj
Oj8ZTV6A99KSmnVadhIOO4Jf1bRHkRfhriMio+bOHPIS2KNrUg9mspeidAAF
Cw/OJieja2v0G0f3R5JTsHNq1KDxZy/Dr6e7xpa6nienQkz2E34Q2ctxrtV5
rOlkBDkNDc4wj/Ypdjo+avt4/eDmcHIGxM4DUY3J7JdxU9N8M+Z+GHkFinWt
t05Z2Jlobhza8rCTvRIhxz1v+7axs9BWu8m1WmS/gg/mT1qET0LJ2Th0ZDj8
fW8IGVhddHHWo6/IEmDr6p7W9OlzVM9BwPTjjb/sJ0s5iOl57F2TzvVcxOe8
2bLpSTDVcxEVeXu8fR9ZyFPV87AnxTbaUc31fJitKSc2JDxL9Xx8GdV7dqSE
LBTgjM/50pxrQVRXWSiE9osTrvmdnFdZKFL2k4pQVvjtpZ+yuH8xngkdrK+9
y/libOzJzD71Gde1yvslraq/DlNCxVR1Hed10DuSrv4xm/MlyuchlSDP+Djt
6ULOl8KR6zwfdIjXV6oav0xVL6P9EEj1ctX6y3Hk8uHNAXWcX6XsJ61C4IaU
zBs7OK+HN3D3WxPlZOhV/fTK+ciq+4UK2IcHLtz4OoDyFXDunD4wtnYW5VWW
KzB8Kau+zu1HeQMmFu1795jDn/IG5XiSAfN0H3qtn3PegA5vwET3cqoLIhq3
P/rG7tJQXsSudvuKptiZlBeV/WQRvr7rk1vDqZ9gxLK9v/2VI3N/o3I+klE1
f1VdqFTlK3F9wPPg+4c8f1VdrlTN34TYJ9euZvhofJhU6zcpx5NNWJy1xHjx
Dj9/s+r9mVXv26z8fmUzuufpbqUO8vdZhZBxebDHQPsZVah+Z+3fV8Z5v1dh
SC93SG46H+Qq3Au12P5s4fPDgr19/i9eGCPDAtHb0joSQ+eNZMHlhvyVryeS
ZQt+Xni/IVnP55EVfbUbf7duIcOKmXNnGIdGQvEPgPq4lQ==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n1MzHEcB/CfHhQnUpxSdCqh2k2l9KDu3YOey111xSFmWFaWx5WSfpmH
bJhcZGM2/MEUltaqC0syJQxR5x8RsTJk9LgU1udr+31/2+322vven+/D7xZs
yk7aYiIIwvq/n3/f7JFrq+srM50xoT5Vq8f7UqWMWcChqEb9YMUCsiW2B5pp
jYnM1tj8brxp228FeRb6XXqfKE8z26HFsE+v8GF2hP2V/q26c05kBbK/Bb36
bM7sjFOrVetUm+eTXSGcPG9TVjqP7IZ1BpeDF2ocyYthzGu1tuhyILujwC29
/o2M2ROP1NdeHgiZS1bC9NWljpDD9uSlUPRUVRs77cheODba1l4ZzuyN6bnu
qW/1c8g+MJ7ZqKt4LicvQ8TC6Z6dM5l90W1+dqCmbDbZD376powYG+bluFrf
IX/syOyPQ2Ytjy3LZpEDsKGjOr0tlzkQ6cWRPcFNtuQgLHG1+DgYxbwCk7WT
qvoe2JCD4WVwWNS1lzkEdx8d7RwqZFZhKK7bsiieGbD29HJ4Nj5zwiJglWXz
pXinNeWh+DlmWHPQgiyGYpptY86OnhmUh+GWQ0XNyziyGIZ2q+KM4UQrysOh
8yiJfpYrozwcw56n91/NmkJ5BJofBufsMVhSHoG+qhe/C2azfCXyCkfuZ16f
TPlKxC8vrPmgNKU8EgUX2+7I35PFSGiOe3mYHTajPIrrR2Hi/25CebR0nhhN
78ec8hguj5HOE2JR8mF3ftigBeWchTg4jT1t9e+bSnkcXtS+/mUcovsQ4pHZ
XHuvrY7dTzwGrOqKRn2nUZ7A5QlwiT3brrtG84RE6X2KiXCKTgiQX2f7XyW1
uApHSjID853Y/tTS80DNnUeNypvZpcq19H4a1Fxfg+8BI2NhStbXcOtpsLs8
SHX7skB9DWSmN/J69T9UE/0kqZFEc+kRubwhCSYK9xFZ+Sj1k2n9T9RPlv5e
TIbPia+DoQ3D1OcspCBN531zl/M49VOk80TmAeqncPvXcutrufW5vIGzkCo9
L1K59VO583O5kPa//wfdNIg5
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzE9I02Ecx/GfU7fhaOiypdtsc5Tl0mnO3Kau32dT51bTTArBJCLwUFYe
rEMGOg/ZrZRWVFBBBoGioVKpo6UdZjQLSgo6rMtk/bls1iRbbf3B73OwBx4e
Xrw/PPnHOpvbBRzHlf+9/1525Iceesc7tFhTlLcrIq0FQmYObafeJtru55PF
kH2afTbSzJwJS+JiTLaiIWcjK/33QN9N5hwEPjinXFXMKlyY9682PlGTNZib
O7ooUjFr8ahCOhu8uoW8FSULr0d14TxyAW4nyt5/czHvQEaP/0TekIqsg8fP
j7ZwzEVQ+W4s9bcqyXq4RIb0QFBBLkW/iNdItzPvgjzIz5y5lksuQ8rAm+Tn
vhyyAS+OPPjqMzKXI1Ja2TAR20zejePvtuklg8wV8M3IxFGPnGzEQmgoAR2z
CYLrd3463JvIZuy8bH9lC2STK1H8UenOSGOuwr7J5b0HjBvJ1Vi9J+pZssrI
FoRLtIbThVnkPfAqPLemI5lkHnxLrK1RyTpwrnD+R/t+6m6g6aQusJLL9lac
9TZVm1al1K0otugPPg1voG5Dx/Mp3+K0hLoN6uTLgCmaQb0Gg6Gu87bvIuo1
GB/r9OgPi6nXomgyTVhxifXa9Xuubv3eXYeIOZ606YXU7ejujc91DJPddqgd
DWb5cDr1ekhSR7u/XEmhXg+XsfdxSJ9K3YGukSp+4i5H/T9zTgg0urhk5Be/
1p303zL/B0YSy+c=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GlIFGEYB/BNMdNdbb1v86jwynLNKzX/3rd7sIEnbIVmKZhXlkSMVthh
RmlJF+YBWauZ0mblnYRkIZQllNCHpMMuxEzLNDN83g+7A8Pw4/8+7zwz8zCO
u/JkmVo8Hi9h+fx/ZYf5DlVXe44TVjQV0pu+YcCez8zDpdrCgHyVI3kNdNKd
ZddTmIXQjs4TDcw4kE1xfyzmlk8lsyUM90306ImYbREctvNYjWod2QGTQzXK
YltmJ+SvEr8fz7Ynr8fmztCu8jt25I34KOgZ0LFndsHd1/euVshtyW5orm/c
c/S4DdkDi1lpJTemrcmekJctPX8ZxrwFfe3xlfrDVmQveAU1OswnMotgnCN/
s/q7JdkbHbwG7rSQeSvOjgpPP4uzIPtAcNNP2l1nTvZFQ5mgo0nK7Ifm8cEL
18bMyP5wS/N/3CtmDsDb5KqKyjlT8jaoQrJ+Hc5lDkT7tHVdabYJOQhhnoqa
AgVzMN5d8fUZrzYmb4ciP+PP8Ccjcggmuhc5dz+WA7OnbltkzFDOAUIPL5uR
JbY+FHzt1tLP1SwPRbFrTfX5DiHlYShUBoZ0NJC5Zbe3nZSUsvpwBIkSKgwV
rD4cdsqFsXQ/lkfAINf4y4l8Vh8BZZBTtsvgWsojYfTV1HzK3JDySGwK9pT3
fTCgPApaDm7zfKWA8ijMGjwoW/Ah86LhHHdxLLVZn/JoeJ/5Nhfar0d5jLq5
GKS6n4sZOcinPFb9flwswuULvjpR1A8vDks86ZKiiPrl4jT6j1dfz8UjqaUq
MlPF+k/QeL4END1pPMAvYvsnwqBAFDhazu6fqJEnaeyfpPF+xBCYPCrZP8n6
E2t8PwkOuQ79zhSTIUGbTUvni3i2XoKUy631Zh6U90sgyXV7+tOK1Uvx4+/D
lHJdVi/VeB9S9fnol2rMhwwr/x+aR8jU55eTISdZV7q7lua7Xwbj1ld7p46Y
4h+eoyfr
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/GTIjpNk9LNmXNq3jIZ5aZ5bb/NzXnNpUSQ9WYgZQ5GYAmm
cqSSXmR5I2gVdAPFSBoROFeiiTUqMSsSg5LQCKxwIXmZJhX7P8HOA4fDh+85
f57nxRNrslRU+3Acp//7/HuzJT74yGGrjYNHLvW1S5cnPouYORxZlC7PPogl
B+Cs2/r0cTlzKDIuJPe5FmLIYVD51qzJrcwR0FoTRRd1zFGQmXO/Oj/KyTGQ
pE1LqiqY45D06c60+GY0OR7nX7f2zSzJyIn4ZulUJeiYk3Hy3atDga1R5BSE
blk33R7fTk5F03hOwWkxswIn3LPVG5WR5N3A9fkP/XYpeQ+KHBbJ4ibmNLiS
nkf71USQlVB2yWzNVyVkFRIbpyZHDczp6DBIFA1TYnIGOmQ1362z4eS9WAs5
ph7RM2dC9aatPmEwjJwF7Uhl9C45czZMzrhBJb+NnIOd8f5zywbmXOjz5hon
3FvJeVgp+RLQUsq8Dyt3/ZvnNMxq1B3vGSoXMwOOyO4b9oVQj3nAaE55+UtK
5jQ45TDmZq6EUNfArG1/EnKLzGlR6xwYemsPoq7FampnY49ZRD0fO4qvvD/c
G0g9H0vB9pb19M3UdejVjI49kwZT18EnJsUddI91PZRtP5Y1wzSP16P9nO/A
zFGaxxXA9XDyd1M46wVwjuXV1w0GUDd474c3wNZv6VZUsV6IHseU+EWUH/VC
QS9Ca0dt9hm5P/Ui7++5Ynjujw/1Ytr/utrTSxDke79hvuunx3yJoJdiIcu9
oVUsUS+l865SL/M2Xyb4f79gvsBcuWC+wJzRez6MdC5avMDDAnMH/vsPEQwR
4A==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtMU2cYB/CTTZyiFNC2oqBoHQRBUFEZlzL/FiiFIvQKrFN0S1hMIJGb
oZNojmh0aOVi1A/qFp2LXEYwiGbGAqsi2yKKA7xtH8ZME294qWEsuK1kW3ie
Dz1NmuaX/3nP+7yXp8s+3WEqfkcQhKL/vv//8kdpvezsLFFhWp4Nd79JL9wj
Zwu45G44W3txGXkWeisy/fps7CCsSHS0RU4uJcshS/mysq6JHQK79W9vXSQ7
DBOPdC8KD4eTl+JQtKN75a0lZBUC3465l3sXk99HxFiQ56PN7EhY3B1xz86F
kaMQbsyMHU1gR0P5a1utfm8oeSVaSxRTLa2LyHGoTzm2Yq8/ezX6cuRbrV8v
JK+B97Nd9uI7IeR4bNV3o/v6AvJaHGgqSa4JZ6+D09HYXNOpJK/H6TsRWTMP
sRPgWPDz0T/LFeQPsHrLvuaeFjk5Ebu/GulWPppPTkK14pTQcJ6djM371toe
Pp1HTsH0ebHV8D83WaTtDyanImnQeeaH34PIH2Kn06BOnJSRN2Doyr0/Hk7O
IQMXQtu/G9YHTlsEgl/IlR4lP78R/eOBZlv5XMo3whbTpBu083gNGve/e2V0
iz/lGpy6P+ft+fWcp+H2Is/zY0Gcp+Gn/tTqqquzKE/3fV5Ml9SXgZ4fk19F
uXn+DN96BK2kPi1iU+Ms3z8OoDwTaZZ/Evy0tB4xEwEV8SkjtZzrUGCL76hQ
8fp1yG2vzyi+zHmWZH6JhWzJ/NmS/dH7rlfU43XSX1OauJmU56DZ+UB5M8yP
8hx4uoa8uxWzKd+E8KnbA4ke3r9NkvpzJfXnIqB03tgX5Xz+eSjVNPbIzvL6
87A8+8R9Wwu9TzD4ng8MkvUafPfPZZDcJyNCQ9xPm47SfDDiW7Vqe1Qf12NE
VmtHW8RpsssIQ2n0wMRCrs+EufOvV5c9oxwmxAZHvTk5RLlogjo+56BsG91v
lwnpot275iDfd7PvfYcZlZ0X6gy7KBfNqNre3JunpH5xmXGka3ZM7yj3jwVd
ZZXjNjv1Gyx4b8kMy41hsmhB7JNQ0X8G9avLgsFPCt+M/8L9aYVh1RlVVQjl
sKLm3ucBwjayaIXu+YNe2WEeb8W64SPVEVe5//MR06Ad1Azw+Hy4YjQv2yt4
fD7qy3a2fWzm8fm+7xcK4DGONBxPoP8XFEA9ce03R5EC/wJicH5/
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQNioVt3b8xWcoDwPtjnVyo4TBKE8RkcpsvtfMGw
VRHK53DYG/16zS9vGF/AYaPqHv2qDwpQvohDC8sL56YuGF/CgXXLNlNPPRhf
xiEk/f1k3zXyUL6Cw2aR53F3/8lB+UoOzWcmlJ1MhfFVHEL1RI5XLJCF8tUc
zKqeqvFxwfgaDltubpvTHiID5Ws5LM4RSGSbKA3l6zgc6N1qIHhLCsrXcyjd
K1+13gLGN3C41jDr29YOSSjf0MFOTHXNryMSUL6RQzjblzthpjC+sQNrPrdx
7lFxKN/E4eDhpUzXImF8U4dlf1fIq80Rg/LNHConiFz1ZITxzR1O/3rR1bZU
FMq3cGg7O10yQgfGt3Q4qNyiwaAE41s5eLy6vo+vWwTKt3aonXd5j9hDYSjf
xuFJlqbV33YY39Zh+sMexnsfhaB8O4elVsYnls+F8e0dskp+bGMMh/EdHL51
rROP/SII4Tc4OAjoGEqf+w/lMzg6uO19meVwESbv6CAt8fjFxEkCUHknh8//
dkU2sUP5DU4Or++ot+g3weSdHYpXW9tvWgSTR+MzuKDJu6DZ7+rAzby26tVk
mP2uDldSv3Fq7ITJuzkUXPt8KFER6p8GN4ftBcsi9URh4eHukB3BHpg8Hcpv
cHd4l3vkq/E3YQcAMGe71w==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2EYB/BTZhd1pm4ub6XOSyuWeMll6dpfp5vbnEuZHyQnISwUIS3t
qh8OUbiI7n0p/ZJWoKZpYVoSkXYlJHMWQh8CL4W24pSliywret4P24HD4cf/
PbzP8z5vdFlVoW0px3H4+/77skda1NPfXSnDfwnqOl+vasGfmUPJbOj8RFc0
eSWszaq9LgtzACwfO/bov0eRJahYPy44zjOHYIN3jaNCzRyBl84RQ/xoJDkK
9xcqhsYSmWXYGWOOEdvXkWPxecp4J/bLWnI8UDqg+WRglqOnatbqbIwgb0Ti
lOg67wgnK1BVb7blmJgToCtRR9mbwsiJuPTVrzIkiDkJP9tmhhvqQ8nJeJrZ
5TM+EEJOwbmJmrqs+TXkzTjcXeCSH2FOhbK10Gqok5KVWPEwpknhDCZvwULL
sugPwxJyGkrt2mnVIzF5KxTC6c7eM8zbsLxoyW1hMIicjvFGZerbC8wZGLXN
rZLfDSSrkM0f+pXUwLwdNe3p6lvNAWQ1/MQDB6unV5OBRa5gcVctmQcCnRKp
IPWnPBOifcnpjqMiyjNx9phX3zurD+VZiPw99CJNIPNZGAoTZi4GsFzjvp7X
uK/nsvGq7/W3MZcv5dnYpEqwPHhP+3E5uBl+o3fEyOrL8ci17vXyWo9ch6vP
Ww741rJcB41lQemtZf3l4o3IXv4jn/WXC31rZ1tcEzsfvft6Xu9xPgb3/XiD
e72cEfv7d2Skudj/RhRf7rgSrGDzyEN7hqxcPsj6y4NJ++TxpIrlJvf58SaP
eefDKS62zZ2g+8Dn4+Spa3EdXuz+mFH2THYvhSfzZrRMHi/T7JbgD7ci/QA=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBWIQDQNioVt3b8xWcoDwPtgrfFgyr0kQxmdwOLiF0SVv
vyKUz+HgoRe24VoEjC/gYNahserDewUoX8Thmn3cB9HJML6Ew4GYzRU+pjC+
jMP8w+dcr++Wh/IVHMosV06Q4IDxlRxmFBWsmGYnB+WrOJwSOpi3ok0Wyldz
OMdw5q7mAxkoX8PhX3nGMYsAGF/LYXGOQCLbRGkoX8eBKSbs5ovtUlC+nkNj
5dtyRWkY38BhWcTLDHN7SSjf0GEx0/xpqlYSUL6Rw1bJZ/e/3BeH8o0d9r4J
9vNfLAblmziwH1Seo/NGFMo3degRvzDpWyGMb+awaX2bnMQdESjf3EEifs+l
PjcY38JhqurfSIb5wlC+pcPpbVtXFhXA+FYOvZs5tffdF4LyrR1imo2jbryA
8W0c3ghHpn7rhPFtHVwaKv4atgtC+XYOxaut7TctEoDy7R3WS6/ZfsmbH8p3
cFhycnEZdwkfhN+AxmdwdNh73OqdxmMeqLyjwzXejoyffrxQeScH3iIj68tN
UH6Dk8M33p2Nf0yh6hmcHZbvvi52SoYVKu/sENhjqM3SygKVd3GonXd5j9hD
Zqi8C5q8K5q8qwM389qqV5MZofJuDuFRRuuKlP7bQ+TdHJgUtH5xr/4D4TO4
O7y3/PXPSe8bVN4dqv8jVN7Dwbj37XfHAz+h8mh8Bk+oPVDQgMZn8ILzARZy
yz4=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GlI03Ecx/G/y8pcnrlpukyXqLVQN29d+XFey3n8N61oPqlAEFZI8+im
JYVPOlhaPejA0iSyJIXIu1UWGhjUSBLEsAWLTpMoJ5Id+/6IbTD+vHj/v7/v
jz1Y5O5qXaWA4zj+z/fvk33EW+/1dxmkcGoma8L6xR4SzMxh28CNp4GPI8le
iJ/09VZUMfsjNeaOJCqYOQjzw/K0+88iyCGoW9oYaNjDLAE/9K5il5Q5Ak3L
bZfVhrVkKVQvE4z2u+HkKEQ/8AsfEzJHY7g88Zxj9xpyLJbFb02qGpWQN2D2
arssWcC8EdVHSivzisPIcVh/2/y2zxhKTsBgtyZcPbaaLMfkQGOGwx5CVuCV
5pF+OpI5EZKWvfbywWByEs7UH2tQTonJyYja92LCIWJOQcqsPlbzRkRORYRN
dL51B3MaLDLV59vGIHI6jl61DoinV5EzYF8/e1DOM2fi4vQpj6lvgWQlhnnL
JVMf8yZcaxsRnR1n3gx5X1jM2zrmLPhvlIc9XwwgA5VX2gWHW8gmQKkoavTd
yXo2Pk7GnIhv8KeejbAQ23vzOTKncrVJhQ6ltCr2sR/1HNT188q0OV/qOWgb
ba0X1pK5XOSUL6QszWc9F4KIDfPCjpXU8/Ci59X313NC6nn44dN7fCGZ9XwE
fAoSz4jZfL7b+QXwMSoyrQ0+1Atc93Fqt3k1Fjnt4s5adv8tMIz0DFl72f4t
bvsLoZeZ1c8PsF6IsdCZD83+3tQ1SDz9+We2ZQV1Dbo6q5vjKryoF+HSuNDR
nszmizDyZNP+2j7Wi7Gu8MK4/iadZyp2PY8rwaFj8w8Nt5ZRL4HZVnNY9XM5
9VJoT8llnic9qZeipiMzq/s6R52n33sh6x/BY7te0WmULjpt4mmfw2kLD+GS
O4c+NHnQvNb1PLjZpIXz/0XgtEXrej6nc5vXud7HpMPX9PlfqrgftF/neh+u
zO3+Za7vm8rovt9o/r9/A/ZcRM0=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQNioVt3b8xWcoDwPtjb9c6b4ykA4zM4pH7jv+Wz
QRHK53BoX33uh5gXjC/gkGg15WreOwUoX8TBozDZUqQHxpdwuDPhGYOVPowv
4+B8PiFBYJU8lK/gUD9jdcGXc3JQvpIDS3GplasAjK/isHB6j8T+AlkoX83h
YOzSBY6rZKB8DQf/6pWsdnekoXwthwotkeKtgTC+jkN+0ZPzuUukoHw9h/+m
ubXthyWhfAOHT4sjD8gbwfiGDpm7J2RuvSkB5Rs53BD8JJlZAuMbO/B+mfPS
e444lG/i0MD/vSXOFMY3dZjaYLtY0EkMyjdz0Iq2OLrPXxTKN3eIv7417nKF
CJRv4SC3s3hb+2lhKN/SwXvzR69AcxjfyiGr5Mc2xnAhKN/aQUDHUPrcf0Eo
3waNb+tQvNraftMiASjfzuE/Q+D/hBJ+KN/eIUp7ose5Cm4o38FB/t/Z0xYf
uCD8Bgc0eUeHD5sv/q0V5YTKOzpMfFxc7fSdHSrv5OBjXr/9sR4zVN7JAZKe
mKDyzg7vLX/9c9L7Zg+Rd3bgZl5b9WryRwifwQUq/wwq7wLVBwOuqPwGV1T1
DG5weQDy26hZ
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU2EYBvCTaZojU1PnPbWULmZ5yWVT92hu3t2cq8xGTdGyBWUuEqPL
VtC6B5ZgCi2Crro/jBTUZWlRYWBl2U1LxJVZQmYRpq0bfe8f24HD4cdzno/3
fOcLLtouL7HjOE7x9/73pMtrdVNb49YQ/NeYyGXXi8G+2WQOxU7CoMq2YGYn
OJRJ1/ivJ7uiNeVEaYYT2QN37hef+nAliNkbn+ROE2FZZH8kpdyrTxydyxyE
zKWea7tXkENQcK3zXJ0ukHk+ZkV2Svd3BTCHoUtduNjNh7wAvTyjQ4DOn3kR
9HbSirb7fszh4MVtejsqIEfgXn9YyXC1L/MyCFs5Y8IvH+ZIVJ0fmBxQk6MQ
V6EYmjHpzRwN3jFBpbGdHIOhfvkO3QzychS/09w4IuQzx+KzaFv6oANZgCi+
oVB5yIt5BY7u28Bv+ObJHIfj/MdV33eQV8KuxjCVpiULcbFa49YCcjwKxvti
Qy1zmBOw99xTk9cgORHDC8crI2VkEZQHowtefnBnBnaWXm6XejFrgXZlaEcg
j/IkuIZH+nX/dmN5Ep6VfJ+5oIWZS0aPqMqe/4byZPCmG3d/PE35KigdL9T6
iSlfhYD6n8+VAspTrNfTplivx4khuTmixhPKxTh763LF6nCaT4Ihk0W7WEDz
S3DAXHTC3ED9VGjqhaLrF1xZnopL8zJex3Qyc2k2eRrio7L0Lirqp1t/jzbd
Zr4Mm/kzoN450TxtLc2XCXGCec+jSZovE46B9oq7PfQ/srBuY2daQT6z1sZc
NmpzdJNDzh4sz4ZQXV6jusHM5cB7o6nnpITyHGw4LBlJuEt9KapDLes4A60v
RXKE6ky5inKZ9fmADIEtmmb9Q3pfZn2+bstQ9CCkNVpL/Vw8bG66Wl5G/VyY
1QtXWvTUz8WPQo1F10R9G3Nym74c7jy+6b2J+nJ0F+Z/+fqK+nJUeNZxpy5R
P896P5GHxnFfw+5S6udhybCf1tme7c/tPOv94hTWORRonDg54g3aTwXcjb1b
xvZRX4Epl82iDrEn/gANpEtN
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd011I01EYx/G/L6i4pFlqutTclFrTlpql07n9NnW6CdHLVjCyoigrA80o
oov6W4ZICwqjIqdlJS6XgaZmiA3TC8nswoFGlILJypdIA0uW2Qt7zoUeOBw+
fHl4ro74UPGuI94cx6X9u/9fdsJMbZ3NRRJ4NKNWXau16oXMHKbnS2p0XWJy
AFIuSt3vC5mFcIbqvzatYA5B8eDn5p9PYsjhOL4w22LezRwJS1Wd4b5rHTkG
R4O1rocKZgnMja9qq8uiyXFouzo20V4XRV6P3u3R/NB0JFkKUbXpbP0BZhki
D39SOTvXkhPg/Oj4ERDELIdclTNiKxSRE3G7d6De2BlBTsJg37tku5Q5GT0N
rdbUu+HkLVDs0d2rFDCnYKq1ZjSxcQ15K948NwbGRTBvQ9mE2DGmDyOnwr87
1powHUpOg3Kue8Syn1mBYb+K4ajvIeR0JBZcbuiyMWdgX4CIv6NgVmL8xMb0
3xWryZnob297XFrCrIKfyevZTM8qshrzj/wvjGuYgYOnCn69/hLsMQ+INYWV
ZxaF1DWY+rChfPMlMq/BjpOy/rkI1rWwKyXHpD0rqWuxKVNudLiCqGfBHH8j
7+05AfUsFPV1vHS+IHPZGBDNTN4UBlLPRqzh1pDZRuZycL3cp2O0gPUc7LQk
xfte8aWuW2peB4FP0/nJKi/quUvN52KvOflpqeSP2tPzcNqeoW55wFHPg3eM
zC2wL1DXL+vLzBng+T/e1A20b5bm85eaz8c3hXtRK3ep/wJjf+KX
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GlIVFEYBuBLC2bjmLlMOZW5tJiUmWXllq+akzk6juN1xsJoU1q0lTZa
rxblrxCU9sDK1MqKaNPEvK4ZYmCWhBQaRWTrxLRomVPRd36cOzAMD++c72zf
vT6rNpmyhgiCkPn3+++XfTRpt6tvZPviv6xR0/ZkX/L0YBZw68f580FXfcgj
UPF2sPSWyOyCzB5747rf3mR3vBz5cPeXYuaxSNI3GKeGMo/HySfXjK13J5K9
IR5Yvtpg9yL7IqA4v3R3IPMk+IUVnsjfNYE8BYffLg8Pto8n++OwxvfprFXM
AdB0Xc7T544jT0e4k/3d3mItORDDN0gbB3s9yUFwjI8I+RjDPAt5r2q35iaP
JQdjxRJz//HsMeTZOJXc373CriHPge1nc9PzLuYQdOQ8r2rJZJ6L7vdl2y1n
PMjz8Mt5TVRdHPN8+Ax70WMbcCeHImjZwbKacuYwZIzQSidCmcPh4DVMbHzs
Ro5AYZa1MKPMlRyJvhKH/a+jmRcg9FF1cXOPCzkK1dqis1WfmYEkXXPT60iy
BMSKA3OH65wpj8boD+4aq4YsRSMnpqDG+RzLYzAjMlCsfaOmPAYlDy/sUG1j
eSzuWAtmatvY+Fi+nrCQryctRHl0Q1OzJ9UT4jDEO+Cn6ooT5XGKXMfPJ+lw
JcJ3rX/DKMoXwcmtfufmXrK0CNfHVdx9rGd5vGL+eKi3Bod35LH6i9Gpzl/b
b2D7W4yaB2Gf/F/ReoQEZLdU3u+oUlGegImDba3zrSMp16O98unXZ30s16Pg
0NDK7mUsT4RfwrHOpeVkKRHf1VW5AyGsfhK/XymJP2/BAEPF0bis2yw38OsR
khX1kxXzG9FkG5W6dAvNByNOd6r6S0PYeo2w3mz/vc/D8b9lI9q01ndFLmx8
Cv9/pCjOQ5HLKfx6BBN/3jAp+sXEn79s4vcrpPLzIVXRrwrLqYrxIn+fEBX3
JfL9J4uK+0nj6yON34+kyOU0RX+a+f6Fme9PyQxjTkDrN096PmUzbIP3luQ5
sOfXAnWO6/v8LWRYUOqX0DWnnj3PFuhqetejfTSNt+B+xuQ6LxV7P6Rjc6et
fqUPGel/z+NId98BspSOi2GzW8rOkuV0NBrl09I9V/wBNTWi+A==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQNioVt3b8xWcoDwPtgX23ySfMoO4zM4XNOIn7B1
vSKUz+HAWuAfJhMN4ws4aP/Q+njlrwKUL+LQ9NmWT3wtjC/hoJY7Ic3CD8aX
cbghFabo9kweyldwKN7AyL7BEMZXcuiPnt3ZXyoH5as4MFR/OS9zVBbKV3NY
+PdQ9S45GF/DoX8u107XdBkoX8vhRtVpAfZH0lC+jsP7r35fvinA+HoOFUaH
H5THSEH5Bg6GTstUly6QhPINHT7N1XPbwQvjGzn0Gb9mvBUoAeUbO2ReU9Xj
nigO5Zs4tE3MtqqWh/FNHVxU+XTuC4pB+WYOJTsPKRz2EoXyzR2WTi0W3OkA
41s4xHBINcywFIHyLR2STijtMm4QhvKtHKLd93P92iAE5Vs7TE79MDlmOYxv
43DJfhKL+F1BKN/W4fO/XZFN7AJQvp1DjtOEvXwL+aB8e4e9x63eaTzmgfId
HL7x7mz8YwrlNzg4ZJ/Yse/yTm6ovKPDT51JNctzOKHyjg6Q9MIElXdyCOwx
1GZpZYHKOzlwM6+tejWZESrv7PDe8tc/J71v9hB5Z6j8RwifwQUq/wwqj8Zn
cIWaw8AAAJeqo0c=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIU2EYwPFjamUrdaabl6nzytK5vJW36R4vm25uc26VIQViKRONsqxo
Kh4/lARpodQH0yK1LJcTg2U3dCWWfshQU+wGiWUShS7TUqIbe94P24HD4cf/
PO97Xk5A4WF10TqKopT/7v9PcrF2Gx/2lgaCRYuihfDtC7VexBQIzfUpr/oC
0Bshu3hAlKgmdoUNpQblRztid1g2dleWd3DRnqCK9Jx9k0fMgWZ+4WTjL380
FzQ8jn2VhDgQ+CV5yyODfuhguFu+NF7NJg4FYXvJM/NxXzQPGIUvZPunOOgw
aOmmZ0bFxHwwvFf0XDjjgxZAj+Nz6bwjcSTc8HVsmNjjjY4C5d7KKPOUFzoa
fM4m9rwNJo6B1mpO8fUmT3QsaNvYIXUexDug4nX7MHOajd4JrX4X+y+nEMeB
cZ+uIK+MhY6HZq7RZe6TBzoBZmvdeEcOECdC7Hj9yZAH7ugk0FDxo71MYiH0
fvO+qtNuRSfDyKkM4cFQ4hS41jHscX7KDS2CCm1nfw6LGGBc1OjAfse0mAbY
pgxyFx9CU6nWplPBbd70RK8mPQ1eFq048e6TngbCaHmdcwHp6RDB5Jmbx1yx
p8MxfZLoThuaygCF5OnQh2TSM0B6y9AV0uKCXQwdI+0nGBXO2MUwtOSiyS/f
jF0CzC/urEUW6RLIy482HA0k85mgFwZqeYNoOhMikgW7Bua2YM+yWT8L1nHD
1hh6sr4UlLcbxEVGfJ+WQpDs0lT+zU3YZTB2b/L79E8GdpnNfDas8hurOsuc
sGeDf5YigdXliF0Oupq1x6Vd67HLQR5X0zcrsMeuwPP8EVm6AmLqv/5INa1a
TCmBYd+t+9xkh/NKqL4y8Yg1Q+ZzrE3bmFLh/6AsBpX1/rQKcs9FhTucdrDY
pLL+HirXen/Itfle0s0Wm2xMqWEhYe13mmDFYrAxbWOT2ub8GuxzOK/Bc1HU
Xw2BND4=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ltI02EYx/G/E1ltaptu03LtlMQfMylrbm7N/dycmy47YgwxOshCGJQk
ES3C2bmI1QgSzQIlKpkWDsyLjDKCrS6KTrsoMHQ3JaXTohNeVOx5L9oLLy8f
vvDAA69274FtXgHHcYa/99/LjqJx5P6wT4eUktYFs8A+K2LmIN6d1Vkc0ZIX
oTWkd+Y2MEuwOLbk0Il5DVmGkPHTs7O9zIU4Eg12jFqZlXghvKadCavJGsjj
Sf3AlIqsgzea8VQlYi7GvuZQZVXrcvJKTCWMWl1ESeYx2G08+cXCXILJmNw1
6y8il8ISsX28NLSMXIavk6f6drxdSl6Dd4qsgeebmdciv809vv9YIbkcj2Rh
4Z7pAvI67HKPYewx83qonkz8fNXArMf17K57sjcKcgUq5pt49wc52YBEZx7f
1sJsxIQneObCDxm5Esr3HkhCzCbYxrerVqmZzfB5hFtbuvLJG9B3Iya/GM8j
W9D98NbhxlLmKnw/f6dg5zcp2Qpx5pB/+jIz0D5899wWPzkArJbycz0vJdSr
0Szs7ylysF6d1m1oD5utkX5ywAbpZ5kiqcilbkfOwXLz6+M51O14EDXN8Ils
6jVpvQabBoMO7wiZc+BqXPzrpl5M3YEV9VfiTbdF1GtxOuQzHVULqdci9Z8F
1J20bwZ1Z1p3/e+ACxsNHaOJskzqdbQfR70OAk3Jb3F4wZrq9TR/LuVAmjk3
zeG4P5jkzfs=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwA2IQDQNioVt3b8xWcoDwPthHNXrWMXPC+AwOIRWp2zk3
KkL5HA5WlX/Ub4XC+AIOpxgjZkxih/FFHOSKGYuF9ylA+RIOlZnTAmZHw/gy
Dp//7YpsYofxFRxMDt3stfaRh/KVHD6kzhIxWyUH5as46D+Zk+kmCuOrOXB8
6FbtUZSF8jUc6h6ftCqvl4HytRzYZdXOdv6VhvJ1HK5NZt50IQjG13P4/0h5
16QpUlC+gQP7zfMpt5lgfEMH5isLr9u1SkL5Rg5za2XSlk6WgPKNHeYI2rNd
/CkO5Zs43P4vvTu6BMY3dYhhCBYLmCgG5Zs5uMx5ILSzUxTKN3cwiG1evneF
CJRv4aBSzjjZ7L0wlG/psLmg+HNUBYxv5bDxk9T8qgwY39pBW1ZMMj1RCMq3
cWh6ktT7ZI0glG/r4NJQ8dewHca3c7AP/xLjJw3j2zt0G6XemZ0gAOU7QOMD
ym9wcFhycnEZdwkfVN4Rld/g6LDC8fDRY5K8UHknB11bvZD9z6D8BicHJgWt
X9yreaDyzg6zr3H/XGbKDZV3djDuffvd8QAnVN4Fld/g4jChhXnH/VguqLyr
g85mFjazPnaovKtDVf2vg9mr2KDybg6BPYbaLK0sUHk3B27mtVWvJjNC5d0d
IOmbCSrvDnXfH3uIvAdU/UcIv8HD4b3lr39Oet+g8p5Q9/2EynuiqmfwgtoD
BQ0IPgCHKspB
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU1EAx/GLRWY6Mzcfm89NrWnLdKaWj/xtOqdOp0lLZ0YaDCs1c6kZ
GVz7oxJs6DSzosSCknyAmoYTKbLSIiUwrJAgM6LsoWVMKh8VnvOHXrhcPnw5
nHPPOcIDBak6C4Zh5P/e/1/6OGq6ettzRVjSdJSq0O1VCYeaQUlZh8lwV0i8
FmKp5JpcRW2HVXbmgIZZT2IeTC9s/U9donaGx/ini3oFtSue8Ea4+196EHti
KLxC+uOrO7EIkfrx1j1B1N7AJEY1192IN+LtMWmRYMCVWIzuO0fqI/nUfkg7
7HPT28WFWAJZvk/YIY2A2B/lhrqxnBY+cQAWbruF7uVTB8JKPjipznUmlqKk
3d2oeeNEHIQeV23+oA/1Nih0E52V9Y7EwXg2cWMeftQhKDh/gs+tcSAORaXT
c6O5kHo7XMfSYVfNI96BCz7zWqaBSxyGNuVU6nEb6nAEmlw2vSu2J47Aw5T7
V1gTdSSOjs48yBZS70RW4b4/Tz9uII6CW/PcaGYoNdArqL3aM2W3ZBYo9q2t
MXYQMzI0R4gOivvXky6DusWg0HVxSJcjT17VZ9toS/oKM9FIy5C26UV0fDQ4
emn4yGk6PgZNsv5Hj/nEbAy2RPrvvveBdgUsPP1+WzfbkK5AxubquOFSa9Jj
l5uNhaRz9ZoQgyXpSpypzg076UHMKvFLYiy7lWdFehy8EupGM5rWkR4HM6en
fC6YzMfEr5g/fvl6mQT0DYR9E0/QnoDu6aqtgiH6/6rlZlVYZHYtZhWR/WAS
ob3c2uggofufCE6e/edzhXT/kxCV9jNT7ULOi02CUJZTUbxAuxoxbOl84Fna
1fBVe/EU+fR8k5efP5uML1ytzlxB70cKfL0t388qyf1CCoaz07/PvObiL/si
+1c=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz1tI01EcwPGDYyit3Jy6aW3ukrVYMXPa2jLbb5uXuXRFF9TcywKRkKG0
h5WjGNGLDxU168EgosusRotF+tCFYjVmdiEqhl3IRVGUZRtClpd1Yb/zsHPg
z+HDl9/v8Ffs7tnWmUMIqf33/b/pEe0cvhXuVkJGSWNHOmZWLKIm0LV/oTx+
WYHOgwHJ3an+dmoBjIxHuIEpOboIPm/hv+OcpC6BGxZx2qCjlsCS3IBMe1GG
lkP00onjrc/K0Eow6tyO0RXU5eBSjd2ReqXolTDC214xEZOgV4HeK8xPaKjV
8ObBXNTVvgy9BmTpJ4/0yaVoDezT3k94HNRrwd7mrUzFS9GVkBidLHCJqbWQ
VMXKuHtK0FUwFHw5PvNNjK6G4cGA6Sifeh10a+Ymnj8UoXXw+MP5BVBTr4fB
MeHNs6FitB7sboH3VLQIbYCnzrbU9KtC9AbwFJ8mxwLUNeDvTPodQ0L0RuiN
T0ecCupaWC0VlXY5qTfBrwu5Bz+aqI3gDl/r39pXgAYILLe9ro4IMvYBTL5V
Ha44hCYmWFwY8fR+4WM3gWXHvI7bkI/dDOFQz4CmIw+7GWTWFoPoChe7Jds+
Cxw48+K26D0He122fXXMfD207tKG9ir/GDO9HtzBGuP1cwR7AzPPmDQy7zdC
jlw9ywvOZ/YRK7PfyvQmpjcBj3O176s/hd2WbZ8Nqo58nzHd+419M/wwzKbN
mk/YGZNm9E/szcx8C7OfMbHjfxLyF0W99hA=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1W1MU2cUB/C7gs6tUalgx5uAuE6GWEedtLWw/kHQqry02FJaSsuWLVlE
3EJxLrKFO+P4MNHIJpvBZXNuSiOTBYcisOBlBOckmGxMSaYxQ5d9YCbrlhlW
prAXzv1wT5Om+eV/z71PztN7npUvvFL+kkoQBPHf73+/8kfrOj/QXZuOeYWt
RZfCsYUa2QK6Wy5OqvpWkhdBdevvSHRAdgzeadMV90+nkeMQif/8ANplx8PY
dOSQziI7GYbQaHfd16nkNOwZsOea/kohp2NygaHh++2yn0Ro51Hj0q4V5Kdw
0vLixx0/J5MzoDWJUc1m2Zm4tzfW+EUoiZyFwtuNs7HXE8l6hDbnt517kEB+
Bk0r5tbv3i07G8MdPR8a2+PJBhyerrHVXX+CvB7N2b0pE3bZz+LmNz0/TgS1
5A3IvT90u8W/nJwDy876YzU9cWQjel897dEvjyWbMN//ZWQz1FFn9029pyFv
xNOlq+KK6mRbYL42cOLyTzHkXFjdf/pKk+Q8D7/eWn1g3X45f476u4Rsxdo8
vfPSL4vJgNtr6KpPXzpvkVnIR2du+ssZw3Kez+oLsGrb+ze8occpL0Bza+3G
xtRHKd+ENz8a/0o7GUX5JjhastdEvx1NeSHLC1FsbOq9qycLRdQfFeXMwmZW
zyxsoX4+QvkWVm9DsNNiPXdSoNzGnr+V5VtZvo3lzMJ2tn5moZitvxipthKz
9swCykvwm3lmtkC/kPISlpci68vohTmHqd9iKToGJrRXk+W8TGmxjK3PDlVa
5oy684H1f8LOrrej9W6wsWCa7i8xCw5lP+Bg9Q7leiUH259ypVHO6stZPbte
2MHqmcUdyv+bxHLBydbvpP//3Hw/RKeyP5KT1buU+wkXe76LPd/F9qcC+5pm
hmrP0P6igtVXKK+XKpT7LbgxlhieOhpD7x/ciGS9+0bHrseo3o3aKxcHx/vU
VO+Gd02r7drrZKFS+f6iEqmzY6OmsPw+s1yqZPvvwZWRvL0N/Yuo3oPjN9SR
0xvo/qJHeT/Jg1D+8MjlBHl+eLG43mAZ30+GV5mLLJe8+OzbT19TN8jzrAoX
wkfWJY6RwSxWQXMvThvWkqUqzAmOuZoGeb75YN+VOXo/geYlfFiryfi9/Tuy
6MOgTzeUoqb5LPnYvK5Gdn/S6jt7yKjGwUOndGejaL6L1Yg8H3z41nmyVA3v
HzdzdA/l+e9Xng/wwzY1MbjkIFn0o3nsg4TKLDpPJD9OtQU1fZDPlwAyq0wj
g2VkBNB+dVn/iS6yGMCdT35wxSTS+SQF0DfqueD2aPEPReoJ0Q==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0+9LU2EUB/CnbTSni27+alNbc5XpnMv5Y2Zr7kydOZ1z0yQUpHIEwSqn
BYUMmhHVG6uVr4TeStGMInS5iGZkRpKBf0CBxl4MS21ktOyuYucJ9jxwuXz4
3nM454Fb2NffcUpACLH+ff696cntmnz+xK2CpNZMnhMrH89mUBN4NymReYOF
6DRIvF33F/VQc9AR4PZMJZTobBizcnf6p6hlcClmdIdc1AXwu8VYtJRFrQSV
03vtV+dutAoiLtFs2T0Fei+89J7u4ld3oYvAn1ZWGi2nLgb3gkYy6C9Aq+HB
SvdQ3bd8tAakgf2B0n5qLURvTTcZ5vLQ5WAIkQkjL0fr4MKa7kWmmboC5syP
05deydCVcHzGJ0/Poq4Cz42x9YGBnehq+No7Ezz5JhetBwk/KjHoqWtgeTiz
2OPKQR+EPnvJfV5KXQtViyMX94Wy0YdArBAdfb2YhTaAYvr81PV56sMQ9Ix3
a3OojWAxfvZ+iGei64DT6PIXEjvQJogcUFWeK6EGcJxRz3+Xc0n7AGJ8qPuK
GE3MMBvb3tkzIMXcDBvbpoc3q9GkHm5fFT771JuOeT28z1uLjnJo0gCap6Kt
+ptizBvAVnM5uKwVYt4IGcKJoejdLZg3wmptnK/XRkzJ3IL5etI+C5M3YR88
PsbkCFPPmDSn9vM1Q+XIlx/m8E/MrZD8PwQ4n5XJW+BYT8WjQVUC6xmTVuy/
gXkrU28DgVIdz3i4ibmN2a+Nma+N2c/O7Gdn8nbmftqZ/o7UHBzMvI7U/mEH
U+9k6p3MvM7UfcPO1P6k4//3fwA5xiCk
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0nsslXEcx/GHWdjKLQd1jhOn1ogUxy2XfNyOXM+hVJoKc7QUUlqztnom
tqSUmmxMF5a0iSR3XeTSssVcoqjZnBbNpoOo/ohqft8/nGd79uy19+/7x/P7
/awT0qKU2hzHyf69/7/0mEXXt9aekGBFap+jwePdUgMyh2a1cGaozppZDzWT
fMn+MLIRUpvm8ixUVsymkKclqjtzyBbg65PKcrzIImSeGReJ+zYxW6G9PW5Q
V0SWwPbl3O1zqWLmLZA9GFUuTFsyb8V3SYp3cSjZBlmii8Y3noiYt6G8y3Sm
3J1sj3bRizuDLUJmBzR4nk4c8SHvRO3Ytc/9ORuZHZE/kf7MUkB2QrCBf1NU
wQZmKbQ87Jr79MnOyIif0m5JsmB2wXTi06y5KnNmV/CGP7OPuJDdsPaRW2Tb
XTNmdxRV3K+UiMm7UDnWUVg6LGD2wMPWEbMeEdkTJo/fH1dfMGX20rA3YhMm
VPZT65l3Q1ess69zgOyDvcO5VwcsyUDsJemhD1MmK+YBR1lxc8g7Zs4Xjacq
YhwEbD2vYc4PK/eH5v2QnPGrQesAzftrdH9MlLi6jN2iHgBV2x/ezo16AIzs
HYW9y8asB2JIuahv08zMByJWt6xYGEhdBmVphfb5e9Rl+LpDIk21pR6Eis0h
o86vjVgPQo2wqnEg1JD1PVjmIpfjMph5DXPBmF9qicnSpflghMu6u754M3Mh
yLR981sppx4CoYVqquAm9VCN+VBsN7aZLe6nHoZ1J02mL6dTD0Oek/JTSRz1
8NXmw1ev5yJg7Xss9+wS9QgsXqk2P/yD/l8O2fNvyein/ZFjTbRWnbqD9l+B
Sdu5TEcFO08oYK/Or268TuetQG/8wdn5j8yvFJhJ6VyQLtL5RyJb522PXhG7
f4iElUpQWB4jwF/oWhvy
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlHtMW3UUx2/qNlBeY4OODaQ8ltnxXKk8xkO+7VhhMKAPKPRCCdEQnZ0y
GSoTH50QcTEawMU/YBqnSLvhI7iH4KxeHAiIYJgZzjmzKHFhygwibnbKpobz
++P+mtw0n3zu+f3OOb/fPdH315vrFIIgHPjv+f+f/ZTlp870O2KwQgu59S1u
zbNKxgKa+lzivCea2Beh2h8npvYwXovs4aU3jEGMQ/DD3GhNR08UcRhadZ/E
Z+kYR+AXadLHdExFHIWrnW0tbh/GMfjcHpt4MTOSeDMmGxYV9e/cTbwFNn/t
118FMVZjscua/3NRBHEc0vYMX+zuCSdOwIasgZ6xa5uIk+AVT+rmVzPehvHz
hkeG0jcSa3DWdfJIelcYcQpq4v5ccqgYa2HR+ArfWTYQ34veZbdqyxElcSrS
FkV10eVQ4jTMHlyn3vcA43QMxbaqhRjGGdhmb3F53CHE26EfskTGqxhnwidy
VdnwufXEWZg4fepYwz7G2dAn1R5uqGWcA42ha7Bwch3xffipOy31+1cZ5yI7
ZXdbYG0wMRAeNjvX0bl2hZ2Areu9o6EJxIIOpxfakzdNBpLXYeSPIIv4mD95
PaYHzi9d+MuPvB7dM37e3lRiYQfE+I6CqSbmd0B1a3IiY+Eu8nlwjA18+s0g
83mc34mO2f3N+hs+5HfihQ5HZrOKWDCg//36w0lVvuQNSDixak3aK8znY2wk
58nGj5nPh/blazd00p3kC7j8CqCIirvp18fq24XrAYMH/0kldu6CZzTzN/Us
84WYCXjxIW9JAPlC+ftCkbwfziLEFr42I7pZfbu5/DgWiuFN6HzatZfydRZz
9ZfgqeduDjmOryFfAteZb5VfRqwmX4r9fVm5H74lkC/FyveuIG+UM4xQFRRv
Vx6neKdR3l/JyO1vkvcTJrS33jFw2U71OU3y/CUTFk5MLz8Tyvpv5uLNXL/M
8vUkM9c/i/z8YJF7p0V+HpJFfl5Cmfw8UcbdZ85LZdz9LOfyL+fuS7l8P4lj
wSr/vmDFXn27J/Ao+96sSMxJKvvsCou3cvtXcPVXcP2rkNcjVcCtOzvyxUa2
f6V8fVTitmC6XdsYRPGV+CD83Y/OFRFLlfJ8BRt6xt9+wq+R5W+Tzw+nDb9e
uqc1+XliifOCiCvJMdpHt9I8gojEYPXvXdMsXkS07sFDj99i8SIMnqsPY5rN
ryrkOZuWNW0svorbv4ruP4vnvFCNl1LqLnXXEqMa4zObl/72p/Wc1TiwddRb
V8riufcFu3yewo6613sVzW+yeDvm19vqrh+i+SvZUd2iFS/MsXlcA4uQMdUf
HIJ/AQqg96Q=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H9MlHUcB/AntKEcByQnIj+8gyIVC/MAQcR8Ax4/j/OOu+MOOrYrd5N5
hclBpW51kClIlKmLBlmShFPUhQ7iV+eTv6CcZFC31tpsNjFbKYtmnCJW6/P5
457bnt1ee38/3+ez748n7oWtJY4AQRAc/z7//fMvwtwz2O2Mx/+aXH/58wfF
xyPZArT7m5zG4TjyPHQ3dO1WvswOQ9OYS9EUwVZA23rjxTfOq8iRaB8Oun2r
ih0DX4PmxMlAtgqmipiyFpeSHI8xuVKuurSE/ATKLR9stgWzn4Rr+177+PZY
8jIkHntLaL4fQ07Eka1KRcfr7Kewa66h/aonmpyEb25dv9M7l/0MbDKPtS08
irwKOXcKl9a/uZisxk9DezJ8NyPJyVgc7axseYmdAt2o/sLRykXkVEzt1lg1
avZqfBTc0qv4LoKchi1pVSFuMzsdraqe0ImbC8lrUNN/TnW+kJ2BlLHmVxMG
FOS18D3velDXE07OxALZoqGJIfY6ZCfZD1bb2c9i1UD00uu1C8jr8Xt4meNu
Ixu4oBfb3ANkN/Bc3tmge59xnoXmM/NXeK5xnoX2jpGF73o5z8Z00Y15dVrO
s+E41Bmw8/BjlOdgYmV8ctVysjsHtcsPHth/OozyDSg4dup4woehlG+AvFq9
drxeTrkGOaaZ1Y/mhlCu8R8v5KJ2UJ+ZPs15LgJUifdkXcGU5+Hbvu//+mFa
Rnkeyle8lz/6GlnIR8dXR16R1XB9PnQn3tE4evj9Beid3Lcy6grnBZL+CiXz
SywU+ffjLoJy9srl9MkgyrX+87m1uDgVaizfxv0Xo80r83Wm8vzFuCvvr5tJ
5Vwneb9OUr8Ryc1//J0lzqd8o6Q/vX9/kNitxxfDGbeX/UIW9XCO9HnG+7ne
4L9eMEj2ywBLufpUdTztlyjJhRI8vS7JdHaC60vglTdU+nS8HhKLJZL9M2Lf
rjl91ypoPWGU9G/070804qFgeGiv4fNjwtTsQFl9IJ1HmND5eOGPKefIbhPW
jA4evvQzWTQhLmtzY+0sn18zZHNO7vjtAJ1vmGEL/KQ1WsPn3ew/XjQjtmvG
a0vj+1GKTLV2T4id60sl9ZJcLIV9W8X9r3/legu21Ez3PmKh+wcLPs1IHjl6
iO+jBR5bwpdLZGRRMl6wwuhtfHsslr4XsPp/P9xWdP8Z9fGOSrJohdMaaNjU
wt+XMuhcYTvfv6jAP0WllYQ=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XlI02Ecx/ER2FzlOZ3m0XRFbCbS7HJT8+N0cx5L0URd4UIYCrPDPPIK
fu2PaAmVB/0hCRnSNCWZdGL6h6EFotGhU4gyLKRhaTXPYFT4ff7IHzz8ePHm
x+95nm940dls4xYej6f4u/692SPKfdhvM0mwocWE2opY6QMhMw/V3Vb9/EA4
2R1VvOnOmTJmb7y6GvB+wYfZDxNzWSeuPQojB6K+9aPhUwFzCOxTvwVBwcxh
OF680KzrEZMlqBr6cbrTuYu8B67ZY/M5ecx7kdcnLcrvCyVLYbrQe7HrQwg5
AoXZjo7RQuZIfH1mPjfYE0yOQpv7qZo3U0Hk/TCc8VWuRDLLscR33C227SRH
w1z6rcFqDyQfQGHEktMkZj6IW4+/N4QKAsiHULHeJZErReTDyJ12s1yp8ycf
gdZhH/Rs8CPHoMAwpNXnC8kKtHe89L8+6UtW4p1xWSB96kOORXhisaXS5U2O
Q3ecpET63IscD51mZPhzPOtHMfzLK0dftoOcALFrbDRmcRsZeP1kwjm1un3D
HHC50aSsE/OpJ2JBse5SRW2lngixVqcQ3XOjrtrUVWicLa9TrbDvk7AW2VRv
LRVQT8LutJuT+k72/2SMBS06WrzJXDL0+xq149W0H54aHuejY9+aPairUaq6
MeDZ7kldgxrZizVjJp2X02w6f8r/5lI23Z8WlbKW5qY+1rVQjPffHplhPRUn
+Xdag9V0/1wqym29lqxaNo80VJRYBzNFNC8uDavpX9wvZbD5pWNeWGBctrCe
jjnZzxp5Fpt3Btq4iVqv+0L8ATeJ6BM=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQNioVt3b8xWcoDwPtjzhfRHv+GG8RkcvgR/u9y5
WRHK53BQlLq4dp43jC/g4LPdQDf8pQKUL+Kg/oFJ4lYDjC/hkMXHWBIpB+PL
OExmfzzHI1seyldwyNhw56DCGjkoX8lhf01G6L/3slC+igPz32feZWowvprD
6xuLIxwnyUD5Gg4y8w7c7LkoDeVrOdw+8vtobiSMr+PAnrbz1M0yKShfz6Ey
uEvnxH9JKN/AwdbK01ApAcY3dDgVt/7TPnMJKN/IYVp/XsGqVnEo39hh2d8V
8mpzxKB8E4f83kpJ4cmiUL6pg3a/2zmn0yJQvplD+lSmEl5jGN/cQVOF/cl3
d2Eo38LBpaHir2G7IJRv6aDomN5Z+k8AyrdyKNWcMnnSJhjf2kHXVi9k/zNe
KN/GIfvEjn2Xd3JD+bYOHzZf/Fsrygnl2zmclfrwaooAF5Rv7zChhXnH/VgY
38FB/t/Z0xYfoPwGB4eLO65+ufEDZp6jw0+dSTXLc6DmNTg6yHv4WoqtYoXK
OzlA0g8TVN7JgZt5bdWryYxQeWeH95a//jnpfbOHyDs7GPe+/e544CeEz+CC
Ju/iwKSg9Yt79R+ovCvUvI9QeVdU9QxuUP4zqLwb1F4GBgC+H7nY
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz1tI01EcwPEzlbCmtuX6u5y5CxFmbW2zmsvmfq45tylRrZg0IjUEy4d1
k2JQ/gtmBmtERUEPQr5UMxd2W+AeEvPBxgINSzGEZUQXo41Z0ap1Yb8T+D9w
+PPhe/7nIm9x72zNIoTo/85/XzqY3Q8GB9oVkFHcqC48/fq8iJpAnl3qmXoi
R+eC6dWuYXcztQCUHYaLAh61CKbPJIOa6zK0GFSSewWsg7oEDnT8OvZ1XoqW
gfqlsklXTa2ASKD0xMjNUvQqcJ07/tjAp14N2lCwX6FbiS6DLkYxoWkpQZeD
1+cYjQxJ0Ovgi9NOnB+L0So4mJptTTuo1TB5ZdK4ZmQFWgO2QXdRkkethYGg
+7LKJUZXwIQrpn+fLkJvgE9diwPebuqNsH3+/ugjM/UmYHMrTiXfMGgdDFuT
PfLwcnQl3DoUHWvzU+th/3Q4fGNOhN4MM43+s75v1FUg3hce91uot8Cz5sZE
cqoQbYCrMR9vJrEMXQ1Nh/f+ePpOiDaCUliWuDYmQAPckdwOjdcvzZjlmNTA
i/zutu/b8rHXgHOPNnhEQbsJHsYvrC+OFmDnmGwF4ZyIiTO0c0zMkCUrT/H7
8rCbF55HakGajkYq40uw18IOn2ZtjjcHuwU8namh9sAi7BY42fM8zMSysdct
XM/WQYOuMzSrot2K7/ltzHQrHO2rMt7tJdhteL+f2G3Az+73fLiUyJjY4bM+
lTap3mK3c3o97oOD5Zg0/P//D/Vs4EE=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU2EYx/F5IbWovE+d8zKtXJqlM/NW+znvU+dUpEQhM0ZRmealcIKt
QdgijTYLXI1UShFTmGKgQplRDbNMS6GyMpJmKTQwjAjsQu/zhztwOHz47nnP
5V1gaXmewpbD4aT9Pf9d6fAsGBg2HhfgvyxiO7Ok+rwbmYMbk0t95v5AZkeY
x7XqnmKyM2qUcl6LI9kd2R99p+WtAcxeMB6Lqf0hJfsinT/e6PnFnzkAswOm
+sMxZAGWBcJJ/U0/5mC85i8eKP/FZ94Kjbqoa3YbOQRjR32CRtW+zNsh7xPF
TfTzmMMwrhw71M4lh4Oja7jYIvBh3oWJppVGicGbOQJzpkWXMi45Esbe8ubw
Ii9mEUQ6vrG+hcschbe/ecNF1eTdaDp9Vp3w3pM5GucMLw56V5D34L7/dS+D
EzkGltyXl69GezDHQlblXHftkTtzHJS1oeaZLeR47DDzVOvtyQmQPMj3C/Un
70XwGRtd9Dc35n14enegq7KCLLYykD+juTTFZ1YBjf1Oofc+uLKeCINqWrm5
l3oiJOElzZUlNC9B2y2Tx+UZ9nuVBBGp+kHpM5pPwga7HuVXnQvrSRDKgtxT
ypg5yRDv/14s41FPRq3wyU9FjjPrKYh9Ptz6eI5ZlYJXihWnkEGaT0Vg4hFN
zSr1VLgujIx251FPg8LQYVvXSuun4fNOgeikkHo6OoKkb6JGaT4dVd3x4r52
un8GaoTNOm0f9QyrLrWal6LYoV3PS6H1M6GeL22cv0P3z0RCZFbDphLqWWuf
R5W19n052VheHSpUO9D6VubIUKjvafMIoy7DxhOuixdOUc9Z+z1VOeB5fVq4
oqUuX7s/kGNKrLXnvqPnkWPJrVCxomH7OSLH7TiRqdNA+5uLdQU2/ZaHzMiF
TmHRFXfS/yEXpSbBkEjlhj9EQRbm
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBWIQDQNioVt3b8xWcoDwPtinpEqt/cgJ4zM4cF2+lDNj
jSKUz+GQLSD4Rj0GxhdweBjJ23aLDcYXcfg8o/617A4FKF/Cof+D1d32dBhf
xsFI++VHAzEYX8FBn736Zn2GPJSv5PBeuPqjxj45KF/FYf4Uxa3X/8lC+WoO
Z0/YKUs5wfgaDnGfPesCF8lA+VoOm8wFZW+zwfg6Dr8azi2wCpeG8vUcThjs
Luk5KwXlGzjEcO+LmC0M4xs6/Lycz+5SLgnlGznssXzvUDRRAso3dnhvYOW7
6Ys4lG/icHLqmsDXGjC+qYPgBD8GRyMxKN/MoasuTnzNF1Eo39zhN1+6/UFX
GN/Cwa9YoHraUREo39JB97l0AxcLjG/lcLLSxSZFTRjKt3Z4vOdvg7a5EJRv
4yCgYyh97r8glG/rcMl+Eov4XRjfzuGZvpJxniaMb+/QbZR6Z3aCAJTv4LBe
es32S978EH6Dg8M13o6Mn368UHlHh9nXuH8uM+WGyjs66GxmYTPrY4fKOzlU
1f86mL2KDSrv5ABJT0xQeWcH49633x0P/LSHyDs7vLf89c9J7xuEz+AC5T+D
yrtA9cGAqwM389qqV5M/QuVdUdUzuKGqb3BDVc/gjma+O5q8B5r5aHwGTzT9
nmju84LzAagqyAo=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQNioVt3b8xWcoDwPtgXJLy5l8sN4zM4OJw99lh7
syKUz+HwKfDwlMv+ML6Aw7aTV/kPvlKA8kUc3CdrMf7phPElHFo/1d+9pAzj
yzisbfzK3VYuD+UrOHyo+1Cz+IwclK/k8K51+qwGJRhfxWHzl5o5FVWyUL6a
Q8wu5aY522WgfA2H6kaNia9UYXwtB2fPezLvPKWhfB2HzwlH7fculYLy9RwY
ruQVZr+QhPINHH7vvMDPVgnjGzrUHFt3j+uTBJRv5DDj4Dzm9jAY39ihqkQ5
f7WjOJRv4rBy/rMN2rFiUL6pw+lfL7ralopC+WYOLnMeCO3shPHNHZZOLRbc
6QDjWzgIrb2a+aFOBMq3dDi9bevKogJhKN/KwdX2Sc35X0JQvrXDvhjVg3Lc
ML6NQ+rcZUzVCwShfFuHUs0pkydtEoDy7Rw+/9sV2cQO49s7+K3pc03dygvl
Ozhkn9ix7/JObgi/ARjdUh9eTRHggso7OnzYfPFvrSgnVN7R4b3lr39OemxQ
eScHbua1Va8mM0LlnRx8zOu3P9Zjhso7o8mj8RlcHIpXW9tvWsQAlXdxWL77
utgpGVaovKtDeJTRuiKl//YQeTQ+gxuafjc0eXeoe59B9SP4AKs3yPk=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQNioVt3b8xWcoDwPtgzP3cqaRWG8RkcFB6d71Xe
pwjlcziozz4o3J4C4ws4nKtZv/I3O4wv4hBwz3CG2i4FKF/C4d/DxVGPo2B8
GYc5Z0QVExlhfAUHTYXmHZwR8lC+ksM2M74Dd6fKQfkqDk4Pp++LnisL5as5
sOmHmmSclIHyNRxU2JnCfkjD+FoOPGvU12jnS0P5Og48/bbZex9JQfl6Dqca
7x7jtoXxDRz6J0YLNV+QhPINHST5p1gtsITxjRwYJ1z697JRAso3duic6s4q
f0EcyjdxkOvIWvlFFMY3deC+/KXwX50YlG/m0FBq/8VKDcY3d6jTqZqd90EU
yrdwWC34TkJtM4xv6WDz9eC9njgY38ohsMdQm6VVBMq3dpjbcLWKf50wlG/j
8EY4MvVbpxCUb+vgtvdllsNFQSjfzqFUc8rkSZsEoHx7B0XH9M7SfzC+g0N4
lNG6IiV+CL/BweHoZ/7gqEIeqLyjQ5T2RI9zFdxQeUeHCS3MO+7HckHlnRzk
/509bfEBym9wcvipM6lmeQ4nVN7ZoW1itlW1PDtU3hnqHxaovIsDN/PaqleT
GaHyLg6Q9MgElXd1KF5tbb9pEQNU3hWq/qM9RN4Nqg4KGtD4DO5wPgArQKXu

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlmlMVFcUxx+IgCLKJqJYGawaNolLUUCRP6u4gMwM67C9WTEFFfelGp9G
RRO1amma1raZWrF1KQ0lRhaXZ13QWkgtkfZDrWPB0rpU3Cgagdpw7od7J3mZ
/PK/5557zrnvvBNsWqGzOkuS1PTm+f+f/fyzTzfVlk3EIHXHr719649yH8YS
Pq7ef6u/NpjYHdrAQ4GP8hh7oXi5dtIoN8Z+CJZ6eqbVaIgD0J62tP5eCuPx
KHu67N7O5iBiDR50tV6LD2U8Ec65hy97rZtAPAktq546r6h+i3gKKveczDnX
N544BD91nTd8PY1xGHyj5KV1xwOJI9B2+0KPuyfjSLy/reSSdvM44mk4EqH3
0zkxno6IavuYsL1jiWfgx3mdqbqWAOKZ2DHwm851GON3sOyoyW3X8jHEUTjf
6OPeXeVPPAsd23xCKsyjiWej+sPV3g1gHI3w5oAXR+/6Ecdg08bwrvbJjGNR
V7H6mWGDL/EcXN+YPNcyhfFcfHR3r9PvT3yI43CuufJO71bG8/DQN9/as4dx
POJznxdmBHoTA8nKhr7plcQKEJrxtl/KMqYnoGlc1WcNj71IT8AI3+/XV/w9
ivREPOtvzN/uxvRElCceODfyi5GkJ+Ho9S/XeawhVpIwNS4y68KfnqQnI6i/
5UZ093DSk9Fdd7Nvy+hhpKegtmZFVWSBO+kpiKhzcZ213430VEFPxeLZW890
RA4hfT5yDTNqVk0ciB/U58NZE/bK4+TrQZbSBF1gaQE8hnyz6f4HTrT/AsF+
Ie9PWYivmn7x/2H8UPK/SLBfJOy/GFs+bzvrf5fZL0ZQWnqM/wlmnw7t3unh
LjtdSE8X9Awh/gzsOlgW+14Qy88SXLsSt35NI9OXwBB+MK11gwfpmcg4tT/F
eprqAYGVTL6eqsCSlq8vtFjblDk3upfVW4t2z91LX2bQfqrAkg4Hdgypv1NE
9YcOM/c9+jdBpforOpRdqz/f1kDnVXV8PJKejx96IZ96bNr66mLZCVey1wv5
ycLjmFf9iZGkI4vPr5LF518VWMrm64ts2q+H7hPTnwyyKrCUw98nCKzkYLA/
O5P/HD4+KZdn5Ar3MRerT86J/+6IRPaCLuXx8SBPsM/j86PmCf7zBf/5Qv7y
hfzl8/tJBn49DHx9FAP/vqsGoT8U8P0DBfx9UQrQ49mw7XXUCLIX1kuFgn0h
rjwbpTespPVKoXD/CoX7V8SfB0WC/6I3/Tj2n5AO5r8ILeO671d5Mf/Fgn2x
EH+xkP9iIf8l/HqUCP1CYLVE6J8yzxpZeJ9k/ryyLORHxuF2j5fHoiheuyzk
W+b7iUOG56oZc9q2s/ffyPcTjVHoR0Z4P/Tz7/YnXTby/UMxIinr9ayhqaTb
jfz5VCPvz2HEzfpbz3/tZf3PxOsaE74NPHXm50X0fYOgyybBv4n/ntkFXRV0
h4k/r2TGguM1JyZ/Sv40ZmwMbX5pXULfU5iRWR5248VYYlnQFTOmeoc8+eQm
sd2MwICOvw4eIlbNSE+9eqUzjthhhme5z4PdK4klC/UHYo0FA5J2QF7D4rcg
OKF0z9p+5t/C+1MEtlv4eUG18OdxWIT5woqY1ib7VQfzb+XPByu/v2zF9k7T
vs5TbF4R2G5Fx9k+JXw2zTuqlfonscMqzEc2nKk4lh85muYpjQ2u2U513ZdI
h436IemyDZcz1cNKI+mKDZ3vhsb2VZJut2FqV6Ay3IXmN9UGvRTdWutN7LAh
8aJ+QngQm+9K4VW50nLnCLGmlF+PUpyOt/VuLvfDf9IwB2M=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0G1IU2EYxvHTUsgs23SebTrTaYUuMUutlqtdUze36aICiYzCRZosLTAL
ar0M7EMwIpohfQhJk1aaySQjGMsCIbNPvejIaFhJqTiaSIXmpGL3E7gHDocf
/3PfDxzFkZP7qgUcx6n/Pv/e7PAVfR738XSEFdTMXAkdypQwc/CYHYo+r4K8
Au9rq2S/q5mF8I8dVcpjmMVorWy1PvGmkaVYGHrwdvwgsxyN39r2q4XMaehp
zt00eiKVnI6xprEai3steR1E02I+yDNvQPD55VD0gRRyJg7PGi/ubZeTlWi6
EKUQiJiz4bbLJj5Yk8k5KPHbFhOGk8i5mLbcvT1QwLwZN/nAoMUlI29B/3hP
/6cC5jw89s3mx7+QkvMRGkh1PBqVkAvQIKv3BS4xb0WtzV/TLmDehs9t7yqE
STx5O1INZhXfmUhWweXx8UNy5h0wTPmexjnE5ELYhs+u5qqY1ZhsadB2axLI
O9HWMZh4bSSevAsbU3jZMQuzBnrvpBWvRWTgjcYZJflItgNZuzPEunrWtTid
daPZ2SukrkWy9MvEdSeZK4Lx/sPO9bfWUC/Cnjrlqx8y1ovR8fLOmdjGOOrF
EKQp52O7VlEvQYapZaTy3krqJZjLdp531cVQ19H/iKauw6muQk1vO0ddj9jl
3eemmpdR19P+BU24l1KfCdteiu+q+cWinK/UDUttNyz9njPSPXTsxoh5U8R+
E/Wf1Msi9pct3ceVR/Ry5F0N/NI+m6N5c8R+8//5P9tC7nk=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03lIk3Ecx/FnOtOc12zO23REiZil5cqj9tnUqemm3aGVB4qSgZhKZqX7
ozApTEqQsKgILNMMselEZlZYYZQXapdJB0ZlOVl/qJlm7Pv7wz3w8PDi/Tue
g8cvM39XtgXHcYql8/+VHeK92s6WPAlMMshGqnmCfXxmDunCs2VdTX5kG+hP
6K+8VzE7wbm78dY6oy9ZBNeD6x0GbzK7IS3L5eFQJLMX3s33z1boVpN98eWn
PEsrYpag1/2k5UiOD3kNzld19mkfe5PX4qud/pGVD7M/eDXGLu9cL3IAVHc9
r/Y/8CQHou/bp6k2PnMQEiJOxYsyPcgb0VD8VlZ30Z0cjBKNsPb4gBs5BBgv
SxUqmTeh4cg1t0CtK3kz2rttY6//EJNDUTTXIAkOZ5biT8GNclWuC3kLhv2P
ZtS3M2+FdHJirMmaOQxpo9rDQyUicjheZRyYNr5ZRY6AT0dhW8UL5kjUfrzA
+zDtTN4G/bOK8Zly5u0YlF3iu44JyTIzA4Ut9yuTS8kawE+eU1m84ERdjkVu
52J6kSN1OfanhDQfk5A5BaL2zEutlA7UFWgzVG/weEnmoqBuqorJ1tpTj8Id
+ZOep+5kLhrCSZHYIGbzo5eP52IwYn8ud1bN5scs349TLt9Po4SFb8CcoNGO
euzS+wj/5f+ZrIk163Fm68eZ3V88qs9Y6sYP2VKPR4/RcXdKAZu/A3nPdV1D
HQLqZuYSUDcimK0PZT0BA7rh369nWE+EoXXg72mXldQT0dKcXxOUakNdhcBW
/gpplTV1FW53jop7vayoqyGwvFf6/TKPupqeb15m6kn0vRZN1iQtH88lw/T/
W5iMZEyFzS0ogiZk/wCDLguf
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzl1I01EYx/F/znzJolnL9lZTWVOs1qbl2mru5+brrMi2EiLBgj8IE4Lm
CNyFk6ybEhzzyhiJRQtRQ3LYHGYZUlFd6EV0kQiOvBjV1kBFo6zYcy7cgcPh
w/c8h1Nw7foFPo3juPJ/+//JVt7FYHjMUYik4qaMlWFlL8fMoS3nXHTuYQE5
CxUFgiZXPbMQn0asdlEsnyzCo0BsCT3MYmTxC82DGmY5Zuw6T1VIQc5HVO4z
v/hykFyIZ/7+OaWSWYmEaaFxufUAWQWbLcc++FlOLkai/1Lt1wbmEhSpFLbu
ARn5CA5t3vWuS5jVmA1mfhtpkZI1aLHEDZ5VCVmL3PGwxFvCXIou5/ixD1Yx
uQwunYoP8vvJx+FQ/1qcf5dHPoFpxX2xP5u5HO2hmfzX1n1kHTTNtwJTT0Tk
k1i/6vzdFdxL1mMsIX3Q0cpsgI+P+64E9pBPQTspK1pyMZ8G73+c5h7IJRsR
lvb5QzEhuQLn20rer0iYTXgqG56Yb9hNBo4a1fbp5V1Je4CpN4YfxZGd1Cvx
URqP9gl3UK+EN+J0m9cyqZtR1vN9rfJlNnUz3s4ab7ZPZlG3bLXHgt5uwfPF
ZnqPq8Idr8PgVtB7nip0dG68cgxlUK9GTL/xx6wme6q33udqoKg7q88b2k69
Bo33tIfTb6dTr8UZXedERC2gnmKuDk2XS0dvFG6akj3FXD1yBCMdUd82mq9P
mbfS/1Zp3kr3f5r+AtlB1W4=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2EYwPHTNCt1OM2Wl+VlqGjZ3NzUptket7l5d5tOSS0qkqBZpgaW
Jp3uQllZ9mUf+iCUlSaZhHkpFhVFYGF5hS6YIM6QFEGdhVbseYPzHhjjx59n
73seWOiBclMpj2GYwr+ff9/kEZqf9HZYxODUrOrr2IZBgzsxAzWOmf3Se6Ho
9WAt6OkR7SEWgNQzTjnII/YFaW2O6EtrCNoPLOdv1PTtJhaBUdmq958IRofA
9/jXnsNaYjEoloa0C9eD0GEgsjgMd+xb0BEQE2h9W+lGHAks7/O0l1aE3gp3
FabhX9cC0dHAKykYm+oKQEtA9j7sKX/JHy2Fuvu3EoqTiWVwtmzmcsuIHzoW
OtrLmyTFxHIYKh5X2lc2oxUQcWpk4KWeOA4SIx6NtjUI0fFwyDKpsfGJE2Cg
7cN82JFN6B2g+NhQHd7ji1aC4FLFwW/NxImwvKRpro4mToK99Tp78quN6J3Q
eaxqvugEcTLIdNbujH4f9C4oOScvGp0iVsHzkvAXQR7EALpn9sMw4O00CzAZ
I5YfjUIzKXAy6o2jNFeAPQW2e0fOWQfQjBr4ZT4/6itIV8MqY1zdd9wLuwYW
+N1nfsd5YtdAf8DsdJPAHbsWfiqXV9QSN+xaiO50dYu/ug57KgSnZSuFD9Zi
T4Wq1iTV42YGuw7qbn/qE467YKfM6MHD5WHN9M012PXUfBo1n8Y9j0kH4xXZ
NtcLrtjTqZ4BjRNVtepFvC+bAS29I8J3ItIzue/DZoLz/8bDngVZCae7JiTk
fMpMNrWfbLjYaEmsDSb7yaHejzKTi55TOTtlxoC/P+k0GHAOH5ayzUDNG6Gw
KLa9UryK80buflnKNiPIG2YWU2wOnDdxDSbqvlS3mbjnMXncfUIet7OUbXnU
fvK5BsosZVs+dX8z9f5m3OcCnm/+v78/caxY6Q==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtMU2cYBvCqUxFEW4EOAQWbbaG21iFqYcB4qFiRa+9lxWzMjJgNNpRL
tN0Yh2xJNYoXKJrNjWWLSwNjOsTLGDgOiwSVwGTLhLkEQjTomJfiBQuxsC19
vz/aJifNL0+ec3K+837fmp2luqL5AoFg53/X///sJzae72gtlsArV6raVjCg
DGYWQFrYV9Zwdg05AO/+WvUg2cIsREvFW3UN85hDESvqtGu+jSGHoymrUeTS
M0fBucN5deTPaHIM6opnrQslzBJYmn9pPFmzmvwSmvQmtXx0FfkV7Hq8W/VJ
AnMszg2MdV+viiKvxTvu218c/SaSLMfEkXZ1Um8EWYHDSQ5pTSDzq2gaVwzf
zV9JjsOVnpS9FT+Fkzeg9XSpQ1HAHA/P5eiD526+SN6I4YZCS8t1MXkTljYp
tZ1fMW9Gaa11ZUh9GFmJ5KfdI4feZE5Abrnww+M9oeRERP2VD+Ex5tcw/Xa5
p+Z8CDkJWW2TmVolczIu9dpH3dUryClwn1r88e005tchlMdFDsyJyKnoiHB8
2f5QSAbmBNq5worlXnPAmciWi79lkQVpfnkaKqWO+rqzrK+CVdo7XZRH5lQY
/PGPJ8PuIMq3YCq4veb5pqWUb4HoXqjYJV5GeTouuI6uj+gnc+mo7NAkJ7hZ
vhU9j5frLXtYfyv6I1wTDmEg5WpMy+s+cpYsoVyNh4kzsyrFIsq3+ZrzsyAD
tuqZ7uJmlmfA2TEkvha1kPLtiM7ISRQ3k7ntyFZWX7ylWEB5Jqoaf+8Uj5G5
TMyPWTsT9N3zVG+eRc+b8ppjHqc8G0ELvrdN1E9Sno342vvP0vhpynN878fl
+D5PkAtX26CnKoy9fy7NbwDleTS/ZC4P0bP9fQkutn4a3/WEBhbZsYyBffT9
OI3v+vMarEtRGLrGg6mvhdmy4XSZhOYDWr/vqUVwyYp/9u+h+eC1WCeKnfx8
kM2Pjt6f5hM6jK+XxH8gJXM633nldUg1P9mRG8nmWe8739AjndvnibOzvh7q
S3+/h0Eyr0d565kDGhvrG3Cr08PJlLRfYMBnXc69RjmZM+DrU1fCjtwg8wbU
ti2R/TzK9pcR3vOT9Y04MXZo3sgk6xtRsK0rcOYH1jfiXsgbRVMHWN/k1zf5
9U24I31kjdPQfudNePD+5afxU2z/m2Gzyu7ceJnOC5ixur38gr2Pcs6MT1+4
ei3gBOW8GYd3VzYX6Nn5kg9eprrfUsb6+RhaZB9a9SgU/wJeMaB3
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlGlIlFEUhj/HtcxyqTG3NAsxFcs9NZ13LHUyl9FxZpwZ80dggRqFCoq5
fEaLgoZmUNEGBm2mYGKr5FdiVFAQhUUREWI/bCJFcEvbmPP9uHdgGB7e895z
zzl3zsZ9hwpKFYIgVP37/v+VP0r94KP+8mDYaEoVFj3RVugis4AbNx9nTlzd
SOwCJ1+Tfi5bZnccVLV4N1iDiNdC6FtKONsq83qU1XzSKbbJ7I+YDzPWqe5A
4iBsmvvtHWLdQByMyooXY6l6mTfDx0/bEtsaQByCksax3ptf/YlDMev2oHkp
TuYwhA+1Ol464EccgYvf20va23yJI3HWM2W4b9yHeBt8gkYN444yR+Ho+HBl
c9564mjEdAX0N573Jo7B9Gr9yJatMsfCoyNXUEcrieOgOHfll0ZcRxyPeOu3
z7edZU7AoGr/fH3FWuLtGDhcNWOu9SJOhG0ensRJKKuev2tnlDkZu8Ta5aiT
HsQ7cG1T1sfYp+7EKTCao/sqg9cQp+KGemT0mY8bsQrm8E7N61pXYuDCmOvC
tThiEViIOF1/vWIF6Wp0HLO//2XvStLVmBp4s9ywTtbT8Mp3avKMu6ynIVCT
k6i85Uj6TpzoLE86EuhM+k78TFz8nRbpRPouXH/0XvnSn+JFjoV0ZCc03RuP
tCc9ner7o7LpGXC1762b7LIjPYP6pyB/Jqdncn4NYtp/zKmlBRuLGs6/G1U9
yao73QL5d9N50+TPonq+kT+L0/dw+h42n5DN3kfMpvhZ0nOgCApbdO1ZIj2H
u38ud/9czp/H+fO4/Fo2HlquXi3y26LCHY472FjSouHy2yHlV5qHkM/OE/nc
vPPZ9yBxulDA9hsFXH5OlwrY9yDo2PtBx8aLOi6/jvMXcv5C1DUtPim/RfWI
hex7lDgW9Fz9erY/op7NJ+nZeQgGrn4De55oQH/foTORFhfyGxAx4OAUf0ru
n5GtDxyLRrbfkpE9Tyhi/78oYnWxiPMXcfWb2Ppg4vpvYuuRTHg+mlJT/VDO
b2bzwcztIzO7byQzu48ECxsPC7u/RAv1exX5LQjoWRorTpD3ZzHcI6L8Xv8h
RjHelc6uCH1ALBbD6mUqnW31xF/FWdjW
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtIU2Ecx/HTRZ3Yasfm2ZbzsqERNpaXZi7T89s0N1NEAg0jiKykyGFp
kTiKFfSuCzbwTQZCwUo5gg2pWOQotGhgi2H1SqRBdKWVpmZLKvZ/gs4DDw8f
vs/N0Nqx+/BKjuOsf+bflQ2haTQwcsyIhGKiM3/I0aJi5tATvTKTfddAVuC0
tz2U1cysQrf33ZDlZy5ZDZ/Z33akn1kL1/MnEWcFsx78g9ab06Ecci4K31h8
Es9sxCHX8p36tmxyHh4uuYe56SzyRvBzE6YpM/MmXFAo4lKHnlwA/cFoZSSQ
STbhmy6YdGpkA9mMosm8e8pFHbkQM08/8i4NcxHCs4vB8H4tuRgtxrKB180a
cglMozea4gGBvBVjOde011OZLbioCV+dP5FBLkVDl8rdN64mb0O6NHU0dpa5
DI1bBowntcxWvO/rtEnievJ2HH85++iAIZ1cDnHP3L6GTJ68A43tBaHvOhW5
ArW3hwfz+9eRK8F/UgsxYS1ZxC3b4/EJnZIMKDuLyyPnyR5gXnn/XNyyhroN
ezf3Oie706jb0BvtctsXUqjbEfO/+HUmI5W6HSb/6uTSy6xX4Yt1adluTqZe
BV/glfBMn0S9GmmrpJ4P3hXUq1Fy6fOCLfhDTPSddP5twh6ZuRpZr6H7vlJ3
yLqD3mXDKesyc7X/7/fIzO2SnZeZq5P1Otn/6v/d9xuDmeL1
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1Ik1Ecx/Fnc0LbY/PR6bRcTUfEUrfc1szVdD+Xuk3SmCSW0HKBETno
TbrQIqe9YyTECHYT5W5SijQmgUm1bgrWYNRNEYYJQUK1QaWNzIr9z4U7cDh8
+B7OufmXHTrW1i3mOM78b/8/2VK2h6cnejRIK2G7auUUESkzBx/fuhAfLSOv
QVS1KATamAXkTzf3p5Kl5AJUZc3y3iBzMeZeXHa928qsQkCUMHU/UJNL8VlQ
DB5PbSRrEHo5eprvZd4E060tXeqJDeTNmJ8Shr7mMGtx4k20Q3ZRRS7Hnv67
2XXvS8iV8LbY23MtzHpEmh5PxmLryVUQS4dqrmiZDYjOeD5KQuvIRuj8bz38
92KyCTGHh/+hYt6GwiJzxavBIrIZfedSz3rGlORq3PHnTIbczNuRcL++Hqgu
JNcgbDu8dMZXQLYg2OpPzcuYd+CX99SyP6wg78T+gxFn5z5mK27ODYtmk/nk
WhztXZoSdTDXQag0lMRW8sg2WI27L8m7mAFdnjYZjAtpDwDjVs0R7fNc6vWr
PZBhzg6ffWRGfltO3Q5drX7vk09rqe/CyPmsRx8OyKhnmGuA6dqXxfqnUuoN
UDtbLMqxbOqNSDyML58tZL0xozfBPWyokFyQUG9Cep7F1B3o6DTeP6lZsaW7
A98sqT92/c+0OSfEpeUpfvw3defq+5wLfNa9voUbInrfldGb6R+O+wv9NMOx

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02dMU1EYBuALBlErRbACzjJEASsoOFi1b7EgMrsIAVODGv6oCQHrSpRU
QqIiIqJUg4rixDASMThwNWhRFIhbYwxoJC4cRQiCg6rxOz/uvcnNzZP3nvWd
c3xW5mizHTmOS//7/vuyxyOt8cq5Nb74L5tC3OrvUydi5nC30Jzf1+BDHgXz
EUmjXcc8DpUqQ1WbzZssgXWM9Pz9EmYvfIs8XNkVyDwFh5wOdo4ukZK9kfMl
6vE7J2Zf6Aa0IYqIaeTpCDsamCU9N5U8A6nmxrdtEuYAFNmlp3oNU8hBuHs9
sunWrclkGTJn7Y3v2MQcjKEPv3+qXk0iz8H3VeHtpT0TyXOx9Wz5wmVy5lA4
Odqv+hd6kcNgkdQ4r/joSZ6H1vJaTU8A83wU5S/3rO2fQF4Alb9Y1uXmQV6I
Ys/7ZQO5LA9H/Mdn18W7JOQIqEOO+Rq9mCMhs5XUX9wznhyFA6+LHTp73cnR
+GDOU9YpWC7H4Enn/G4lyxdhtXHwgkM6swLu7y3NNVo3MhDRceVYy6tx/20S
mFNifeD+fWUNLFdiXU2UouE4y2PQ83JmYUgBy2Mw2y2gt+IByxcjo6KuaoKM
5Yvh9kniYfMQU65CtfKmtWWiC+UqOHoH/RDVjKU8Fg8uPel/PiiiPBZhuz9/
V1pGUx4H6XD7vXDbGMrj4JdgfppZTeaW4I5VvtHYNIpygbl4fI34MRwTPJLy
eDovNB63FEOysi1n1tJ4pqWCPAHXbkd+CXhD8zUJzCXy12tKREptSWx2I62X
S4K1z1WXmcvaJwn6TxbMPxmlhSMudRnY+lL4NqXw68WlwiUvNOpRAauvwJya
P1+oYec09iyjK/2vRnpmaH2eL9mixgVbacikdrZ/GsyWB+tvvKX+oBHsh4a/
XxYNBlwub/s1n9VHy58PtIJ6aPn1s2hxsvXEBpGRja/jny/o4LLWvWdHLjtv
OvQNN2UUOJMtOiTHtVi75ex86rE58PZQdiprr8dpv4QX85pZez2iQ5O2i7Po
vlj0GCiq9zT0s/uTBt3TncUPp9L9Qxr/PprSUO7/O4M7Oh5/AKjSZ2Y=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQNioVt3b8xWcoDwPthPX8b4PooHxmdw0DHTr0xf
rQjlczgsap+rIxsM4ws47JaaMnfnewUoX8ShTJLlWOBCGF/CwT1BpGSfD4wv
4yAjvtme85w8lK/gEFIfn+z3Xw7KV3JY16t8018HxldxaCxcs3dpiSyUr+bg
Y1tfumaFDJSv4TDjhFuA1ANpKF/LYdOK40lNOjC+jsO/6K50zQ1SUL6ewyKd
YJEgRhjfwOHkVbfcg+aSUL6hA6fTiVd+2RJQvpFDJt+PkNzl4lC+sQNriax2
/Q4xKN/EQd7D11JslSiUb+qgfVzi65KHIlC+mYNfsUD1tKMwvrnDu9wjX42/
CUP5Fg6GbrN2ep0VgvItHR7v+dugbQ7jWzmUZCzf5y8G41s7CL04cGh1kCCU
b+PwnyHwf0IJP5Rv6+Ac8seM1Y0PyrdzKN0dYGPxA8a3dxB8IyL2QQzGd3CY
fY375zJTbgi/wcFhQgvzjvuxXFB5Rwfj3rffHQ9wQuUdHTauy5+iF80BlXdy
qKr/dTB7FRtU3snhveWvf056UD6Ds0Ngj6E2SysLVN7ZoXbe5T1iD5mh8i7Q
8GOFyrs4fNh88W+tKNQ+BldU8xpcHSDplQkq7+YQHmW0rkjpvz1EHo3P4O7A
zby26tVkRqh+GP8jVN4Dld+AxmfwRJP3hNrLwAAAQtnFBw==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2Ecx/GDmJqlOZ3LqaXOMmfTdN7vv6nzMi9tXlIrwgJRUTNMI7Bk
ivgmXHkLoqAiKiyVTJY3LLMXBcNBiVFir6Q0LzXT8oKXCv/PC3fgcPjwfTic
538et3Nl6fkmHMcl/Lv/P9klyNIOdBWLsC1DtLiquE1oz8xhWKHPae51I1tA
WOernj7BbAOJ9qNt4S9XMh+fm3KnspuZHTBScKZ/HszOKKrcqPiz5EJ2xYyH
8CxymUXwDr9uutp7kHwI+iy1Xf/qAbIHCmJP330dyOyJ2U8PcmRNzmQv1Fbr
W0VLTmQJ1tT6e2HZzD4YatD68sYdyb7QhLeIayyZ/TCRcUnw5ZaQLIWh+/3G
VXtmf0z1tPv5ZTqQA6BZzkssHdtPDsRivTxHLmUOgk58/pnzuoAcjIWe9Az3
KOYQzGn0z6M/2JND8bD1Iq8PzGGw7RgrMlTzyeEoaDWpsPJnjsD3m+Wyjmg7
ciRWkr9a1KTYkqMgTnPny0t55Gg8cleMBwzbkAHeHF9gEFhvWw1UDigjQlbI
nAxp7Rp5vtaKugzekT6Zr76RuRgUv+t9Odq3h7qRuVj4N8wvy4Z2U49FV2dZ
i88pC+pxO62OQ31jcViVizl1OX6Grm3G+JhRl0PSbWoWpGE9HquSpiuPS9j7
4zHiaJhpsbGkngCXzRFdiIGsTsDJo42J+svs+xIx+Dbsh+fkXuqJO/fLJSE2
cz1oVzybT5LR/hVG81MY9WRYlUvDR2vZ/JJREnNj0Po+m28Kkto6nxy+s496
CpQlXrrfQvZ/Uo16Kp5GiAo935C5NDg5TE43NtF6dRq2ONVWXgXrx7G42Z9b
a866kTklrknzJ27nkaHE7MSRumO1bL1RH1IanScVbCR+TvotMlRI7l5QqILp
PKpV0L3QtpVfsMNfH+YX9w==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2Ecx/HTtDQ3c6Yz03nZMAkTS+dlNud+m27O28xB2SQyDQkyKC9r
URZmCIUmmPWijAgl98I2ypLERS8UpZARvhlk0k0I9E2LBXldF/Z/XngOHA4f
vs/z5zmHI2s4b24UcBxX+O/+/2RXzNEx1/MmOQLyat7crIkbDmfmEARffeGE
jByKxPiWppU6ZjHs9SLL60jmaPR9Rqp5KJkci9lPpeMVKmYpzKZ7ynhXEjkZ
Y+3vndW+RLIc6pavjmMK5hQcfKV1dT5LIKdiu2F9qWRDSt6Px5vKbmUXcxrE
ERsNg+54cjo8oddOV0mZM3Apa+qL7UQc+RCWO2+kRjn3kjNRJT01np3AnIUp
+8uHeQ9iyQosLpibr+9gzkabYkZtde8h58C3NjO9MB9DzkVK89yHVQlzHu73
Pjo7eVFCVsJY1jM/aokm58NSN2msPR5FPozu20/2OYKYVfg2kJvzsX83uQBh
QysnDdORZDXeeVJ+rYuYCyHTnrll9YvJGrSOqDSjg8yAzz9h6QwhdwCiqEnb
haUI6lpYXUcKlCu7qGthetqrbxwLp66DIDltTTgioq7DgEe4OpwjpF4Ed5x3
+a44jHoRkvzuWaWXzBXzejHeTqttbROh1PXwvpjbvCrZSV2PvsXWK7rfIdQN
W9d3GLCafqfdfo7WcyVb3VGCwP8uoG6EMMhxebl/G3UjqnsyDwR3BVMvpe/F
UeeZK6P339AEOs9cOa+X8/ZX8OZXoKY2y9ki/0P7K3nnq+TNN1H/SfNN+JG/
5tdlfNf8BQSS95M=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0V9Ik1EYx/G3TUlb+afW9tbUtuVkbDFSc/Y26/1tc3NWCJomSZkIg/5c
dJGFhC0vFmFNaSglgQWFRGwZs8TEEdNdReKFdRdMIkiQxAninEir2HOIPHA4
fPhynptH036twS3hOK7sz/37sqNoGpsMXdUirbg4cG4o0LSdmYPw6utU7UsN
OQtZU8ZWTwNzHgaUzXJvQk2W457uw9AnPzOPB7UjLQeNzAXwP1l8e+XpAbIa
74oSjf5YEVmLmdD6yHwJczHwokII3S4kl6Crp9jcEy8g67G83q75WMhswE3f
jWeuQRX5ELoiHt0sz2zC5+DCzM7L+8mH4dNYosnwPnIp2pILyd49zGXIlKTC
Oi9PLkdu5MywhGc+gpxOw9lYv5JcgUFh8tHStIJsxn1PqzK4updciY6JaXX0
JPNR8BfDc31OOVnA42++bbGV3eRjSO+H2YIv7rVs/UQ+uQpi8+r5OhXzcbxR
BcfnTuWST8DeuGnOdOaQRaS4+lRbB+tAoEp7SR8ld2PLfyvqgn0O99gu6lbk
/5Qr4go2z4YWo9812ymjbkN571LCGsmmbsdDr/T9/IUd1O2o95UaM+5mUK/G
6co7499NUurVuB6wiKPPOeoOmpcU090BidqwIQtsps05IZO+vrXYv0LdiWVh
45fNtEa9Zkuvof6Duut/d//zb3mkygI=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tMjWEcB/A3le4kOV3ESXIZdehyqpPD+Xa/qNO5GdrQUps5M8SMGufN
fai0mkbTTAvTxW1UCscltyaSDn+Y1sIw6pjGqSWi3/PHe8727uyz7/N7nu+e
d++s7M2a3Akcx+nGnn//7Cdacb3lij4A4zIrUOgxUOHOzKG78fKpsruzyI7w
UOrtRrKZ3aGpeG9+5MrsifuHPasGavzJ3hD3fq7IS2D2g5/XNYVTh5jsj/oX
OR+kQcwByHL9+rLt5ExyIPqHvB2922eQ56LqjNyhK5J5PqS1XsGrr/iRF2CO
pGZL66fp5CC0li86si+cWYIz68PS7hX6khdDuaog5LvJhxyCjNfBWU4Wb3Io
xNVFe+elM4dBlvQKVy95kcPhuKdk+tN1zFIU7zDslb8TkSNwZM9ar7rBaeRI
dNY9/xG4iTkK6mMhC+0OeJJlCDIXNzSWTCVH48mueHnOXOYleKAyVvI3Pchy
3Hp0qMdiYF6KjdstN2xWMi+Dc7VlbWLbFLICLb7lp5sH3MnA0dDct5VZZB6I
041E2CdOojwGP92aC0ekrpTHQDz6rD3K7Ex5LGannjBlXiDzsWN9ovvn99F6
Lg4T/BcMu9Sy+TgcLNVHF4gdKI9HvmH4rv7iRMrjYb7W+Xv3NCfKE1Dat60g
9het5xOs5hOtzk9E5sLS5I6dLpQnCc0n4fh+26aeNax/stB8MsKKvv2KMbLz
U6zmU1Bpchk6J2X7p6KzqXvwjYXlqcI+3HLhet7KXBr0j5tudzWzPA0XYu63
PfRxozwdwUslujsfyXy6Va6Eye3whiEly5Vo+zFZm7mV3X+GVb8MDMiGR2Ml
dN+cCuLkdJnoov24ocL5lteip35kXoWVmaENeQF/FP9tVCEt0tDYJ7GlebXQ
UGNb7RLF1bMczavp/Y/QvFq4H6eBi219/pcyG5rXCPfjNfR92I3bqBH25bTY
XdXVKupl52ut+muFfYxaq/46YT/o6H5+jptn/kj9dTTHcX8BmGNUSw==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GlIVFEYBuCbmi1abs24ZJq2TSlDObZoy7wzlk7lOqszUUQxFBll64Qh
XSpbyDazH2VWJtkiFSqR2QS3YkQKo90KIyzKsk0yyops8zs/7hkYhof33HPO
/c58J2bRSqPTSxCE5X+//37ZR2m5eKUmLxa96tSWNK7fXODPLGBFiyXldG0M
uT/0t9sL9TbmQDzZmK9x/xxOHoLyGcM+7q9gDsMo952WEQbmSIwpajtsbosm
D4fKe/GnQ0OZY5G4WV2tMkWRRyLvnXNM323DyKNR7KmxVLZHklUIWu57+YiK
eRy2ZL2Yd9U1lByPxtbRzvaDEWQ1utqKKqwPw8njER5Qmnw8iXkC9mje9Xma
E0ZOwNqnlU1Bj0PJGkTtWHbmi4I5EVffmzKzKpXkiWhOyQ1/1a0gT0LthW1R
Ya1DyJORUzwhzqeIeQqC/ULdr90h5CS4FGXC3irmZJxM1jSdKg8mT8U9bYlP
6LMg8jQMrOxekOphno4Hzq8DVJeZZ8BZXuW18TizFtMS0rcPXsgMxOiW7FzX
E9hrEbA5Es6vjg2gXIfTuhuexvBBlOvg6QowOVb5U67H3fqHXx53+1GuR9kj
v+9VE8lCCpenILqn+daUzoGUz4Qjbr/h9gaWz4Rm94dvOmkA5bPQ5JnuWtvQ
n/JZXJ6KmvMrS9XzWJ6K+Dof30l7+lGeJreYRvX3odyA9MmbLr1Ue1NuwJrq
qdraEwLls/Ep6UePXu1LOWdhDvc8Z2EuevvLi/K5KDx6361sY3m6fD8iZyGD
mz+D218mN38mt36WfLzIWcim8/6t/U9kU32/91rMlo+XuPFCjnx9cBZz4Od9
rqDjQB96nrNglNcDRpy60qK8GdmXnucsGbn6mxBtyEhSnqUcJhRs+nEt7yw7
L84SN14wy+eHmau3mdu/mTsfi7w+sMjfR7TI6yFZuPWt8v8zrOisu/urUEEW
rdi31bv++XzqF8mK5ojOjtJA1j82ef/AxvWrDf4h1135b6mfJRvsh89VKOKp
34Vc7EpwtpYtJCMX68aWHiipZfcBl0u58vkEO4LfSNerjXSfwE7vS/eVaEfN
54hjBUvpPpPsWNQU26AR2f3mQF3+mi7HBjIc0F8zRcVF0/0oOpB4b7drVANZ
cqA49E7J11UK/AGg87OW
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtIE1AYxvGhoHOSl7Utr7npCKk1bDNTt7VnW9t0jop0lBWBxuiDlZVd
wLAWQQWZVEYfDIJEzHBOViydLqmQiMBiWbb6MIooJJIW2DYtR8XeQ7QXDocf
f85F0ty6zZ7E4XAq/qy/OxuRzTPubilGXCHt2MUoT5rBzMGdhp9K2X0JmYsX
U2cVahtzFnz8wCleTEwWYIvg/WC2izkH3qsD40eszAUw2UI3fLNFZDGmhi9L
2tcyFyOzab95tnslWYoHR4NW/vNC8ip8FTW6k5YKyKVokBblaXYzr8azieqx
ycl8sgxvNCnH63/lkeWwnQ5s36tjLsOMoyfsuZBLXocy8UJMdTuHrEDmvKt+
TsGsxIG+5tRzB1eQy+FU9T2xzIrI6yE97H+7IGSugPrHo2DnHiF5A4I7us53
RgTkSixGDb0nZMxVGDnU3ygXLidXI1r3iXvGyiersKZQlLuviVmNV/ZwWqk3
m6xB26BKe7c3i7wR/SWWd+WPmbVo7Bm6JZQxA8P5zpGXdZlxO4Bj41vVldEM
6jpsdnYZ7Z5l1HXwj76eD0TTqevhdrVek+/iUtfjyse2k/pIKnUDvlUtxvTy
FOoGhO75lzqEadQ3QXlpLqJ7SHYkmGNEy9PRiWkvvecwosRyfWbnAI+6KeG8
CR03p32iD8nUzdQXtPFupv+E4+bUID15qP1L93fqNdQ/U69N6LV0LxvL/3b8
82/8EteJ
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0nlI02Ecx/FfqWkuj5zN+6zMzEaamrcfp+Y8pm4WJCY0wYpcWZpGdvjL
DjMrLA0StQOjw2gkYqWWVwXq6I8yllgUJZRZoZEVmo6KfZ8/tsEYL957fsfz
fL1yCxR58zmOk/37/v9lH9HGts6WfG/oNRlzxqLCZpcNM4fQiUZl/EMvsgXs
0vJNZ3OZbdHtHTSyaNaTbI8rkrzX35uYHVGYvmbl6xRmV4Q+84yOm/MgeyIs
1vLt8CZmb7jczqo0O+NOXoZkravm+E03sg+iR7aOK8dcyb4oOFrO9wmZ/RCh
zhpefcGF7A9hU09dyxNnshhmO/ldus9O5DVYKI0M/iZhDoCf9o6dxUVHciDW
1ri1HK5zIK9FoMNl5eYTInIQ+OKYqXAf5mAMvDx2vHhgCTkE5r1LG/y/Mq9D
3dlLO/pKmEMhHX/VZV1lTw5D6f5Vn7TLmcMxrSyaO9ImJEdAc6/tVuFu5khk
J3Zbzty1I0dhy56cP4Nji8nR8IrdVlmssyXHwEpl9+XkHmbgdqT3dt/HNnrz
QFVg3pv6LazHIkPlp/npROZjcW2gqUSw15q6BB66Z5rQSUvqEkz7nz94Q7WQ
ehz6n0bt29thQT0OLeqCWnE2mYvHRNiMTiJeQD0e+f0PuobaBdQTjNYnoLRs
pje/mf7Prce50aIDkt/m1I3MJcJDKgsTNZtRT0TqurL7o2IT6lLo538+dSkO
XRp6KHrPepJRT4LA5E7peM086smG1+OTjdan4EbnK9GgK7t/iuH1uFSjngr/
VtMFIWfZ88uM3k9muB9cGiZbn88dWkL7zaeh+pjJg3c5dB5cuuF58Omo1wqm
rwez/c3A6ijxhu6PVnrDyHyG4Xn3ZOCHriOr3JzNhxwqSfUj66vUIYfW6uT2
6TS2Xo6kW+rm5Q00Xz1ydDrXNrZPsPUKw/mEAr9OqR1ypmh+eQUCOlxWfCim
+e5RIFNbefqFG5v/TLi3F92r0AjxF6bSN24=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GlIVFEUB/Cb69SYWtmYW5qV1SiS1rhkNn9Nc9QZnXEcSymwKPrQh0pb
TCinaCE0NQwxAzNFDSvDSrQ0GT8oLRQtaFFiGxWIkpW2mIwVc+6Hdx88Hj/+
59x7Hu/yFm3bnbHDjjG25d/9/8kvhamts3VXIGwaU3evqF/K3LgZ1JsuHjjZ
sogsw8Q9vxV7t3O7Y0Le193hyO0BL9XxqtYbAeQFeOXfd6h6K7cvBqyVpwZl
3AHoqJqoMej9yYHIdRl51nt+IXkJ5jYlfGVTfuQgxPR0qfIiuJdj5uCtsrpy
X7IS5WVPdB4TPuQQ7Mnu7bcEcYdiaPDzzrIqb/JK1NSqsnPDuMMQ0lDrqSzx
IofjiJ9nw7ePC8ir4DbeYhwN514N1wJl1lCFJ1mFturGuFI37gjcHTGmpdcr
yJFYNmS4tN+ROwpNnS8UD3znk6OhGX7R7VrsQV6DwzXPuxTv5pFjEDJW2tJe
xr0W7y9EqF5XzCXHovhMw9Jr9jxfh1+pH2VHtTxXY2249pRr7hwykN96/bS+
kGwG5PbXCocreB6Hzc511T6JPI/D/YEl439ceB6P6MedtX1v3SmPx3frnexj
zmS2Htd9rrY/S3WjfD2mmWE6dx+ZJeBpR//4y19yyhOQE3xW87iAzBKFPFHI
N+DH7NtHp1QulG9A+XH7jjdbZlGehJCbDk4Rpc6UJwn9GixOqRzIuUz1Zg38
rY8eRo3x/mTpeuZkfImetMaHOlGeAn+NLlrR7Eh5ipCn4l5v7MF9d2SUC2Za
PPIeGz7nztfX4sKA/Hejis+nE/p1KCya7NnVzNdPE/I0Yf90Ol98vnTpvEwP
Q0lYsMMJB5uhh+1/YEf1emgji9o/hNrbbNHTeSQzg7QeBul6ZoN0f4tB6M+g
8zaD+gWbM6T1FsHMKDWMwvxGrDoz+jPO8ltt6zfCLkA5Kb8yZTPLlBqZ0npz
JjbmhLfkBU5Tv2BmEt7fJJ3HbEL+lRj1jTpG85uE/ixh/yz6fj9of8EWwWwj
+ZP6Lw1miIg=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVyV9IU3EYxvGDnly2LLV1WnVqbtkQJ6e2Ultz7dlx5iEqdCDEhG0Iu8nC
SCNJyIMlkcZApJD+bFGhorKwkCINChJahF1EddNVWykUaEVWq0XF3h/RCw8v
H77GphZvKIvjOOnP/n52QsPE5HizCRktuKTZuHNaw8zh8wP+8c1BI3kpWnJ7
AlMKcz40x7SHbMkisg7ewk+BcC+zHm9jc+WylVmEbzR78/17BnIRUh1c0Mwz
m+BPTi8+smwkF+N7JOppPLCBbEak59lFZUokl2DlqfhPVWAuRfHBrgapaT25
DKffzNUd+biOLKH7bMQpGpm3wj8bbMvtX0u2InB4PDrwQk+2YabWr/0iMm9D
2W0+pyK8hrwd8fNj9e9LmMsxmB42mC8L5Ao8TVxPo5S5ElkD0R+Kupq8A1fu
VjX2x3RkO+q2XDW16Zl3IlY77z2+fBXZgW83NCeT7kJyFTxqe9p6poDsRK8t
9PpSMJ+8CwUfdMKCsILswv6xcE1oIo8M5B21OZ53kVVg054LL33Dy6i74bP0
KTPtWupu9CVaO+SvGuoyTnSmHjaP5FCXYVD22YWRJdSrMTT5SngiktVq1J+z
WvhunroHeys77ySkbOoetI46XLeucdRrMG9P/ZKlRVemM7/LmNv9v9V//g20
ZbK3
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtIU2EYx/GjzjKHYV6mqXlNi01WHm8zzf2mzuum7qLdMCKwP1IQtBIH
5SjSjDSiCESpSFmgtNBICQtWUFBQVJaBVGSRwTAyAnOSWrHnDc574DA+fPe8
73kPYwkHm8z1voIg1P69/32yS1FzZ2KkIRFezWu7tjSVJCiYBQRcm/mUP5ZA
DkCeaOhcf4A5GP7KqRCHwByGvJTV2cbL8eRIbFPXXzijY47BimbwRdKHOHI8
kmW9q6po5kQMPhk4Jj8SS94Mk/uqp+3sJnIKOruGa+8vx5C3wrjoES2NzEos
t3480fImmpwKm8/Yl95qZjUKlc/q3jujyNuBfve08+5GchrKol6/fFzELCJQ
dapu3XwkOR1JxqO19jrmDIRXHsqeHY8gZ+Jnh363XmTOgq196UHDkIKcjbme
56PaV+FkDTSHtWJ3BHMORm91xEa+CyPvgK1N9XUqmTkXreF9wnlHKDkPc6F7
6he6Qsg7ETiwuL/40QZyPhxJ5dMZD4PJWgQ1i7mTJ4PIQN+U3OPIlHttB0ac
TZfU+wKo66S265B6W7Ymq2ct9QLElRpzFEP+1AtwY+Kt4mkMWSiEIbt9/LPa
j3ohjl+ZvKeYIQtF3HwRTOfSVLLTMup6yP1u2twXfajr0TKcqx29LlAvxvec
pZUC9YLW2zkLJeRZ6iVcL0V697dfOpeHeimty64y2v8H9TJuvpybL8euvaKz
OXGVegV845VL8uHf1Cuk6wkGbt7AzRu5eSPXK7n5Sq5Xcb2K69XS9VEtPb+d
s4uzYJIaJu59m6TndZm492eWfh9mbn+z9HldZul5BIvUsHDvi+suC3d+q/T3
BSu8/4e+Xtut0ud1Wbn9a6QdNf/P+wclq1x5
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtIU3EUB/Cfj0yd890yNV9lmM6Rr9l85Nl8zfnelOUqiKBSNPNFxqy8
GYmEGisVTIrIwnBk2VOzTI3SrAyTmf0RJYKg9phQmkOyYuf3x+6Fy+XD95zf
/f3Ohet74Kj8oDkhRP7v/v+kFy/3QV93oR8YpY9by43YreNSEyjQ1A41dPui
reGMdcP9h3nUjnAutk2dt+SDdoUmD6Giv5XaDeyvlhWLZNSe0G4zODv32Rvt
A2GSBMOimNoPap0PtZiVeqG3AjdkKLN6dDN6G4yRN5+2f/FEB4BQl+dp6U8d
CNFdeVPBzR5oPvxSyohywR0tAO2C+HBGOPUO6Hn50Te8ZBM6BOpzbaXvb7uh
Q6Fxeb/0iG4jOgwKJv0FHA11OKjecQtap3noCDjFV7cV6zeghXCjudypF6gj
Ieh80pjktSt6J9QMK/cZ0qhFcJnRqR26XNBRsCf5ma3hjjM6Gvr3+g96cahj
INgpYPHSuCM6FrhFzgt1pdS7QBvjlx/w3AEdB3YuQ5Ulc9QATl9deXqevdEM
wPVX7cc4FWgihkluXf5KBhdzMTwdjvoeMGOHuYSVS4BbFho9UYMm8abrMfEw
3qP7OfWbg3kCFI709E/0opkEVp4IqiCNdOw4zRNhhX/hREeRDeZJUKspjKry
Xo95Eoy8iK2seGyNeTKoqw2DhZ1WmCcD/56llbAR64nUtJ6Rwg+R4Y9EgPUk
xbSeSYGOvg+8Uc91mMtM6xkZnLwy8YQ3bYF5Kmt/qRDW8G1ZPED3nwZv3fXz
TY62mKexzpcOW2Qtk6qbNE83nQfJgCVu7+nVCPweTIZpPclkzS+TNd8s035g
mckCzUx5lWQZ9z+QBdn1IUGWZy2xPxs4FrfU8xfNsD8b0iKrH80I8PxMtuk8
Blj1RA7mPoEGjnY1ztgvB+P/yBz75eAtTRfxOnHeA6ycKECpCu0q81vDfgXr
/Qoo10bH3b1GsF+B818x1pMc/H6z2J+D6xLyF8FwSBA=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQNioVt3b8xWcoDwPtjfdNKprRGC8RkcFsq/lZRb
rwjlczjYKTKHl3rC+AIOGyPsTs94owDlizhwC619VtgC40s43Lh4fW+oOowv
49DnN4Np5wR5KF/BISj1l5XZFzkoX8nh/+J7dloiML6Kw9czJzdWTpOF8tUc
GA+U3ku/IwPlazgc/LywWFYFxtdyqGLc9nRmgDSUr+PQ3xh/OLBGCsrXczhy
w2uW81NJKN/AgdPDxvStE4xv6HAqbv2nfeYSUL6RQ+Y1VT3uieJQvrEDa4ms
dv0OMSjfxGGWwlb+Z89FoXxTh9O/XnS1LYXxzRy0j0t8XfJQBMo3dzi9bevK
ogJhKN/CYeGSE6L914SgfEuHkozl+/zFYHwrB7e9L7McLgpC+dYOxRvXdwZU
wfg2Di4NFX8N22F8W4dKzeM/U/0FoHw7hyUnF5dxl/BB+fYOTApav7hX80D5
Dg7XeDsyfvrxQvgNDg7feHc2/jGFyTui8hscHT5svvi3VpQTKu/kcOKobXnJ
Lg6ovJPDT51JNctzYPLODvL/zp62+MAFlXdGVc/g4jDxcXG103d2qLyLw/Ld
18VOybBC5V0dAnsMtVlaWaDyrmjybg6Q9MsElXdzCI8yWlek9N8eIu+Oym9w
d+BmXlv1avJHqLyHw3vLX/+c9J7ZAwA6o8Yf
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/GjG7pYXrNlZd5IMbXlMqczlz+3OXXqtkLfFHSRhEhDKBLt
TccXlUQJpRFNE6HLGy3SGN6aWcutArOSSopCsyZdrI3K1DQq9n+I7YGHw4fv
/zyc8+KJKavaVu7LcZzq7/73ZEtSau7vrIiFW87sXw77y6AgZg7pbSM3xrti
yCKYDNVnu43MwfA56PxU6oomh2HKEPRGcI45HI+Dy0KvqJkjsL1dEGfpiyJH
o7JjsOVSIHMsmjvq1f7ySPJaXB3/YG0pX0OOx5lBy504RwQ5AZIMXnBcwZyI
CeHJ88Ndq8nJuCjaXft0bBVZiod1r21iJXMK7o3pTOr3K8kyTI+4KpUpzBsR
VTAU2dgaTk5FRNuBqRLLCvImuAJLres2MKdhoC9U5GySkOWw5n9rjbm1nJyO
Cw2t++9WM2cgyR7+4/JEGFmBXS/MO0drmDMxt+fQYp15GXkzHtRqsvbGM2dB
pjX16oZDyUovb8HbZnnaq0bmbGj4mkXZiRAyoHjU32YbD3abB4q1tqF3SjKX
g8P9xqyM2UDqOQj5HCZxSsicCvqOhtxycwB1FZ4H1O+b05M5tec8r/bqGqxX
SktuO9j7Gq+ei5mA3rqFtKXUc/Gk59n3sVkxdS0s9swvCZOsa1Fxv2dgtJf1
PE/zeei8XtUk3SGino/U09M/cwaXUM/HV8X8b5XUj3qB5zxfgOSbQj95gz91
HYrSj3ZPSgXUddh6SpYkPCakXgj3/fKlXgix4NqRj40+1Iu8epFXL/Y0Xwzf
6MR5cftCtrvrqbvc5vX0/TPUDfR/c9QNdC5bRpp3uDv++w+yJw6h
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0nsslXEcx/HDWCGOJOF0QQhH6nSh3M7nuDyicM4pa5VZq52lslUuFZae
dHEZupxWK2yZyiKWdVnp4KTwh2ydRSu2kLNouhylOd2o1u/7R+fZnj177b3n
93ue/b7uO/YpVeYCgWD9n/vvky6npLsPG/d64J8M0iBP5WS4kCzAYIef49q7
7swzEVqkEV9IIdvjfYVv0I8pN2ZHNPXYBRy5RHbGmgyLwYwQ8nzoco+3qosX
MbshvP+8k6BvIbMHnjYaGwa8yZ4QGopP3z63gNkb+q6xCd33+cw+iE2+01Ow
leyHk93BtyoLRMz+KOkashvUujIHoCzkvO8xa/JyrCz9MCnTujBLsPdajutB
f/IKWJpPa7xOODOvBFduNV4jJq/Ch1NWtScL5zGvhmXmAvHR+07MgXhT1ZNk
70oOQtIry6LC3LnMa/Cz2sJ95Jkj81rkZItHXniRg1G2P6t220ZyCCr53hxh
wxzmULy7kC6rl5LDoFYZ1Mk1DszhkDSJlrzJIksxrPnFi4PIQEuy16OFNsw8
wDW/2wPdbNZlyNfvKNXfZOZlUFVeN8+9Qj0CDqPatjol9QhIN08kJ4ioR5r0
SGT7dn5TJdqzHgXbNIexwgPMfBTcZbuKsqaoR0Oe5tf11YV6NNIizjTbVdmx
zqG5M/ijz/As1jksDQvY1PrWlvUYvLAtTP2WwMzHwDZ9RcjzfOrroLvfO/HS
aMP6OsTeaKj1qhCyHvu/+ViInIdHz56j74sz+f44k/9bjy9TTVvyZ1A3sWAD
pgWK6e2ZtP4GRG76GWjJ0f/Fm+wfj3uGM8tcu6knoC7UI9XnMfUExHMd7fow
Wj8R1xfH9a1qo/0TEcUf/iUpoPORw7ramMK1M0Nuct5yGK/OyNPL2Hxo5bg4
VGL2epzmRwEJd/lBXDczFHgi15bzTTRPCpTethK3DND7Coz4fs6WyGlelfA8
ZKYO/MQMJRzqe3cb8ti880rs7Ndoat474jfhwTKD
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1I01EYx/G/0ywcja1srmWps7RStKk5p9P91L3PRIUoSIsiC5oglHXh
CP+tMsghRaIQKUJhNXoPK19YrhdYF0Kyi2CFIuYKM9ygRAZmxZ5z4Q4cDh++
D5xzcdKONdc1CjiOU//b/0+2pPsHR57aFIgoqJ04bfZ8lDBzuDUx/+zb8zTy
OmSml+aV1TOLMSY6Ojz/O5WcCE3GSqCpm1mG9Y9nA5Jc5mSErJNqvEshp4IP
tui88cwKXDuordce30bejuoHnfrGwa3kDLR/P1KSt5JM3gmF8+TUi0zm3ZD6
XQ7rhS3kbCQ0zzravHJyDtyazyqfjXkPZtI9+X3uzWQlHE0/O+5+kpHz0Jn/
I8Zfy5yPAyfuLYVjmQvgHF7wH+5IIu9F4f26BotdSi6Ebocoe0rCrMLFS2+/
9IxtIheh+ozY3v0+kaxGTW6/okXGXIyvp3YVL1/ZSC5Bz7QzZjK0gazBIePr
hPAT5lIoDTeHLOPMZVi8+iip4ZeErMXM6DKfpWIdaOwdENj7qfPAiLyrd2hB
TL0cA+kWf8EbMl+OsyM1mqIlEfUK3Plw+5ywhcxXwOZ95fYNCalXYlwenOsS
J1CvxPk+36h0Opa6DlWqtpczOWRehxTTPrXUtYa6Hgvq8J+KnHjqetQ6lVlx
l+OoG6K6Ae3XbcX2lLXUjWhtC3tsLtaNUfebEPn/Auqm1e/hzKvnefPqec5C
9y9qIz3KnBXC2IetczdC1KPMVdF8QPsXeejp+Q==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQNioVt3b8xWcoDwPtgfWPxUTVQQxmdwkDi7TdNr
kyKUz+FwY0640MtgGF/AwfZv+xehrwpQvojDA06L1yemwvgSDt8vnOisc4bx
ZRxeLznDEb9LHspXcAhK/WVl9kUOyldykOS5rWomD+OrOLQulmsISJKF8tUc
7G6lvUp8IQPlazg0mmm1e3nC+FoOC/73z+xaKA3l6zjI/zt72uKDFJSv5yB9
NDifxQvGN3D4eTmf3aVcEso3dOivdFymcVICyjdy0NnMwmbWJw7lGzsc6ukX
XKwE45s4ZJnn8TWEikH5pg5nnSMkn/4QhfLNHNrOTpeM0IHxzR2ss4pmJGwR
gfItHJqOh8f+8oHxLR3KRWcz9C8ThvKtHE5v27qyqADGt3bwMa/f/lgPxrdx
eCMcmfqtUwjKt3XQ9FMWcc0VhPLtHLqNUu/MThCA8u0deIuMrC838UL5Dg4b
1+VP0YvmgPAbHKD+ZYfKOzrUzru8R+whM1Te0SE8ymhdkdJ/e4i8Eyq/wcnB
uPftd8cDP6HyzlD3wvQ7OxSvtrbftIgBar4Lmn4XNP2uDu8tf/1z0vsGlUfj
M7g5cDOvrXo1+aM9AN9ZsB0=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQNioVt3b8xWcoDwPtgrTte1+80P4zM4ZJ1frB+6
URHK53Dg+a4/63AojC/gsFNDJVTyrwKUL+Lg3W1lFrQIxpdwkF39uSvRCsaX
cWCc9vf+vE3yUL6Cwz+rxstPX8pB+UoOs9d0OLObwfgqDhrXZyxj7pWF8tUc
bkeLsU+6JAPlazhMrWrse8sK42s5NPs/it5bLg3l6zgsfB/P/2KiFJSv51AZ
3KVz4r8klG/g8NvYeJ14Joxv6HD2Y1udSpEElG/kcNX7UNRDRRjf2OHHdu5w
mRPiUL6Jg1xH1sovojC+qcM8nunbRK6IQflmDqwlstr1O2B8c4cYhmCxgIkw
voWDiyqfzn1BGN/S4XGjkEZBsiiUb+WgfVzi65KHIlC+tYNKOeNks/fCUL6N
Q3fvUtW1zDC+rcNSK+MTy+cKQfl2DievqXz5zSMI5ds7dBul3pmdIADlOzis
tlHK0DjMD+E3ODgsObm4jLuEDyrv6JDjNGEv30Iov8HR4eKOq19u/OCGyjs5
yP87e9riAxdU3smhqv7XwexVbFB5Zwcf8/rtj/WYofLODu8tf/1z0vtmD5F3
QeU3oPEZXNHkXR24mddWvZr8ESrv5sCkoPWLe/UfqLybQ/Fqa/tNixig9rs7
QNI3E9R+d4fwKKN1RUr/ofo90MyH8Z9B5T2h5kBBA4IPANAuzIc=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mlIVFEYxvGrXyoct1KzxkrN3DO3ydzycV/GxlkKF4RM1MyMSo02P0x9
qLSSMgiyTY1Ey6VJ3M3EJYpIUUHSok0LpZJCNJXUCt83GC9cLj/+51zuPedY
JR9WpuoKgiD7e/978mW2p65Fc9AaS/oRMNHQ+2bKiC2gxfHFwleNFXklHmV/
rnLezzZCeLlP63ZDtglmq0pr6+ssyebwiY/oVu1lW6A3RnTx8fQmsiU014ek
VhFsawyXHTHVLdhItsHuj/k3hns3kG1hn/b27g5Xtj0SRWmS4koLsiMMjRoL
syfEZGdYtN0YPZfAdsHx21sWFX3rya64UyyJT3Jju+FMwfU3+yvXkd2hY3Jh
cmHenOyBa5afx+SBbE/kDN97bvx6LVmCDmm5Y18ieztEFV6K1rtmZC/YHO0b
mjVl78DLubH8c/dNyd5IljmUL4jYPjiQMnVimx3bF+/iCs5f+mVC9kO7U9D3
yiy2P+oC0mZyM9k7oZkpGDcHOwA9++J+Tg6tIQOjGQ4+8+fJaiDUfzS3d241
9UC4hRU1Rb0iqwORkTNTrxPLPQhuzWK7T8e4B2mPF4KhGsy71L+B3x+MpfPG
PQRi85Gxq4VG1ENQtjlq2LODLIQisqL6wZZbhtRDUSOubOiXkoWwZT0MmUFX
nhiUGFAPx7R+05nfEhH1cNwc1Jstk+hRj8DB541tA01kdQQG9S+kz8r0qUdq
v08dCf0sd9+Bs9yjls2PQnlgZ/ezddyl2uPVUmz1d9n99Av3aHRPGqoSjvL3
RcP4m4nZDzP+/l3L+jILMsQmuFdnWfP/y7AoKBaTcnh9YvDQzzrdvpN7jPZ6
CXLEF1WVmDrTekMO756W4mcfeD/kSFxRWiQONV5yuxzZmpo8+SmyoEDq7TLd
08VkKBD2ZDwDfWS1AiOt82onL9rvdgW+rYlPnc7j/VeiS95+U91MhhIvTob4
pdjyeVHicu0qp7b3PF+pfZ4EFSYOdU15TJOh+n/+/wC7A0GQ
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQNioVt3b8xWcoDwPti3xn5teiUG4zM4nNm3yC5l
myKUz+GwIXpl3Y5oGF/AYccRQd27zDC+iAPH1egZ+fMVoHwJhwS3X0YLPWF8
GYf2bDOBpivyUL6CwwS5+E/X38lB+UoOvOL5iVdEYXwVh1z1U3tlq2WhfDUH
26CUQ2lPZaB8DYff7fX314jA+FoOnuwM8787SEP5Og7OWmdj766TgvL1HOSK
XZSufJSE8g0cfhsbrxPPhPENHeJzN86fcVUCyjdyCE9b8eMXM4xv7CAqbqp9
tkkcyjdxmLP9XbcsJ4xv6jCvdMUtAyUxKN/MQeGx6NTFkaJQvrmDdr/bOafT
IlC+hcPpbVtXFhUIQ/mWDoa7pNUflQpB+VYOAjqG0uf+C0L51g5CLw4cWh0E
49s4FG9c3xlQBePbOsSwL5ol7Qrj2zlUah7/meovAOXbO/xnCPyfUMIP5Ts4
OIf8MWN144PwGxwcmBS0fnGv5oHKOzooe027FrWCCyrv6PBTZ1LN8hxOqLyT
w/Ld18VOybBC5Z0cqup/HcxexQaVd3aQ9/C1FFsFk3d28DGv3/5Yjxkq7+JQ
vNraftMiBqi8C9T+P/YQeVeH95a//jnpfbMHAAApotA=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1XtQVHUUB/AbkI9WHqEu4GIISoAy4KLIw0W+rLyfuywL7IMyZpjBoAEJ
SSnzhoLggxTSGpSCiofQ0pAvQMhFWlEZahxic7RmCqgoG2MUKEilGs/vj707
s7Pzme89s2d/956z7tkFqTlWHMeV/Pf+/5O9xOoLlzvzPPBUU+E1sgKJlYSZ
Q3157eHBPnfyErw86iOqymV2QMw2j4RvHZhX4EG1V7/asIbsjKKUjT53E5hd
Ed3eP/PaD27kNTCdeWbPuCuzB9KUH507mvUCeR2+8VN8FdeymvwioMj+QHnf
lewNcTBvXRHCvB5Tlblj/SYJ2RfnOw5UOsmZ/fD+Tieu0XUVeSOk8mbPpgYX
shRfRFSVzS04kwPw43wXZ9jPvAk/W10qqRlzIm8Gb//XwZcCmQNRun++P69N
TN6CmUvl3bN3VpKDUHfTsaehgzkY+3ThsvNpzCGoLtzdplOtIIfCUeTU+0vv
cvJWDF28cLaokFmGI8eaPA3WzGGQRtd1xw87krdB2iPxGtvNHA4HX6nk64Xn
ycDq9kdmfRCZB2QBiYfsdrA8AjfM66b/WcbyCGjqDI0rfR0ol8M23/Fe5S4y
L8cCp1zYUWxP+Xbky4/32TXaUb5dkEfi0xuflIiKWR6JvsHQ+97jyyiPgtuT
4aHgqecoj8Jps2iuOVBEeTTyrnd9OdJN5gXmYiyv52PQ2VHwnp9uCeWxmPOt
easlfynlsXT/FlEeB7fYpBBx27OUx6HiRF7om26LKY+3vJ6PF+QJ2PfhSK/4
J2vKE6A8Kt1gU25DeSL+DJl/Ivdj9YmC+iTLfvkkXDeFvVHcw/pPxtr4U2Zt
KzufZPies1m0pZrVpwj6TxHkCrRc/k5805VyKAT9Kiz7MyoE56fErG33O48C
6X5BaXn/eCVudY1O3/6bzt8oMJdqaaTC9NBepd3F6lNhtq3MnUu2pfpUtEYM
mK65kDmVZQ4VLk4d9181zJ4nleX1RpXg+9NgWxSwdaSM1ach7mxHm+cZej75
NLTLPHK9B8hGQc6psddncC4nhZ5/qHHve6+D/mVsHtSQOI9PnqghG9VIir5m
mghj85MORf76oRkXVp9uOV98OsIzpvXJEpo/Y7rlPHIZiOT3PJYeIiMD+sUf
10mi2LwKcmMGCs0Pr77izvZBJsomso9NfMbqMyGyNpT+XsvqMy33gVGQcxpE
9/32Km6xeo1gX2jQvDb+zuar7Pdr8Hrn51WKUlavxdP/H+oHWoz3PuY3BJF5
Lf5YrsmZrSIbtdAf2KS9Pcn61+FXnwd7pQraf9BB4d/gUexM+5PXwdEwunPq
bbJRh8zYdx3GrrD9qkd9l0xX20GGnuaB9jGvx9D85OGKJrJRL9jnWWi9O3Cy
3kxGFq64nXauXyrGv0fF7XM=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/HjhDLntbalU1NnNl3znndtv6nzOnU6QpK0GAjGoptKpkVT
wm5UBhGxgtLUvKCmYS0FXxgLI3whxiKELEOLEFwlpWZZsf/zYh44HD58/89z
nvPiBOqOFVfwOI5L/3f/f7JLtG9oZEAvgU1WhbPxSJCzkJnD1NKIbno0kOwE
h1++DWPlzB7QPRDPnnZhFiDI75NZ2hVA9kL3vEXRr2T2xQV9nEfja39yAMJE
baJ3ImYJ3o5K142NO8g74SZtMcy/9CPvwrWi9wsPZcwhMH9315ae8CXLEDnn
2mGY8iHLIfQrk2l5zOGYOVx/JqFWTI5Eq1wrKHZgjoLaBFXobW9yNHSmR4lj
017kGCxGJuUPLm0n78GH3RVjfDlzLO6788RrKhE5Dq9WP19uaheS4zF8XP5T
y2NOwME3Q+VTtQJyIga+ie/VVW4jJ+HK1fbgXkfmZLS0jQuvW7aSUxA17COd
rWFOxXLenFODmnkvqgb6L2nqPMkKzEdIYo6GMgOKkqUDBT5kAxDmGfLVOOlB
XYmcrr7u4Lvu1JXYb+xtEcpZT8MTa3OEeMKNehrWuaL1Q9U0z6WjZkSTkrDM
ejp4AbJVfo8L9Qzox02jU8/41DPQqXxufuHtSl0Fi+vFypUCskEFzwWByCqi
/bhM3LHwVzpi2fpMjJtTT1UPO1HPQlDuLUtppzP1LDSfdzTNlJG5bFgfT/4+
K9xCPRsTYuuXmx6s59jPG3LQdEOfVO+/mXouFhNX/6SFb6KeS9+3prD1PFT1
JCsGWznqeSgpje47KVmnrqb1P2w2qDesz7efN+TD9r/y6P0FUMefe/ox3JH2
32Cu0H7eUGh/Hk5jvz80G86joTmO+wvzWgRJ
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdyltIE3AUx/FlrsSVrZzLy3JuSugm1i7a5tT95nSbQrTKLpuVEdmLlCaW
KUXrYZBhQSw0EpojmTZaEDQClbK1RWkGEVQURFZYSKvpS8zELuz8CTxwOHz4
Hsmh5h2NCRwOR/13/102wl2BkTtNUsQV1X/S6YNZq5g5sKbk33znl5CTUNY1
Ku85wMxH6LxM7k5gFiB38FyD7lYOOR01gsDpF7XMIkQW1AO9z8TkHAQ8Le/v
JTNLUSe58DHVnE3OQ0Wr1VDq3kDeiNnw5zzTrIicj+Yup/PoEWYZ7PLLluen
ssiF6J6YSvkwlkkuQsx+1/CNy7wZ31eGXG5TBlkB5e/DGQ/608lKhATtHTlz
68kq2KSa/je7mdW4qh3piQSF5GL0ej1D0mzmEsjqNeH729LIW3Cp5YSvfqeA
rMGZ6y9HhVOpZC2+FMx1KKzMpbA1BC32vcw6hKxjfY7hdeQyuBqjrn2DzOU4
eHz/r/Gva8kVmN4kVR0rYNbDm1v7Vh3kkwHbNb8nrZDsAAae3jjJa0uhboCx
bqGEayI7DEt6JfbYlbdbpWuoV2LI8Cj8OGM1dSPEi5MTmmgydSMmM6MzV/hk
ThX6XvFi3mIe9So8CZe3tw0nUa9G59n5h02+FdSrMTjyWjgu4lI3YXu3Qp7o
TKRugtiyVSv0sW5e0s3gLfd3zriWUbdAdTHy0zAW08e7BT+084uVRdNxc2ro
j8bx338ADPDEQA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQNioVt3b8xWcoDwPtizvslJFZSH8RkcJt46Y2p+
WBHK53DgfuTqU5wB4ws4vPlQ4ryTE8YXcWDn42E5t0wBypdwuH7jUNeqEBhf
xuFtxu4L11/JQ/kKDkHb+yy3qMH4Sg4XtNhWbUmSg/JVHKzXWV3P3yEL5as5
HPh4pCBaAsbXcGgKDVsW7S8D5Ws5iN1a1eTdKA3l6zisEXx4nO20FJSv5zCh
hXnH/VgY38DhfN+3Xqe5klC+oQO71rYesS0SUL6RQ3jaih+/mGF8Ywe5I/d+
XPIVh/JNHOacV/Vk6xKD8k0dLufc2XkiBcY3c2huOXxn+gFRKN/cYenUYsGd
DjC+hcNW+7QfNTkiUL6lA7scS8iRS8JQvpWDpgr7k+/uML61w8lKF5sUNRjf
xsHV9knN+V9CUL6tw8IlJ0T7r8H4dg6PZpuZ3p4M49s7vBGOTP3WCeM7OBi6
zdrpdRbKb3BweDmtyHGtPcx8R4d17u+Dynmg/AZHh6ySH9sYw2H6nRz2xage
lOOG6XdyuJL6jVNjpyBU3tnhkv0kFvG7UH6DM6p6BhdU9Q0uDiUZy/f5i8Hk
XR32Hm+//6MeZr6rQ3fvUtW1zDD3uTkEX+vsuSQLc5+bw9yGq1X862Dy7g4B
+guUSiSg4dvg7tB0PDz2l4+IAwAd4ru+
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIk1EYwPGTZl7m/bLMLOcSExUr79ftcd7mdDrnpDIsCARBKHOapmiv
XcwPuhqhYkRQRoqmoCnzEvlqhhpdSCFhfogQoYLQvkwUzYo9hzjv4GX8+L+c
85wzFnjxsrbUhhCi+/v8+6YfcdHo5FC5FKzakA+bOivb3KgJVLdaRGVDgWgH
WC6T9kaeo3aHKWm02XlHgvYGb8NDktxF7QstfisTIhm1P1RNzzZ//hiAlsB5
0177cRG1FAxbng86rx1FB0FLyOCFG3NH0MEQW7cW7OpEHQK1xcbG9XR/dCi8
5yUHfhkOo8OhfeDOmdcLfugImNP0LjbKqE+C4xW1+9r0IfQpcAq7WeK44YuO
hCb9yIl3KuooqEt+LCsKoo6GjruXKvpuH0THwG5loLo6njoWVuZGzMt6MToO
2rmUbg8FdTys2XVYTJ0+6ARQqlrNw2e90Ylgf3S/bnbRC50EuXHXTasR1MnQ
NdVTUxTuiU4Bz2/8TL/WAy2DZ8dU5ugZd7QcnL1maiq+u6EB8p4bMkpHXazm
AJ4udF8VVbliTwWLy3jTTowz9lQonx97tTQuwq6A4jCj8kMtmlPAvVu2Y19K
nLCnwfyblJqqCQfsaWBc1dcrNu2xp0PDo6WX4q+22AUmGXhe2jOgZ3JZ/Nbf
DnsmnC6OHKyU7smtPRNEtgN1P+7vw57FmssSrK8UdIFJtmD/bEFXgb4/ST78
hGBXse+THHZeLgcClOoEcR+dPxeajeWJ9QF4H1yuoKth48Wn3QYfR+xq9n2S
J7i/PPY+SD5Y/9822PPZeYmGnQ80gvNqIKrt52Yqv2Vdj9fAesL2b0WEBdcv
YA0FYCMJ3Rb17+DvIei8oBMte5+gZffjtOx5eC17HlLIGgoF+xcK5heY6FiD
jp2XE3T+f/8DOf1e5g==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XlI02EYwPFfasPyyGMudctjZK4SS5e3tmebzs1jTiOaB5iTRHOoTGlo
YtPKKDCtLAyNKCkzNVKYeTM0U5JVIhVi/zkEj2paeBF2sOf9o98LLy8fvu/7
8sLrqypOO2dFUZT07/y3ksE6rR/sLuSCRWZBTil71wKDmIKAw7yippe+aFtI
ay26nqckdgIu/3LV8m8fNBNufL5YHtJD7A5867OS93JiDjQZM9uKZrzRPsBp
rHJRMoi54G+j+lCr8UIfBKNmzar4yQH0IWBmeWgztzhoHoR+TOfY+BEfAc7I
fVNtBhsdADm9p8qPXvNEB8LY9MAGw574OMgcxX1ptzzQQVAw2FCgn3VHBwNL
OK/uvEDMB7P/hNfuAuIT0OIsYExv7UeHgG1VPfttNnEolG23c4MiWegweDY3
dvfBJzd0OMxXu/BKcokjIHduaKhthYmOBL0gb7NSTRwF3Zs3F92BOBpaTVdV
4jziGHiXo1z9MeuKPglTvfp2TQmxALRuzVT9U2KA9OxRaYYSrQPoXvN8WJFP
uhAW72mEXQLShfBaYWjWDbhgF0GNSVVn6nTGLgLJ8OJ5mEZTYrCz7qpYukO6
GARnfmbJ2aTHwvIX/yvHapywx4K966i2ZHEf9jhIlrwZN8WQHgcd0dx83hjp
EpC1v3ju14LWScBBExw1U+OAPR6cV5gsM8sRezyoRQ3Djo/QlBSGJyK/8ebt
sUuhcLJvZKbfDrsM1h36q3+FkC4Do6d5qdFpL/YE8N4xToWb0boEWk8Eft3X
DaFhD/ZE2v1JsBVwu7JNTXoSTI7HaMsGbLEnQ1LYpVfzgdbYaabktC6H0o4o
Qc9jCnsKfI/Y3hEFrgssPQX/Y9ViSoF9wWJQ0PbTbFDQzqf+b6BZR7MhFd9F
UX8A7fQlLg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz3lI02Ecx/GlVpqJ5zxK57IMSx151PLcZ6uZx5zbVEqNAsM/wqjUrIiO
KZZUHqTroOOPIo+cChqWB+QyDWtkqZghEnRikjgrspad+H2C/X7w48fr936+
z8OzInufJseKx+Op/r7/vuxxT2/rasn1w7xMkoW9E0E6K2Ye9CdkYpF+BdkW
d+8XZAyomJ1QxD8YWW/N7IaIwgWvoluEZE+Ip/KcD6iZveG+vlbZYsssxAVB
7nnrfF+yH2IvydOKDQLyKnS5La+NHfchr4ZS0TM5KmQOQKPJUJGd5U1eC3H6
06ZHPcvJQSh5PaHaP7OMLMLOvS6Rs0HM6/CjYfJZ6VEvcgiO+3jUfHrnSQ5F
ye9xzSI75jCUdU6P7TjrQQ6HoPflt6Fk5vXoMGbc2ZrhTt6Abt8rntfsmMUw
mifOnKrhkzcifKj8kH+nGzkCgZVxAzIjcyRcmkZ2m44zR+Gyssj8ZglzNAQd
BXdKja7kGORuW6zedZE5Fh8u5EubJMwSXL/Zz6987kIGPrpm5Hw9TdYCxW+z
y982OlOXwkc/93y7mKyVItg5YObyoBN1GQrX6KqrWslaGWpXJo6F97C+CQm3
mhv8rzpS3wRlY4U8p82B+mY45IdGDReTtZsRHCNK637Puhx9nx1TM/OWUpcj
M/Bc/MBhe+pxqJc+6HvoxebjkNvffm+4g/UtnL4Fg+0jX158Yz0eT5aZJnVO
S6jHw3R78Ocxvh31BHwPqjpat4es5ZiXiLDyqVmpgfVETk/i7J/E6Qq0NO/T
ibJsqSs4PRl1XaPuj70XUk+Guiwk0OakDXUl7K2bjkxWL6CuhEJ84u4bkTX1
FFgJ15rt9XOS+Z5C/9mjovmZ+Q4V3ec7rVdha2Zoc77f73kbOOt5asv9ocZ0
hPmXTPSV5tWW6w1qy/15Gsv10HDO59igQYE+StJ6g0f3SLU0UjnnM7+n+dT/
9/8DxSZOYw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XtIU1EcwPGTTnuYOmuzabPpKvFxWb6ar+z+NnU+N7dZiIJ/WASVI+3x
T5a0P8o/osc0CZJlaaSCGJiEhiZjokklZIahUiaGkliujELzUbHfCXYuXC4f
vuecyzkn5EiZ8ZgbIUT79/33pY//4Sfd7aVycMrB/555Pu7rS03geFd43kB7
CHoTPPW5qy/gqYVwkrPr1j8Go0XwcNL+XWqhloBy7HajLpFaChqhtco6KEMH
gyOZCHoDqeXgFS4bXC3bhd4Da29rLWP3gtCh8CrcIJoZl6LD4PVsb1FLFHUE
PDAJSzyrd6I5mBgpDzP1BaIV0Mjli4wbqKOgXjV8VZcdgI6G4pvcnQ9lEnQM
eP+wfs6x7kDHwgJ/KmvKgzoOqoNOzNdNi9H7odXvqyS0g1oJRyd6eprnReh4
qDgfOTu6lzoB9Pvuy89JqBOhs7ypUCHejk6C8tFFe0nINnQyvOFrBDve+6EP
QNPu7PE4uxCdAoV1bQ1ijvogaDUD/Z9SqHnGAKmHVpQeGh+nzYyJClpUff0D
Ad7YVWBSW575NNCuhv5F3/yi01uxq8HRMbxaKd6MPRUWEpfX1ApP7KlguBYd
KbgiwJ4GBUUxj87I13lnT8PxP50m6eDl3lYxd+sb9nSma5iuYXoGuAVHLHu1
rmDPcB1PMnH8DPZMpmdB7PUvv1S2JexZruuRbKYzJjlwtjWZf9xIcP850Nz9
zv+F1AP3nwtV1aVJF2QbsTMmWqZrgesQeCpv0K6DJa7mYrMJz9usY+bnud6H
OQ8sl927Jou3YNeDbG3oZYIDDXoYCnTM1QrRZr3r+jY9c78GyI2/1DmtcMf5
BqisH+nxn0KbDa77txlc75sYXc8bjMx9GPE/+NgYk/z//gOlujbW
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlnlMVFcUxl8RRcUFZBEY1BG1BUUUcAGB8gGCyL4MDAwDvJlhBlP3Amq1
xmfTRm3VIFpjsG1GW5eKYt1BBJ8oqKWYYBtMTBunpajYViFVdKxK23DuH/dN
Mpn88t3vnDvnnrtMNq7MMjsIgtD03/f/X/bxzDnXcGqpHwapN9pHdLqU68ZY
wIGOoarui5OJh6PtnjYgxczYBU4jIpubPBi7oy7pRPKVNjWxFx78avXRrGTs
i8awvkuuLozVmLFpQK+yTCL2w7v74jUfyROJp0IbUBux9B3Gb2Pz6uONh8on
EPvD/W7f+nU/+BJPx/mzK/ZFeTMOxPZObW/3DhVxEByr64p23/Ehng1VS/ZK
xyTGwXhuCmuv/MObOASi/YF9hxvjULitSr6yYqMX8Rx0O1xYU/XbeOK5KA9t
japoZzwPJd1lZ7dFMJ6Phu7TvvcOexKH4auKo3dn+zEOx6TE1HDPYx7EC3Do
8zLXejCOQFqZy4a9Le7EkbAbyl5vPudGHIXghOr6pPZxxO+iST/tykRnxtH4
ydw/wr/elRiYHFO6reKNyyBLQGRIypYxItNj0OCz58v6J0yPQUXAnt1Vp4mF
WIU/VqHHIb/6xAGPQKbHIWPZ9LZn3kxfCNc/3T17PceQvhBpx3fGm8+NJj0e
DurpL51rRpEej2WxlY1jDtB4IQGfhZh/3i+y+AoWFvH5pEVY/G3tsWlfjCU9
EQNC5oBYTiwloqwmIvr0QeZfjJudU5/+M4rqIS1GQNoU9/jlrD5JuD/LL3RF
ANOT+PFCMibUvOrUz2d6MsJvNVhbbSx+ClReXQ93VbH5pUCrC6l934/NL5Vn
KRWj3JrXruphehofT0pDtPapPk3F8qcr8qcr9Aw+PzL4/y9l8PWUFeOFTD4+
MlF26uS2jPUsXybfH3Kmor+yUL7kSFO6J/Unsvh+lbJwO7rKcfwvNF7OQkJj
z3voYP5suAQGq24NsPzZWCitex28heXP5tdLVuiCBnqng9WqeObX8OMlDb+e
sgbjHsrNNVnMn8P3O3IU9cvh6y3n4IOA63ZzOqtfLt+fyEVqQmvL71HMn8vH
l3MV9dfy/QAtDk9Jujunmfm1ivxafr2EPF5HHma6+vdVdzB/Hr8/5Dyc762c
5dPO9l8+KhoyIsNeECMf/aPrN7+ay/ZrPtp9eh/tcRlJ/nzs73S2H57rTH4d
Kj8eUnevkHToMCVpb6fuKLGk4/e/rEPj9QWP/buIhQJMetPeFtbL/AUI3fHX
8xh5BPkLsPRGXdOP9ZRPLkDvmY7XGz1IF/S40RK1tvzicPLreV3SY1dX2YbY
507k1+NJ+Ms3sUHDyF+IIw13PL/3HUr+Qjq/iaVCZG4PnuH4iSP5CxF4xnHY
vJ0UTyhS+IuQMn/Tha6gIeQvon4SyF9E58FA9KC/mGcU0/z6B1kqVviLMXjf
O1B+kdfVItXPTvEULCpYEvn8VhHOQ06sf7S7b5BlRXwb09+i/AZFfgM/Pxj4
eogGRX0V460Gfn1kA+yBVR8eWUbraTPw/SEY+X5UG9Hy99hs3WrqLxj58aKC
JSMf32rk+0k28v1sM/L7QTDx8dQmxX4w8f0omqCbsSvx1jqar6QYbzUp9osJ
R2OutrR6031qM2FmVJDm8n12v5bw+0ldwu8XlPB+UTFeUrC1BN/c/HqNczmd
B3IJf9/aShCneTVvaAI7P8z8fa828/OHmV8P0azIb+bjWRXxZDP/vrApdMGC
ztFbl9jTWH4L/76ABSdVxy/cTqb5ixbURPot8b/K7mMLfz9aLfz9JlvQ/2nt
+MKnxDYL9St7j5WiYNHlkS+/I1aXomhrQk/UNXrPoRSPl197FtpPLJbi5Yu4
g2sD6f0nleLUi509XiC2ltJ5445/AUQXGf0=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XtIU2EYx/FT2gWdeWnN27QpTs0sU1PTrP107nKmZAqGM7EQhCi1m2IT
ipNGCVIIYWRqSWKiNENXQa1pmXYxGkSsv0YXSGpaaehqGV3xff7QFw4vH76c
8/I+J6z0YH7ZUo7j0v49/3dakoJb5v4D4ZjXtOJPQVKhzYvMwagsvRxiDGNe
iVbLzfHG3WQffK+022aXk8XoOWn2rzbKmAPQMxmf91pBlqK+vfd4sWktswz6
qLq5cRE5HNox3i45HcocgbQJ9+gLrhDmSKiMF2OuppOjYUg3lXtbpMwxED8x
7DqxgxyLsTZH96XqYOaNGFbfG7Bag5g34X3zSP3HOHI8kucqhiw3ApkT0NGS
GnmmmJyIroHRzoaXAcybYdWUeDql5CRMKSr5d8v8mZNhHh+QvrkmYU6BoUls
45eQt6DqzrDsoW4Ncyrur8/8fP2ImDkNXypGnInfVjNvRbtgq/XuI6dDv2dY
W1RI3obGs11yoxt5O1qGumsKYv2YFRgslj8I9SQDaotjP174zlsAPDpdJepR
Zi4DqVZzx6O3PqxnYNIedSqujpnLxMzvu/q6FdQzYVj3+EdZLnUlGhPK7K17
qSvB9/T1ytu8Wc+C7yexZFqyivUs3J5uigt6zsypFlpQLXpfDa9yv8mGw/R9
NXaWxzxzBtL5mkVdg6evImZ/iuh+2oUWtPB0M9ZOnKfOL5yHwKNqX/dgroTm
p0OfZiq/RsTmLeiQbfqqy0uh+WfDdOjoTNEx6tlolv/Sc1eo52DDh2DBw539
byEH/a5zjgCI8Rev5+mF
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdym9I03EQx/GlUbqtcjbn1GmbiYiJtNa2Ws595txvOoOiiERCMCrUFUWt
Ikm2YmAIFqEYqNEDCaX1hxhp01yDFKTUEMEMKSPtwbJIK2q6CRW7LzEPjuPF
+xRHTx84HsPj8TR/999lIzn0pP+xLRMRLRjkJy+UNQqZeXB5tadcnQpyHMz3
js2F9jMnQDHgw7MlOVmMjksVH++2M0thczS/55uYZZBq1PUvJ7aQ5ZgOnrk1
IGfOxNWxG30GYwY5C41ZrhPCs+nkbDz3j7wJfJCRcxBqcMzcFzPnYijR5hKU
pZHzMFKIbnV7Kjkfg1PWNtOnFPJ2hFSqh8k1zEoopFUro++k5B2YEn1PqbEz
q6Cbn3U+ak0m70Svn2+5My8hq+E8b/ipy2bW4GBHS1qdMomshWy6HAk3xeRd
yPCe62l4tZm8G2NV5Ys/3jLrUHmNC+gHmffArJ+7/Ho5kVyAJk/8Nt8Msx5K
rs1rHWUuRK092LPmMLMB9uou3z4JM8DvDFZyQ6KInQA3EKjFOJlnRLo7PHlE
y7oR/aktt73fEqgXRdtZBHdBZnXOi03UTRB9EUsWJBupm/Brg/dKWC2kXgzb
8FPfhFdAvRhbra2TFd186uZoO83R/zwOC57xlfqkeOochof0F+19cdQtq7oF
eZ616zTX11MvwV6to3c2P5Z6CVRNX38b/UuGSC9FjDx3WeAOR+wsXdWtEMQ+
qPvcvEj9v/8AefDe1A==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtI01EYx/F/beFGpsvZcnmZt0ptadN0Tl377aZzpU1x0IsCKURIRaKE
6OawTMIydPbGS0mDhKmEg2lrXUYXpHpRGZWQb7IrhZgwLM1LxZ7zoh04HD58
Oec8CQfry6tWcxyn/Lv/nWxJrG7vcE0iAvqhcTTOi7tCmTl4PCNWpSuBLIBm
ok72ycIsgvqs+OHH6XhyJFo23+t91s4chWuH1Z6M7cwxqKiesZcMysjxqB30
9TjCmBNhTokWPjbHkZPxxeU/cKQ+lrwF+28nNfWMxpBTMHZz5GV1GnMaZnvu
Cs/sjSbLccgydGvOuYmcjmWrJLZ1QkreAWl4Z16filkBo4C36B+OImei74pA
MDa+kZwFd9cNbVs4807I3Q7roldCzsaFhRdO6dIGcg708tfPec3MSuwzXRZN
3Y8k5yIkjl/xaFxMVmGqOyf7nT2CnAeD7fiSomU9OR8RX30PBsqZC5BamhRp
rGNW48mbZP/vUOZdaEjttHe4RGQNvk9uPZfRxAyscGUrlcfCA7YBrZlVk92V
rGvR4LUU5P4Ko65F6WCbscq9jroO8/KOU/21Quo6nG+vyTspC6GuR7/3reRp
zBrqeqzlDZ34Zl9F3YCjA/ka13WOugGnr766I3nPo26EzFSikjjZfWNQLwx6
vxB7lI2jH9JZL/rftiKUXVRs4zfzqZuQdWn6p9Y3rwl0E803GzBXjBnVwrIu
fY56cVA3U/9MPcjcbvqH4/4AoAzZUQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQNioVt3b8xWcoDwPti/237+9lcBGJ/B4YhAwzSZ
jYpQPodDrhVL6A0/GF/AwVh1ofrGDwpQvohDbaH8gvAZML6Ew+sgjh9qPjC+
jMPbjN0Xrr+Sh/IVHCQX3T+SZAvjKzlo7v80rTxPDspXccj+8mPll0WyUL6a
A4u+cDPPRRkoX8PhwvN9USsMYHwth9azVhvmtktD+ToOB7TmX/IUhfH1HKKe
+7jLNktB+QYOU95WTZK/JAnlGzrsf7J+/0NTGN/IwXX9g7aJeySgfGOHKpuF
dqEqML6Jg9+5gCPLM8ShfFOHjOp7aYuYYHwzh/eWv/456YlB+eYOv/nS7Q+6
ikL5Fg5zd9hET14nAuVbOgQzWJzbKAjjWzmUi85m6F8mDOVbO/xYwl73xFEI
yrdxaHqS1PtkjSCUb+vwrWudeOwXGN/OQejFgUOrg2B8ewcbI592vgQY38FB
V1Dj46yLAhB+g4NDeJTRuiIlfqi8o0OO04S9fAv5oPKODqW7A2wsfkD5DE4O
e49bvdN4zAOVd3L4qTOpZnkOJ1Te2WHi4+Jqp+/sUHlnh7aJ2VbV8lA+g4sD
N/PaqleTGaHyLg5MClq/uFf/sYfIuzoY97797njgJ4Tf4IqqnsEN6t7/UHk3
NP3u0PD/BpWH8Z/ZAwBw0sGs
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtMk1cYB/BjC/XSMUBouYgWOjVMmgZQrur4t1wtUGgLFsv4YrLohlHZ
UJhIqNEZl4gO0X3QxJhouDUzqDGD6bbXEDYvwUhwxVuyLCRzcVExOhyEi5o+
x+ScJk3zy/95nve855w0YfMO52cqxtjnb7/vfvlHX3n5yoVaIwIaz9mSl7R9
dzA3g6/FmmH2JZAXoKlMs0/n5g7DjOZE7orZeHIkEtjERPJ57mj4/9E82m/n
jsPI6EFz138GcjyiUu9HVTu5jYhW9k/UdCwjL0f1wxV3n6m5V6IzdeHjbsdS
ciKMKlNfUGMceRUyG4fVvTeXkE2IeVww7KjjNkNpvZwc/iCWnAzfv5Yt9jXc
KTicsHZg8moMORXjl4ZnmnXcqxGxs/ja9uZo8hp8e6Iw2HAnipyGZYe+6H6l
405HerezxtakJ2fgTKgqdjqfOxM7Wr+OiWjXkbNwZOeunmpXJDkbyxvmtac/
jyCvRYPuFDvawb0O1YW/LprqXUxej5SCk/22Ie5PEGZKWXJ7Lpycg6W+af+n
GdzAro+Ptx+7GBawF/CtM25NHAil3IJzN87u1tZ/SLkFXZaBwd9iQii3YvBl
qMtT9wHlVkyE9O+bTiOzXNRe7/tlpF9LeS5O+bWTHWlkloeh2PEnx8MWUZ6H
1a1PX1uUhZTni/XefLGeFYj13gI6L95fCMPs0K3McT6/EN8dUPf9WcP7izDc
98ere//z+UVS/wZMmo7t7dzG528Q65lNnOe1wXQpSJN+ZD7lxbg+uL6h/qcF
lBdjT8vUtdoeDeUlMBSVZul7gikvwcG22uwmA+8vFeu9pSjJaPlxzKym3A6t
+oc9T9rnUW5H55VR/c04msfKpPllaD49clX/F+8vx/OsqVmrmeajXFy/txwf
2b73e7ro/RTJzIGff89+ljhG5w2HdN4Oqd8hngdzivVwwpPUVnS7kfc74Q85
tHXSTvdNkXLmEu8fXGgb+6rJ+pqv3yXun+IS94NViDkqxP31VkAVv2pK65vO
CfRXiPvNKsV6VCLwf6qifslKpbT/G8UcG6XzlKxIZm7p+W44DqckBX0TRP1u
8XwVt3S/qsT7girp/avg9qSe/9I4R+8vmW2i9bwIGJK9kpVNtJ6/qd/z3m8A
QKCvmQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCwBmIQDQNioVt3b8xWcoDwPthPXn51zw8eGJ/BYefObaHm
mxShfA6HA0cvtTJHwvgCDrPvV1+88F8ByhdxeL3CSPrTQhhfwmEW65uJqS4w
vowDu/eZvLlH5KF8BYfD/s+jy0xhfCUHzvKaGZItclC+ioPwvKNH/Y/JQvlq
DvVbWGYZSsP4Gg6fZoW5P/WWgfK1HA5sPvM6f640lK/jcP7lo/fbWGB8PYdT
jXePcdtKQfkGDgcMOtMKuiShfEMHd9eSTOY/ElC+kYP84t4mdV8Y39hB+LCi
rvh8cSjfxKGvrL7J5p4YlG/qwH35S+G/OhjfzKHk10olQysY39yBacb83x4N
olC+hcM62ctKWs9FoHxLB5nbEQ4CE2F8K4em4+Gxv3xgfGsHnQ9967b3C0P5
Ng4+5vXbH+vB+LYOhruk1R+VCkH5dg6P9/xt0DaH8e0dTl5T+fKbRxDKd3Cw
PLd7wbEHAhB+g4OD58p1q1Tn8EPlHR1ynCbs5VvIB5V3dLi44+qXGz+4ofJO
Du8tf/1z0mODyqPxGZwd5D18LcVWsULlndHkXRwCewy1WVpZoPIuUP8wQ+Vd
HSDpkwkq7+rAzby26tVkRqi8m4Nx79vvjgd+2kPk0fgM7lD7vkHl0fgMHlDz
PkLlPaDyz6DynmjyaHwGL1T1DV5o5nuj6feGuhsGfND0+6CZ7wuXBwCSgPml

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02lIFGEYB/DxzDLJNt20LHWTsFylzTSvbf9rHuux667uQWaIUhEZhBl4
VDialWZqUkQX0fEh76g0Oww2xC6xEEntQxchRhYtZaVSdrDP+2FmYBh+/Od9
5n3feZ/A/N2Z2xw5jsv9d/9/sktq6rp3vUAGu2yqvA+V/Z3ezBy8goZeTXQH
kt1w7n7nWO1mZk+MR50x3PoeQPZC2hNJaPN5Zh9UqXtCYtXMfigMnNbWTviT
AyAbPCp5q2KWISf89txFxcvJQeD2TT7361tGXgnDiE9zQzBzMMp1O5UvS/zI
q6F8fbq35epSshw3mh7lV8qZw6Cf51D3ZusS8hqEHtE2N/f7khXwDegzv3dh
Xovx7jaFwuhDDscmWdTFUfNi8jpsHSvqrIlljsD9T1m6jCtSciRKj3u9SHFg
Xo9ezbcLgT3e5CjkRipdXw0wR6NLtX1q/y4vcgym84p+V3QtIsdCbqvv6G5g
jsP4qq+lCj2zEvb/KSFvQNH1azX6soVkFVSWyRzdUmagqDVWdeOyp908RLka
m862X/KWs1yN1jjZjuDeBZTHC83HQ9dWn7ity4PyjULzG9Gk7u176MvyBGSH
NGqelbhTnoAVqaeGs5vmUZ4I283B3we851KeCH+NNlra4kJ5ktB8EsrKZx4U
tLhSnowv0TOz8WFkPhnp68u734c5Ua7B1Xsj0qd+bLwG8pvOrpH1cyhPEdbj
U0TfT4XhmCLE+ZAz5amiPE1UP02Up+NwY0HMPn/6Hi8yp6X/6Ui5FgcuDPVI
37H564Tr4XWi+hmi+WWI9kcPd6f2so8nHOyGHo4Bq2fcW3+p7O/rEV73+afa
Om23VZRzBqFhENbjDcL5Ww3CelwmLNlrO/bI/tD4TOH6+EzReFHOZQlziMxn
Cd+3Zgn3gzMKDaPovBiF58FqxOM+ZfHeu2403oSBJbaPJz3pvMKE41VOt99s
IfMm+M8O9EfZyFYTrZ/OM2fGD487Fb8i5tN4M4Y9qndM61i/mGl/qL+sZnjs
kkxUF1I/chZhf8OCqbQxt4p06n/egpyD4dmjHyT4C/1Jdng=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mlIFGEYB/B1PVMzrzbT1dVN08wj2zQ1c/9q2nrvuqvR2iFiWGiZdmja
MZVHHyoySyKigj5YhoJI5ZGxWZIYFmpkiFoaSRaRxwe1gw583g8zA8Pw4/8+
7/vMzOORXZC2RywSiTL+3f+f7JKkP2hvypNjUVPKl+LaFEcbZhFk2zP6993y
IFsgem70wwElsy2yj2blvhh1JzvCS7H06lgVsxPCI0ZHvgQzS+HG+cvGmmRk
d7y37CiZNWKW43VKoXp3jBvZEzPKEc3EXlfyahz+7qxYY5CSfZDR+ebroD2z
L86mjmd2FLuQ/TCZLwktmHAmByAgMnb0bi7zOqRHDOV4Dq0kByFVmtWywZV5
PXqnK096FjmRFfhWuaS+4twK8ga0Srfv7/ZiDsZA/nBrd46EHILrPfZttxuX
kzei4MKxlQ41zKEQX7v1U8Uxh2HQrGrQdcaRHA5zNxPd834H8iZM1hZFNSiZ
I7DjrEL/7rM9eTOC2ly8x48wR8LyzvyuuC47slJgYCJQrjiwhswB1g6dxQcn
l1Eehfh7jfVeN8hcFGJ0v0JM42woj+abi0bX7DKtvtCa8hhUfzxUFj1nTnkM
KqvzwstkZNEW+DWbmIVcZPkW1LUPSnqkppTHQqZKDpPUk7lYLM6rmPI4vrk4
KC58m4syLCgX863Ypl/fWCT/s2huK6yMG0q/1BhRvQqa80FrTSpMqF7FP08U
L8jjUXrqx9O8ejPKE/j9cgk4cXPgsWTMmPJE/nouEUkbTz36GMDyJMH+SYI8
WfB+yYL+UyB29/1hdf8XvV+KoD5V0F8qFvwuH6/LX0K5GlPNfb9PLCdDje6u
zcWH2yxovZr/fwxq+r6sXsNfDw1/f04D/dpq1asSK6rXCOYjDasSat/q71pS
fRqaGguuBGSy89Nwqdy45f1Oyg0Ci7R8QyuYJy2/X4OWf55Ih7zulicDrdQf
dHg4dSnQuZfNsw73I+R7fZ7R/Bt0+DrsXR54xpbq0+Fv5zN9vY+MdMwnfrI4
nWSPv81NUGM=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03lIlGkcB/BXo8t7TMfJytRaU6fTK7Nav5p3Hq8zzg5NtZQllLVodGgX
vkXUUpqVUqFIZjW5WWJKrRa1g2toWi0aSlQ4pAPLtrsypslod/j7/eEMDMOH
7/t9n2eewyczR5VlKwiC9tv3+y9/5Jo792/v8MW4zJGakaGgJ85sAb8djnqh
vOdDnoa+n+M+F+jYLvCRVypMFm+yG0Iivii0hWwFTO35fbdC2LNhFLfqT9fM
JXvD41OXY0ynF9kXKZlX6y4GsOdDCDns0J83h+wHcWpTlbl9NtkfvcmX6ovB
DkRXbaX29xuzyAsxMyUnq1nGXoy3Xp8ic7M9yUtxUf5/2+brM8nLUBYftE+h
ZQehNarOrq9ZQQ6GeUGr1+Tt7BA45Qf+1FviQQ5FWdqocdMXOTkMk/fMURY0
spfjzoYDm7Q72eG4oL9c7evFXoEwz+lXBivdyRFwObFrq7HKjbwSFVL3Aefa
GeRVaMjdPaTLZ69GUcN05UOjK/lHPGg9YbQUsCMxvt9sYMPUqrJZsbJxS8Ai
mf9gWacL5VHYG1Bacq6eLEXBYUZzXu4/zpRH49/XC44tOcp5NPbeF1eFW5wo
XwPZf25ys5wsrYFOeTbhWb495TF4NOSs1u1yoDwGZ45NajRutKM8FjvaGh8+
b6LnpVjcrs0pXbx+GuVxeOppflvqQs9LcZj7+WlHuJn78Vbvj8eIY9ORj6Fk
IQGdjd3DLyz8/gTMSzrfo6vmfqLV+Inf1jNiwL+f+0nocfx122iqI+VJVv9v
Lcp77Ef1odxfO3G+QjJsvQPH7Gt4fslW80uZOJ6Ugp3RZx44Xeb1TbVa/1Q8
7pk//MGB9lNIQ1aF3vZgJe9vGo6aMotMNzkXMXKy1mPjMBkisvdY7tpo6XxI
IqZobBrMf5INIq5FBLddr+Dzk44W0VAu3SMjHbGrTYf+GuN+OvLcy4ViPZ1P
Qzr+Dni3f5nI51WFC28KbXoHua9CX3lY6KsS7qsmnleDCqeKrv1waxL31Vgf
/4fdWB331VbjqyfeD4MaA7+0vA8e4X4GEpIKX9avo/uFDCiL455Fd5ClDISV
tGxLdKX7aMhAeHZkUJEH308Ncmw+HL+xkgwN+o+4+uduIUsa1MgGFH4N7vgK
9L9miQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAWIQDQNioVt3b8xWcoDwPtif1n44RY8bxmdw6BN8KLd3
uSKUz+HwKfDwlMv+ML6Ag5OYldWKjwpQvojD0vuHPslMgPElHH6KFsUX6sH4
Mg7qC99+5uiUh/IVHLbIfQ+ZeE8OyldyMFhyPZ9XE8ZXcXgnc9NDokAWyldz
eNar8LXqkAyUr+Gw+KjIu8UWML6Wg+j64vNlxdJQvo7Dlh9/P8ouloLy9Rw2
s1869osDxjdw4PSwMX3rJAnlGzqcilv/aZ+5BJRv5PDhW2rdg4XiUL6xw5nt
IVwqkjC+icPt41tuXS8Wg/JNHWadEtq1YJ0olG/mYDb5SIanEIxv7jB3h030
5HUiUL6Fg9PBYDlteRjf0iH4WmfPJVlhKN/K4UjAgdkNu4SgfGuHH0vY6544
wvg2Drulpszd+V4Ayrd18Fy5bpXqHH4o3w6Nb+/gt6bPNXUrL5Tv4MCkoPWL
ezUPhN/g4LBxXf4UvWgOqLyjQ1X9r4PZq9ig8o4OgT2G2iytLFB5Jwcf8/rt
j/WYofJODsWrre03LWKAyjs7hEcZrStS+m8PkXdGk3dBNa8Bjc/gima+qwM3
89qqV5MZofJuqOY1uDlA0jMTVN4dVX2DO5r9HlD5j1D3eTi8t/z1z0nvGYTP
4AlVBwUNaHwGL1T1DV7Q8PwD1e+N5j5vNHkfVH6DD9S8b1B5XzT3+cLtAwDr
Ret9
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/FTaS1Tczmnc96p0HlJM295+83pvMxtB8suqJWRIHTRHCUK
xpkvKgszC3phgWlCNzTHtNBp2ZZTMqR6YXQjwcyMXswLpjbtgs/zYh44HD58
OecPz/Mc/6MlOUVrGYZJ/Xf/f9JLmNtp0B0PwIosyUkTLboyZ2oGpe3q1rpW
f2IeeM+DD53LoXZBg7iwetnqRyxA7VJB19Bdag+U6vSNl9XUXmB+J+x7bU/t
h0+1nna9Z32JA1A9mBd28IcP8VY8Pj3ztsqdejsczvvylo94EwdCMmY0aSu9
iCWwrlvWD+nExCEQKUuKjHzqMLzUfjZvSvQkDsefqJNVF0wi4gjwOwyiegn1
Towu+ORWh3sQR+Kwogc9RnfiXTg2rumoiaeOwseBjg/vNELiaLwau7MECXUM
SmorRK7X3Yhj0V0a8mvPWuo4hE6IOQc7AfFuDBcemJp570ocjxDLlbYnddQJ
aGoZdKsb2UKcCI3uUQ1bySdOQtyw4bZ51IU4GY6uxvLSyc3EwBkDmxA777xi
DjiRcrXXuYmYkWLOqUtrjXIkXYp7UlO/WeREegr4PwVCi5C+n4LM+20Ptt2i
35ehImhgoUhN5nOyVT3V1twqM2kYcbpYvKAi87g023mMHLK91mh7OZ0vt53H
pEMpN/d/TaTz0yH2GPtef432DITyA6ca3tCegeT9s/kqMV2/TNv15DKRv6G5
QZxGexa+7QiIPBVEe9aqroD3Q+tIfgztCsxdanMvmKU9Gyv/H9k/Lhsv2L6b
XDfdTyXmFeM8bTbtStTqNwY//UK7ynb/ORXy0p85LLbTrsb63DV6i4l2NSaC
pisiWHp+WEzeKJO2JhODhW7as7GymJhjsVCoWdJ2EvexWJyXNZeHCPAXoVwR
mw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0lFoklEUwPEvtUytttk2tdSpjZK5bM6pbbY86tRt2kPTWGgOKqJowXJB
RQW5ZdLDDGqjoAWrBY0SbZVjD4MWsVGDvTRoTJAKjEG1qAjaNHEVnvugFz4u
P/73Xs7DJz3S1XaMRlGU/t/3fyer/MDYxNNOGeT0wxAc8YhVbGIKDAeHzgaj
UvR6mJ1LzEw4iYvh1fnEG3dWgi4F+baa0MxdYj7EhcyPh43EQvDyxm/fv1OB
lsAAK2a/tyBGy+BJ4jotJiCuhBJ+PEv3itDbYeXTmHPwnRAtB6lkqa5PRVwF
seiVazzTVnQ1DFv+zJ4LbEErgb2qPrn0XoCugexjkc4jIFbBwvGBrmiEj66F
ZKLN17OOWA3+ouVAh4aHroNHQ4ujCm85WgOVvrfxVBmxFpI9XPnpo2VoHWj7
p060cIl3Q+/rdm/aUYquB6aY4Zqa24xugM+3uo0RA7EeQs9ZihcfuOg94LFN
stOjxI3AfrDSYZ0uQe8FUTgzf0hHbICviR2BXb3FaACzK6Nda92Usx9gZ6PS
Nbm4EbsRpn8VOd2+DdiNMDjPST3UcLCbIFV989LIKRZ2EwRvdDZcrGBiN0Pu
/6JhN8OZsN7wbJjC3gQceuTCl/412Jvyz1MWcOgujyeVdOyWgvvWgvetsL9P
pWBcZWC3AU1SleaEM4Zct4E69G3Z+DKVM9VccL8Zvtensyblb+wt+fYXmGrF
+X9ib4V2d220W7aK3Z5vv71gfkdBd+TPS+3DcxT1Fx+h57k=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzGtI02EUx/F/m6Zt4L017zo1vDGampd52c/N/XVeCruTFqaIlJUlkmYX
BmUSKGqakEiQSpHSQCLK1DDQRGOBGib1wmRmaUXSC93UXIXneaEHHh4+fDnH
P7/kQKGA47iEf+//z0Zy+Flvd7EMG1pUrRZk5SRJmTnk2wmsbYP+ZHs8j73R
ca+I2QmTuuGRKRGzG/j98SGCfj+yFNM+V4e7ipi9cPDy7WMV7sx+GNW7BAiP
+JJleDhZIjM1+ZADsX7xeoTLJ2/ybvgbcpMalczBME4pSzOavcihqD71VFEn
Yg7H71yzo7bAkyxHzdsZh88DHuQ9+Lhu/P7lnTtZgTzLV0utK3MEDM6jc/Nt
UnIkWp1V28csu8hRaK47f6GzinkviuWr0+MjEnI0GrxP/2gx7STHYDF7ou5u
NHMsqisHK8ytbuQ4RI3Xlge9ZFZixaxpKw9njkdIoN3scqorOQEKvqUn3ehC
ToSp748+LIY5CSH7Aty055zJKvD982cwxgy8L1zaEdxD1gOidvNJfoj1ZLzK
DXrtI6Z7+uQtXQ1Pqelbwx0n6mpk8W+GZhPJnAa6x4bOoFZH6hpYuWxrXhmZ
S9lsfQo0h9aibXkH6lqcVdf3Ozwg67XoGGm/JC5jnYfRY3GhyUlEnUf9TeGL
6RNkLhXdhpImeY499VTcaihWXvG1o56GR70fJKNettTTcO3+RJ9kRkhdh+wa
RZhNlQ11HcTCJ5ULjduop2/ZT9+yn4HI2p/LyQMW1UbPwNHjEYZSmXXDXCYE
fqEr4q416pn4FbeyrpYvUc/abD3znOovByT0Xg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz11Ik1Ecx/GHZqmtcPNlWlrTETVcDafNvdp+m01nWdFWKZOCRd5kMSqF
GJmPknd2Ee0iRMZIilQcalqECmYTLyRjWBDdjYU0UZsESiPXC/sfQg8cDh++
h/NSdNVtb9zBcVz53/lvZUNycWx8uEmGpGImT7NBPprFzMG95K3vGysip0Hj
Wm10XWIW4fOTZ9MziUJyNvrax3NbBpnz0HfaJ445mAtwpDPcfSEsJRdCOD8i
siuZZWge6tVfu36QfAh+r+B+9N0B8mH4/MbUBQ2zHD1KfAzVF5CLMXcz2BEM
5JOPInpDonUv7icrsex67g+qmUuQbjOqVyz7yCqkFr/qkozmkUvxqSGsiyZy
yWXgMzYeXFEzH8fksuPsuV4JWQ1fy4svJTLmcjh6vPkeVQ5Zg47Zusvx2myy
Fq2+hQlJOIusg7Xi670P8UyyHpGJTV6hYTYg89vU9IBdTDbimFi+1h0SkSsw
OatflUf2kE9Amng/p43tJpuwvvdN+y8168DMjwyH8xaZB5yKR7b5u0LqZgwH
3F5lQxp1M2IvQ5utOenULfiuiycsyl3ULfQfAfVKeNrib5v6Wa+E1HZGJ+nf
Sf0kznepFCmdKdS3mbOiVtP2OqKk83gr7gwYTCNPOepVqHOWBm7LfpuSvYre
s540V42yhysb5qmf1KupL1K3QSgY9Cw9XqO+zVzN1v18Dd3Lxqmt5v/7DymH
08k=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02lIVFEUB/BpQcPRchu30VyztCjTNNPS/+SujbOIiBqRkhlUlFuphL6k
qD7kNhWBRZmiLdagYpZaSGoWbVTgFykDh8glHdJccmmhcz6MDx6PH/97zuXe
+65r+jF1xnKRSCT/+/778mOT2NLeeNgN/6UP3VQtH9KasEXw1IaoxrSu5FUI
GzeKzFewzVEyWdm4T+9CtsbU55HRAA3bDmdspevr17MdEeT3fVh+05nsAvfp
RVvP0bVkNxQXVHSVB7A94B6kuXo+34nsiTH8+D7c5EjegPEJba3PhJTsjf7u
uZ6jyexNOFHafLMwz4G8GV3v26aNTNk+UDjuf7TNyZ68FRgoSrWItCP7ov+3
tD0115bsh9ZOk6gbIzbkbXg9WLMAb7Y/XAYll2uSJeQAuK789GVi3pq8HTW6
s+lhB9mBSBAFvm20YO+Apdi242uHFTkIJyVVorI6djAidulOvftlSd6JmVrj
Ip2MvQvtDpeuPx43J4fgZZ/H5JypBTkUoUmTe+OlbEC84n7hsIYsYMl4GVxl
mRfyFqmfIIPZEcuR81ncfzce6su3OLxZTfluJKX4Psh2W0N5GHom1iSkZJlS
HoaqPvFsnb+Y8nBDC+Fwj73Sl3LbhPIILHfx/iW+x/URhvOJIpf0j4RZtm/w
xxIzyqMwZfb49Lw/51FwXnzzKlDP/aNxW9bV89yexgvRS+pjoJU2tH6Io/UI
MTC1enby+BCvLxbxDaURGS1cH4uYOw/urrvGeRwKvHpnMxS8f3HI87qkqWzi
/dsDqd3gt4pKzvcg515waNMtzuWG5yXIUaJLv6hr4POJNzx/IR65h+qfKmz4
f1Dg//3mXIFuZWeV0Ma5Ek96zw3MFJOhxMuC8J0HPOl/E5RoPV6XvFlC7lQu
qVfBy8NYNx1FOVTQZOg1e+t5PhWqa19IyvrInSpsdLKxz0zjejWMEpc167t4
frVhf0GN2bSchdMtPL8aY0e7f/pN8X1IwLnC7vyZa9b4A8MZPCs=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtIU1EcB/CLr1Y6m7YtH8tXZaJr5LtN536br+nmnoZkKFEJhoLUIFMR
r9BDKc3R6o8syQKLfDVNtEybhEVBgUpmkFkMhUxzQeADe7Lf+ePuwuXy4Xu+
55x7LtzwYxWGEjeKorT/7v9PcvEPDQxbyyLAKYdMVi+WGn2JKejv8EwYfRiO
ZsFyccCEj4GYA90X/XhtK2FoLgxFuae0W4gDQJL6aXYxkVgAXz8XVFrvhqLD
YFFwVTH6MQQdAT1Nuz9ohcR7YJ9P6Y/uol3oSJDWqme1jQJ0FDxhN6dNDQaj
o+EW62jV5EwQWgjGYu6la0piESy12o8/fhSIPgCB2y2S22LiWODL7eVdZwLQ
cXByeq/I27wTHQ/D832CuQ4+OgFWxBu/FSLiRDDetARXx/LQSaAxcWquj3PR
yaAYM4bEhBIfhEpeK3WlYwdaDK+qMlJPRBJLYE01z6pX+6NTwGTtbdRV+6FT
XSwFdrn/t4ZTHHQaHL7R3c4TEssgPX8zyTPLFw3gt8TlO/hoGmCa3VC6rmFj
LodyRcuIbzvJ5dAb3DU4qdqOucKlr4CJoXc/Z9a8MU+HN0GORQtnG+bpUBhj
Vr49S/IMGHkp+R5l98E8AzRdzZklA2T9TNgvFeU/W0DTmXBf/nz8RSDJs5jz
0VkQ37S8KrdtxTybaTobrD0VFtERFuZK/H5emCuhum5jrOwBmsoBdXLdoF3k
jnkO1LZNPeV/QVO5zPnoXHD0T/yq5ZH1VdByzn1oroi8vwqE/R5eSc1bMFeD
2W6qUayiabVLPw8umMskNaEkz2OOpzQu76dx6WuZprUufR1zP6AD/eXYGI/z
Hjhexxxv08G94ff81wJP7OuZ5wd6Zk7rmedn04OpM0XWd4fCvgH3vy5z9g3g
/B+5Yd/APG+bAQoK43pOR/xxjqeM4BYWveHduYl9I+5nwWnaiOtQ1F/IIzvE

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0F1IE1AYxvFhtba0T7e10jWVzbSNVa5tzml79ukkywhGpiMkqhuDqAkr
KV0ZhNGMMOxCQbRaOKNwMswiaMgwkz68aHkREQUZQbVytM1sVPieCztwOPz4
v+/NyT90fN+RDA6Ho/57/73siJyhh0ONBVhQzFhc82NkVMzMwdMLXS2zwXwy
D94Ddn9RNfMawOIz3/qcRxagXyWsjVxiFkPw8sXYLgVzLq6Pd/YoW6TkPJzo
C8mcwU3kAnxNiXniSQlZhvbz9QNvNjMXIjzb55bIcslFaKt5X//Ik0PeAp3B
GVb0biQrkSzhjtuszCocnGlo4nduIG9DQ2om5ctm3o4bGb1d8jIxuQR3Xkve
3b65nqzG91XOseKtzDvQ3DoXbgyIyBrw09f4Bi2zFumTCTk/IiTr8La24+Ll
hIBcipDxaPLMMWY9PMJuzhV/NrkME6et5YcLmQ1wtanrpj+tI5fDPXSvfW/z
WnIFJIPzUZeOeScmorL4ryxmI4z74649OcxA1cDdgLxn9YK9wNT9V/HpZCZ1
E+oUVx3PT5G9JkjTzyZLYyuom9EdzUz5NaybofZ9SZge86lb/tu34OfK0XPz
mizqVsSGp36fFdK810r/yaVuW2yvDd/0c2mzinU7lMNLudqO5dTteBKp8DQ9
4FGvXDzvrUS1rnXkg2oJdQekjt16UWAZdQfcgwZjsJ9DvYr2Pxr/ACOhzQA=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tI01EYx/F/W9FqkbOcLWflNJbZkjYt81L7bd7mnBWKiLYgBYNQmKUI
ScLKIMKM1NKYYNmiFTpMY12mlE0kJKhMGssCi6CsEGdGoU67sOe8aAcOhw/f
53l5ZCWm3FIex3Epf++/l53QfEdfT1kk/PKqnf0PW20iZg5Huxc6wvtkZAHy
5qdcg0ZmEcxvFkxhPOYQNI5DnmuNIEuQf9/47bWGORxvt3w3GdybyBGYdJxy
Dm9jjsTgqGrrpbMbyZuxrL6pRftiA1kOX52ztU3JHI0u78CFkoPh5BgE/XTq
vGVSsgLl7xv3y11h5Fh8eZzVZpldT94BS6aqWlLArISwPuGE/ZGErEJV8QTP
eYQ5DtcuCwRPX60jx2PoidUzUMK8E0nyO56uhlDyLvCuXJ3XmcXkBPisS2Wf
X4aQd0OnPz/WW8iciGf3HLePV6wlJ8FYF1fkmVhDTkZzqbfZaGNOgUihlD7/
HUzeg8qe7nMHapj3osI94yqWsXl1QAe2B0dPW0ZEfpsBqeTjRGMTmdOgXlX6
ru0w6xqoC34Y90nZvhY3o/Rj8S7Wtf/Pc6kotNg7xArWUzGz6Cw8vZz1NNwY
tlYLq1ZTT8PQTFBe0bFV1NNx8Qz/wfihldTTMatoOmkrX0E9A967Iwu1YrI5
A3ENk780A6xnIkrf4i66xfYzA7ouYD/AXBZq20f7Qz/wqQeY08P/f3jU9RDy
7TVfm5dQzw7o2ajsTFb3XueoG8CLiJkTdvrU/m6g/Wm/uRyao2POwVTi3KI2
9pP6Dy7Y93s=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU3EYx/HTlrK0qXnZplm54RGVWLnSzdvOz81Np26KKZHlm2IFmci0
KIVw1RtTDGMvomG+EKTyMknSTAsvMBAsJHwV9SYkk5JmN7MxurHnH7Q/HA4f
vs/DnwNHebKp2i7iOE7/5/n7ZkdWOz79oEGFoDYEQ9n6elQkMwch8Vm31aMk
S1B+ekbIq2aOgbi/tfJSIIUcD8lodpO1j1mBLv7VkrKQORmquMUa9+w+cgpe
T6zyGQpmFd5aKjPM9r3kVKQ9/HZLO7yHnAaJxeP2yZjTIV3L/h7WkkzORNL2
M+65kd3k/TCdMprCa5nVUEx6t+ank8gHIdpxTXc9nTkLOf7GmaejiWQN7g1O
dUQomQ/Bzmdt0y8qyIdxs1/c81HPnA317TFffUBOzsHj5GONCzyzFr1LvCW8
U0bWIdXx4uWPBOZc6M4Kmm55AjkPdyYLjrs88eR8uG1X/CsRzAV4l/G5Nasq
jlyICm37oxU1sx4u+4brxN1YsoCu7gF+RMw6sNnpkdd/3RW0E4hdm50fqiZz
RZCei/3Q4YihXoQL01UFuq0o6gZImzX5y1el1A2Y2Og5kPScdSMs9z2DfG80
dSNswzdM9nGa54phrAnkhJlp3lkM75foI3WOndRNWPAWXjw/JaFuQlu7f65h
MJy6mb5XTN2M4P8sol6Cy33LT2RvWC8J6aVoGcoXxvo56qUQpWT6I4cCQrBb
QnqIuTIcrdN4mlW/gvPOspD98v/tLIcv1//ToF6lXoFI8Ujbe9cn6iHmrHQP
Hac1ZN9G3qR927/53yCa61U=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlXtMlXUYx98QEURuqSdADMTmEBAUBOQmXw7K5cCBw7lxONwODZYbLDKw
i+Z4Y+Jl8wKO1bILJgwblIxYCaL1xkKwgo1YRLmSRtqikENYXOalms/vj9/v
bO/OPvs+z57n9/y+z/tuerZKX+4gSdKJ/57//9lPZfqkr6siEI/JnuRq1Pq0
OjOWEBHerFd3bSJ2xjfNa0aGyhh7om3w5yfSHBmvQ9VchvvZlgBib8ylL93+
U8vYD63mSV3zpD9xAKZ/99tdV8Y4EEsxxoU/hp4mfgb22bZ+zV8bibfAZfvN
lE4T4yCcbLY29r7jRxyMibzJG4O/bSAOxRm36bcCzIzD0HXz1E+j9b7E2/Hl
hOZcym0f4h3Q2FVdR8oZR2ByuUf6qNabOBIe9y4ZZiIY78TMUZf2+uNPEUfB
ye4x3rhPRRyNDq+73lu61xPH4Ojwmz6WUMa74Hlsf9mtC+uIY3H6hQPtBQbG
cRgptczN/7CWOB4hG1U+z5U+SZyA1S2LxakDXsSJ2OYVNHdu1JN4N/p8m97t
nWWchISIrGPuNhYP3AkPjHx+K7EMIT4Zr24dXCrPIZaTMf/wSn7dKqar8am9
Idx32J10NQ706RJ2LRJLKRh3O75vKduN9BQshZ597WKlC+l7ENrt6BR9ehXp
e+Cfro1Vta8kfS8u9n2v+sqPWN7Lx0upONpYEXfIn+WnoutSVVNYgTPpacg9
uSPEsd6R9DQ+XkrHbOzyQ3WYE+npOFi7/EVFO7GUgcPvjV1V/bKC9Aw83hcH
0jWo7ohP+viCRLoGWTG1l6fCKF7KFOpnCvlZPMtZwvm1fD+ylu9Hyhbmky2c
PwfWkMb0kVdcSc/BwLyHwbp/Dek6jPZ8d29ikXTo8I9b7+v3o0iXdagY6vls
rJd0RYdhX/t0k+dqys/l7wMCy7lonKo+pF4gVnKF+ep5P0CPa4Nxd4OmWH09
3F6MiB+rI/8oerTeaHnJtYb5y8DrMAj5Bt6fikHwpxHbEsOMn99h+UYh38jP
QzHi7XHXpbYomodk4uNhEvbBhEp1wzX391l9k9C/mddhxiMp95GtxoPyzXAI
CF527WD1zXw9KQ+bNW+MWz+g+0CecN95/HyVPNi7Rx8cXs/2zyLkWzA0kPhy
zRXyj2zh70ux8H6W8nn/IV/wu6Ar+YJ/rfz+wcr7RbbyflKswvwL0HBkRc+t
ItZ/ASJPzSwkK3Q+uYCfh1Ig5BfyjELB/4WC/wv5elIR3y+KhH0tEvoX4qVi
YX+K+f2Vi/nzKMW836USfp9RwvtZLhH8X4IU4/3olanMfzZ0bvjw8reZ5LcA
G3SVwV//7UPvd9gQO9J3/voksU3QZRu0qdcHfk0kPm9D22bNjzv7iRUbqrs6
T+gO0vdl0oapqw/kkBj2/SpFfkl/utWyFv8CwvE5eA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIk1Ecx/FHnddpmbo1zcu0KaY2r628tZ9T59RNXbcXZVcSjAkzNFaz
cBRpmSljvnHRBcFEK2tJF9BMqzfa5UXWeiURgVgWmgiiRVbsfwifA4eHD99z
Hs5z4Ik+YtxR5c5xnOrv/PdkQ7z7waDDEAOX5pR+9pqNfiJmDs5joVb9w2iy
DwwtV89d0TIHwiK4ETo9JyWHwDLWfC+lm1kClT3Ot7WAORy/jCbP0z+iyFIM
JfTalYXMMXg+kbapozmSLEPvzj3qpI8R5DicOJsRvXCUOR5GkUDifBJOTkBX
jpt358wGchKCDqwRjSuY5chPeL1/sj+MnIJWUYqsVs6citj2d+ql46HkNCSv
pA7MeDCnQzgiVSY3SMgZeBFiOiWdX0/egvaJwEuvSpgV8KyPSGx8LCZvxfv4
msM3H4nI2/ByebqlqZs5E4pvU5O3vZmzIDk49LZNHULOhszkZlPMBpNz4JgP
u26uZs6FrWrOVtkTRN6O+uqe4XIxsxLDlbGjkUJmoM5x92KFeZ3LFmDMKVv4
6U/m8uAf/MxU+2Ut9TyscPqVQ/VkToXNufJdT6cCqKvgDLhQvVRG5vKxN9Gq
eXNSSD0f6Ze/L+aN+FIvWG1LAcyNy6OGPi/qhWiyGrIaoryp88ypV6+3qHm9
CEkDAi9FG9tfBEe/sUO+z4e6hrdfgzPXJobEnzyoF6PuVrbyfhdHvZjXS9Az
+EE8Hu5JvQRRGl2muI/MlfLeX8o7nxbWz3UNqkV2Pi1mM5d/q+Ts+3XQt6Ym
Cs4LqOsg9Lhj/mpzo14G1//rTr2M7nNJ6erltI6GhWeuYrXx338Az2DwwQ==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQNioVt3b8xWcoDwPti/aeFhNWWG8RkcpMOuOe+e
oQjlczjktp0ym2sG4ws4ZK5w08l9rADliziIHPqVydsE40s4hMxcdPiZKowv
43B0sv0qptnyUL6Cg8vCj6GTLstB+UoO50IbhHf9lIXyVRw6m6JX3lGH8dUc
Wjk4/qzNl4HyNRyCRPZoHl8vDeVrORwVym7h9obxdRwWvo/nfzFRCsrXc2jt
nGcrowjjGziIV7+3aCyVhPINHf6mVVWknpeA8o0cTsWt/7TPHMY3dlhzXfbB
8iXiUL6JQwOHcd3nJ2JQvqkDa4msdv0OGN/M4ev21p3fbolC+eYOlRNErnoy
wuQtHK5q5CQu2w6Tt3So06manfcBxrdykPfwtRRbBeNbO/zmS7c/6Arj2zi0
sJw8xTFdBMq3degrKF0VHQzj2zn4mNdvf6wnDOXbO0x/2MN476MQlO/gIKBj
KH3uvyCE3+DgYHlu94JjDwSg8o4On//timxih/IbHB10bfVC9j/jhco7Ofit
6XNN3QrlNzg5HP3MHxxVyAOVd3b4qTOpZnkOJ1Te2cG49+13xwNQPoOLw8Z1
+VP0ojmg8i5Q/7JC5V0duJnXVr2azAiVd3UIjzJaV6T03x4i7+bw3vLXPye9
bxB+gxtU/UeovDvUHAYGAJr8s6g=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQNioVt3b8xWcoDwPthvMtgwZSMfjM/gwFoe4TDp
sCKUz+EgNeEW364kGF/A4WvXJkYGVhhfxOGW+7pH92YqQPkSDueiarW79GF8
GQfpVov94UfloXwFh2ddjqWhvDC+koOAWHsuR7EclK/i0OwqylZ1VhbKV3NQ
XBdjN9kKxtdwmNjBuep9owyUr+VgGiVR9uKJNJSv47BlXXOHuBOMr+dgzfP/
Vc0CKSjfwOFWaolcCguMb+hQu3KqebStJJRv5HAjfUr+urUSUL6xQ7z3Hoc9
h8ShfBOHz22uEa5GML6pA9sH/msTM8SgfDOHFbcPT517TRTKN3cwm3wkw1MI
xrdwWCd7WUnruQiUb+nQwnLyFMd0GN/KIerTbTPVv8JQvrVDuehshv5lML6N
w1Ir4xPL5wpB+bYOb4QjU791wvh2DlklP7YxhsP49g7Fq63tNy0SgPIdHCJn
rV0oqgPlNzg4VGoe/5nqD5N3dAiPMlpXpMQPlXd0kP939rTFBy6ovJPDxMfF
1U7f2aHyTg5V9b8OZq9ig8o7O8h7+FqKrWKFyjs7cDOvrXo1mREq7+Lw3vLX
Pye9b/YQeTQ+gyuU/wwq74om74Ym7wY1l4EBAGSBsTI=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtI01EYx/F/bpW2SstpZpbbSlG3pK1cXttv03mZGmiU6IvUREo0jWUG
dptBWCRliREZEilpOKMQy1thwUqJwFhEXkJD6YVmWSs1mVvFnkO4A4fDh+85
PEd8qCQ934XjuOi/+9/Jlvf+9u5HhRI4NKNqLc77tUzIzKElfUR5pUdMdsVQ
ofbh8WxmD3hN+++7wWcWQqX0bSxqEpF9cLd78rokg9kPvfLI4cblzCK8LWt2
Gy3yJ0vgmWyUDvVvIW8DL0s3YfZgDsTgi9xTd1I3k4Pw5FZBVbXJjxyCytw2
+dVVzDKMj8naohSbyKG4+LWgw2z2Je9AsPW06ncJsxxzeeFvqqc2khXYXjF4
UPDTh7wTN5/X8yoPMO/CgGW+dyCbOQxNLe8+zH3ZQFaiv9aYNhXEvBv3Fpv9
A297k8OxYsb9/bUjzBE4KyuvK57xIkfCpp8LcDMxR0E07lXbkMkcDTH/45jF
KiTHoFeqmTbqmfcg68ewMmDRk6zC68ft9/XHmIGnrypH58+td9gABO/dKtQe
XUddDbH68KUTNg/qalxW5I/U5ZA5DVLjX5omYljXwGLryjy/kvVY2Lk0e06p
O/VYNPY3lAlK11KPw+yazgpr2GrqcSjs63hm7hRQ16LPFHOytMuVuhZn6s09
3p941OORViWX8i/wqccjI0vxQC+xqxw9Ad8iFmya0M8OGxIg4LWWT9Z8p55I
fZZ6IlxEIQuCFiv1pKX3DUk0ly3dUht0S+dxyU7vncylOL1PceqpTv//7z+o
ufXJ
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwB2IQDQNioVt3b8xWcoDwPthHNXrWMXPC+AwOHWH6wrs3
KUL5HA7OJgldxZEwvoBDpoS0+PXfClC+iEON1btF3XNhfAmHmTq7+vzMYXwZ
hwCL0PbOdfJQvoKDVc1/zyXP5aB8JYfZazqc2c1gfBWHKZwtF5f2ykL5ag41
nSpmnR9koHwNh5zVHtvVpGB8LYfYCUvqolOkoXwdh9RD2wPmb5OC8vUc2O92
b9z8ThLKN3AoiKs7qOID4xs6pKoaMtqdloDyjRyeMm0vm/RIHMo3drj9X3p3
dAmMb+Kw902wn/9iMSjf1EFwgh+DoxGMb+ZgJsW5+OMCUSjf3CF4zhTpKkMY
38IhsMdQm6VVBMq3dDiXGPHx801hKN/KwXvzR69Acxjf2mGd+/ugch4Y38bB
cJe0+qNSISjf1uGH91OORh8Y385BQMdQ+tx/QSjf3sHGyKedLwHGd3B4pq9k
nKcJ5Tc4OPAIHyoveMkPlXd0iJy1dqGojgBU3tGBt8jI+nITL1TeyWH2Ne6f
y0y5ofJODj91JtUsz+GEyjs7bFyXP0UvmgMq7+ww8XFxtdN3dqi8i8OJo7bl
Jbtg8i4Oy3dfFzslwwqVd3WonXd5j9hDZqi8qwM389qqV5MZofJuDsa9b787
HvhpD5F3c3hv+eufk943CJ/BHZXf4A7V/xEq7+HApKD1i3v1H6i8B1T9M6i8
Jyq/wRNNvxeaPBqfwRvqTgYGADml1fU=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2Ecx/GDU8mmw8rN28ppamWymrea0/bbRZ2WRovIDA0se6NQLbQQ
B2slJSmZWi8MKoPWRSa4SjKLrgRLTOYoIYKVlZAlzReWU2wV+z/B9sDh8OH7
XA4PJ7H6kL4miOM45d/n35sN0a57Q/21SfDJrbT0L2Tawpg5mPcOnGu5lUhe
gumqGEe4njkS2j6H5so3CTkKeaneybqLzDHYd0D42JnHLMaCIK5s5mYCWYIG
s83aOruKnIQ3c+qTG8CcDOlkyuDh8yvJqWhqSc5pcYvJazHrmmiIrmROQ3Pr
Tvvw03hyOi695Xss2cxSXLCeLn9ujyNvhKfirup7CLMMw2Ny7+D+WHIGFg82
Hq8ZjSFn4tN7/ZETocxZEOVKDOHGaHI2aqULrjG7iJwDVA+Mdxxj3oQRTXns
lzkheTN2tMrWBzdHkeWoOlP4Nf/FCnIuCvI/N43OLycrcLbteoqVx3oeZA/i
10zUs54PPs/aONW5jLwFltUl77KeRZKVkL8euvryAzNQv66rs8NGNgF7uq09
wnTWVahTtz8S9AioqxBhyFA4zRHU1QiSpM3ze8Opq+m++dQ1aD/Fu++qXEpd
g5E491RXJJnTwn3HsWgUhlHX4od8/rdaGkq9AAm6Urnodgj1AhgvOx+KPvKo
F8L3/wZRL6T7DKZe5D/fVIQbQ+OiV2Laj9MFrNfhaK9CabvGUS/G7oqMPkOS
V+nrxXS/Mz5zJfS9P6kzT1Lf6j/fFGBuG51DwxRgrtR/P1Op/3lcWcD+Zchs
m/6leuKhvv3/+j9RlgBw
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd031MVXUYB/DjXdP0clHgxtsFRBTjTTRINODKF5SLKFzvvXDvBYbA3G5L
oCkgSNEfR3TKSkmIcuXLYlS+YLQkSmLDczGoVDaVIpxoc7CCyIW7hJgvVON5
/jjnbGdnn32f3+8557fnLNuxy+JQCYKw47/7/ydf3taOri9LQjCnyaSrqg+M
Wne2gMmmW/6nupaRn8ctU0hanIO9BI93Fc+6qdlaXG/8pv/SV8FkX0y7nFfC
ctkB0FcvPxDvyQ7Gq/uln1yVS8khaD63Uhd7J4i8Avrye5/bYtkrEa3TBbcW
BpLDsN/NeDtvIoAcAaeruSJwBTsKCW25Q6ve15Gj8ce7nYaE7/3Ja3Bsp4/Q
HMB+CWd/ix4ay/Ejx+DahlGDpd+XHIt5R28+G9/HfhmFTtFvkRd7LZyXP1UN
5vqQ49B3uGdv1SVv8jpcG2l5igj2enxYf6q4p+oF8iu48MXBIN9hLTkeUmTK
/fPl7AQU/tJRMFDNTlRYjzffiPx9MJS9AQV1hnH9d17kJLTvrnDlVbOBY/cO
z7v7wHPOIjA3D2QhGUVl2x9fGfOgPBnd+aHOIDXnKUiMyTjkXsR5Cha1zBQY
esnCRrnFjQhsfTKYv47zTQg3Ltemvs75Jvl+QipWeYQ9+OjGEspToSn1nKgr
IwsGZBr6ekf1nBuQfrbtXOiJxZSnwVQacfVvP87T0OXfdLLzL16/Wf4+4mZ4
jkk9rRbuny63mI53YhzDx4t4/RZ4/Kn1nvR2p3wLziRf7u3z01C+FSU/XOwe
6FRTvhVR7c/Nj6tfQHkGYo/cf5gsLaQ8AwcbSuJrlnKeiYaRipqUh2QxE4+i
Gt86XUr1ghE3Lv48NTTD+xsxqKl77ZGR+29T9N8GTXlMwkAt5yaogiP+Ube6
zRkmGM/Xpzo6KBdN+OTHlir1Hvo+yQTXs29zaxfw95vl5wszvp48utq/n8/D
LN9fMiv6W+T9YMG0pnPfk7VUL1rk9ZJFft5CltzIkteLWajsMiWun+H3V9QL
2Yr+2eh1Lc7KK+P+2XDz6tm7e5zmSVJYsMrnAVZMDL94YHUtz5sVOt+RsYZG
smSVz7NgQ2V403uNF3i9TTGvNswK5tmiPdzfpph/u6K/HUn2qXyjjufVDsfJ
z1Q1H5MlO6bfbvPZPsXznYMj7Qsju3+l/xk5GC0Oj396yAv/Asjfie0=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQNioVt3b8xWcoDwPtg7NAq9ny4A4zM4TL799t2X
VYpQPodDu9Zu6zhPGF/AQVR7mxXTFwUoX8Shf2GVgt0EGF/C4eGJDs9b+jC+
jEP1TGcl/dXyUL6Cw84T7B83vZaD8pUcpk0IWp/nAuOrOBjuuFGjO0EWyldz
+Mb0SM/mrAyUr+EQHlY8K+O/NJSv5XD7yO+juZEwvo4De9rOUzfLpKB8PYc3
sx8n79wiCeUbOJxTtHV0D4XxDR0MFH7+s14uAeUbOTxl2l426ZE4lG/s0H9Z
oPuMF4xv4pBlnsfXECoG5Zs6HPb4PE9xjyiUb+YQPGeKdJUhjG/u4FcsUD3t
qAiUb+FQO+/yHrGHwlC+pYPOh7512/thfCsHtlDGzR8OC0H51g5NT5J6n6wR
hPJtHL51rROP/QLj2zq4NFT8NWyH8e0cPv/bFdnELgDl2zusl16z/ZI3P5Tv
4HD0M39wVCEPhN/g4HBW6sOrKQJcUHlHhxNHbctLdnFA5R0d2iZmW1XLs0Pl
nRwmPi6udvoO5Tc4OehsZmEz64PJOzv4mNdvf6zHDJV3dnhv+eufk943e4i8
Cyq/wcWBm3lt1avJH6HyrlBzoKABwQcAK8KrqA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlGtMk2cUx9/BROUmIHYIyE1nDOuKoHIV+FNu5dpCCy0tRbcERwKJjsJY
QOfrsuj8MIQNZ2Zw7pYg140RBMaQFzYcSiARhts3szGnI25WpxMI4rb0PB/e
p0nT/PLred6n5396Ql89XFjuJAhCw3/v/z/ZS1HUP9xbGQYH2ZNnXX2O7PVm
LKDKdu5OfW8o8QaotXfKF7WMvRB0/ftHF2+HEPvCM+GC7XQzYz+spSX1jagZ
B+Kc3ifi7HwwcQi6rrbHFmxjHIakVZejFw4EEe+A7das9seBbcQ7kaAURoo2
Mt6Fh+eLM2/nBBKHo/TQpPVuWQCxEme7T5m+u+ZPrMLA0m7Tg2TGu9H40XxD
nWYrcSSmH5x8a0e1H3EUjIcuLa04M96D2pid5f3lLxDvxfn2sdTH3QrifVg/
tr1VeW8LcTT0rS0B9ZGMY2DSnPH6ddSXOBZ6IXam15txHJT2xp6BM5uJ46FW
HWypPsg4AZbMUdeVr3yI96Omou2KVsE4EaEpr52uXfMiToL75vG6I39sIk6G
rip86vFW5oHaYd3+2CVPB4tAqmE1el0GsZCCrPaejhdbqV5MwRfXPn/DrYZ5
NSb+3qQ3v+5OXg2nkPAVt05iIRXLyvePtlVtJJ8Ke9+Np8e2EAtpnE9Db8/h
FpVlA/l0nGyujG8IXk8+navP4DzHQibux62sqVUu5DkWNMiNOT6woHImr0Hb
8E+K64HryGdxPgu2zoTkrz8TyGfLWcyG0RzVUx32LNnhc+Dm3F2/+MFz5HNw
7OO5bxW/0HlCLnf/XCj7nneJbmT3z5P3Q8xD84KtQf2E+Xyuf/m4MTj/6Ocl
N/JaeFRHJcy97UFey+Wnw02PdyuW88lDB/NLzZqZN6le1GF79oc3zZdcHSzp
ELw2PRVrJxYK5M9HgdyLBZj2ty+2eLH6Ai6fQtQfXxmr7KA8UMjlxXmJ84Ie
jv3lRPV6Li+9PE9Jz82XAcGavDhFB3kYuDwM8n5LBi6fIkxOJNbVfEPngWOx
CE3vOA/esrLfX4Q97/35JEVi81ss7y+K5d8Xi+X9lIpROTl4ZW6I5WuU5wWj
/P8nGpHf1Zhe3k/5SkZuPkxyDxO87/kq7Aq2DzgvmfByosow+juxUCLfFyjB
Px5DJ1b3seeXyO8ncV4wY+SH+L92LRDDjC8DugZmc9i+McvnUzKjSt004vkp
m1+LfJ5hwWV7U4T/NLu/Rb7fJIv8fKFU7lEq349iKfIyrk78lkgslcLnrjTe
WehN9VZ4KSMDZp4Rw4qSA+Mas4n2tWhFT+b9wjp3YsmK3of+F+sr2D4vQ9CQ
7fKpKWKUYfkV29MT/ay+DLqIT8Jq/HzxL58C+dQ=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlHlIVFEUh19iZCVp5jI2o6VZak3ZaKVp5s8xn+a4jLNoxtjqlGmLK7ZB
rwiiiCQ1IkExISeQDIUUHbPJyEpDUkKwhSJbrKBGpmyisoXu+ePNg8fj4zvn
3nMv57yAHQc0RieO43L/vv++9Hjrb5hbCwPxn6xxD2Vng1SuxByG7QVHpzoC
GLvguL/qYoKO2B2x/UuGDPaFjD0hKXvU/qmeWIKxjr6tV3hiGeqnm/LyexYw
XgiNW04770kcCME22a0M92cchE+y0WRJkR/jJVDP6Gy09ssYh0CrafVOnZAy
XgrDrvu541uI5fhQ2cnH3JvPeAUKWw8W7bT5Ml6JMqvipkc8sQK+0sL8i/sk
jMMRdffYkfouH8YR0CpcuFEt8SqY37TJXjR5M16Nq0/vXKgb8WK8Bnvyvh4M
CyaOhPup4rwXjZ6MoxBUMa16zed5jNdi+TupMMuZfDQkW7uHz/HEMRjcvmnC
Nkrx6yC3nmvpqCSORbXRWm0weTBeD3e5Qjr4ey7jOPQYFt/2n00emDzT4pP7
hXkBKMs39WR4k4+Hsa7J6UgD+Xi8DQuM2B9K6ylhnl9T1/nZnXklmhalPFnV
y5hLQHloTXVVG/kEcTy3AR+fBZ8MO0F+A9YOmhv6XpJPxKHQe9+NGeQTYZvq
yjkxgzzvkM+L47kkcbyQhDS+7+7rWPLJyKm9dtlLTj4Z5Wb1uij7HOY3Qr13
6cBXX/Ib4df8c8QQSedPEdcrpIjPy6kQmr7IM3Ef3Z8Kpa3XT6sPU34q+Jvv
CzBEPhWPjZMzQzrJp4njhTR4jFt6mzXk0x18OpbPDZmoHaL9MxzOn+Fwv2px
vVDDdV5vRdF7NxavRvbm8JaSQMYWNUqbY+LaGik/EwHxu0+XT1F+JqSSsfHz
VbSfg7dk4sFI0JcfrlS/RlwPNOL+ETTieItGvB6nFfcvtLCr3rgcT2X9K2gx
HFfl7POc8rW4dMtUoZdTf+tQUGZvn5bNGDqHedBhrPuXsCySeYsOii5p8Kty
yteLGXpciY64b6qj/fVQrthWU7KNzadF7zCvWTDseDUmH2eMLCyr5AeVA2ze
hSwEOD9/afvJ2JKFriL5N60T/U+y8aO44Vhavhf+AOOvfyo=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQNioVt3b8xWcoDwPtjv2rNz+nIBGJ/BwWg569+Y
TYpQPofDGZnvAlODYHwBB7nJjL4bPitA+SIOHOtN833nwfgSDpnfzsRO84Dx
ZRwCF/+4prxfHspXcKhPSph+XgDGV3JonN7YrJggB+WrOGTMnMJutEQWyldz
iDD78J7vvQyUr+FgXlJ4J98IxtdyWPfAd/2ENmkoX8fhhEVpt8AFKShfz0Gp
/MWS60YwvoFDS4r+8V9tklC+ocP/aTuTHz2UgPKNHCzdrzhsWi8O5Rs7yHVk
rfwiCuObOLAfVJ6j80YUyjd1+M2Xbn/QFcY3czC51FuuuksEyjd3iPp020z1
rzCUb+HwXPNTpWEAjG/p8Gi2mentyUJQvpUDWyjj5g+HYXxrh5KM5fv8xWB8
G4eT11S+/OYRhPJtHXiED5UXvOSH8u0cSncH2Fj84IPy7R2WnFxcxl0C4zug
8hscHHKcJuzlWwiTd0TlNzg6bPswQV/qLEzeycE55I8ZqxtM3slB11YvZP8z
Xqi8s0P2iR37Lu/khso7Oxz9zB8cVcgDlXdxOCv14dUUAS6ovIvDh80X/9aK
ckLlXR3kPXwtxVaxQuVdHQJ7DLVZWlmg8m4Oxaut7TctYoDKuzkY97797njg
pz1E3t3hveWvf056zyD8BjQ+gwfUHAYGAOMVv6g=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIU3EYx/FTaRfbbNN58lZta8aSFJs1b+l+Orc5HcvSMoTABNPUzJkU
9CJOg9Bq5ItovWhgVJBaLYwsU0INKVToKsYCoxszMULLJF2wip7/C3fgcPjw
ff5wznMU5Ud2VyzlOC797/3vyS5+T1dvZ40S/zWty29a6K4WMXMYcKhvHrqt
IK+E0f1j7w0DswSumaCjZRNysgyOUqfnzjnmSAjdRc1CFnMs6lIdw9aLG8hy
VDvtRUmv1pOV2FnuPTCrYFbBN9cW7KxcR94E+Ys3KZ7RWLIa9zz3XU3FzPHg
33bYC07FkLfAsiI5eGQ8mpyIk5/bzbyKOQn8uK6n0RlF3oq72Wfs8/5IsgZu
6bB38ipzMkoOtv1aWMa8Dc6WuvqO02vJ2/GgP8TUOsWTtXA9jzMvP8ucApXt
pWc+gjkVlTVefb+YOQ2+0ErdgCGCnA7thcEqcxhzBvbltUg+9snIO5AwESOE
BDFn4tIHx5J3M2HkLJTZ9vuGv0jJOoxWzK1SP2QGNls3ygyHyQKQ9qz3ypP3
EurZ8HO7/GWNa6hnQ1wbNtVsYz0HhbXxIz+jyEIOSko17gYlzXN6WG+dN1R0
ianrMSZurpq3krlcPHqa/k39SUQ9d/E8Z1g8LxhwfejasdWNodSNSMhMLO7z
sm6EuEGT8drOzpsCugnSrzJ+mmfn8wLeLw/64t/aYCPr5sXzghnmdndHnIt9
Xz5E4Y+P10+y/eQH7KcAQ2OqWZ+I7bcgYP8WDBb2XxZ66H8JFnR+j249URWO
PyBP400=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBwBWIQDQNioVt3b8xWcoDwPthrmTUWp8nC+AwO+S3lJub7
FaF8Dof6rA9b7qXA+AIOvEJ8hxr+K0D5Ig6FHyscVbfA+BIOz9sKjgcmwvgy
DncMp81x+SIP5Ss4ePjILpqqD+MrOVSrVigX58pB+SoOE5Je3HfcJQvlqzlY
6zDsDeWE8TUcmqsai+3DZKB8LQfngEXKkbOkoXwdh/nnefgmX5KC8vUc5i0w
jUwwhPENHKYL2e5f91gSyjd0kO60Wn9HBcY3cnimtPhr6hwJKN/Yoc/4NeOt
QBjfxKF4yrpazgPiUL6pQ8CXLSd3uMD4Zg5G4vMTY9rEoHxzh9O/XnS1LRWF
8i0c8hl/t62yhvEtHf4sZlF8fkEEyrdyCGawOLdREMa3djhZ6WKToiYM5ds4
/FjCXvfEUQjKt3XQ9FMWcc0VhPLtHHhzhF53FApA+fYO66XXbL/kzQ/lOzjk
OE3Yy7eQD8JvcHBY4Xj46DFJXqi8o8NPnUk1y3M4ofKODm0Ts62q5dmh8k4O
kPTDBJV3cjDuffvd8cBPe4i8s8N7y1//nPSeQfgNzlB9MOCCJu+CJu+Kym9A
4zO4ocm7OXAzr616Nfkj1H53qPnfoOa7o8l7oNmPxmfwRDMfjc/ghaYfjc/g
jWY/Gp/BB03eB819vmjyvmjyfmj2+6G5zx/N/f5o7gtAlXdA4zcEoNp/IAAt
fgPh5gEAjhAB6A==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tIU2EYx/GTczTU6ZZuXrbyUmSUTZ2p6Vz7OTenbhrdqBSikiAQ0XTT
UMQlFotysLILQSJCRBcMi/CyqBACFRqUmQVCiSHlJSeVywhX4fMG24HD4cP3
ed6/3hN/vGrviQCO4zR/339f9kgPPHb2VCRgVW7NwKIk+WogMwel5pLe1hVP
FkDuCV6Z0zGLkHjHoBZ8jiNHYE0Hr/x8A3MUuj7k3LAnMcsRdCrF3N0ZS47D
jPyy9unEBnICKi5ct4XxmTeBP/Ap2mBaT96Mwr66wPI2OXkLnG7ztY085q1Y
dyRUMpIhIyehzv6os8ESQ1YgrW3ek/s8mpyCj0Oz4spI5lSMGQdLJ+OjyErU
RFeOzzdHktNwuOmr/uIPKXkHht+0nrUMS8jpuHWlVtwP5gzYqy13y/ZFkDPh
OnZo8dv7cPJOiJJSZS6vmJwFZ0z7zf4FETkbsxOJrcktzCo8kN3vfW0MI+cg
JHywvvoLsxpebo/3qJl5F7arFfufTQvJGojnIqRuaSgZvt0KvBXaTi6XsPlc
v56LJWH/md/pIdS1ENYoVaMtrGv99vPwqm/s+7ufwdTzULrNUeA6TeZ0eBnj
nmkXBVHXYeiFut48IKCu9+t69HRXtSvKWM+HY6q2UetZSz0ft53j0hE5n7oB
5xwV2Y2xrBt857kC3/OsBX77hVj9PwKo+5krgimzuXdKwaNehIOlyu6aBK9m
tRtRe0+ledjFUTeiqWP0iXSS5jmT77zVRPdzmfaLfW0t9j2PK8FC1q8VrWKJ
OvM07e/+7z/Xbf+T
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtIk1EYB/AXKzCXpmbzWunKMp1aU9dFbX81p5ubuztYFhEYi6SLRCWE
rfoQGEaBBBEEZmXoun1YZqXOYmqGwbpTHyoqu9BllYWaYYXPCd4zGOPH/z1n
53nOOW/Shq3mqiBBENb//f77ZR+pzXP98mYZJhVQdVUm98yVMAsY8EyP2dOe
RA5GcOSDJZq1zOFQabPjIqcyR0HuHzOe7Ekkx8DZGNAK1cwJSFZ2TG8PYU5E
2t6JyviN88gyvPv6NCjTM5e8ALn+i37nxBzyQsQ0bMpIr2ZOQVBi6pikLYGc
itbWX6c2fokny3GjMbP+QDZzBuZrjz1ynIsjL0GtpV7ePxFLXoq3Q77wYRmz
AvOaG/Yv0seQsxD4WVX3oimanI0vqi2al9OYc1Bfty7aPTybrETL9cfSgQTm
ZfCmFX5y10SRl8Px7Zky+fcs8gps6Jddy3Ixr8ShhjPJ56cw56Kz7+Dzkb2R
5DyMlL0J3qdjzsfx7pZdNjnzKqwp6Q4Zu8SswuR+MwNDmbKsLYsjJu0C2vJk
zpRbMykvgF7d63udH055Aa4EjmTGDYZRXojQGkXu/f2hlBfiZ2jHvvGcGZQX
cXkRIj5GSQNSNn61+HnXai4vxolHktGzORLKi//Wv/Jzyis2v5obr4b/6sPh
JyP0vFBC54PlJTh9u3mnZAebvxTVhUc6w5rIrlJcjHe33ytj9Wu4XAO7Q3Gh
RsZyrbgfLi03vkxsVxlmzLq5a9t7lutQ7j5cXOVh/dGJ6xX0cKQdLb27m9Wv
x7mCW77eWHpeKEeRdVw5Tc3+v1w8n2CA7/tMi2M7q9/A7Y9R3E8YuX4axeO9
RgzGBT40hofQeBM291/tut9B64OJ67dJPL/XxJ0fM2oX941WGeh8wcz12yyu
x2vmzocF6fkZ1u4hysHZZRGvx2sRr1ewcuu3cvVbxf33chZs4v2AjTvvNq5/
XC5UiO8bKrj7VgFjdeqdH7FkbwVU9uHK8ni6r4IdeQrdwbD1ZNixw9nSZZDS
/XbZxe8Dr/3/++QPFfx+Yg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0w1IE2Ecx/HTSW/LWGlqajVXWpqYL5nv7re5qc05Z6YLYSCSUGqpmWBi
eGmmYUJklBDItCxRDGz0xoJc0AtCCopGiKxQMoRIMswtyYr9n2B3cBwfvvd/
7u6BCyquOFriznGc+u/578oOn/xHlqEyGZxalI8fb6ow+zJzSH2huaOwBJE3
IN2qXI42MkvwSjpimhEze+NWZ1PlW7OU7Ad9pN/stIE5EDZVz3Tj3G6yFG3d
+eOhB5ll0BVMvyzt2EXei+6AVpvuw05yCCYH1mrd8pj3w2rsNSn6A8lh6AsM
Lil5H0AOxz5edqpAxRyB0Rlz3swVf3Ikji0NlVsmdpCjUGSft7d7MUej09ol
ainwI8fg9N3i9ZfP+JIPga+R/0gM8SHHIi18ckzUvJ18GJKWqhO2Hm9yHBrf
GIwOLXM8zJXVS4W1XuQEtLX3Bg+KmBMxH/r9fJSeOQnqlLn6Mcc2cjJKz608
djMwp6Coyvhr5MtWcioSRi2m1x8lZDlqLPrk+JUtZGDKs/WkXefpNA+8819c
uCHZRF2BPZqbU4V9ZF6BZc9nF1djN1NX4vaU2H4vVkxd6Xo/l4Zrl0RPbUY2
nwZ7+PX6++Ubqatcn8erUNfgsJb1r6OuxoWuiec+n0TU1dDGNTyZjSBz6age
SJI/7OGopyOm/etPxbBd7uwZcJeGOcQDq07zGa73c5mC+Uw4/wd36kdgKIx+
cFa2RvMCcxrBvEbwflmu6/FZyL0adcCj2YO6VtC1gvWzIRYN1i10uFHPFnSd
6/N4net+cTmC/csRzOtd9wt6fEtw/FZGfKbvFXhYT+uyI/d//wOczBuj
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzGtI02EUx/HNTZ0t21zz7222uSLUDfHSdFvqflOnU7CosaTEF0lCZGXR
DbOxBdogysyEoIsQRMN0kkhepjlEZEvplVC9q5CIRdS6IEysVXieN3vg8PDh
yzk5rR0H2+J4PJ7u3/z/2ePsz2fG2tXYVNh0rvxHxsdEZh6ioVBrz0gOWYS3
D5pkIRuzFJVLgaHrv1RkOeYbbP7kfuZ0RLsuDs0XMCswGO85dnxOSVbB70j6
JJMwqyFdc046z+wg70KLxavhT2STd0OgznYaOOZcuO3q9KwmBTkf6z59c7Qr
i6zF0Qlbp8adSS5AVHfK4V7IIBfCX8hXDkuYi7Cz8cIhV0s6uRgjb7Lfex6n
kUuwnHf6mWKDI+9BSt8+nrmYWQf9CVPxzbRUcim6hS+XRHfl5DJow72jk7e2
k/VoDap9JS5mAxLs/PHwgoxsxOrsb5emjHkvZjIHHk5/k5LL0ZkXiLTtZ67A
4XveR6la5kqkfJFzYW4b2YS15OmrG7qtZGDxp8R25CzZBfR1C6betWyhbsb9
1+LIE52YuhkvAsavuatsvwrtwam5lWnWqxDR9l/xnEyiXg3ln1fL+jDdc1XH
9BqMjXYMFDSLqNdAOy5MKO1NpG5BcLHi0nkf65aY/dqYXhvT63DtdruxS0n3
XHU4cKNII+wRUrdCaW00cE/jqVvhGFyZ5T4IqNdDLPBe/nyHT70ecar8dfHw
hmmzN1D/bvoL07nLBg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAmIQDQNioVt3b8xWcoDwPti/qbitliwJ4zM49D187Cu5
SxHK53DYV+TOejgKxhdw6HkR35DFD+OLOFx9HhDdt00Bypdw0I3MubEtHMaX
cUhbu/s/wzd5KF/BoflcwnluexhfyWE6V9s16To5KF/F4dup+H9P18tC+WoO
/381qpx5LwPlazjcbUjJWh0M42s5nJrzcvmsUmkoX8fhTNWpxEXiML6eg+0m
pxcT1kpB+QYO7He7N25+JwnlGzpcPi7DfIsdxjdymOGjEsTRKwHlGzt8msH9
r+e9OJRv4vBQO/UQtw6Mb+rw+dexo3duiUH5Zg7sB5Xn6LwRhfLNHe6/Xl4a
PgfGt3BoYTl5imO6CJRv6TBV9W8kw3xhKN/K4bnmp0rDABjf2sF780evQHMY
38Zh7/H2+z/qhaB8W4dvXevEY78IQvl2DkIvDhxaHQTj2zsUr7a237RIAMp3
cPBcuW6V6hx+CL/BwSE8ymhdkRKUz+DooGurF7L/GS9U3tHh6Gf+4KhCHqi8
k4Oy17RrUSu4oPJODj7m9dsf6zFD5Z2h5v23h8g7O3Azr616NfkjhM/g4vDe
8tc/J71nUHkXqD4GBgBdG6lb
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVzltI02EYx/G/FZWYMXNu0+maU+uPiuSmazZtvx2c2YFGR2Z32ogaESUm
GsF/F1GQFbF5o4Gxi+hoaEhultPVVkY3oh30ZkRlJIkaNpcdrNjzEj7w8vDh
Cy9Pdu2JPY5lHMep/75/m41kf09fl1OFuGYMwW6+eGwNM4dFqUeWejebvBpH
7WfH3u1jFqFLsZfrjCnJYig/HpkcvM0sQ0vCY7nKxpyJ47VNvP7lerISUz0u
/1ABswrPOq49cngU5FzUWZ2zg5Es8gZkSX+MTMiZeUSTfa6fpZnkfJht3hx7
m5xciIDffcUjYi7C9TrNzqArg7wJnwPV7W3f08nFqM4YHQ5bmNVQXcSBN60y
sgYNCxvvD72QkkuguHDs1lwacynCLcHG0wEJWYtvD8/5ouNp5M3Qfq3hd0SY
dcg/pAv172Yug+j8ycMRr5i8Bc1NBZ9e5zHrkduY4NZOp5LL0Zr3y851MFfg
qW2gXfCvI2/FqCOayPtSyAbcyNk+XhIUkYH6O3pDt5csALus4dCHCtaNaOiz
letia6kbkfJFLJmRkDkTbhqfhMLpydRNGO59Nfc2lkTdDOfz3v4RH1kwQ3Np
at44kEjdgqvv68+Y5ldRt6DwwYqV2stkrpLu46hX4mCNuvOUatEQ71YkLb/X
POmejVuwYrps4bepaIJ61VILVfQvm21LLfz3HwwBw20=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0X1I00Ecx/Efs3Jl6iz9uaaZGylTbCtn5Zq2z+bD3LLnJzL9w1EwsjJn
BSXilJCIsgUKGWkPBDmjmTMtsCh7pHKEWJMoiZAGVtSoXCisMva9QA+O48X7
7uA4qbl8024Bx3GayflvZYPf2t3bWSZDUD5ts9mrvSVi5nDopD/M0iklC/G6
okJ0xcwswpOUnvqBsURyNPhtGo31MrMYoy7tiGc9czyKh4SqzwLmRChDq97U
WBaRZciIa+vQPUogL8aSbMWWe96F5GRsHBI7TsuZ5fCU9MtT98WTU/HVPGP4
xmgcOQ2utqfmujRmBT5+78q875KQl8It8X1qFDEvw8sG/yl9ywJyOqTi0oB7
WExWobbyprLfxJwBteEVXB2x5OU45+jLGbvOk1eg7e3DphZPDHklmhta9zw4
zJw5ebY+QfwumqxGsVBiO6tmXoUNyouyg2JmDV70dDusB+aTs9CUFNjBXWDO
xnhpZaC2m3k1nh3JzdqVzKxF8L/nkQH/CWdsyc+ooG2AVylT7U8hczpsL0p3
WmWR1HUwOpztSefJnB49PrtS4o6grkfUl2jex5O5HIRb0zWDdeHUc7BXb78b
cYn1XHjCj1vG17GeC0Fi6kTYtbnU8/D4R+TmogqyLQ/2YyG335fMoZ6PMyOV
VfpfodTz4esaCFTHzKZuQKezvFGxU0jdgKM1E31l7bOoF+Bq7xD/PH4m9QJU
tw7e4T+EUDfS+/9og92Ib+qJ33qFN2jORPto2EzT+pqptk0zVzitF069j1v7
338B2tDncA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mlIVFEUB/CHGi7jOunknpqGjTG55G76H7dxGXNGk9CmUEusFCydQgxr
UCI0hWoKMiOpJI3RMsLMzNJEU0yoFOuDQqUQ1YTTpmkuFZ77wXnwePz4n3vu
eZfrnluUlmfAcZzk3/v/yx5BRnvXvQIPrEoXJRZWz6SZMnPorfHWHGp1J5vA
ctOFb43RzNaIU++f/KJ1I9vi0ZilqLyO2R7Di4Y51hHMzuiDa6XX8EayG54X
pL80iGX2wKzItK76uivZEw0X3dvfLLuQNyM/RtHQG8jsjQ9WVp/alM5kIW5r
M8sivzuRt6JUaFvSLmcWYdC3S1kz4kj2hYFpZUiVN7MfXgR9NMuYdCD748i+
k72eUuYADCjPlxYl2JO3o0kz9nZOu4EciB7L4O5nfOYgjBZOdA4eEJCDEXv1
Hb+zyo4cAt+9lU3dzbbkUChMHFWXQ5nDMH14S9jSmfXkcFzyWsrkGpgjsEfy
1GyhjU/eAR8XgUN+DnMkFMY3rjjF2ZCj4KJZHFcEMwM8w9ayz2qyChga9/z5
x5zlYsgKhcO/HKwpF0MT4XHQu8+K8mjcdWrpeJ1MVumZi8GxLllEyG9LymP0
1seicejmcZ6S5bFoFvf1DzhYUB6HFU6+kq1k/ePwQHdum+MI1XPxMHATLvA0
5pTH662XIGbXYtC6eNZfAoti//DRCpYnrK1XJayt5xLR/8MqPeso65+IgsGH
T0Y7eZQn4fxUyYnoOWPKk1B+bfSx4L0h5ckIqP06J+6Zj1rNkzETurAcLZpd
NSfF7iz/O8UeK5RLIQ0+1TElYutTIK/x8zE6bUT9U6C7/2qp3M6U8p2oH+fN
3wqkeVR65lJpf6pXperNL1v7/5DBRmsr0AnYecloPjr/HhnO+udN1GfTfeDk
a+8T5KiYzq2dbmH3SQ51nk6taOLjL88+G9A=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlXlMVFcUxh9IiwVsR5YBOqhsrQwMWBYFBMoHsoysM8PAMBsMNlSqFFAg
CNL2QTCgbaUg2hZiVNoMJFQMEJEl1QkEiyHFYtOJUWtbaUQlNUBdQATapvf+
8d5LXl5++c737jnnbh57ihX5lgzD1P37/veljzDz4nDPfk/8T3PRpw96dxts
KDNo7/hgz4U+D8Lr0TBQW1KvpCxA/82RV4yP3Qk74hG7uej9k5RdkCiava7y
ouyGLKOtRXj1FsLuaHjWe6xzbDNhT1QKmbqE1U2EvVGzcm1hRUb5bdzWCq2b
b7gR9oHgu8duQRLKvjCGKMzLjSLCErgMjC2ODL9JOADHI1rENTaU38GlviM7
8/pdCQei8+PUIqmIchD0jZKv7xa7EA6Gw6iHv/MZZ8IhCIOXJRaEhLdjcELd
r1JT3oHO26MnT5udCIdi+cDZT1ILKIfh5TdWHjM/ORIOR7a0UXDvCuWdqKr0
mzG/RTkCFU5tTKPRgXAk4qP+rL7+wp5wFPw2CV335lF+Fzeim62cf91IOBql
PReOyqooA/YPTCNdCsIsYPRKuhUyIiB6DGSFvhNPXQmzMVBpgroPer5B9FhY
uvu+sO2yI3os2sy2S8bttkTfhf3jA5d/HiTM7sKSpLm6o/A1osdhfCyqomxo
PdHjMNc3tfKRE9XjEfz5X89jTITZePR0F7cEaEk8k8CNZxN44yfii7p1A7/p
bYieiKbp0sOxz62JLuX5pdiy+uNE2ByJZ3Zzmd0Nr6RTZk0n1ZN4+SXx9GRI
+qxe3XGcjMcm8+pP4fUnBRq/JunkIZp/Kk9PxdTAL09uLlI9jRvPpnHng0lH
Z8zo2FXXDURPx4ZC+9mGA3R+ZRC5TD9oaiYMGf5eHVLXWtP5lqG0KyK6t52w
SQaddXurKJ6uHzmXIUe5uOVEcy/1y3l+Oa6ZvZ8s21G/gje+Ah4xe4+Wr1K/
AnHsoZXAehJvUiAyKKX+dQP1Z3B1ZHB1NgO2685XPTpB/bx4RomE7x/uwxT1
K7Gp66VZF0r9Sm59JiXPnwlxmpdj/IfUn4lK8Q9L+ek0/0xufaZM+G/0mW+d
ov3P4tWfhfDJ4bNXf6f+LF7/ePGMCurW8+ecJNSvgp3DSEXJQ7I/WRV3P5tU
3P3OZEMgCRRNrtH8s3nnQTb3vDDxdEbNrQdqXv/UvP6pefOnwadB+XfaDNSv
weydrXXbamn9Gqwx8jVDGanHpOGdP1r4RwUor9wn6xtars5q0RXpWeAzSv1a
bj8ZHXe9QsebPx3ub/MMLhLT/HW8/PW8/ukROCTaeq+cnL+sHvvKFvstVIRN
eiT3zSfJQ+n5nYMv//jM4u480ZGDc9+OOzWaqT8HZQUdl9OF1J/D/R+Tixnx
QmWgjPwPuVjKK12puUiYzYX/jIi1sSL3hymXd98YkFYqOHxqjLC7AdM19j4l
75H7CQZYfnVmWcoSNhjw9NKRwWe3nPAPhRUa9A==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0W1IU1Ecx/GbTrOEWlM3N6fpqMhcq2ZZpm2/bT5rBasIywwrKTFm2JtY
JaO0iLBwSYJkKRRq6mCFq7WwKUE2X+kwkRRagkhNNF/4hLWK/U/QDlwOH77c
e865J+FMhb40iOM49Z/n78yG8Fi3w1oug1+zaptPqrLxmDkUO+OXvR0J5DAk
DkQNzeiZ+bDGHeEsi/HkSOS2WU4NNjNHY2AluISfzixFmvRn1c3RjeR43FWP
mmOUzDLI3o29WjLEkTdBU/x86II7lrwFTV8E/Go+81b01aB2xCAlb0O7t9Co
moshy/Fj0CVp286sgPVz7fhgjYS8Ew1lIq5FyrwLzSFO/QejmKyE76H97FdP
NDkZp3tN4rURzLvx/dyLG3OdIvIePBvzuIcXheQUKEVPSopuMe9Fo0vwptkS
Rd6HVseI0CVlTsVt4/sri48iyftRzfvoCmtgToOga7hstoo5Hc4k7XRnJfMB
DNi62ysvRZBVaHnaH3X/k4Cshv++mQFvRGHp/B2yCUiKFYrPl7CuQU/R5t64
cNY1GFKbeaLxDdS1EEw5+zr0ZJMWkztkyYZE1nVwSOqb7DN86jrERE9M1ZnJ
XAaOn1BaKmXrqWdAd3QlJSRrHfVMlPe/7nHbw6lnIrl2ekHjXEM9C1ZLRb3i
ZBj1LNRNXL6qXVhNPft/m7Ihf8kLTbnHek7A+zlYkpuvtV5k38/FTOryL60i
lHqAuTxcf+x+K/QEU8+j/xtEPR/hwV3Gbw9WUc+n/S+p/b2Azu/z21QQ0A/S
evPUmSepH6J1aJgCzB3+59+X5vvI
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIU2Ecx/HTXFZKpObWtNWZJlZujtRMp+n5bfMy3TQTe2EvTAbhC29h
BF0MD9nljSKWSESaWmuSW2ARUksURBEliwLzTaHkhQLRkBrakor9n2A7cDh8
+D6c83/OE2WtLT4r4ThO//f+92SX/NQLV39lNLxaFYYfLsTKQpk5qG0Oc+Dz
KPJ2HJ6UvV8pZg6BvdQ9ciCAORwDI+0H4ztVZAXehVjDbEZmJcpjGo2XXDxZ
hVu2uZox935yNDI9gfUdZ5hjsPS2YWFteh85Fi0NLQuWROZDUFz4fq6tUUmO
Q11HYo/m816yBjUVM2XSamYt1spHhUFbJPkIhvrNTUETEeQEuMN0chXPnIiZ
irbap04FOQnKruqlksE95KMQd7mvlyUzJ+Px714+9r6cfAySuw9+mUQZOQVR
0k+za55wciqG1YZlRx2zDtbx6FdJ4m5yGr621+mdAnM6uh+Ny1qmw8jH4T0/
5gxcm7c2zztCyZlwRbZ1vFwJIQvQTbm6xmaZgfN96cKzHrIIlN5zdss0rOtR
VBU3+SOCdT3iM7QlQ4s7qRvQqx8ZHYsgiwYkNS+79cM7qBvBb76ZTF0Nom7E
aXWraepiMPUsrGtu19uraL2Y5buey8bN1sq0K/w26tlY0W1sGrSB1HPAmwp0
8idbqefgZFOCWnpDSj0XVzs/vJbPBVDPRXCA8/K3O1uom+j/Saib6P0/BW/P
o3V0iXnUF6nn037XvRbzIVHFbQT3eaib/brZbz4L7K6P8gklm9/iOw9XAEtK
w8AXLZu/wK8X0vlx1At9v8ed8J1X9DNX9H9/fwB1EQYA
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0A1MzHEcx/F/D6iu0uOfiK5jic7TnaJCn56fdde5PK2N5ibVSJhh6Y+K
zcNYWpujSVtXUpuniWSn5KEtm3nIsAwrVLg2QvOs7892v//23+219+/7+/3+
55+1Md1gKwjCqj/v31/2iPpLzedyFRiRJeJ2zo19+U7MAqqL9/bWmfzJDjAZ
z1YEJTO7YV35sbq1n+VkL1TqF89WVTOPR25RWbdTNLMv4vQW47W3fmQ5bmba
BA9PY1bAbajoclH+ZPJUdDvKVDMvTiIHoCNnTZC7D3MgPA0GrU7tS56B2E3l
A93bJ5KV0JXHVjQWTiDPwtOfnf0993zIc/Cmt93tk4J5LjTn5IkZTePJKsQZ
HQdNQcxqiGHyAufCceR5MLvOb2n1YA5GzY9av4ATIjkEu5Q7jBss3uT5uPuw
uGTrXeYFKO2s8FmuZA5FQl/XddcDXuQweDQ8Wm/ZxRyOrDuKq2rJk7wQr4wh
wc/KPMiL8DW5x2F3CvNibMk2XU8TmSPw0DDkGHjFnQwYTtbY7jxFloC4lnc5
uM96JHpnK9QbprMeiZopSU/ntbpRj8IBleG5cTVZ4ixEwyXPo3//JtajseJ4
Q5W3kvUYOHu2bst/N5Z6DPKijrS4VrlSj0XL7bAPga+dqcfC+Fj2rSZYRj0O
95sefXrylSxxFuJhK58xLKtn8/FwKVCFP9jjQj3B+jwpAe4DXqJFZOcnojay
rf2WD62XElG/UJEd2Eb3FZK4/ZNwpNiu6UWmE/VkKC/Yjw45PIZ6MkqP5obt
9CMLKfBLSA0Vz4yinsL1VHwMHf4ZNWs09VRoD84Nsi+xp74EhZUProkv7agv
gam5S+zwpf2ENK6ncfMayOwadvSV2YwYGmyuD484f1qg9RqoD73/Emn+FvHP
Zg2WrVQ1Fih+jVjQcvNa6y5p6f/5TvNa+p4hmk+n+cERI53uRY+UTut7aZ5b
L+i4eZ31fSWum3XW+wlLrQ3O0lLr+5i5Lui5ec6Snjtfz31/BjefYb1eyvh/
/m8TH3ME
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzl1I01EYx/H/VMw5tU3nWurmXBFrLXOWmq/7uTnNRco0y4TCisWwQGoj
TYWsCApE8KVdbAqJkcGyKJMiw0rR1kVFL4ygy0WJSs66WFvZKnzOjQcOhw/f
B56Tcay5xhLBcVzev/v/ZUdSNz5x76QSq/Lr6g2mi4YEZg5XDuxImrifQY7B
pZBz6kk1sxB8qXnJ/11BFuORKrJwqJ9ZiqaWT7URWcxpaHbONtkc6WQFgnn7
AwseOVmJDnnPZFs882Z8ro8b8Ohl5C3g9f+YlFnTyCqkHfeVvJ9IJavRqhbb
xs3MGjz4ubIsG04hZ+JVin++X8ichSNfG+38vo1kLVZOtLVa3kjJ2Rhxf/gY
WNxA3omCBV/nXQfzLgzKr026Sphz8O3w84dHZyXkXDxNd0kH+cx5+HX6+vl9
1mTyblTZhO2OGTE5H86qCyFfLHMBar1Xu97JksiFiK7jjfmnE8lFEGq0qa/D
InIxEueeTblrmEtwbuuLoKVaSNatMXDIOTqUrCF3AqlS31xPL+ul2C5SLTvf
sl4Kd5HSqppeT10P0aJY4pckUNfjxsvhswI7mTMgzJnDjXaa7zSg6na30TIe
T70MEQp1SOCOo16GTSaHt+FWLHUjXF5B8GaOgLoRnpniFvvjGOrl0IxFRed2
r6NejqCmt2PkFJ96BXp8tnZ9gPUKLOWH/ugzo6nvgblLuy3qchT1NeYq6X+/
dau9EoLI0bb5Ph51Ew42ZN85owxTX2NuL+37ovsLDBzXJg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0W1IU1Ecx/Grm6hNcqYunXM+MMuWjdRsTa39nNrUaetJRTKIqF60FwXr
AXygi+TCMMgcFBQivliY5tgitlqUBhUoVE7SiChCIggso6lNUir2P8TugcPl
w/fccw6crKOn9h+P5DgOf+e/Lxuy+vs+lyUbIc3rpaaGXGMiMwdpW708wZtF
jkHUaXOD4hCzFOaqBd94BHMSotfGiV86MskpOKM2rlw2MitQqbV0HvySQc5E
08aO5c9xzNnQtN368OqEkqzCixnlnM+VTt4AxTHVs0BAQc6FdPiboiCPWQ3/
SH+j504aOQ+NJ3McqjRmDaZeB/tKrsvJW7HlUt3g4EQqOR+p8fbifh1zAcYm
BkqP2FLIhbDaR9pjR9eTt+F599Pz557IyEVY8HQ+WHyXTN4Ot9OmTHmfRNai
OUbO39Ax78CB6a5uf3oiWYfQe6wjF+Nxc86YUsJcAqvL2bW3JYFcirOb7L3X
3FLyTvxcfdjUEc28C860YY/fFE/WY9L7JvD2l4QM3JyWBB1FZB6Yvze50p4c
S70s3LzAnAFXL4q8Hw+voW5A4ZW5pbJR1svDzZejZ9baaliKpl4BW4+luDWD
zFegvW/qkeyTiHolbvtmZOOKKOqV4eu53ajVXvDMamg9LzBnxL7u/M3iTjF1
IySiuy1feyOoVwn2r6L7BvWhXg3rUInePcBRr0ZkpnpZMvSbeg2+65ZXDZrF
kPkawf8mQTfR+T+o19I9aPACc3WCLjC3R9AF5syC/t9/ANix6e0=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0nlIFGEcxvE1CTWPvHbzLF0PTEXzKC2PfXS9dT2KjdYovDajJG8rERqF
yiizFCE0Ec2DygOV1bIwFQNNEhURirBQMUUjy9RiWa3w/f2zA8Pw4TvvO8z7
vrYpmSfle3g8Xti/+/+TLoFU8arzshC7WhNJ3TWLy3TJPKSmWrgrmmyZtSE+
vdgQEUE2xOvyocGZFRtmU8y1CpVpNWQz2LXMOnVIyVZ4MzUxmahNtsHNHd2J
fMkhZiHyH7frV5QeZLaH3dqX/ulP1syO0FQtRhc4kp0wydsRq4qsmJ1RVVh8
/9tesisitXh1W7BkdkNXYVNtQKUF8xHs2/G6tDprzuyBDeOttGFHsifkDh4a
gWNmzF74+Uh3+973A8zeUOXYSvJ9yUch7NKufisRMB/DXP201NCC7INMDeWt
Z358Zl8oRBd+F2WYMh/H+dKw5YBhE+YT6M7KXU+8RvZDb1azzI1P9kd94wi/
fMaYOQDD8QM1XB85ELv7SxZhWr6p4/TSiBlIyj6nfLfEzAH+njG3DZKoB2F0
xv6XUo96EHKf+4m6GgxZD4aeydDVrOX9rAdDVt1Wz3elLkZ8hvPYhjkzJ1Yb
H6I2PgSNo08KdPMMWA9Fh2Vr71Q09VAYrZoK1gTUw9Cz9sDd4j0zF6Y2fzj0
M4xXSrPp++FY3+6TlWhRj0CzXdRH7yHqEbA0m196WEE9EovuQq8rh+n/I1Gy
kFK20ErrE4W8iy39cQK2vlwUyrp1XPo/03pHw8VaYJ6eTD1abX9isGoik2/e
oR6Du2VNDm2atL8SpIwI+7w4Zk6CGJ8bvfNu1GNR5aCS8eqox+JPcq6qWEE9
DoXXXb7OOLDzxcXhFM93vNOIzls8xnoUT3Oy2PtQM6fmgXiMJ5/5sf6B5k9A
7Qv/s5XtbD4kQGmQLhoM5eMvQ0kYxQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1yl1Ik3EUx/HHtrIcmaV7dE63KSHN2XAtzan5/HymJkivIImZgWQF9gYj
q4UhSq+oMLeucgkFJWqUmxbDavMiFAeJJbWaGUUXzRsldOAoydj5HzgcPnxP
RsOFI43rOI7bubb/Lxu+emR0qCkTUS0K3j+r/t9yZg5t5ySh874M8kb4QuaJ
ExeZE2DfPGEoSWROgiLkjGkb1pBTIIZnf8zVMKfhXrBgMixl1sD6c2ZWeVJN
zkTPmd7bugEVeTsiwfj5qkg6OQsOq+2OqGXegR49ZqZr0sjZuPzGaJ7yKsk5
cJ3ms/rjmPWIPeWZ/NycSs7FVFe4U3QqyAZoQu6RwLcU8i40D6m6q78mk414
O/Yo4Gtg3o3g+PCXTxaenIe71+uTB5fk5HwUL4/NddQz70Hu8fYnr/uSyAVQ
eSwvbvkTySbUtRtrA7+2kQtxbJ83LvKcuQijqQ6nZyGBXAzh6FLdAeVW8l5c
0jrs3S7WS3DobLZ/WcEs4Kp2fKXxIDPwTDn48n3VlqhbgfsfZSuP82TUS1Gr
s1W+u0JuLcWie/pvi3wTdRE5bumG/K5Y6iJu2poKr6nJnBmHOww66Q0pdTPU
lftNfP966mVoefDhFf9dQr0MMslT67w9hno5LANFgushR70cC6bIqqgPC9Fe
QX8c9w8wEbMy
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0QtIU1Ecx/GrVljztdxsvucSURMrl5vv/aZuTjdFNDGNggJFktSsWA3E
ZUFRGIY9MIygKCUrNDfUxF5iTyyk0iAqyLCS0pliMpyr2P8E7sLl8uF7z/lf
zg3bXV1Q5spxXNrf+9+TXX5F5v6uSgkcsih2fWt4YRIyc7gwbw5+1RdGdsf5
SwKzvZDZB4EfLtrLp8VkAXaWGI6GNjKL0GPfPmWNZg7C8GF+3dfWULIYNZ01
b5qGQ8gSCN5/5reImMMxaBgtfl4VTI5AtXCFaHQgiByJkd63c+8WAsnR4CWW
f/whZ45BW9GYKX5vADkWFaMhnd3X/Mmb4CI4MbtkE5E3Q9t2chvPizkO+XOm
Z72Z68hSXLe1h0a0+pG3YKanoHB9GnM8xOPCc1dLhGQZNJNj97xOCchyhOtd
mmXTvuQEdP0KuGyoYE7Elz1RSbbjzEloud+mL4pZS07GxEaJtCqKT06Bh+8j
fc13b3IqDvbnpyQseJHT4Fkbl/y6wZOsQN7N06oyMzPgKo628jo8HDYCA0+S
piLHyZwS7crBocf+9L5R6dTTndanY96z78hiPOsZGA6wTJ71WUM9A03H3Ho/
7SBzmbB0j9jqhKupZ0La+PO38gGZU6F0wxnNy0M86iqn/dX0/1lXY2jWu7B0
H+tZyNi6KFuppvMwZjl9v8ZpvgZPh1L1B+66U8+God76sPLGKurZ0Mnre8Zj
3ajnoLg07natxK5w9Bw6j0WHOe1yG7WYTrQupcdOUNeB53bLMNk8Q13ntD4X
+zuSFXeucDQ/d/k8Lo/2m6f1ef/3/wOeHQMm
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0GtIk1Ecx/EnN7o4Sps2nZecU6xs6HTm3fbb3M1NTSvTpCCiEWEXs4IR
GU9BL4SShtGLkF5UkDRtuVhDZhcMC1oWZRgUZEI4ii4r7DZNK/Y/RM+Bw8OH
73nO4Zz07fvW26M4jiv/M/9+2ZA1eP39LUpEFNJ61NfO9C9h5qDPvzld6U4n
L8QTqV3S18Aci9zcodtJ0wpyPFS7WjlLN3MiNoQGNL8KmFMwLnrpCL1IIyug
WTE0Nq5kVkLdZdiU3L6cnIlh097TzlAqOQtxXwLBulTmlWh5pFrU5kwhZ6Nx
56UbrkAyWQVnsHXHsYkkcg58P9RNn7XMatxaJ33lvyIn5yGv/KIiXMOcj7dN
I46PjkSyBiXmZ/C4E8gFeOjbGJ0pZ14DyejU/tmjMnIh+EPaqdIs5iKcU3hj
JoPLyMUwdL+WDnQwl+Cy/7nsQQpzKY7fb9waro4nl0EqSRicHIwjl8NY8ebI
47CUXIH3cZvt3zqY10Ii6jv8rmspWYtVtRnxxj3MQKprZmxLEZkH6nZnB77K
Y6nr0Nicf7VNGUNdhzmufm7bQTKnhzu51/fUxroePbq7w/fki6lXora302j3
kvlKQTcgbXYkUByKpm5AhvXsWHMPmTNCdV08v7BzAXUj2s+PDsomRNRNqD+Z
t1p8QkzdRPedR92MA64yrecCR90s6BbB/xbB/lX/r+er6D3mtJFuRZQiOyxx
zUTMW6E59eG77s5P6jZBt+FTSXhWnzNJvZrOocELzNUI+j//Bjt830I=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQNioVt3b8xWcoDwPtirsOw8rSII4zM4VNfYPVh6
UBHK53DgPVbh45QD4ws4SPy/0bdPGMYXcVC7sjT4xhoFKF/CoXOd7NHgWBhf
xuHSwYKXXO/loXwFh/21nM+F+GF8JQe7P2w1c+PloHwVhybV6Lg7s2ShfDWH
qxu+xWc+koHyNRwOreZTP+wD42s5xMc7xE5bLA3l6zg89Kz79va/FJSv59Aj
aqBSoAfjGzjEPU8o4ZwsCeUbOvRXOi7TOCkB5Rs5bGJY1NAtAOMbOxhPlt1Y
N1Mcyjdx0Nm6OPTPbjEo39ShodT+i5UajG/mYPP14L2eOFEo39xhnexlJa3n
IlC+hUPT8fDYXz4wvqWDRPyeS31uML6VwxvhyNRvnUJQvrXDvhjVg3LcML6N
g0tDxV/DdkEo39ahUvP4z1R/ASjfzoFH+FB5wUt+KN/eodso9c7sBJi8g4Ov
27GjT2yh/AYHhxynCXv5FvJB5R0dSncH2Fj8gPIbHB3Co4zWFSnBzHNyWOF4
+OgxSV6ovJNDlPZEj3MV3FB5Z4eJj4urnb6zQ+WdHarqfx3MXsUGlXdx0NnM
wmbWB5N3cZD38LUUW8UKlXd1COwx1GZpZYHKuzpA0isTVN7NgUlB6xf36j/2
EHk3B27mtVWvJn+E8BncoeoYGAACQq7V
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzl9IU3EUwPHLutTWnC3n5nKmu2MTsbHczLmldo9T57ZKWBJaJshKon9I
tgr7Q4MIexBlyz/9fUoK+zMYI2PoQ9SDDVugWRAhBLKQQXSjNdHSVez8HroH
DocP35fDeLr2dQooiqr8u/8uGcX+ZxOhExrIiGPLWnsVcQkxBTW+wh53mEEL
odq0pze7g1gKn9or4qMy4lxgXr87JXquRith0u9ZSjYRF8BIc872ofdFaDXo
jt8zH5MRa+BA82L7mKMQrYWfb6KhnuGt6GIQRieL5wTEJfCEe9HvaStAl8L4
FJdiR1RoPSQGIvaqqXy0AY68Gjf2SYjLYHrWmo4c3oI2wlW5+sqt60q0CXSi
t62GeB66HFa7mb1nLcQ74KZ1YvjrSwW6ArSnZz4uy4nNwNDzn3/8zkVXwtEh
gVdSTmyB8/I71MADGdoKRvvtiCuWg94Js2yAzpvfjK6Cuc6UqCRCXA1sS/JQ
k4q4BqIftMlfWcS7QKVcWPQHpGgW0pQ73eHdhAZwjgUf6e6ifTxTtTAavX9O
7M3GXgsCdemK+HEWdhsUrcWmLdxG7DYIBbsGDW1C7HUQy+cSg1LS62BZH7j0
8KQIez1w4ZnVy3K0r57XG0Afpteb+zdgbwD/wpmLtiU0Zed1O7j7jNvoazT2
xv/ta4SWg6ZgtybNZroDvllX1myGVMY+B4jXPb2QuPEduxP7F+xOXnfxuovX
d+MfFPUHUm/WRQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQNioVt3b8xWcoDwPtif1n44RY8bxmdw6AjTF969
SRHK53Dg+a4/63AojC/gMPt+9cUL/xWgfBGHKOYTiQqrYXwJBz3pzXwNwTC+
jEOeUqdMHCeMr+Bg6ch170aEPJSv5FC4cKtK6CY5KF/F4WCZhEyTBoyv5rB2
52F9syxZKF/D4fWNxRGOk2SgfC2H8n3Gzuf3S0P5Og6isrFawUwwvp7DDyO2
464uUlC+gYPXB7GNLamSUL6hA7vWth6xLRJQvpEDX4VW2L3J4lC+scO72IPb
E4+JQfkmDlc1chKXbReF8k0drLOKZiRsEYHyzRwC9BcolUjA+OYOSSeUdhk3
CEP5Fg7R7vu5fm0QgvItHTT9lEVccwWhfCuHZcpet0wOCUD51g6Kjumdpf9g
fBsHXUGNj7Muwvi2DievqXz5zQPTb+eQ4zRhL99CPijf3uEab0fGTz9eKN/B
QWczC5tZHzuE3+DgAEkPTFB5R4flu6+LnZJhhco7Ory3/PXPSY8NKu+EJu/k
ENhjqM3SygKVd0Y1r8HZgZt5bdWryR/tIfIuDsa9b787HvgJ4Te4OBSvtrbf
tIgBqt8VTb+rg495/fbHesxQeTeoeYxQeTeH8CijdUVK/6Hmu6Ppd0eT90Cz
3wPuPgC4A7xD
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtIU3EUB/CrTts0dabT+ZxaabTLaprv2c7ma7qHc8Mse0kiFEWmaUYl
XMJQYlo+6I8kpJKSSEkk0FTYKCuRrAmZkSUlaRSlSfkI2ip2fsHuhcvlw/ec
8zuXCzfqULmhzJWiKN3f+9+TXIGF9wd7j0aDQ4tyQVnsRRdPYgoaPs2N3OqM
QnOBHjwytE9BzAfTAXuudCkSHQAhN7rHLnUQC4H7TWUryiAOg0hrfviuURE6
Ehb6H6mrRcTRYCu9ZmtnItCbwHchSfZqNhwdA/Prhy3uEcRbYH5ooKO0MAy9
FUwR3mbrcCiahpolhcaYRiyBpLRCi7gjBL0deBVa/kdLMFoKLqnigec84jjw
P6G2HK8VouOhzj5t8OAR7wCjlEu9NgahEyA15t7U3cZAdCJkbvahZ/yIk8AU
9KJluUKAToZ3u5vqTSsB6BQQPxH+7HxPnArCg0MTTdnEaaCUlLRVlvijZfCh
PTHhTesGdDpMyFs4QW/90DuBT0tDx+3EcpDFaep9SogBvkzH1m07z3eYAdhz
tfu6gEZTCugcvXnKq8oHcwVMejccXtN5Y66ELsXDkcfBaEYJ1YN6WfIq1lMZ
UFQc11MZ7Yt5hnM9lQnF4mbV+GkvzDNBZHs2lrzoiXkWbMy7MlnchWayoHn2
5FnlyjrMs6G3p7xNspeLeTbEN35dUZh5mOfA5Tq3/pn9pD8HrP0vf0yt4nmU
ipWrWP25zvswuc77UHmw2Gf9XSvAeiaPtZ8ano6k11Q9IPupYY1uOXf7GJmv
Yc3XsOZrWf1aVr+O9f46532ofKD7OB6JTbgPkw8ilTYl8I475nooMEnFnAsc
h0EPjv+BK9azbNbj97TLHf0FsJDyy6aULDsMLDMsmwvwXHIZwMut+8zn1u/Y
zzJjcK43s0wZcf4c9hv/538AVpUw9A==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQNioVt3b8xWcoDwPthH+ttHJQvC+AwORstZ/8Zs
UoTyORzWfsiIux8I4ws4hPZmTmD+qADlizh4+uzvXDURxpdwyCq/HcxkAOPL
ONyYWSOhM18eyldwiNex/Nv+UQ7KV3L4NO3+wTeRML6KgwuzB8O3ybJQvprD
g2KjEqnjMlC+hkNw0EYxn4/SUL6WQ+yEJXXRKTC+jsOyl99a/G9LQfl6DnVP
VnqKqcD4Bg4rS2/Zz+6XhPINHWqOrbvH9UkCyjdyYGX6v0e1BcY3dti9SG5O
jRSMb+JQuTHwh0aVOJRv6hDDECwWMFEMyjdzUL8XuLCUFcY3d/jNl25/0FUU
yrdwaGE5eYpjugiUb+lwLjHi4+ebwlC+lUN371LVtcwwvrXDkYADsxt2CUH5
Ng4x7ItmSbsKQvm2Dt1GqXdmJwhA+XYOS04uLuMu4YPy7R1WOB4+ekySF8p3
cJj4uLja6Ts7hN/g4FBV/+tg9io2qLyjg7yHr6XYKlaovKND28Rsq2p5qHoG
J4flu6+LnZKByTs5vLf89c9JD6bfGU2/swM389qqV5MZofIuDsa9b787Hvhp
D5FH4zO4OoRHGa0rUvoPlXdFk3dzYFLQ+sW9+g9UHo3P4I5mPhqfwQPq3m9Q
eQ+o+z7aAwAE4smk
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tMzWEcx/FHkXSV6pc46jho6EJO0lWf6lSn+6lzMG1tbv2hIpJSbr/c
2kwlRozaqFWrZMJYp3FqNfKHP9gYfwjRxkq5JWm57Hyf2e/3287OXns/3+d5
fts5C7fkpWdZMMYMfz//vvkjrLttvJGjglmjEfeW1S1hjtwMThvXK22MC8nW
uKPUDT3YzD0bp5TBr6rtuV2w7nhWWV6bkjwXuZ2uaUjlViDFzbLy9RdPshJj
I2/rAwK4VTjXdlQoqPIgL8bWl+96SrsWkL3wdVN9TaAd91JMGzg0mKNVkJej
ISD92a/K+WQfVPvWP+mYmkf2Q79KM9CRyr0S1709gjSj7mR/fKnxi71rz70K
Rwbu55emziWrsd1h3LCj0Y0cAL2/NXuh514N4/t2RX+DQA5EdcOVJpUH9xrk
lRe7O591JQfhYkVtdnchdzBCs/MvbLrlQg6ByTtquDWfOxRlJT37xi9zh+HT
jp7v6jFncjiKXC+xygbutegr1oRt8+KOQI/OdEnsmEMGxk62uWV+czJbBAZX
qNQ7l5FZJPa0hEa0X51NPRJ2zt1Fuz44Uo+C05CLMCo4UI9CfV9doW0BmUXD
N9zPcH/Qnno09hp1YUHjvGuk60WNrMcgw7tK+3ifLfUY9H511GfstqMei5TW
ipis23z/WEQbJgNnxPL5OOl9xTjpeqbF6WOWd/szbahrsSjh/LOMJjKLx0+f
Mwcac2dRj4enNjlYaJ5BPQHm/48FdZlZIhqNz4VHClovJqLk8ERXTrMV9STp
fmISDtY+7RTeWFJPhs/N6VaBFTOpJ+NEVU7Ifk8yS8HD3vCigg5r6imy/VOl
60WZmU56X+hk5+mk9zHpsCFjVVu+6neEeT4NFsrlE7Ytk2YjjX4vjOZlNqXJ
5tOhLh/+EWn6SfMyi+kYCZ6YivIbM9vEPUjzenoPeqCHreW1ko9nP9O8XjYv
MzPIzjdIu2iQnmf67z9G2VUV
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQA2IQDQNioVt3b8xWcoDwPtjvuFF8YqoojM/goPDofK/y
PkUon8Ohd49VHVssjC/g0KWgOqnlrwKUL+KQ1DDBbuMCGF/CYRbrm4mpLjC+
jMPbjN0Xrr+Sh/IVHOLnNQcURsD4Sg4JPG8uHZ0pB+WrOGgar5khsV8Wyldz
eGmkeFzslwyUr+Fw9DN/cFQhjK/l0MISuPDCPmkoX8fB17pv89YfUlC+nsM+
m9vml7NhfAOH6UfOLg3ZLQnlGzo05bztXn5dAso3cog/2CDJJQzjGzv4nQs4
sjxDHMo3cZhzXtWTrUsMyjd1SM9+5nyAF8Y3c8hM+Vqhry4K5Zs7bLVP+1GT
IwLlWzj8TCz+27hVGMq3dNj4SWp+VQaMb+Ww1Mr4xPK5QlC+tcPk1A+TY5bD
+DYOl+wnsYjfFYTybR3+MwT+Tyjhh/LtHK7xdmT89OOF8u0dJj4urnb6zg7l
OzjIe/haiq1ihfAbHBx8zOu3P9Zjhso7OoRHGa0rUvpvD5F3dGBS0PrFvfoP
hM/gBFUHBQ0IPgBIRI6Y
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzltI02EcxvE/bcupZdN0mm5NJcNSl9M8bM3t2aE5ddH5IgszoQszMCJt
aMmigxcZuilWQyIkMg0FO4CmQZIdXFiUF4uyIqzRQW27GGkHO+DvvXAvvLx8
+L6nhLLKbfsXcRyn+jf/r2yId94e6K1IxLy8WnPS9fxdImYOD++nVUf1J5CF
qCp3Cz1lzCJkj7xwHeKYIzFV4ws5cC2eHAP/iQsVfVuYJXjHe231vpKR45Hu
TivN0TAnwtf/UT7lWEleBcFZR6v+mZS8GtLon2OeOOZkBI/famxvkpDXYnNt
p0AzHkdOhWCp1K22McvBd/aVNLtjyemY3Hf18nAWswLj26vFby6uIGdg3R/F
za885kzY23lN05oY8noI6xrjXHujyVlwdg4Z/N1icjbs0vJJ50QUOQdq/9Db
hhLmXHQMuMUuCbMS9TXD1pm2SLIKp/gjLuF55g2ICI0e9AwuJ6vxufWwrlvL
nIc9JzOLX36KIGswcyWo7oOOWQujzfpbUR9OBtQZlvqwUrINSAtP9jmfi6jr
ULWmpdlxg2zToaCzpyupbRl1PQw7fmULTGHU9ShOsZufWkOpG3D3kWo6eWIJ
9QBzRsjmRp/kekOoGzGb6jjWcTCY+kY8fpB39MgdIfUAcybIzJuU4i4BdRPO
2CtUtbIg6vn4pvwxp5cvpp6P3p7KFvludt4ccL954X6uYOF/bAUYjfV+aRHR
f7nCgPcLsbVBkcI/zadehOOXxgbF73nUi5B5buq77t6sdr5b6D3PvG0WOsdx
fwE3bOWo
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd01tIk2Ecx/E3fTNtWWpuHuZps0JyLg9l2lrvz6VTNzfIKeKomygKvFjp
RWJYiw4EpalFhInYgrLVjBJPmaSBUYmChrYLw2ThhVBNUDxEWrH/E7gHHh4+
fHkON4/suKXwpA/Hceq/89/KhqS4o/dFmRweuQWXSngr3cLMoX/xxPi0XUb2
R0KqolmjZw6CyL8veGoujhyKhPjkmg9NzOF4Px64MKdljsLOoibZiCuWHIeG
kEnepmCW4+tC5b2pghjyDmAWE8W2aPIumEyiIpszipyAy9W8zCeYeTdql9Za
Yy5IyQokVUY4ql5FkpWQDposvI45GU53y8O+ighyCpyn7ljaHOHkVLgmC89e
8mNOQ1PXjxvRAWHkvegZKu0sKZWQ98Gy4dc1u0pMTodmwBSTGBtK3o+hzo4n
5We2kzNwTnyfu/WIORMp2sYe3XAI+QDGhAY+7EswWQWhZP6oUcp8EM+lz7rG
9NvIai8fgkH7bvCbOogsoLTR8UCsYAY63XV7Ioe3emwFktTKojczgdSzMBF4
/fSykWzNwmj3+LxzSURdg9jV4aEM92bqGrjbR39XiwOoH0bdFd/uqWOse5nL
hjmxPm+kks6zZiNed3fC3Mp6zvr7rDmod1Wc1yxuoq5db6sWinbeL72W9Vz8
zFxZ1Sj9qOei6uLKQJmdzOWhuvnTa8m0L/U8HLmZkshf5ann43HvZ8nHqI3U
87326+D5Pz7Udah4qhJe2jjqepSYU9vK5WuCp+uRVvN9Mat/2WOuACJfR9Xs
7TnqBfTeGeoGr27w6sb//Q8dmPqN
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIk1Ecx/EHc+Zt5UqfvOuWmSyb5cq8tt82b9uaSRiBhV3FaJHD8EWE
sN5UBlmCGdGyywtZGgvTUpmYGXYDQZ2OKAik0hTFgWJqahf2P8R24HD48D2c
8+JwxCfKD5R6cRyX/Xf+W9ngDz63tRgkcMmpeHvm1RWjPzOHrd0fJmceiMm+
+LFNaCrLYg6Cathwo/pTLDkYtqSuL95G5lAc6S8Z8eGZI+Fz7VbVhbMx5Fgc
C5wa6rsTTZbg/mc5L5qIIscBJb3qaS1zPL753YuX10SSExBS0dpg74ggS1E7
bjx1aTScnIhhh36gQscsw9Tdryc728LIOyBqs4XVSpl3YmB2oWfgaCg5GcI5
84TOvIksx4zinGZUwLwLjSuWmHgzT96N240PLZJo5hR8F9TPt98OIe+BNcou
kY4Hk1NR1WDv4kc3ktNgdMz2HhdvIKdjuHTeL6FTRM6AWFlWXbkaRM7Ee0fc
3K9A1rNQaSvMTF1YR96LpxFP2od068kKqIuWUwS5rAMW5eu+N2FCl02AaCqY
d/KsK+EQXj29WMC6EprH1qYtZnaeyv08k8p9P6fGC+fNpPB+1tXYniUrejnG
ejYGO0bmPi4EUM/GZm29o9jiTz0H/eHOybogsikHhncd3fZO2s/lwtk6uFIV
4kc9F5drDekXY9ZSz0OLtbxOdtiXeh4SW719UmpYz/fo+YjJ16fxTQLqGneb
NPRea6hrPboWrv/kRV3nbpOHuX0435yhePaIo+5hTo9DxcnWCslvhavrIb8+
/VPZs+gyV+DRC+AVK10KaF6mvh8zaUurKtk8deYx6oV0Dw142OThnv/+A4Vg
B5Y=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tIU1EcwPGrZi3NmK/pdDq3bA0VSa35dr/NqVPn3MNpjnwQ+ZdF2dNH
4oVAK1JbLwqsP4JQWgUqy8iMldjDShIh//APSyFkUKmUmTWt8HeCewZjfPje
e+45555J9h0y1XgyDFP+9/vvl3wEFsdgb60U1jWvXDjjrpCHEDMQUOdzutIh
QfOgeVXosVZKzAdf3pD/9EIUOgiuJLcO8M8Sh4K+WtJVnkUsgpHvD8aezIjR
USDoVXRdDCaWwg1lw7kPSZHoaDi4Y3QooikCLYOZ2RSJtE+ElkNsyPgb76Vw
dAx0+rmuR5USx8HUxGH5geEwdDy4Zt8tiyOJd0L+1uyHJpsQnQC1txvDTsQR
J8I1XbSJ1x6KToKqp6zQJ5B4F8hOTY4P54Wgd8Pg+QvdTb0CtAIUi1Z54XQw
Ohns/l9CZf3EKRDbmTumfh2ETgXR1B7g24jToGrSUTlRT5wO1sUpxXZ3IDoD
XjVoMvbLiDNh6EXb9HJLADoLqusqfo3O+aOVoGHr3QltxAABc85ndhOaBaqr
QFn2ba8+nHQVHB80ZKQsb8WuBv3djpwahx92NXhGxaz42rdgz4Ye1fDIcyHp
2bCt4Op7a48Pdg1YY23asXpf7Bqq58DbsHnXZT6azYH5/nF3c/Bm7LnQaqtN
axJvwk6ZyYPuwUnBqMgbex74et1rdF3ywK6FMmvi/SPSNeV612JfWDeTD0nt
n3+onD+x5+P6fmMvoO4vgK+pK6vq+CXshdzx2ELsn7DrqPF11P1FVC+i5q8H
XXLLwGy8F65PD803Jx4LPqKZYqoXw/r/3RO7gTseGKjrDdzrndT1jBGO2tOV
fbcYvN/I3R/WyJ2/00jtr4lrMHHXz5q4++s0UfM3g1hblCq4g+8XzPByJPPk
sUc8nL8Zn4/nxWmGuP4NGxUd5HyUcMeDEmr+VHeWUPtr4e4XWLj7wVqo9Vuo
91v6/zz8AeJ2cjk=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQDQNioVt3b8xWcoDwPtiXdSclPBCE8RkcKlYvj3qz
VxHK53D49v+c1M5MGF/AYXm6sfkNYRhfxMHrWY2I0DEFKF/CgaNfxn93MYwv
47D9+8H/yyRgfAWHsC9G9770y0P5Sg78cgFL7QRhfBWHN+q6/JE+clC+moPE
gr9HE1tloXwNhwMfjxRES8D4Wg6fZoW5P/WWgfJ1HMwyj9yavUQaytdzeJkj
ZpH/TArKN3CIzxOy+q4D4xs6LLBs5XrcKwnlGzlUNAhOL78oAeUbO6z1uPWs
iBHGN3HIXZLE3pYnDuWbOiTte/Dp3xYxKN/MoaHU/ouVGoxv7nD/9fLS8Dmi
UL6Fg1+xQPW0oyJQvqXDucSIj59vCkP5Vg7emz96BZrD+NYOhruk1R+VCkH5
Ng7futaJx34RhPJtHVLnLmOqXgDj2znoCmp8nHVRAMq3d1gvvWb7JW9+KN/B
YYXj4aPHJHkh/AYHB11bvZD9z6B8BkeHizuufrnxgxsq7+jwYfPFv7WinFB5
J4faeZf3iD1khso7OTApaP3iXv3HHiLv7PDe8tc/J71n9gCneZ2a
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIk1Ecx/GnaanZxZnOu9NNY+Ql56XcTP1t825qKaMrQUJYGBUSBZqy
DFeGBuYwEjEjK9QMMsJlE3xj7Y2QiSAiA1N8IZlbiTdKK/Y/hOfA4fDh+z88
580TXnq1+IJIEATd3/3vZEuif/fhTbkMTtnTlxT6/hIxs4CqmYh6szmc7I6y
Tr1o8iyzF4oGYgZ1bsw+6JnZWW/sCiP7Y09HxRVVHnMwNpI7P8ttUnIYrFmb
rgNyZhniULjYdCOUHIHayDPnplpDyPvRd7FicHMkmKxA17dTlWk/gsgHYDEd
vH8nkTkajrGUoa+PA8mxGAm0z5u8mOOg1L6IfN4RQFbii3UivkfBHA9p7nBo
c7s/OQHPRE9aItXMiXgqawu+1udHTsKC0aO77h7zIfxc/zg8NSkhH4ajv7hE
nsacjJI2U1Cl0pesgu3kg7sNKz5kNbx7xy/Za5hT4O3pZ5mz7CMfwaPphm02
hzc5FVEhkoCy88xpWO10q5nVMKejdra0cfaVmAzEiBWO1lEvpw3AidPxrytk
e6lrMPhJ/V0xs4u6Bsu739/+lUQWtBg1jy9NrHpS12It+uGtl5c9qOtgHU69
eX3AnboOxqZydZXUjXoGpDkFKkn3duoZqG4fs0imXahnbrUhk7ufxd3P4no2
17Nhfzv6u9qXvS+H6zlYVK1vaGN3UM+F8/8QUc/F8QZllGudK/U8ml9Od3bm
OaeFfJqjZcjn+lGucxYKuM5ZKOQ6Z6EIni69lfPNDnpfERIaF1Y0Q2v0/WNb
58HZ8N9/ABP57gU=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GlIFHEYBvDRrdTW0vI2TTNLXWWtzFKzfDzy1nZddbODojCCNQzMjtVw
EssPdohKQWV0gFuKgkZ2aLQqJmhKEmkfoiWMtRTL8EhFJWPffzAzsAw/nnne
9z/7YTYcy03LNuc47ujS79+dXY4Zz1oaNV4waTzCr0DzxMWBmYOl22TeofYN
ZEsYtTp9Rw6zLd4MfNKOLWe2x0b34U6fJ55kZ0zISs7YRzK7IcpwosKm24Ps
ic/Nxk1+zsxeqG6QNEvL1pO9cfn9lVrDtDt5M3o18nlJBrMvwqunClX33Mgy
GDsD+my/riMHYEqdyKlHXcly+Pd9t0pNZd6C86duhOSrXMhbUZwzVqYbdCZv
w5E23mWlHXMQLjQqZ3y1TuTtuH62qDj8iyM5GO+GHi1AxrwDhlFdvvquA3kn
Gtw/eMmG7ckh8D5nVrnjlx05FGulTq3GVuYwaPZbKI/fYt6F9S/zmkt7mMPx
uqvUMFO0lrwb2dU15gX315D3YPSzT0lgsS05AnXhXid9O2zIgCJH1jPlQjkP
ZN2uf+AQwJ6PhLVd+7nTP+h5PhIpsW87v+1meZQoj8IFv67Z7H0sj8bE4qus
Ygs2P1o0Pwb5flWVFU0sjxGeh9uL5vHyQNfe1ZTvXXrfsJ++Q9aUx2J61ctL
88FkPhblJZIXhsMrKY/DxsSbAwcek/k4zAZUFOpyrCiPF5qPR9C1sT+RepYn
YPxp/8JFB5YnoNd1fKTKls1PFJpPxJ0B6WxNsJTyJPS/+Dj5aYbMJwnPwyWL
+smi/SlobMitkh+0pDwFupZBx2635ZSnQls016apXUF5KjziU0Ida1m+T2he
ZE4hNBT4FTq3GCVn8xRQXt3qv+zyMpP1Cpi+F+bUVyKvbldE00OO+kok7yx6
PiSXUF8JqaReO1JpRn0lzD1lc9K6+QhTP432GU2GyHwa9X+brGf5NPVVwnlQ
CXNeJeqr6P+dpX660EgX7U+n96RLL8q5DNH5M4T7eJH1InOZQiNTeB5eZH2m
aL9aeD6IzIusV//v/wUFmY70
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02lIVGEUh/Hrlta4J+O+a7ikuNu4NH9ndNRxHbWMtITEoDTMtVLEKSkJ
EtKEQs0sQ0zJstAQTbRckCgyU0qIcglLCLVAU0ZbmPN+mLlwufx4OOd8uo4n
8lNyNDmOi//3/v+yh3+op7871wlKrQqPiKWXxIbMHJwfe61U9TiS9ZB19mPm
RDqzMaaK2zW6FA5kM2yd08pOusNsAfeT81Y/xcw28Gmv2t6ZtCc7IK0yKzvx
jx3ZCccXR9dHPJldENZ6anytxJa8D78Xe1Ibp23IbjDJ29XX5MbsAcslyaSs
wJq8H8eW8+ZXTJm9cXprIWcn1Yrsg5EP0gbxV0uyLxqi/Uot0pn9MCBYQWGt
Bdkft4abtaoPMwdgOmNO8H3HnBwIfohDoX4FcxCa9W/2mr3nk4PRXNI+6+PE
fACKVm3HpbdmZAFEw6l2nvbMIbDrK+qtfrWXHAp3F93FjWjmMNQ83e05+NmU
HI7BTNdhOx7zQbgnOptFnTEhC1HU/ehqchkzYNupmMkMJsuBNmfpbMALY+oR
qpZHIFJ+ftu3ms2LkHO7TbO8hc2L8E5Yp23+iXWx6n25GAmSsdHFcLY/EtYW
C99q69j+SMQ+6OpwbTKiHqXWoyB4098y9oXNS+Bl4rbWMMm6BBfcxzdzkliP
Rp7o+nPDu4bUo9Ee8XJ0zNKAegxGfxmlHi3Qpx6DdYO+i4pAMhcLcZoiSEfC
5mNxf6K1lFdM5qRonOFttgXyqEvx2mp1ud54D/U4dHfl13tn6FGPw5Xa3JBy
e13q8Wo9HvYxCQJ+hw71BFXLE1DUGSp8co+jnoj44MpnC95a1BMhu+brqX1Z
m3oSlP+3JvUkaDp4bPE6FUJlTwZP62HZ8g0NZUcyKpqnBvhzbJ+ah5JV73Ey
+Nf82IgY2lTug5rlMtq/pvSQDCuCrR2R9zrdT1E11CxPUZtPobsc9xewpy9c

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0llIVFEcBvCLFmSO5jY2OeUy2uKaOWqay3wujea4zFamSdgiBUa50vKg
1weticx0LMiIVFyibdAosyEbDLIIi4x8qMRKspCiKc1MJSv6n4eZgcvw4+O7
/3POPT67D6kLbDiO0/59/v2zn/vWW8auQgn+yyyzNb0ZcbNl5nDkmcEx74oP
eQkMH/kL29KZnXBoLLLC/NOb7AYsKn3o3MYsQklWqP9rBfNKjJ9oXV036kX2
Rv3YlkluNbME2xXyWV2pJ9kP4YKImsGJVeQ1KKz2iy8OZl6HlgcjosDYleQA
7AzVC1vaxeQg1H8s2lv1zoMcgvPfBYUiF+ZQJBrnT6ZUrCBvwMK53j3v34nI
YYjeJr+ks2eWwuS48V6/y3JyOFqrBN1tKndyBJKCXj6zrRaSIzFX3FyZsZ95
I7oNNZ6iN27kKJwuKr+yQ8McjX1nbcocpMyb0L5J+qjzogs5BjOKD0uq0plj
YfRovNj71Ykch8fDflNzAmdyPILjQrT3xx3IMisD0tovPxNMdv/NA16/B59E
mZdSnmBpPgGFj+70vei1pzwRuYH1qU+PkPlE+KadG869zPpJmHborZqPEFCe
BBvvgFn7q2Qu2XI9fDLKjcrYqBlHyjdbmt8Mg/haz5BiGeVyLHCqhfwyMi9H
knY+crGc9VMszadYvT8VOU3XW4RBdH58Ksr9G/UN3ew8t1iatzKXZnn+fBqO
+g/8KshiuQLZuWE3SiRsfQoEO6/71vSc5ekQi8Y+1TewfrrV/jJw23xmvccg
W38GlAcCnvxYwfqZlvP4TMiyp/Iyxez7Z6H0aoysu5XlWVb3Q4nop8bmh28p
h9Jqv0p0+Ka9Cu8nm5QYXy+RHvRnfRXsba8fm9CTocKGu+K178vpfvIq1N60
C+wbJZtU+OyaUzCtY/dXbdVXW81XW+7HpEZpl0GnPMbmazAka1i0fIT1NSga
nuzf5cPma3Bv4PjoTCWbr4G+wKzP62TztdAM604NrXKlvhaJIfmNJflkXoue
oo6cECHZpMVh4QWursMVfwC60U5m
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tMU2ccBvB3UAGHG9RhRUVuCgNZmMAKFnHnAUSq3FootBQNblnBhG1u
qBEhxOPmMCa6iRC/oG4xUTdUOqYGhLGcuOFlBrdCxGU3osv8INsoYdFy9ZL+
3w/nPUlz8svT533f8+9p1Nvbix0+jLH3n32e3/mlK73c21kTDa/c0qjBOVOr
5WZINxfpPR1R5AB8GrPl3c0m7mBoy/6sbpqOJIdAvnng69WnuUOxJ/76pKOI
OwzRhpybC4ciyJGYamBbYzXc0cho1d+6+k44eSW0MZ+XuQaXk2MRWpce40zh
jkP2pcrb15xh5FVob58+VTW2jPwaPijvv6PEcidiYmu/1Hd6KXk1vnf1PPZb
wJ2Er3b9KrV9toScjNmq+jrHT6HkFBzXSn6uycXkN7Cn0+yJq+fWoympK/yu
iTsVTotGM/6fjpwGP3fQcPM27jVorJAyLlkWkQ34+XzfwY+HQ8jpaDw59K3u
3ivktfAP11h+GOTOQHnlVaPdxr0O99tS9b+1LCS/ib7rB0Y8e7klJCzXLal+
ixvw5P0dsC+fLAMtDnfL5rM8zxTyTAxKRzWL/9BSngXHiTM+DV+Q5SxEZVYf
3DUXTHk24gtXhOS8x/NsjP7+6v7XP+L5ejiXne8azAuifD20/4To3LqXKc+B
T+SqqcBzCyjPgav7zv+/eAIp36C2vAEDS90PW4NfpDxXbTkXNTe6vxu6wvtG
9E8Eldg/5OsbsWLTsWH7l7y/ESmH/32cqcynfCMi5gZurXHzfJPasmCWh7bh
wMkzen6+PDx66cq+GT3tx/KF9fPhvuiabVxEZgVqywWIMBYYdO3zKC9Eftre
rr8SfSkvRKDvhfqHLS9QXkTvD8+LcLb3ru7HMN43wfv/9/EaJpgPJSVoPtHQ
94VcMaGzY3trYkUA9c1qw4wj+327R7bweQhWzOp5sGLYE5qNt+vIKBbmIVgp
xo3+dbt39vD9S9DUXJPeEOFP/RL188sl1J+UvH2ej3vNLBgzTM1lJT7yGhZ6
32a8li2w2pM7aqOfUN+injcrVe+HUvW8ZCFXStXrszK1IVgWrJSpz8us6ueD
VehbhfNbsePcWumbU4zObxP2t6nXk23q/RSb0C8X5idYLhfmL5jZhb5gWbBi
F36/CsofUL+CzsXYU2Hy2NM=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQNioVt3b8xWcoDwPtg/trY/JM0D4zM4TG7z/my5
QRHK53B4wrKs/KAfjC/gwM2xV/D+RwUoX8RBcnV4dMZEGF/C4biAge1cSxhf
xoFRIvbvmjXyUL6Cw9r4FfeyzstB+UoO/xffs9MSgfFVHAQlbv5jjpWF8tUc
Tj9dmfx3nQyUr+FQNNdokc49aShfy+H4lhMnK2VhfB2HZbKsfZfDpKB8PYeM
a3IbNi+VhPINHNxdSzKZ/0hA+YYOt5WzFh1Xg/GNHIqnrKvlPCAO5Rs7RNa+
c+35KgblmzjEMASLBUyE8U0dbL4evNcTJwrlmznI3I5wEJgoAuWbO2RHsAcm
TxeG8i0cCq59PpSoKATlWzo0PUnqfbJGEMq3ctAV1Pg466IAlG/tIC3x+MXE
STC+jYOurV7I/me8UL6tw97jVu80HvNA+XYOUdoTPc5VcEP59g7y/86etvjA
BeU7OLy3/PXPSY8Nwm9wcFi++7rYKRlWqLyjQ2CPoTZLKwtU3tHBx7x++2M9
Zqi8kwOTgtYv7tV/7CHyTlDzvkH4DM4O3Mxrq15N/giVd4bKP4PKu6DJu6DJ
u0LtgYIGND6DG5wPAP2FqPs=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtIU2EYBvCDUphzpjmneUmdkfM28zLvtledOjeduxSrQXQBbWqR1sos
xJWShjMNs6CLXU1tZWk5S4ssKRMzUGOEBFGCEN1WkTWxVrH3I3YOHA4/nu/5
vvecP07Q1p2KQgeKoqR/739PcrHX9Q32lHLAJrNgpORhXZkzMQUthyXfkm4G
oZ3gQuJ09WIlsRvEx7l2aOcC0SwwNnjIuzqJvaHE9NIwlk3sB5VOZ1qTFwLQ
gbCprUZWvp6YAxHFqu+jwyvQK0EV2p1SGkK8Crwbi3mR2/3RXLCU52qEfX7o
MDj+RHBdRRFHwO3umnqvDF80D7YYlZXhdT7o1RDRft4rTL8cHQ3ChM98NY84
Bs5W+RW1t3ijY0FV1Plz3pE4Dpqm3Bqeib3QfGhzOWlkvWCj42FQ39xxoIc4
AbaVzmYOMYkToatsfEJz1BOdBGb5VFNrPHEyiMT66d4NLHQKVLVN3WO/8UCn
Qs9Xn3P7NcRpoDQd0U/6E6+B6AHfkLd7lqEFECoNZmXtcEcDvH8VUht1yM1m
HUCkO/fLqQk0lQ6VoSOWwgKSp4OLx6OKsndLMc+AyDTe2gezTMwz4P5I8ifu
jAvmmeD+gcU2s10xzwSjuTnKZxxNCcGQytFwh3E/ndB+PyoLLo9e2svQkn4W
rZ8NVkpu3awl/Wy44Xutf1JC5ssBE7NeY5GS+XIgWHzCpO50xlwE6vBjouf7
GJiLoLnW8c7rjSTPtV+vy4Wnj9MqtANOmIvBfGviV5XnEszFcNrEsFzh436U
xH69TmJ/HpVH2z8P5ph3Dy7wyffLh4Df42OJZpLn0/pSiG38+CN9iJwvtV9P
FdjPoyugvZ/Mvg8yCBDlJ7GvLsL1MshLqO6f4TnaPEQzJQfb/8MB+3LYbUgR
9F6ksC8Hh8CweYZhQWDr00wpaH0FqNQx3bs4VluuU9D6CpzXgn0lzoEX/Pcf
bsEwlA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tIU1EcB/BLD5PmdKs1c06dI9KsXM1MrdTvNF9pa7szAqmoSIqUQksT
hZgmKBU1o4dh0cM0wRcGlWaPYVSaaJr4IKRV0oOeM3qoSFb0O3/ce+Fy+fA7
v3N/5/zO8d+xj0+fxnEc//f992WPcuON1qYMLf7LGZ37dHTw9VxmDqfPNk24
3fEnuyIvI++qZSuzDBWOgt6eKQ1ZgetVmvKA88zz8aq9NOm5jlmNl+acUfU5
P7IG3QON9cO3fclaTFW+iApSMC9AwS69izt8yAuhm9nTpzmiJgcibOPT+o42
b3IQBiNdci2TKvIS1MQbTl+f9CIH4+Qlx4RjD/MyHPLxrPr2Zj55OUaG+axC
F2Y92o6dkFdqPckhKI9oPfO5TUleAbnNyBn0zKHoD8zcXn1rHnklrrUOKp+o
mcMwWTnD/12PghwOWUnWTscV5ghcsPbnezTMJa9CQ8JX/qAb82r879cc8hq8
1WlD9i6SkyPxcTigWFckI0fBlBnU+cOLORo3nTadqsudDFztqMyVHCBbReYM
wvFWAzJjbHfdL7N4DJZGBqfefyuleAwGpKW7x41kLha24unNji2zKR6L3ub+
70NjEoqvxTRN0ISk1o3ia/FT2lI4GUrm4tClcn44JWP5cfD73dUZ7iRz8cho
b77X10LzWeNx9/GqL4EjLD8Bjd51t54le1A8AZvS9A3ZWjKXCGm2fnVfEas/
ETmtpjXhY2x9SagxPHj4yIvFk0TrWyfcD+s6Uf3JKBvZXxDzaxbFk4X7waWI
6k8R5a8X1bdetP9GUf+Mwn5wG2CsOx6XfoPlbxDNbxLWB5GtJmG9dpOwH5xZ
2A+Ykba4LLE7j63HLPy/3SzK51ExIBmvDqXx4CH/pFA6lWw9vLB/dh5H9enD
FdvYebZgznt7Wy1P5x8WyJYs9+6eIlst2Hw4JG3oPd0XuwVN31QX83ez+5QK
35b9N0s6yUjFZleVtTxCgT/XaFOw
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtIU2EYB/CTl6wMW9aWNu+XslzS1NI03X9bc3lL55xbUoGV+cEgSoSo
pPOlQCzMigg/hFrZBzPKS1peOlbmMrREsjD6UJIfAs3oolnZBZ/3w3kPHMaP
/3nePWfv8y5476GcQhdBEPb/u/9/sktla+24UxyCeU3pNBVNnXYls4DmevfY
7tvB5EUQI97OOuzMCjw60l+R5cK8Es6axOTzdUFkH/i+v1S5ZyuzH1ILJz44
+wPJQRgtDYytDmAOgbphZ7n72QByGNbF3Lzs88CfvAZVUldP+LgfOQIdM3e/
qTYwr4dpn9G00KYma+CML61QvFhNjsL1Q9rQNWbmjdAa6sOv1/iStRgMTtKb
bczR8PDb/yGp0occg9+PAytaRleRY/HltMlhimbehMndPW0FT1TkzXjT1zL6
qoQ5DkbNy+eup5TkeLTqDsycOLiSvAXenqs6xztXkBNQe82prBzxJidCe1+9
9n0p81YoNFr14J/l5CRE+qt8iwpYngxP18ZjHy+wXIf60LTR2IcKMuQWgWB9
UXnpHMv12FndWKvUsFwPY+6vze4pXpQbMNT+8uvrGU/KDej9ssyaf3gp5Ubk
R1ZtHzzKciMC5waexU8toXwbBlZPfbyoIIvbUDVWctww7UG5CTc6Xqn6/dwp
5yyk0PstoDwF8/PsQrkZJQ2JuqY6gXIzyq4Md6reuVK+XW6Rs5AqX09MhT0/
+taRkD+6+TwNMWcnpvXSj3mLaXAJWj/r2fCL8nTq7zPl6fi0ZXbOEPWd8gz5
82KGfD0hk1s/k6vfweU7uDyLy7O4/rPlRjbXT7Z8PYl5nOot9DvRBYv8edEi
/37JIt8PIUe+f+AscpZykBF3sm0siu2Plau3cvttlc+LZOXmK5f6XUj1udy8
cZY4Czb5fICzaJP3K3G5kAfLGW2k2yk3qs+T9yPmYap56HeZcjHV56HY2d49
fI/Ok2BHV1/CZMQYnTfYcdBwrsurls6naJefX8nOnX8Hno6Eff25lP4f4MAu
j7pqtYksOrDk6syelF6y5KD+vfEX27WkZg==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0F1IU2EYwPHT5sdyCBvtS1tuDhlia+hM11Lb49z0uJwXheQH0oqMYBf2
BZVFO1CtspjU1kVGdBGtWnjCDVs2KEwKC4JaYVjWBHHEbpoFfaycFXveYHvh
cPjxP7zP+57Snf1b+jgURdX9ff69yZJ0jIVHHSpIK2Hk8lzOU/nEFFw/eSJ2
+2YpmgcvOQapmyYWgO9N9MaPuBItguHjor3Ll4llELE/eltWQyyH3MGz4U+s
Aq2Ekec75gZnStAqmPSmPOoi4jIQymZS3N41aDX4qrd6gkE5uhyW1g4p/L9W
oyvAHlHcu9ZDrIHKuXhvx1gxWgsr99kECxNF6Eo49pT9WPBFhq4Cw7gzKtYS
60DcvlsfC0nR1fDVZem06IjXQ3ghII/6JOgauPV+8tLVaTG6FgJ3XSWyWRFa
D7T1/LtAF/EG0CTcbGhoFdoAbXpnaF5LvBGeHTHX71IT10HX9sd0dydxPUSM
F3OkH4ToBjAzh5eqThNvgnXC8sXhVwK0Ec7p+mav2IkBpgvP7PnZXpg2A+CY
uv/w9TgfeyO8KE7EvYIC7I2gCebk1brzsZtglO33ant42E3w2ZBMmbR52Jtg
wJmccPjRTBMoaJtB4s/Fbs40Y87cj7LA1JOGQwcfkP0tcGH+wFHTdzK/OfM8
TDP+Py72FuBzRwbinhXYW2Bbt47dr1o2pjsNHGVFkn/nd9oMjd8vYm/NNNOK
9/uG3YqOYbfiXLI2Z5rJMtWW1bNM2f77D7tK2O4=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GlIFGEYB/Ah13PzPvKq1rUkTaQ0b82/97qaexnClhWWFESZqZlauoYK
YZclEmRSGSlI5omtgi6GWEJlEJra8cEoEywrrzSzwuf9sDMwDD/+857zvOOW
nqnMWMdxnPLf/f/JLoe9Hd0tx8VY00yEgdVFx7INzBxCOz6lfO1zI5tAVmu+
an2Y2Qq9w28Kpg2Z7XAkWhVzt1lEdsSo8WMvk33MrjBpRcXo+81kEew8g+dK
vZjFMLduN6wu30TegnqP8cZ3SxvJHuBSh6RznszbUDTxLCSv2JXsheaBdolm
2oXsjdaGgfQL3sw+eP/289GrN53JO3DwpE3IgjfzTixrhyyN8p3IvvBdPeLU
e8eR7AfL2SbVtC/zLpjP1nxJrNlA9sejFIHg+1cHcgBKbg8ddDrFHIja3Iax
HWLmIMx1lmnnx+zJwcjR9omeSJlDIJka6bGosCOHQv1jPGDrii05DOlPxV1+
GuZwxIZ/PPdyyYa8G4ey0pYHJ63JEYhInd2f7MIMuDhOTFZet1qzBsj3HPiV
ISNzkUhV+zadFltSHoncbnlY0KIF5VFYJ/JaEjaupzwK/T8tVeosMheNa6UG
jz+kmVHOMxcD7zaBUcAVY8pjkBRY3DnhY0B5LL4FL/2J8jGinGcuDi1NmVU+
+0woj8Nz55mpKivWfzye9ofn5XSxPF7/fU6CmbZXK+ftTSmXQHFp53ZBmYDy
BH1rElDfPeIw6GpIuZQ3P6n+eFwiKieyC6MW2PoSeeMn8fIk/flwe3j7s4fX
fzLcpdXD6ga2v8m89ct4+y/TH4+To7zyeEjhZjLk8Ls8vRCpY/shx61h4a8H
/sI16+S876eAenul5MVZyqHAvLm25Lc/qwcF7j+rOyPMoXrRKZDdGBrReo/V
lxI2k7q+RiXVI5TwTHa3iz1B1vCsU8KsbvFAXD+rXxWEBg8Lpm6w9iq8zpg3
3aZl7VVYvG9c9DGSzoNOhZxj9T0yB3Y+UrD2/yMjherPFn8Bc41JIA==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAGIQDQNioVt3b8xWcoDwPtirsOw8rSII4zM4tIpKb5uz
UhHK53BQjJXbeNQXxhdw8Pi/zcfumwKUL+JQ18T98f00GF/CYdF9m1l9OjC+
jIPz+YQEgVXyUL6CwxTOLd4LbshB+UoO5/0KA+KdYXwVB781fa6pW2WhfDWH
wOsSK/s1YHwNh8nNO4+8mS8D5Ws5/C1/UFd8VRrK13E4U3UqcZE4jK/nYH1x
f7FLmhSUb+DwqqlZTXidJJRv6PD2/MccWwMY38hBzPFxzpoyCSjf2OHHdu5w
mRPiUL6JwwE+872HhGB8U4edpyO3hUeKQflmDvm9lZLCk0WhfHMH66yiGQlb
RKB8C4dN69vkJO7A+JYO2v1u55xOw/hWDk4Hg+W05WF8a4fpD3sY730UgvJt
HLRlxSTTE2F8WwehFwcOrQ4ShPLt0Pj2DrKr/1yLMYfxHRx4c4RedxQKQPgN
Dg7rpddsv+TND5V3dFhycnEZdwkfVN7RYe9xq3caj3mg8k4OziF/zFjdYPJO
Dhd3XP1y4wc3VN7Z4afOpJrlOZxQeWeHCS3MO+7HckHlXRzeW/7656THBpV3
cYCkRyaovKtDeJTRuiKl//YQeTQ+gxtU/zeovJuDce/b744HfkLl3aHyz6Dy
7g7czGurXk3+CJX3QNPvgabf04FJQesX9+o/UHlPNP1eqPwGL1T7GLyh/oCC
BgQfABVK4K8=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/HTmjVb5KXNmU03V1rZMG+Z185v0+ncpmEjS7MQoRdeSuwm
OYjzQpNg3cwgAiGSLBQNlcQIb2CQiFHWpKLeGI1YiWuF1hCt2P8J9MDD4cP3
8H/gOTyR5TUHT4g4jsv8u/692RNy6PHTnioNfHLzs9uKLGNyZg51Zo/n3WAk
WYIF7/GKr2XMgajMeuCSS5hl6BCS4q7fV5ND0eGc5h/pmJVQKvp4/xcqshof
+p1Ru0KZNbAtdp08VR1B3g7TtHKi8WE4ORqjRtvtdo55Jzx3inI/m5XkGOyI
Vlkb7m4la3HMVT0zF8wcC8uwf397cRg5DuebROWSgS3keFQ6DH6tQcwJkI6o
+T22UHIixmR1F9QeBTkJl25UpdlUzHsx+M1acKAthJyMW0JmW5CeeR/G3zQ0
nhuXk1NgV7xsnq9lTsUR47XAmWEZOQ2l5TOftF82k9MR3OWocF9kPQNGk/19
bzFzJloFR31AN/t+P6zTl+1T4cw8hkqjRiOkwWRgim8WKz4G+SwAGQmWpk1l
ZE6HZa5wuexsAHUdDpckdJ/WkDk9Xg04fr79JaWux7MfAdaS2o3Us1D1fGDo
9RPWs6BampxIcW+gno3JMLerJZAsZKOnu6Yl9qiEugGF9vjd4kYxdQOka7vq
XTfXUM+BypifGtLhRz0H2j7xuuSr66nnrpwn5K7qRvp/ZMGIM53pfO89jnoe
7fed9/U8zKV6l/SxTp85E3meugkidYxX2rlI3YzEK7MLupHf1M0r53EWOs9l
6hb47qOI9s9f1VeZK/g/7w9CYfBo
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0HtIU2EYx/FjZpmaGdOl5pouCy0V85bTcj+nzs3btOiiBl6iCzowLJnd
NSGRwpyKSFZkhCtTQVuUiA36r8zQQCcWtCSLVeCSkKw2K/a8hOeBw+HD9zkv
LyeotGLPkRUcx8n/Pv/ebIT7Hg31l0vgkFU2lj27EOPHzCHXqDZGGYLIrugY
NsxeKWT2wqBic/jISmZvvL/ZVnK4O5Dsi6PhMxeS0pkDUBxcl3J6SEwOhD2r
u0HrwiyBQPxuzKrZRA5GaHRPu69RRN4Kt1z1yyIBcwjKvl7UzucFkLdhQXjJ
+XjdRnIYFi22X6lmf3IEdNWfijr9mCNR29j25liPH3kHvEffPrdbfMlRaIz+
4jSdxxyNHpPIrL+7gRyDfEn87an9zLEofWqetxuE5Djcqro3HSlh3omJEE1J
12MfcjxMq+pNonlvshQHlde8ZozMCTjk6l/TLmVORLDWqSVuTkDeBUtbZXKv
jHk3PpSFJtjqmZOwd7Lh6msRswyKYUsZxteTgarQ1pbmAS+Ha4D8672dPmFk
Lhmq+33dW26so56Mkw8SZQN3WJfDQ/BMe8LCunz5PpeCAwVRfZUS1lOwxOUt
FZ9iPRUaedOwZ6cn9VQsrB2s/R3rQT0Ni2HN5/SaNdTTYH04bjvvQ+YUKNiu
U76qdqeugNg+OhJvdaOejvEnE9+nfrCezjtfuXy/RomOSffFrlja51To76to
jSh0pa7CZV15wlnxauoZ0A+ZhC8CXKhn0P/hqGdiTvrTLo/4KHP0TLg79575
3PLNYS6L17N4PZvXeeZyeD2H972a19V0Lza5y43//gOlOAyK
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mlIVFEUB/DLOKYV1bhNNo25JKJZlltpanPc99HRGZUIykSSClumvijh
s+VDkJYUWR8SK1FKg9L0g4Y9ywqyiaIPQpi2KjiEk0IujbYw5xL3PHg8fu9/
77nvnvv89x8pKFcwxsr+3v+e/FKbuvseHAoAh2w6ldl6+LkzN4PoQWuZsd0f
7Qot0j7lwVxuFSx23Kz0tPqhPSHo18zuiPPc3jBo7zx5PJhbC9aWV657e33R
fjCnu2oam96ADgC360FvrHHcgWA63ahs6PJBB4HH9NBEvg93MEy9HuzxMmjR
m2Bgz+/RUv169GYYHZk4cPGaBh0G9Z+PPfTx4t4G4fG3/RZy16HDoWd4Jsr9
hTc6AmKe1VQ39a5FR8JQSOV9rV2NjoLmNQqNPZU7Gs6cfTrSKHuht8Odo5a3
FfXcO8Bf+eHjjN0THQOGC+GhynPcsTBfal6s7fZA74SQQJevs+nccVDXtTy0
f8wdHQ9z2d9ca3O4E+BERVt/npp7F5TfaFVUN7uhddC6Met91BMVGqDHdmmr
xrLaYQlgS0KY8fH4KswTQd9Rn1rejZYSwXfJMhRjW4F5kmgpCSwa2+QVFc+T
oeGLuTpp1gXzZKiqWRg4dHcZ5ikwFbuwlBSGllKgrW9Y/VLrjHkqnGp690j9
yQlzYpYmjpfSwPE/KzBPFy0Rswwwt8fpOm8xzDNInknmZ5L1s/D8lJhnifVY
Nu5vXOfIs/E9v3JES8Qsl+TETE9yvbgeyyPr58FKp3tVk5d/YJ6P+U+HgVgi
lvNJfQOZbxDrSwZxvEzMCsTxQCwViPuTiVmhWA+IpUKxnlwIkXXfZxPleVzf
KBqIJaN4nrKR9M9Evt9E+kdy2UT2X0T6V0T2TywTs2Iyv5jMLyb9J2YlpH8l
Yn+l//4DNMigGg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0F1I02EUx/F/20zZWMxaf3WbzS2XucLcTJ1btd82N5eWuiAsWxFmEZkI
WoR1M8OXoAJHUVBR2JtF2HvL2K6E0JSFEsxokF11IUb/xCSDRsXOE+SBh8OH
LzwXR9fQsuOgiOO4oj/v72bD73wRftKkR1KC/Vmhr3lKysyha6U6dO2+jpwG
hT+7VuVlViAxvtvf+DmHrISsck/72+vMmeiR1eik25k1iOfNtmyLack5qKs3
P2zVM+sx0fB+nG9fRc7FUP7IY8vLbPIaaBpzX8/Nachr4VB3lKZWMRvRI6o5
ER5Wk9cjwzZ4e+SLilyA/S7BGpjPIhdi36G+jqUBZhPcjz51ByOZZDNuiW5c
MliZizBUdc844c8gb0R8+PmHyTaeXIy8j76+4ynMJTgQj0T6Z5TkUmjiu6AI
MlvQKXkzmnaZuQz1s/ESw68VZCvOnr9jGBAz22DyXHlVGV1O3oQjx36EltQx
b4ZMPHBy+kI6eQvyq1cr3c3MdtQeNY59z1KQgfQZJS/wy5IOACGhd4MqSuYc
kLeabe9Oy6k7EJOfObxQTeacuBqTLdwtllF3QpuIjlkEKXXXou5CVCVMX1Sw
Xo7eTvHg1F5yoBzdwSbrKW0qdTd850zrJF0S6m70hyf5UU0KdQ/aHtjsT29y
1D34WvYz4SyYtyd7xf8OVNB9vlH30j80Ae+ivvVf/w2acL30
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n1MzHEcB/CflIeuc1GdruJ6QjgpPbqkd4+qU3dXbKeFyW7+OM1Ui0pc
pTBE8jBpzUNIIq2lLpOMUuxYDxrD/FGzmLXfpkXJ4/p8/+j323777bX3Pp/f
9/vZxy1tT5LeguM41b/3/5c90s1NDxoM7pgSH/b07sFDckdmDibeeaS/0Y08
B+0dvcUztzDbwkrt2/tnwpVsD2P3kXs+15kdkaH2Wf5OxeyC60rNVdVvOdkV
26uKNHt1zO64z59e7WReTPaE/7YdO33imJfinTrsbUXVIrIX9EMF6Q4S5hWo
9EZ/j86FrEB9g+dSSb4z2Rsv7S7bjg86kX3wfMYr5TItsy/eJ2dLP1yUkdeg
prb1qLUbsx9Ex4Ny7rQ5kv3xWWfeP7KfOQDi0crPqsqF5EDUhVR3xg9LyUHI
mrjl7qtkDsaekzkyu3IH8lqUmC/IdApmJbQnfFdaFtuTQ7DrnEWW2I95HRR8
6d3mU3bkUKQW+aW8GV5AXo/CobSTQ3XzyWHoHvAc/WnDDGypuHPFQWE7ZSMw
/6u9lJfOozwc1d3XskVZZGM4LFxXTIhu21AeAUNXS1ufSUR5BDzizw+k1FhT
HgmzE//lrC3ZGInTh2e2fNzK8iiMK84cuLl7LuVRgjwaJWUGZZ58NuXRKBvM
zIv4TuZi0NURui+rdQ7lMeAbe37lO1A/bgMUjZazAktZvcBcrKB/LOSxCWul
tVaUxyH30MRjQ+0syuMg/21+Ecyz88Xj0oBo/EYAu3+8YD6q6TaqELlpMtAq
hs13I8QZa0L6CsWUb5w+by4BiXWl0fomliegJvxJR6eMzCViTGwqmAxg/RPx
8JlyxGuQ/V+NVaHemx59YvUCcxrUO9c196okU4ZGcB4Nelpej775Qfdr16Dj
myQ5ZS/rrxXUawX7pMXyRA/76HTat3Yt+vVjc71MbP+SkNlQf0yTS0YS2lKX
PF4sov01JqFcz5en3lyAvzfmJKY=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtI01EYx/G/10nm0LX+U+fSWVrKMJ1539xvF3XTmRVJL5KKLiBNskDJ
JuheZCpdrIjAtI0IShSCEZZuKJYZapSUaIF0Iag3FboKN8Wu7Dkv9MDh8OH7
nPPmyA/X7jkWyHFcwb/9/2SLr+x3Oy2J8GtBc6FiMv8gz8xhfijI7nXJyWHY
ulmtLKxijkSDd65f6U0gi3HbLa6w3GSOxvmkuSm5mjkOTQ67fd1wPDkBpsn6
xXoNcyIel6UHdJ7dRN4Cl+BAy/V3MnIyOpo7PpmVzNsQU+Jo3H0jjpwKgSz5
efsvKVkBk4BzeMGcBs90wcjHzlhyOizOhpNHfsSQM9DTVH7CKGVWQj7hac1N
iSZnwiOsHE3ZLiHvwMNnkpCVQzw5C4YkoeJ9FHM29IqZqaCWjeQcxBvL8/he
5lwYuj+IBtuZ89BqfdLg6xaT8+H8HuuwVm8gF2DijEF1NJlZheN1vgcB+0Rk
NSIVGdIXf6LIhXiluRosecusgaxvZbYqhxmIqBF9aTsV6bcNqHfvUuX6hNS1
iPoq5hd4sk2LGt3lIeEt1nXQ713JDilmXYfZiLbqpZ0R1PXomg1fupMVTl2P
lwMzP9/4yJwBgQmpy+F966kb0KMdHXsaw+4XrZ63FcEyPjA8PcjuF8N5r/Za
2v4w6sUYH1OfrnORuZI1vQR33a/5ybgQ6kZYm5cfWXpDqRuhuB8cmn1JQN1E
/0XzNhPOXbHkN8azXrqml65+jyvDfN7yb13aosbfy5B58ZtXO7LkN2debZuZ
5j9TL6d3OO4veNrkcw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtMU2ccBvATr2gp4mxZAaFYUQELSh1UK4wHWioIlNKLjMYszqWLiqiT
Olx2ydEE0UwcRD+oqBF1eAExilgq4rqYKsZtZiKNH0yMyvywGG0y1KKQ6cL/
/6E9ycnJL0+e97znvO85c9ZutjgnCIJQ9eH8/8pHjL2792K1CuMK5KlfmH9P
jmALiKx1T0w/Poccgc++bD3Sp2dHY9OA64fLz5PIMtQ8OvPPwYNsBQ4MaU06
HXs23nTVL95/TUlOghhwGfqnsFVQRr867UYiORmZPQ++T29KIM9H3y3di5Sn
s8kpeOr4xmBTsNOw118Z+LsxnqxGlqZdkFyOI2fgv+n1a48p2Ytxe9BY85s2
lpwJ1zLd7lm/KMgaKE827lxQxl4Cuekr7TP3x+RPsN4/L0PSzM7CruZq3XdK
djYcd6XrDz2OIWuxQbspSrSzl0KvHrw7sV5OXoZLF3YlKh7KyDq8DepP1KnZ
y5Hoqb3ScGcWOQeNXdMWXn/0ETkXmVfjFzzZxv4UeZXDq03xM8l5uO1PHn4X
yQaqDp9vlaujxy0CP2mcD1vWkIV8VDo0nVtVMyjPR5nxpm8ol/MCSLdqlg/s
lFJegL96BocfBCWU63Em/4bvZizneqTnZth+fUYWDLgSaFoU90cU5Qb4/p1h
dXwdSXkhJiSlvZW0k8VC+KW7142YuG+EY2Fz0Z/b6X6iMay/AtX9PdcHPJyv
COsXwdSxr9DZzfMrov3F/WK8lnp2jGbx/YvD+iuht41mTzby/FeixS8Zacvi
5y9Bvy+3znU1gvISqLsmTcneN5Xy0rD5lWJjQVNfVCuNJ5SFjV8W+r4FE2Y+
l8UEYjg3hT6PUA7zxrQ7r2J5fctRfLbz3LwjtJ6COXR9EWbRjG295pylQRrf
a8aF+A73vRLuV4TmqEB7jmpdyg3uh+XeCnybemvEWc77x4LeuANHPS/JsOC+
8/W0FA/tT9GCVNNcWWEN2WsJ28/WUMOKHE1pQ9Qa7luR0D7qX63lvhXTTwY/
N/q4b4NB3D6W2cB9G4Knpv44lE/fj2jD+P+R7LXBvaWtKkPO358dVv+evfcS
yLBjaEOqbqyBLNpRJ28Rfm4je+0Y+aJ2bEc391fBvOi4yqWQ4T2ax1sA
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H9MjHEcB/BnSSU14TrXXT+UzpSbX6mjonep3HVd3Y+SFIXZ0K9RI9Uf
Z7NafxQ1xtTWNCtli2MmOu2MaKJR6wdjRsswPy6kTvJrfb6253m2Z89eez/P
9+fn+/jvKjDsceA4LvXv/e/JLnHqtQ5zTgBmZIvSh5kf9nsyc7DJpb55nf5k
Fzg8n7I7ZjF7oEfkKqsbX0wWQTX6UvHsDLME7toDd68sZfZGLk7tuHzKj7wY
U3XB5ZMuzAF4VxR+7NU+X3IguuLzT9TYfMhLIbdnDFvAvAxFn6UhQVZvcjCq
dkdJpl/LyAqk7Zc3BcqYV0ATUaYW7ZKSV+GZeHZLb7IXeTVu9zRGZpdLyGsw
6nD9UO3rReQQZKdvsZ/OYV4Ltxal3tIgJoei8sfjVq9pT3IY/FTa9eJWZiWG
nCqGfL6IyOtQUXK3eLKeeT0kWZa+6njmcJQOHHHnspkj0Ltz69jXpwvJkbDv
LJw+eo15A8xfpA0le5k3QmGrbrt+nDlKkAPnznd7Hh9cMGMT0BdV67joxXzK
o/FmZUBIfhDZFI1M58azsjiWxyAoaYkoLo/lMdDlBveMe3lQvgnqlrZWef08
ygXmYvnvm2KRtm1N28EAlsfhQvSdrnte7pTH4db98E/LRtwoj0fd4Fx7U+hc
yuMRUvVxIto6h/LN2La8RtVbzHKBORUeSW3vT3q4Ui4wp0Z314bDRTddKFej
uWNI/MB7NuUJtL9kUwIUVx2dwqqdKdegZqSwNGaCbNLA3FZwckUGtccl4sSx
We0vt7P+E/nz4bR40j7wbXiSjV8rGH+SYP5J/Pe5ZMH3yfz15HT89iCwScdf
D6sOfr8e9ayzsfXR88cPPeyK2rLmXFp/k57fv1WPnO72zv4bbHwG/n7DAJlk
5G1NLasHA3wu/hzMVFJ9WQ0oNF+q1JWw+jPy6xFGeChWy3p/s3o04sPC9D3f
K6m+rUbM/O/IXApGLNOm5UoyUjCpGXU5msjOQwo0V8cS9Eo6L9YUwflL/e8/
RMBfsQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlXtQVFUcx2+8BEHFgo2AAjY1EAYEBARBvoCsIG/YZYHlsTDtYMFABtYA
MV4IZRiDVPyjoIdZQQFiQKiA2U2HxzSDDdlQY5QyUIySRVIEDI9q+J0/7tmZ
Ozuf+Zzfvfd8zzm/65JXnGwwEgSh/r/r/3/2U2h6B7oKlNiguVD1Jw+OqEwZ
CzAdG+tUtrkQm6Ow8zMrswTG1vAanjXDmjOxDTQnDLXFnYztUJnRENIbw9gR
o0NFkbaLTsTOuJkwo3vFj7ES90uDaiZfeIZ4Byb8rSx+6n+aeBemLlu//rsV
Y1d0vL2v5mGII/FuvLOraP7WKQdiD2xqaUiuXbUn9sTPEzP5b77FeA/ufxnd
3LT0FLE3Hn7zZ2HIHsY++PH9/KN17XbEvigP/uCAZgfjvSi98+HI9h+eJPbD
7PPd1Y86GPsjtaXZR2vFOACly58qvYMUxPtQqQsN/lxtSxwI92G7vz+atCEO
QnmZ+8z4Tsb7kTei7PcVnyAOxozbozLvRMYhOFX/8c6LxowPYOraquge8Dhx
KF4an7+R68IYUH1x/0WMbd9gEfjOsGDh2kcshMlZDEPmpgtNDpHMhyPYJ7Z2
q575cIRq/8qMd2A+Ar96KX2L3JiPQEnXpbrEcuYPwiUsv+7YmjX5g1x9JI65
nWs82818pHy8oJKPF1UIvDVwfuge84e4+kNoD1Yecb25jXwULjl0XPk2hliM
wvbfbBRziq3ko6HN8Ol8Wcl8NCLUK/6mKuYPc/4w4jsaIg29W8jHoGDk6vXb
fZbkYzBqP/fgnPVm8rFY8jj7WmuhBflY/BG4vBbuaUY+Ts5iHJLe8HY3OWFC
Ph5OUXGBijZT8vGwNL5Y/qDxMfIJchYTUPne7WuKSWPyidg4/0YbjET5/UWO
JW68kITy48tfFbTR+yEJHj0mZv4Nm6g+CV2dxec8deZUz40XklHSvj+0+4JA
9cmU53roRj3npWRu/ik4M1VSEf4PPQ8pXJ4p8nykFLQOfK/42pFYUMvzhZrL
U83NX43YgONXpjxZfhr5/aDh6jkvaeTzE1Lp+QsbDI7FVPl4KZXLXytfT2i5
/aLl5q+V5yWkYa5nbLXSlvJCGkYGQ14t7af1EtPk6yVxXkjHyTMFQRVOLP90
bv05ltK59cuQMzgWM7j1z+Dy03H7Rwcj593Llu0rlJ9Ovv8lHXe+Mrn9mymf
j8h5KZPLL0t+npGF5nHLpRY/dt6z5OdfysLpGuOrd7PY+c/G4Py2lIyjVlSf
Te9PLHJeysbClr6qFT9iIQeX50572Y9SP0IO1oWkdX0p60c5iFMNDU6HUP+T
cnBsIDF43yLrX3qUuQ0vGRLIO+vR8uzhO3tvEEOP2YnnaryqifV6ypv1Uz2q
p/Pqpzuo/57Xw/Bui1HFeWKJ43t6LMb8Yl4Vy74/uWg0zDVmthI756K+x8L9
+l1i5Mq/b/pc+fdPzEVTfNXy1GYb/AvEuz2W
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQNioVt3b8xWcoDwPtjf0f41uYkTxmdw0Ew4XTR1
kyKUz+Hg7nD0ckEIjC/gcLXhW332bwUoX8QhqWGC3cYFML6Eg3j1qyJZbxhf
xqFw1zfflPfyUL6Cw+vn507Ya8L4Sg5zl8nvjcuUg/JVHGYb+jjtuCEL5as5
XOr269JUh/E1HOaliDoe6paB8rUclGcxzph0QRrK13HYZl2Uct0extdz0LNz
vbciXQrKN3CI4d4XMVsYxjd0+L3zAj9bpSSUb+TApd0cy/lBAso3dmgs3qJ/
xgvGN3GwdL/isGm9OJRv6vCRL/Swpj6Mb+ZQ8mulkqGVGJRv7hA8Z4p0laEo
lG/hoH1c4uuShyJQvqXDLL/GX4+5YHwrB5Vyxslm74WhfGsHJ72EKUUJML6N
g+EuafVHpUJQvq3Dbqkpc3e+F4Dy7Rz+MwT+Tyjhh/LtHZacXFzGXcIH5Ts4
rHA8fPSYJC+E3+DgMKGFecf9WC6ovCMqv8HRQdlr2rWoFTB5J4fAHkNtllYW
qDwan8HZAZK+mKDyzg7Fq63tNy1igMq7OHAzr616NfmjPUQejc/g6mDc+/a7
44GfUHlXh/eWv/456X2Dyruh6XeDmgsD7nA+AChEr68=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tIU2EYBvCDEZa2lZeWlyxdVpt5ya3MTNsz001N55zbrIiwYNhFsotK
UsQhi4ropkaRSZctoxShqERFWqWpVJSlBlIRaVHZxUjTSu1C3/vHOYPD+PF8
D+d7v3NO0Lo8k82F47jVf69///STWW40XN0kx3/1a35bFq7olJA5HP2oj7Nf
D2KeAD2an24xk6dA+uiNrXMokNkbbt3NefvKyT4I9BgqHdGSp8M+b+3DFx0z
mQMx9nJWzKkgshzuypmto3kzmIPRmV+sKm4KYJ6DlteDml1+ZAW8W4usuw3T
mUMQtaGpu9zhzxyKk2GOJ/VjfszhGMh7lLZqK3k+Bl0/VOZc9WWOhD4xf8O4
ER9mFWTantzqQrIa1c8CXl1yTGNegFqnm/5sn4x5IR702EcRQo7CL2mO5nbi
VOZFeFzdeLC4y5s5Gs558Z+qt5EXI+eES75ETY5BaP+RmtqjXsxLoAx27R3S
k2Mx7HDd3av1ZI6Dm314ja7Zg3kptlct0Vy7MIVZgwa/soq6L2RAkzWw2uDP
1vNArCp1vzSb+lr4+/S8O17C1vNa9D2fuzdiD/XjYcwNuT/oS3k8wjwUX0+3
U75M1BeZS8Ahle15eTblCShQlpWWXKM8EUXKlh+2dMoTUTkrpXvBHcp1wnl4
HdJ095p74yjXi3I9PN8571SZaL4k0fxJovNLRgK/YzRyP+XJeBshV29WUp4i
XM+nQNf4fiPaKV8OW0Wly85zlC9HkDbnYMEY7S8VbV3BA78mUZ4KSa5n34Gt
lKeJzidNNL9BeF68Ad/G6lfucaU8HTf7j0X4PZSyPB2ONnuhez4zZxQaRhQ0
GGOjh2m9KHca0SU5sP6HQcL6GQiLCzffesuMDNH9MuDx0VvWL6O+yJwJWatU
Ndvkk1nfhNz4Y43S89Q3oSpWvl5xl+VOk2j/mVhmHokar6P9Zwr3w2eisSXm
s6JnEutnwiUw5Kd7FTNnhvrwpyGtcyLri8ybRX2z8H6cRfj+wyKch7cg+XLN
ldlnaP8W0fO1Cp8/rOiwfZ+oqKP3wYqLMerWSxXs+3Zasa5VXq/mvfAHO6h0
5w==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzl1I02EUx/E/xpw5WGtt072oc7RqNaY5c5nT/bY5dXQR9KKoC5ohJbOs
KIRFJCO6ySJDkNbQmUht0WDBIl2tLRBkUDcjtOgmg1FKJIEF0js7D8EOHB4+
fM/FU9kzcLC3gOO42r/772UjOxKLRz0a5LRqMRtDsaCcmUNh1ibVzFWSiyBw
akN2N7MIUxf7z+r4zBIkRgazvrCaXIrUWODWWCezCpmFq4b7axVkNdQl0xWn
qpk1KGhaaVf6yslbEbu29OnxZBl5G8aDZn7GxLwDwxNdIzMBFXkn2l7f+Xl0
UUnWQ9iwqL6tZTag3fhI5z2uIFfjeXT/cHFaTt6NtzJe6NUB5hr0xW/2xd6U
ko3IaqbWegPMtUhKHvDdyyXkPUgKTc9eiJnrEHN5j3X0y8gm+NPi2WBESt6L
G2cuhLsPScj1cPUsfdB/3ELeh+hXxYT3JHMDdpXJ5CfcYrIZCZc2VS5gboSL
f9evdGwmNyFbpTGe1jFb8gx0+h9OSvWinIeAlXfbr1T5yJwVHV01kXOaTdSt
cIYiYW2AzNlgP/yjjtcipG6DZ/5JIjMjoG7H/Fzj4PnZIup2vFSsLo+Kiqk3
w3j983drciP1ZkQjA6OGbrrnHPBeXk95woXUHbgXX5ClVTzqLbg0nnkqe7+B
ep65Vvr/b0uut+JL/fovm+Fbzlwb3dEM5Zlz5vX//gMJaLv8
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tIU1EcB/DbxEe+mK8153xnlMqymbM5c7/N15zTdDqtVf8YQmVkKoG0
HlfoYdLDqUR/qIhZSpakYqkDvSpEBAoSLSLEaBJhSYtASywr9jvEPRculw/f
8z3n3HO50RXVxkoBwzDmv/e/J7lEphHbYFUMuORUO1Tq6TBfYgYUk/KplYlo
tBe8rqkR9lQQC8Ev0H+a3YxCB8M98VKNdIRYDGMtfbZaA7EUFNfkG4ELkego
iDvZoTgRRBwDoTNJKv+MCPR2cB6vaOw+Fo7eAXGnxxPs/VL0ThhKDQh/50Ec
D086T5UdSQhDJ4Jhoccj65EELYNbqrZdDd7ESdCpmW8q1Iei90D6uP3KfJMY
LQdbd0T7eQlxMkzN3BfYD21D74XsSsfwjbsidAp4TsW2J34JQStg8XPv2fJ2
4lQwvXW/3mgh3gcHdbeFHyaD0UoYPlP33VwfhE6DHz2eF5c0gWgVVHY8EFi6
AtDpoJyzdT1/L0TvhzCx45O1hTgDnjqbd0tm/dFqygDmBKturt7HZRZg1W+s
YSPFF3MNxOrv2M193phrYFbiXG4TohktNF92G108SnItVL0YnXg1hvMxmZB8
c2VNw23FPJM/nsmi+lnU/NlUng2DA9VtssNemOeAc3j+14UQMn8OledCr+2N
6KXUHfNcMKReeuaQuWGug0hdgVL0kOQ6sDrqLNo1T8zz4Kq1Ks0SiWbz+OMZ
PdXX89dj8sH1fwkwz4dys3ygNmZT7coNUNevUg91M5gbwMft8bnl1m+YF/DN
FsBX5fpvrWwV80K+2UKqf4DqU2aK+H0oAkFU/LpP/waOp8wV4ff8if1iql/M
z9liXG+L6/04yoyRPx6M1PpG/vlxRur8SviGEqpPmSuh9l/KPw8oxff5iP1S
3CdeHJUzJr6BMkuZM/HnY8r4hv/+A1/9cI8=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzXtIU2EYx/GTluksL6XLzJweK2bKTM3pvLTf5tQ5nYki5lErinlBQUql
pYaHlIQocyD9E4EWRigIagNvQSKWQZiRmPSHRlJEICqCt1hW7HkD98Lh8OH7
vO8TfKUqx+TEcZz67/fvz440zzrSV8HDrhV1Tu0LifwgM4dwZcTN0p5gsise
vAtdKrnM7IWmQd386mFmHwjDfLlqJIjsh6FQyZrhAnMAJo2TtbHfZOQgxM9P
P85UMvN4Wr4slHYFkk/A9GbP20AJ8ymc3CqcG8Vxshx3d2Rdq8UB5NNYl952
Lms6Rg6HMaF1wLrpT1Ygr3Eu/6qG+Qx+df+cbmk4So6EraTObHrvR46Caqhx
wVfBHI2x8S6n2YIj5LMo4nKl2RYpOQZfO2fyvPyZlRgLaZZzvC85Fpc+WS9+
NPuQ42BVl2w2VDKrkMvFTfV5M8dDb7j3ub+AOQHZER18jR9zIoqaooW5H4fI
SVgctYlhscznoBPNtsgWb7IaM6Z1N/kQM6CaGul4/cXLbhHoSeTL5OOe1DWo
1La99Oj0oK7BxJpnrnDtAHUthDCLfsrsTl2LR7PuW89iyFwyQgwPZ4XnEurJ
aGt2HlwoJnM69PVWtSsKXanrHO6nYHIi6UbNMOspuGOpiK+X7aeeCpneqJJ2
76OeirrG7bGKbhfqabAsVtdrN2heTEP4wF4XZSu7r0f0/aUNzSs36nqsDHyw
3fIlc+kOPd1hv8FhvwHVPQnq/icc9YzdFjOwrNr+rVWsq+09k97fslvMRL4Q
1Xud36Fu3D0vGnfPc1nUv1PPor3snP/vP/8U9LY=
          "]], FontFamily -> "Arial"]
        }, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd021IU1Ecx/HL0tTm0CznLNNNe5BpkjPLOXW/zbnNxzSSwDHCwJIULKem
VraMqChfWFnUiLAgQzFQMa1wuCBdiIGI5it9ISQkLZVKt3BW7H+IduFy+fA9
99xzDlzJyaqjZTyO49L+3H+f7BIW97/tqYiGR0tKyYP9Gb+CmDk8WxOP9nVJ
yP6YM6ofdhYwB8PvQ0PTyqKYvB0zwwUjK7eYRRjYMDhcUuYILNsWjIHdUWQx
MpWKPc1BzNGwfLo6GyONJO+GbdE+Vdy0i7wXveXVQxvjEeRYzJfUaY6JmKU4
q9U0XD+1kxyPsncDhU9e7SAnoLV+4UR7OPMBPNLJ6kTHw8mJwFyTYatWRJbh
cWSb1ZIRRk5C42WXraJTSD4Ih9E2UDrCnIx9s0Xttb7Mh5ByRilrCQslH4az
1LR+pX8bOQUtfQFx1rkQshw15R3WI0LmVEhUp2/WuoPJCggqQxZvnGNOQ2Gl
dOxHOHM6BNUyxWSzgJyBKPf4WMrSFrISrfOmC+pVPzLQ87LqXoLB32Mz8E3u
cqsTNlNXwf4+/XzNG9ZVXvOpkdTydVU1HEBdjaW+ifVLoWQuEzE596dLXtB4
cyZK4lr1H+v51DUYGk11xM4HUtfAMs13Pk9mPQsTg1PfZ9bI5ixU2Aetk69Z
1/4/3qz12r/O630deGKpi99F3+P0cMbfudhRydav91p/ttf+sxGlz5cLO32p
58Dz//Co56DodmKczzUf6rkwdSmUvU856rl0vj+Vnp5H5+f02JwH/qbuxi93
l6nn0/jP1P/5N0y+/BU=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0GtIU2Ecx/GjVivnZN6m1nJuLbMakjPN5XS/M+duXgrJygV7IY6SjEQz
UmEsI/JFRRYVeCEXIcsyVmkQKhaSJVJvpEEIvUlEAkmJOSeRFfs/gTtwOHz4
nh88PPKa85WOSI7jCv++/77skVQNjzw/q0BIS7rbkxfbW2OYOdxPe73ADcvJ
W7E4Zh84XcksRk2zxhrzM52cCFOus3rpAXMKPnwW+ZeNzFJMIO3K7mkZOR1N
3giBN5tZgaecX3PXnkZWwuqTTl/17CRnYGFK1jAXkJIzMfTlVc+1Y8z7cM4Y
lzA0tYOswh6Xou64gTkLszMNmfUT28kH4Jx7bJEombPhc3WtDHekktUwlVyo
i/qVQs6Ber02dbyP+SBate6iKiVzLlQvN23Ju5lMzoO873Ii/1FCPoRxWXdK
7zbmfGj9b79etyeRNZDOnoS4M5F8GPHC5NH50QRyAaZaDNraDGYtTpnGo9e8
8eRCrD4SOOd45iI4evsj2/riyDo0PSnQvXgoJgMte98HHUfILqC6a9CdpGKd
R/PIUW3+aix1HvX6W2OxbjKnh0/UcSZYIaKuh21/p/nTJSH1Yoga1QUz7awX
w8NPvJtMJXMG7LLe89k80dQN6PYJg/25bF+Czm9NbfqAgHoJ3S+ZM0JmLtdI
BjZTN0IYNdj6/U4EdRNO2NTPGhXrulA34Ydm7bc+ayVkzkz3wdHevPF/zhK2
t4Ttrci5sRjg3wSpW8N6KZ1nmXopnYs9ZWG9jPbztC/faFd52L7if/8Deo3s
oA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/HTJLA200qXOsu5spbYsq00W7af08y7blPLRRRRUFqoGRqm
dSrBNxZYUnQXqawswaSMVDqkUhRhw9ReRBFCFynvaUquC/s/L84ZjPHh+zz/
Z88ZC9qdZ90r4zgu+9/7/yd7KTMftjTmauDSsOnYl8eyopkgMgf9M7cVE1eZ
3VFWfq/LCWYvnOgKHxnrU5O9UfPGW5Oay+wLQ6f5Ubg3cwCqLg005VwLJKsx
V1ttdH+7hKxBe7Xz3HI/5mXQqVTq+p2LyctxeMjfsFIIIGthsPd2VH5XkUPg
s3hHiE3GHAqj4s9AaY0/WYfVWWuXjo77kcOQe7PEvyiUeQ3C1FNOY50vWY+q
/sKj5slFZAP29wbr5FXMa6G4E2Fpva4kr0PtCcWDGxbmcJwqb39/QfAhR+DD
tjMVlZPe5PXwqijY87GWORKDBzt+GiYWkjfgKt9T4tnAbETjqP/1kn3MG9Gc
fytb58Mchab8wjH7EeZNSGoaSbREMJvQkS5c5p8sIAMXn9YVZ4aSeSCu7VsO
HPOpR2PVfO3IJYcX9Whs1CdXzNvFuhkq3/6vVWdZNyPhTsPd4Cue1GPgcUhv
7D7pQT0Ggc7Xr9YPz6Uei7bnGwa1/QrqsXA87hl/90tOfTMu98qnbq0j85vR
OeZpsxfQei4OSxPP99pv0zw+Di86o4oPP3GnvgWNDXnVuu1kfgumQs+W1h2Y
Qz1esj8ehtM/JqMF1hMw3OSYKfMh8wnieVwiAuNTIpV3Z1NPhOv/JKOeJDaf
JF7PJSM54nhzv86NejLqWvqULwNYT5H0FMn8VBTWG00PajnqqZCpQ6bl9b9N
rp4mOT8Ncrf7JQPnZtH+dJRd625VfqL5SJfMSxevFyTrOYtkv0X8/XmL+HkJ
ks5ZxfNhlZxvxVa7vuGQ5o/rPoKVfp8pup9NvB42yX1t4vMEm+T+GeL1yBA/
Pz4DQ5HTTrNugs7PoH3slUnzRlwdmeLOSyxIzGXR/M+mv5pBX5k=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU3EYx/G/SrkYiC5d5la6oZG1hpfmJS/7bVOnm9tMEKW8hCYYKyRM
KildvauMRA2pqBcSDbUZVlay8lKCphWEhe9LQ4RyRV62YVTs+b/YDhwOH77P
8z8vDkdW21haH8wYw7/7/5Nf4rJh55BVDp9c6rC3CTKHkJvh6Xpvb5JDRhbg
Xc5VZaWBOxw9EyvJOlccORJfHsq9x+9wR6M96JVEXsItxbRpujl9MZYch/eP
OmQtB7jlqDAWeK407SbHQxtSksE+7SLvwZHOuugxBfdezC721W0OSsn78Ove
g/2qYG4FYmsveW/mSMhK6J4td6quxZCT0C7LeuN+uZOcjPqE5KDc2WhyCj7o
q4WrUu5UCFpvSGZqdpAP4nbfhG7VISarENFhZpoU7jTEFpoyxf1R5HSkdU02
FIm4MyByfD7hao0kZ6Jmfrh67hz3IVyeKq/yFHNn4cepydXUte3kbFgrQg/X
9XDnIDE+dGFdz52LjfuhrQsaEVmNY6ervDNLEWTgTIN91CKmbgNujdnPlin4
vAaipfHXA6U0b9NAXf670izh+1o4Y7rvjqyEU9fifOKUu95CZjp/23RodpZk
Z2yEUc+DdfrF6NyIkHoe3IrOC/aT26jn+9uWD9eTj5sXo3gvwNBgY7fyqIB6
AVraPBPW/q3U9ShOb3v+VRlCXU/fYwv1Qtid8+IZKdlW6D/PiiAMcbQsdwVR
LwrYN6BpIEv9uJdRN/jPMyNWMj1/tMo1ta8bqf/0mRUj9fr3dc24m3qAmSng
fBN8/2swnW8O2Df7v49ZyN+oW2iPsb8FXf8Y
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtIU2EYB/CTLjOnMkunzsvUzEzNmvfpbM/m1Dk33c0+aBFZEmEgZRJq
5kG6fLCbTe0CRfihiVKkaamzUMosRfKCszKI0k+DdFGoW2IX9rwfdgaHw48/
//O873sOCy+t0Ja5UBSl+3f9v5Mft6jX1FUeAQ5ZxQbj7OCaJzEFciXv9vCz
cLQ7nHhftyQqJuaALGHMrFoNQ/uCuMNsmjcQB0DMg1f+pXuJg2F+fdJ2uY+P
DgMO+wlP7kEcAYu1gpTXRaHoSOhdZB3m3QpBR0GbR2uTfiYYHQ0W9c7pySji
GHiYpDX/vh6EjoNQyUaPYoWHjof2HElL93ogeh+MTwv/9B8lFkBEIxyYawlA
J0CiIaTr/B1/dCL4+SfHTjQQJ8FP+5uRz5+46GSIPDX10eZHnAJ1JWJRj94P
nQpyy9xL70ZfdBq8q5aJjkVtRwvBUGY1HDRuQ6dDbAg38PgR4gwQDATt+lZF
LAK266Mai8EHnQl7fKJ/3J3ioPeDidd8r3+ZWAzVu0dtZYXEAFUmtShtzdth
GsDrdELGTIMX5hJ4MZq+FL3gibkEpvpmf31YY2MuBVvczXPGk1sxl8IORau5
uN0D8yy4ccG178shNJ0F/I2J8TQryWWMvgxq6u3D5R1umGcDX64Scjs2Y54N
b0cyz54ZcMc8B+KestxSrm3BnGEql5HnwrLQviGNJ8+XO5uWw6Wm8vRaPunn
Mfp50PW4ojm+hMxXwATPamnmkP0poGmhsla6Svr5jH4+I1c674dWMnKVs2mV
83lRBc7roQsY51PovB+6EDRXBLGsiyzM1aBMrX++EO/qMKih7v7MIPcrmmbk
Q2pw/F+4YF/D6GvAaJrjjgWT96VxPt8hRk5pndcDWsZ8LbiExdjZnetiR1/L
mK/D738T9nVQ2Zkh7m6jsK9j9Bmm9JB49fuqZMjmMOhxvSsO03qcQ1F/Ae52
TGw=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzV1I01EYx/H/5lrlErbSTZ2m0wqdYk3zZabbz2lz021ZIcbQ3gPLxEyK
TAR7MUkykOzKCkpUKhrFkpARFGmwNCVQu1DoQiqQys2Zb2hW7DkX/g8cDh++
nOdRHa86cErIcVz2v/v/ZUde3ON6UREDvzz6qQ7B6rSMmUPfzpmBwh4VeQNO
D9f/yrIzS5GwoPaOrESTgzF+1efQPGQOxeSr90c6jcwReDwY8EDriyJHQ2d9
7rPEMsegWrDv63j5VvI2uIKVXbqJSPIORJ6Jzb0WwhyHsbLBOHVlBFmNm4de
l94fUpITIew4drFlIpycBGX/wSpRAfMu/GifPNH7MoysgXvUWPk2nTkZZleV
widgToHK7W3KiA8l74ZtqKivu1xBTsW94e1mcbOcnAb3yPXGC+4Qcjo679bI
esGcAWlT9ckvj4LJWtSN1gZxR5kz4TxX47Nf2kLeg+/xM7WaIuYsiIsFTs+7
zeRszDU7FGWzMrIOgR0Lh439zHroS2ZLbUpmoOiseuB3mNTvBmAuqPfKcuom
6jloH5MsdqVKqOfgY7hnqk0aSN0Aj/PTSn3IRuoG3GityKyLWk89F1Emq1b+
ZB31XCQ6ReK026zn8f7noXWyps4wz/peTGuX/hiSxNR55ozodn2Wf4hg8428
/flr9zXk8/6beN2E/bc0CaJGEXUzhNHqJcnTZb2/m1FiT3acj1n1mytASsvP
+Zw3i9R55gohCXh2eeqOl3oh7Z+jblk7r8Gydh9n5XUrr9to3jf9X1hg9bg=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQNioVt3b8xWcoDwPtinpEqt/cgJ4zM4MOyTnWK1
ThHK53BIEKp1VY+D8QUcTjFGzJjEDuOLOLDz8bCcW6YA5Us4TEpo2p/iDuPL
ONjNW79q73t5KF/BQXXpEUfPWBhfySGHrZPBYq8clK/iEH1b9co7ZhhfzeF7
stUEZQVZKF/D4QnnXDXjPhkoX8tB4dfWM3efSkP5Og7qDUqZYS4wvp7DsTtq
qc+nSkH5Bg7/QsVku29IQvmGDk9cOurfJcL4Rg52Yqprfh2RgPKNHcLTVvz4
xQzjmzhk8v0IyV0uDuWbOux+uknm/jIxKN/MId7Mlu3uWVEo39yh7ex0yQgd
GN/Coel4eOwvHxEo39IhhkOqYYYljG/lUC46m6F/mTCUb+0w/WEP472PQlC+
jQNbKOPmD4dhfFuHrJIf2xjDYXw7B11BjY+zLgpA+fYOpbsDbCx+8EH5Dg7Z
J3bsu7yTG8JvcHCQ/3f2tMUHLqi8o0PtvMt7xB4yQ+UdHeQ9fC3FVrFC5Z0c
uJnXVr2azAiVd3Iw7n373fHAT3uIvDNU/iOE3+Ds8N7y1z8nvWf2AMiEmTA=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCwBWIQDQNioVt3b8xWcoDwPtjHfuIQ7xGC8RkczPYbHXy7
TxHK53Dg9lRd6ZwI4ws4vIhcHFDBDuOLOESUvJ5ls0MBypdwWLhwitOzWBhf
xiGz9G/Jty/yUL6CQ3iU0boiJRhfySF456R/s+vkoHwVB/mJsWHbjspC+WoO
1gf3mBaZwfgaDvqsFy4rdMlA+VoOL6cdqfS7JQ3l6zjwWd9QmKkK4+s5aP6p
sf+ZLwXlGzhMP3J2achuSSjf0EG602r9HRUY38iBXSblqW2/BJRv7PDgp1xo
kwGMb+LwYzt3uMwJcSjf1GGnTGTuCVUY38zh9vEtt64Xi0H55g4ucx4I7ewU
hfItHATaC1PuLxKB8i0dPLx6bm2KhPGtHJ5kaVr9bReG8q0dfixhr3viKATl
2zjoCmp8nHVRAMq3dSjdHWBj8YMPyrdziNKe6HGughvKt3eY+Li42uk7O5Tv
4FBV/+tg9io2CL/BwaFtYrZVtTxM3tFh47r8KXrRHFB5RzT9TqjqG5xQ1TM4
O8h7+FqKrWKFyjs71M67vEfsITNU3sXhveWvf056MPtdHIpXW9tvWsQAlXd1
gKRPJqi8K6p6BjdU8xrcHHzM67c/1oOZ7w5NX//tIfLuDkwKWr+4V/+B8Bk8
oOqgoAGNz+CJJo/GZ/CCuucZ1Hw0PoM3mjwan8EHzXw0PoMvmjwan8EPzgcA
E33YyQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HlIFFEcB/DxSM3VXNO21K01jxQTS8v12Gq/bnmm6+quVmYZgVCtUtof
kVJOYhIdomgHSWnRqanYQYpZq2VoYhCiRQQRFZoGmp0uZQf7e8TMg2H48H3v
/d7vwczi7bvTc605jsv5+/x7syHLuNPRavSBRZPqo/H1445SZg59Pa/PHetY
THbAlGm+leN2Zinsjc3a91bM7ihbr9oaf92bvADZAWGVxSnMchz4VVsa+E5B
9kaq04mml/7MPshq6D5fe2gR2Q/fnuTMvG9ZSF6Cr2ppW/ss5kDIXdP8TubK
yUFQ7nz0svaSFzkYFyZyXEarPMkhUJrzH3S2eJCXo28oLr8rgjkUszW9Y1rj
AnIY5PX5I4bO+eQViISvNaZk5JWQDH4pmDnIHI5+8+jR8svzyEqUD5z22BjM
HIEu37JAzoc5EqpdhWe23XYnR6Fo/9KRYX/maPjts6pWTriRVTjp/2sTV8e8
Cq1TnnVFO5hXIzmi5O7bEOY1kAaHej397UpWI9v+4lmvWGbAOW/u+JECqcU8
MP4qoGxZKZmLgS4vqP+rB8tj4OTWvW/PBxfKNcjTVHbOuTCHcg2cC8NUg6XO
lK/FsPORHdNaMr8WPZ9d9FkFTpSvw7O2oS8vfkgoF5mLFeWx0N6oiM29w/aP
w7WYhz2PPdj+caI8Hq4f3WWTMna+eFGeIDwPnyCqnwhjb9v9wXZWPxG+SaeG
s645Up6EyjKbttdbyLzI3HrhfF5kLhmKmYH+yEmWJwvrcSmoHZZMXwln9VOE
8zktWpt314RsdqBci6q3e4s13+0pT0VRibnL2GBHeSoUCSlRsoZZlOtw4Pzg
PdkbG4uhw9WO57Incsp5HSz/B2uLTTpsyAprLvT5rbasT8PeRpX65kWO1ovM
pwnnm0Q5ly6qn46046FLbQ/b0npRbkrHRJR5RhNC/XB6lFcZo4sV1C/0GPCc
HKuRsvvUC+/DpEfwLVs7ZQW7H4PwfmAQ9ssb6Hti9Q2w9g4ySxp/Uv8ZdJ5v
FiMDEpumorHqTxbzGVSHhklkLlM4H5nC/XlRbsoUrd8gNETm//sPO592iQ==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVzF1I01EcxvE/s6m01Klzrbm1uWqEjZnZNHO1xzndNIyVCSVFGs0wLyo2
xCahEaFBGSIETYppJMM1QseiLOkF7OUmkmKFF72J6bzIvCi3Ia1ivxPswOHw
4ftw8o6d2m/jcRyn+3v/veyI6wMPR1tViOuHYc8Z+Ye2NGYOg1P83NnxPHIq
JvVZ7sfNzEL4iwrXhNKZReh5fs8UeqYkS+BumbUFTjPLMBd+qdGnMysh9b4x
KboUZBXml6Z5BYH15I04ctXnmdYwq5Hc7np3oF9O3oyfBuH9B3zmfEgH6ttu
H5WRNfAM3jpx4WIuWYtF8/nPdUEpeSu+9oTfCzOYC9EYmYtcyV5H3gZH0zxv
vFlCLsITkTelaWEteTtagpu0gj5mHequx2asMuZiqMZSXZO1YnIJvJnfJWp/
DnkHPh7s7b68LCKXwlrgVjkkzDvx6qxJf1ydTS7DxIvuT+HOLLIeVROhk5jK
JO+CffTuJauTeTdsN4Z5HW5mA+TeleDhEmbgkMs3mKMRxt0FxLh9sUZHBvVy
7L3TW2kLpFEvx4aaa8EGz2rqRgwEBZFhnYC6EQ1b+iyv28lcBfpm7B3G5RTq
FXB2Rp+2jiRTN0FhqS0Vj/Cpm6Dxr0ou7qU9V5m476rEuZtvH4m/JFGvwmJp
9LdR+8sQ71Wwe8sMY0McdTMEST7nQv8SdXPinrOAp8yPCrwr1C2Je66a9t+o
V9O/7NT89x8nA86j
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tIU2Ecx/GjlkqizEtrleWlEptrVqZLbe23aZvmZSucb4wiIxQXGSgo
rtrRqKDUMIMQIfISg2aXJVGZtnUxfVMQGRaScZgIRlIWoU6TCv/Pi50Dh8OH
73me//PElVYePO7PcVz2v/f/lz1S88OnTks8lvVDYy4aGQmOZObgbHws+D+J
IwfDKnzrDj/ELMHRsq6Pw4ux5ChUzuSGXe1ilqFj62ivwcQcjcKyVNfCUgw5
FslB1k+2cuZ4nFRMr8xt20jeDHvCmOOzdwM5AbLajC33UpgTsTAvPytpjSbL
MTmoeCsR1pMVuOW41PwzmVmJK/VHXh44vY68Hb+E8x3FH9aSd+Bcz4tI82Hm
nWg4MX3ZPiojp2BsU0XnUALzLoTVyovHW9eQUxF3sz5K+0ZKTkOZZTLLHcqs
gqc+IvHUsdXk3Ugakv3uFqLI6XDONU/JwJyB60Kj3/hMBDkTr0zudr6PeQ9K
DK5V3vvMagwMXfwyZ2PeizaXvcasYNagutz+zChlBjz9f/gkFZmHqGuhH5iq
wLtw6lo0TJQ2TfSQOR0K9K8HJ9QS6jpsUyuLXJOh1LMwPKiuqe4Lpp6F7+ne
JZ0ykHo2WjxVVt1sEPVsXGixZFhjyNw+KHpXBKY1sy4yp/f9n9fjzI33/VIh
gLoBzruV15QlbL4BdTbvc8ttNj9HND8H+SrbI4+Src8VdZG5/aL5InN5ovPn
ie6f72s+X3T+At/z8AWiXijqhUhpmp7Vuuc1y90I/1i5N8SxuGzeiCpHpuZB
J0frTb77wYSQgDt1X1v9aD+T73o36zOavwZ2Fno=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10mtI02EUx/E/S8NYrq3m5tI2HU5siuTmJWu53+Y2J01pWczGQBsIQ4Ok
AnsTTbqYYCYNK7CIigovrWIoXTUFIZOKLbAJhRIRCUZbuUIxrdh5HjgcPnzP
yyfTfXhvA4/juMJ/83+zJ9k/+PRhkxJxRfSqEYWnjM/MYaHm17v2QCY5CXXN
064JB7MQS5PZ6rUcsxg3PipHAvcyyKmo8Ag/PHMzpyNkf2RbI2XOwG6BbLCp
XUFW4lNX65OVmJychdnY8SszNuZszLV26Qb8W8g5iI5/zrJE08lqNM6fbPlh
Z86Df7bqftfZNHI+rr9dL/CFNpO34UG9rWTIzFyA8KWwfuu4jKxB6GVY05/D
rIXnplTVlpJKLsRYxwXRLaWUXIRr8u7hnjLmYsA99P5ii4RcApNKkDcjYt6O
3ubXQU9nCrkUt7uPih6DeQdOJ0y8SrosJu+EcbRGnqtg1uHNwdroz+lN5F04
UDdmddYyl8F1SusMf91I1sPXEPG57jIDwy7VqJxP9gKW53ONCIqoG6DT2NoE
9WSvAXrHgqs6jXUj9hxST8ZkQupGrHL21fpjG6iXo7LX36e6SvaWQzQvlkQk
AuomTCWf8yxWJ1M3oXqg09wwSObMKN+3XJxooXuvGT1T/MU7RXzqFkQCwT8n
UtZRt0BhrSqV9CVSr4C9oyA34UwC9QrE/zuPuhW8DPUSv39ZH+9WOJwa/xHl
atxcJbTnv/02vFikXonvpUsrxvwv+r8KVMsD
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntMjWEcB/D3KEK6IEdI5SBFDpVKnZPz1eV00e10zulcjBFZW8ZcRoX1
ImqTVpjLNBu2RNOWZnKJ16XJfTSxMY3MraEwnZOO287v+eN9z/bu7LPv+/s9
z+99nil5a3Pyh3AcV/Dv+f/PfnLj+ctNhQo41as5VCf7ah3FzOFJXdam5qYp
5OE421uwtEvH7I0Foy2aZ/ZAsg/Uqa9iGo8x+6JShqSPKmY/3IT/zun3AsiB
6Hn/sF0TwqzAaa/D/rWl/uRpKJZzZdrfk8lB6Kt4t8aayxyMGW4hv/Ku+ZFn
4oRa5nakZxI5FIaKG/c3qpmV6OtQCW+OTCTPRf+K+Q+qeyaQw+BYVVKU/8iX
HA7TqnrbgAtzBATP6NYbY8aT56HOUR8QVCsnR6K42udpqow5Cq/MVeWV/T7k
aJSX3Cqy1TLPh/Xbi6jpjrHkGNiXb3BsP88ci7x2xaUInlklydV4H/KtOCyb
OQ53ihPVK4OYFyBkmtvb/mRmDVpvl3fZSseQgZEnbUu1baOd5oFJvt0favZ5
U74QPS9nlM3ZQeYl5uKxoUGlOXeC5fHYE57/8ugylicgwTAYNVTrSXkCGtSK
guCbXpQnYnV8davncZYnotOjosCe6UF5EmbHKQ3X3pH5JAwJnDng3jCKcu2/
eWK/BHeTeS2mph3stNaPpDwZbd+99NZ1LE/G0U53e12kO+UpiNj7uX+hMILy
FPH7XKq4H5+KBxN7Px3wZv3T0Nv82LFtHKtPQ1Pj2gPKxcMpX4TqMpeWriWs
fhFCm12HRVW5UZ6O3TWFsVsCyHy6uB+Xgfa2uM0bL1E/PgP20H1bT61meaZk
/5mS/WWJ98NnidfjsnHq8jP5Xb+hTkNiPhvp0aUXupUuTgvZ9P0HNc56ndjQ
wd3lbMmn/TKq12HbsY4r8tesXidZP0c8HyTmc8TzCjnieTm92NBLzkOPrzED
v+OVw6heLzkfA6yzalIeFtF9gAGPW57+eG4j8wbx/RIMKGxvudpxkd0fI356
XNw+GEk5jPBYH67q2MHuq1HcTzCK5+NyoasMm+W6y5XqcyXfX2IhFyWlA9cL
z9A8nAkBKRkx8jPs/EzifrxJMr9J3I8zS9Y3i9/nzZLzM0vO30Lv/6Tzt8Bk
DW9cr/jjNG+h+9DntGChdTnuLx51sTc=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd039MjHEcB/AH86MlOuo6neuXXxcXuqJSuff1U1fdXXdFWbbz4/JzQ3Ui
wzOiGrXl5DdDGFKU2lB0q8kwbWhtaKRihY1mfquwvp8/7nm2Z89eez+f5/vZ
9/t8vFdsNJiHcxy3+N/9/0mXOKW2rmq9D4b0WfXOIntR60Tm0KhpSbXe9GYe
A0m1vGPtSrIzKrPcG4pGkF3AP8i/PveCF7MEGX6dOxfGkidjSndpdvMPT2Yv
VBcodmlDyT7Y3/fr99FcD+apOORxJuPtcxnzdIxZ1Vl6wY0sR1x6TWv+0snM
M/HY5jWqr1jKrICHeqBG882deTbSl5sqOxLIc5FwE9G+Rycx+2MrLzqS80TC
rMTV1tRtL1PJAQiwyqp2HnNjDsS+kvULtnuS5+HOR6NWVyZmno9LL5tKT7W5
Mgch5fnIwoLt5GCUde9dEZnhwhwCIxfcUiUiL8CO08/qxW8mMoei6IbDrLuv
JzCHwf+2dEanhRwOZ4W/tGVQxLwQreZvDvJbZBVMm5f9fthDBi5O0bwIbHQe
Mg8kxjTf6w5n5tTQb5j56OskytWw+B6yHqymPAL7leb2EybKIxB3ufLKtJPj
WR5pbz4Soo8u4s/icSyPgl/47OSGd04sj0J5mM8aeRPVRwvqo6G9WhxtrmXv
czGw1OnDgn+w7/ExWLJUWZnpQ/Wxgv5iIZV09ZQcpP4XIas8VFV9jvJFkJX/
aUsPov2JE9TH2a/HaezX4zU4/6Bsi2M25fEYO7ExZ1Mv5fH4MnA7bfdoWj/B
3nyC/X5ziYL9T4S3enWhZYByLT60z8ibs5tyreB8dEg7XnHWVUG5Dtt87/80
6yjX2/cLPQa5pEFTNvWrt/8fbHrB+STBTyTvO/6E5RCYF9iWhJCWujPNHbS+
wb5/GAT1BjiOqMh9b2XnYTMgq+paoT6XzseIKH5rv38+M4zoqu/nZwWxeeCN
MLYVHngqY/NjM6L3cKa6QkXzlIypOcOs8z8xIxmrS4dnOwWw+eOT8Sq1OP/A
d2abwFwKgteplEVubJ6Rgj15Te1HbK74C1uZWMM=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQNioVt3b8xWcoDwPthbPVwb4yIJ4zM4SPC2NdTv
U4TyORwaD3baRqfA+AIOBx2XXAoTgvFFHJINn/DN2qsA5Us4xAgc5+JMhPFl
HCbLnJh7lBnGV3A4f/4F5w53eShfyYFz6+JHPSVyUL6KA2+RkfXlJlkoX83B
bNHkhVtOy0D5Gg6/2+vvrxGB8bUcHj/Q2WxtJA3l6zh8yT/vG1UoBeXrOfjs
cHDVnCEJ5Rs4zHI3KpMIh/ENHY6VTKzI95CA8o0cFirNkSnYJA7lGzucnLom
8LUGjG/isKiRZ9OSQDEo39ThoHKLBoOSKJRv5mCdVTQjYYsIlG/uMLfhahX/
OmEo38Ih6YTSLuMGGN/SYZ37+6ByHhjfymFy6ofJMcuFoHxrh5PXVL785hGE
8m0cSjWnTJ60SQDKt3UIyNE6/VUSxrdDk7d3+M8Q+D+hhB/Kd0DlNzg4+K3p
c03dyguVd3RY4Xj46DFJKL/B0cG49+13xwOcUHknh43r8qfoRXNA5Z0c3lv+
+uekxwaVd3aonXd5j9hDZqi8swM389qqV5MZofIuDpD0xwSVd3EoXm1tv2kR
A1Te1YFJQesX9+o/9hB5V6j9PyF8BjeoeR+h8m5o8u5o8mh8Bg+oe59B5RF8
ABdIyNg=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2Ecx/GnqaWp5XUuL7mZlamIl5y6afvN6bzPbSTaBaJIMMSSCgNn
dDCK7CLMfGUoZWYv1EIjJG1gvqkkqZDWK1/EQNLSjEJziFbs/7w4Z3AYH77n
PM//PBzVqXPWWhljrOzf9f+f/+RVz8eH6+Pg0bJOudzX0xrMzdDUMjLWPqoi
+0JImHXXVHMH4WbeveYjK0pyGFo0S723urkVmDqtHRnM5Y7Gg9k/Vc3vY8lK
KCMexTakcsfhzVBS4JppNzkeDfunHDG2GPI+2Cccr/bORZMT0PFUoa9TcSfC
PZZ9bNMWRU6GKj79Y8m7SHIKTpwN0awmc6eiv2a+Lku3i5yGT4uC7zeXgpyO
tvUZ57CBOwPhEZlJ060R5IO4bq/X2GK5M+G30emnVcvJathjznzvcoWTs/Bh
0NF21RlGzsblnpmX8i+h5BykGbtelE6HkDVodP6aPKni1qK2u19mux9MzpU4
DwdMe8IKG7gP4cKAVjfSG0TWQVf9+7gpincgSuH6au+gLgB9bx82+V/cQV2P
gNDJS43zO6nrYTi8rvYx8p4PZ+CNujVTIPV8OF5rlhJcAdQNmI5cXugM2k7d
gORn3lvV7duoF9D5kYUCPB7/LJ+K9qFeCM/3KaNeCMvttCTva97UjeL7BSPK
s66MulK8qBfhR457Iz9lRefpRci4s7iqn1jzmBVLejH8vYaaF+7+pF5C58do
/RLJ+qWS/UvF87Iy8X6CxKxc0sshUya6/QfWqVdI9q+QvL9JPI9govm3UK8U
W6gUvy8ziw2zZB4zqo+mPzkft+nxhFk8D7OI14dFfH6Chdafo+clZlbx/bCK
u2ClfRj7Czw2NNM=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQNioVt3b8xWcoDwPtj/1y3vuiEB4zM4zM6bw3xy
nyKUz+Gw3aJ5ycx0GF/A4ajCqQV3uWF8EYcLk7af3b9FAcqXcDB/WyhYEgjj
yziUTVjNIP9THspXcFBw/7F2uxmMr+QQoCwbLFElB+WrOPAaHvKvPyUL5as5
PNaMD7nsAuNrONT7ZdnerJCB8rUcDF5bKLz4Lg3l6zj8F2qao+ED4+s5nLFz
WGE6WwrKN3DoUbQ+/HOPJJRv6LBvj1wI8xsJKN/I4eDpRTYJbTC+scMBkdXs
ia/EoXwTh4OHlzJdi4TxTR2W/V0hrzZHDMo3c1g5/9kG7VgY39zhveWvf056
ML6FQ+hN1s6OalEo39LhoHKLBoMSjG/l8C73yFfjb8JQvrWDq+2TmvO/hKB8
GwfDXdLqj0phfFsHbVkxyfREGN/OoeDa50OJijC+vYOAjqH0uf+CUL6Dg42R
TztfApTf4ODgtvdllsNFmLyjg6afsohrLkze0SEgR+v0V0kBqLyTQ+nuABuL
H3xQeScHJgWtX9yreaDyzg4njtqWl+zigMo7O/iY129/rMcMlXeBqv9jD5F3
gYbPMwifwRWqDgoaEHwA/S6g1A==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03lIk3Ecx/Eny9RMs7Sl01LXZWqrZR55tM+mzXnvKsuKIhiYDuxQKM1a
URBR5tEBlWWHTpMEEytb4XDYvcDIjr867FC7VlQ6j6zw+/tjDsZ48eY3nuf7
fJ/ATXkqrQPHcep/3/+/7MNb2WxszBVgVFbx8o+XGre5M3M4Oaulm2sOJDuj
6oXR8/1aZg98vVJcMaMvgOwF80Gvs9+qmb2xb8qeeW0xzH7w7O9sFdX6kwNQ
0Z6T2fl+FlmAzAUNMbnzmefguPO98091M8nz8LLXdr38sB85CObi2hDDI19y
MGw9w4MJr/nkUPgkDvLnRDMLITUOHUrc7UNejM3G0s3NL73JInSmtGW9CWRe
gjWCqKoXq2aQw1CYPzuvXsK8FLnCwVdP7vPI4cgfqBOIopkjULfF0pFdMp0c
iQi+y8XvVcxRWC0/6vG21Yu8DMrDopAJB5ijsWZDmzxrtSc5BhVaa8U6wzRy
LCauHNdkNTPHoTo67J6hknk5+i857X4nYRZDJDvVkmxhBkQ3fee/LSDrAW1l
jUNR1VTqEjzV/nYJaiHrJXDTTft0cKsHdSl2Lrhr02aQ9VIk1TVcnntmCvV4
FBgVsVH97tTjoZOW3nY/T+YSMPWzF8/KYz0B/n8sD6Osk6ivQOn+8TderSfr
V8DCt/Ye82BdhrKu7UXSPifqMsxOPvEsq5b1RPx2a9k7FD6ZeiKyQsrkj3e4
UpejsSHvmHCtM3U5Rt8HB+pJCDvypU9isolHexIcAoIHXOuHRs0lY3t9jPjq
BY7OJyM1cs/1LuF4Op8Cg/E574GfI/UU+MvTlvEuk7lUhDZNmBhRwq4/1f5+
uLQx9zfGXPqY60+HLbR8l0HnQj1jzPwyYG3qGC6ezrrCfp5Q2He9wv7/TAqc
fuZqqwln81PSPGi+UGJhnFDT+sGNzisRrxmKcJTR8zUpUSsxt9/xoc6pcM1a
uohvoQ4VRjjlyMZ82h+9yn5/TCrUxwqyg8xsv9RQ6IIf/vKh/YMavt5d3WXl
bB/VSJPdaX8XRzapIc78uS7dl+23BrLbPTnoIEODrlvD+pBI9j5o0PiDf64w
2xN/AVAOUxg=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQNioVt3b8xWcoDwPtjrPT9pe5QdxmdwSGxrblmx
ShHK53C4KJTKvTYUxhdw+Ms21Vn1nwKUL+KwznOJtv58GF/CYXXzV9WVRjC+
jEOARWh75zp5KF/B4c3svxXBv+WgfCWH21Exx2pdYXwVh7U7D+ubZclC+WoO
k02WxJ8+IgPlazisfBNZZfdJGsrXcpBPavw91RbG13F4vrGm4kuVFJSv5/Av
VEy2+4YklG/goNp/xe1nIYxv6FDRIDi9/KIElG/kEH+wQZJLGMY3dgg25GC4
GSwO5Zs43JiaELXmghiUb+rQ+evCKsm/olC+mUNttL3NlhAY39xh8ZPWJOc0
ESjfwmGq6t9IhvnCUL6lw97j7fd/1AtB+VYO9uFfYvykBaF8awfeHKHXHYUC
UL6NQ0CO1umvkjC+rcN66TXbL3nzQ/l2Dtd4OzJ++vFC+fYOyl7TrkWt4ILy
HRzOSn14NUUAym9wcJj4uLja6Ts7VN7RIbDHUJullQUq7+hQVf/rYPYqNqi8
k8Py3dfFTsmwQuXR+AzODrXzLu8Re8gMlUfjM7g4hEcZrStS+m8PkXdxKF5t
bb9pEQNU3tWBm3lt1avJjFD9rg5MClq/uFf/gahncHN4b/nrn5PeN6h+NzR5
dzR5d6h5H6HyHqj8Bg+ovTDgCecDAJGCxwc=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtIU1EcB/CTEWputvlYvlabWk2T0pW21PTrs03n3MOKIkK0kaWRhT2I
oClBihaF/lMJJQWrrKhEVEQbRS8joawMUqyGQaZm0mOVaIa/88fuhcvlw/f8
zj3n3B9XWbTPbPVgjFlm7/9Pfsk2tXbeKQ3HnCZSDYPKD01SboaeVu+gY21K
shc8JzWf7u7klqAvUDd2U8QdgMEG60BPh4IcBGNskPPdFu4wRO/QSJ/dX0pW
QDW/+Ou5UO5waLUj3V51S8iRUNj1innDcvJyWOWuc7e3cquwwjPqb9G9MHI0
Ij09NrtCuWPgfB/TkqQOJa/C8GSLxnE3hByLj9Wufski7jhsSNTFhRcGk9Wo
KhurtfcHkdfA3vzq7a/RxeS1aGwbr5V7c8fjW5vZEpEiIyfgrHz36HlnIHkd
nJV+qvJibg2KDFFXp0Xc66Ed6e/2rQ0gJ8LypqbupdyfnISPFxLi39X7kZMh
iYkL7Z2RkjfAlTvsVanneQqyuz7vwQuep0KZtqvm4LSEDHwZWHFidRXZBtSq
rQMXCnmeBt21W9eXNS6iPA0zzDRTWEFm6TCWRT/7Eczr0wV5BpqTw0tUD3h9
BqSjAbIJmS/lmXgjri75bRBTnonnIRMjDZKFlGfhp7ijcipeRHkWrqY9ePgo
mMazbGxbeVbbe8SHcoHZRogPqJP6qvj8G5FRMJWwIJu/XytYn9Z9P0yHK08v
H/KpoPE2nft8LMd9PluO+35YLl60v/7+1sXXl4uux4njKifth+kF6xeY5Qny
PJQ+ae/u6+C5QTC/wCwfHoroPz7N/Pzy3ffDjDDcOJ1lbaX1wig4LyPK0s90
+TbReIdRUG9y/94wCfrBBJH//cPlnyl3mNzPm5khLvP7Ur2fxsOM9b2dlx69
5/VmJKv1J30LqX8dZkQZIgKy9vJ+trj3PyyY+59R/9sss+d9csh1nOwQmBWg
3jpRv91ORgFOtXiv7B7i9QW4Mxly8WiJP/4BXSpMGg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n8s1HEcx/GvsrK05ff57Q53EimkIz/udeFwDofJ2Gn6cWut5KYsTEht
lVYtp1ms0EJmjKQmVjqWsNRq1B81Jb9qs06syaIf83n/wXf77rvHnt/P+7Pv
D8HBzAT1Oo7jZP/O/1c6rJLaO1uPOWNFekmJwxW/SRMyh5u1V4eXWwXMRvjz
Yva6KJVsAoFVtfX4Ap/ZAv3qeOmDcrI1ircUinSBZHu45XFuo0+dmPkYn5Ee
brcgO8PcafS1/rgjsyv49Qq+wYQDswhDg2O8ey7krZjq6qg6lGTPvA2DGb3F
vc12zJ7I7y4QDlmTvVCb6e0iirBl3ontF2IaGgZtmL2Rk3HNPzuR7IM+acum
MZ01sy/ygmpCklzJu5Blk/FuppDH7Id9dZU+yZvJu9FQNdnikWbFLEbFgNnj
6mZLZn+c6tDxe+TkAJg1DR/VF1gw78F5w/4Bo3JyIBYXQu+c9iQHIZHzH2o1
JQfjzO23XVafzZlDMOX+I9dbSZas6cD+i7Kvwb3MRUCb5uRcag51KaLbZuXx
YupS3BAupXBV1PdCdc439f20GetrzIUiPHg8/9Ui9VB4yyo65C+ph2GvV3pZ
VjrND8MjTV2KlyXND1+zfzgWoieMzipovQwr/y/Nl+GNpNSQ99GU9Qh86Voq
8hBTj4BWrdeq6ml9JBbubiwYl1KPhGZkTndAQD0Kxuub8r5p2byiKEzucPY9
4U7z5XBo/D2iElOXQyA9cil72YT1aJhNd+saE6hHI2Cos/r5J+oKpFQ01Vh6
MhcpkOve90sdRz0G2e5l2tL71GNw2Uf9oTKdeiw6bctudXynHrt6Py4OkuR5
Vawd7R+HJyrhM0djej7l6vcFJX6WNPPS5ul+5er3063EhiSDNn0PrY/H4MP2
hiwN+z6IR16ux9SI0AJ/AffeGHI=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQNioVt3b8xWcoDwPth7F8reKOOF8RkcfleltUhu
U4TyORze7FwwSzcRxhdwONvG3VsgBOOLOATcM5yhtksBypdwUFvwVLEsEcaX
cTA3Y909mQnGV3D4UNX12y9ZHspXcrjs2qfJdUAOyldx0FrQsaxKD8ZXc3BY
bGq5sVYWytdwWPkj/IL2ThkoX8vhXRLL3Q0vpaF8HYepvpdt5H9LQfl6Dlm/
Hqf+C4bxDRw2T6rTmzBbEso3dEhVNWS0Oy0B5Rs5bGJY1NAtAOMbO5zWzNsg
80cMyjdxYPvAf21iBoxv6vCv6Lsq51FRKN/M4UPg5f6pZjC+uYN2v9s5p9Mi
UL6FQ+28y3vEHgpD+ZYOS62MTyyfKwTlWznYGPm08yUIQvnWDievqXz5zQPj
2zjkOE3Yy7eQD8q3dXAO+WPG6gbj2zlc3HH1y40f3FC+vYNx79vvjgc4oXwH
h4mPi6udvrND+A0OUPcwQ+UdUfkNjg7czGurXk1mhMo7OSzffV3slAwrVB6N
z+DsIO/haym2Cibv7FBV/+tg9io2qLwLmn4XNPNdoe79aQ+RR+MzuKHJu0H1
f4TKuzu8t/z1z0nvmT0AEX6+9Q==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIU2Ecx/HTCtSWl5VOl07dCtF522Zmpsvf1E2nLjK7jqaWrALFSgw0
CY76JopKCSQSCgtyopgio0zEFzGpQMGkaRBJYo4gaPPWCmsV/p8X7sDh8OF7
Ls//PLJzl45aBBzHZf87/1/ZIT5uGxmslmNDrpwm4dbLriBmDtED46jqkZH9
kdWqmujQMIdg6Lv7tfJDLDkU5vaKuPt3mSOgeGhxX81kjoLD7pzdwjHH4llk
3/N3xTFkOQYWRILVJ9HkvegpO6FPmpOS41DSdDt1ScQcjwLccHO1UWQF0t7o
2mockeQkGPy4Rz/AnIJtiVaV/9xushLtDc6KLgmzCuXOyvqAexKyGt6O4ar5
zxHkNJQrVleqY5j3oXGw1BN/LZycjotNn84/FjDvR/NX2di8QUzOwETeKckX
Txj5ALpHZsRvo5gzoTS3do9aQ8kHUTFjK59uYM6CM2GpUXVkFzkbiVKx5MLZ
nWQN1m72h5tXRORDkPauO85kMOfAy5V6K+uDyYDoW6jYJQ7aMA8IYhW/hL07
qGvR6RD+fJoupK7FnqIOh8m6nXou7MvBZaYrdD+fi7XA4eb1dPZ8ns/783BL
bfnYWRlCPR/Jonj3gykyn4/lPy9Pt/ixrkNgnTpruiWQug6H++7oLDYyp9+8
Xl6PZE3KsbFF1gs2my9ATW7baFAXrYcrhFX7yj4uYb0QUy/er8x6aF7OANfQ
1O/rYQHUDT7zFW02X+Tz/WKYEtsLJxvY/yv26SU4aVL318lpP/gSGPXj9gUN
m9+IxVR5Wm0C7R9vREiSKnLSK8JfDLfnlg==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlXtMVmUcx09Air4Q95drchMiYVAgF32B9wsKcn25315ur2xvEOgorg5l
Hh2tmuHkIjMxa9aEhCgC4jp3BGFQ4RY4sLSwaM2ojMRASKAav+ePc852dvbZ
9/k+z+/5Pb/zexzzihO1OhzH1fz3/v9ljzylZ7CzyAlbtKhMWV7y/tqIMYeL
TYaVa12OxPqoue92xvIwY2NEdo90Cxxjc2RfMDWTtToQW+HS1HTVeipjO9zs
UF8ZWrEndsBh4772Wn/GTmjY0Cvua95FvBuyuIepscvPE7uiOylY4RXO2A3f
Lqz21r9jR7wHrXYuWu2sLbEHqicV4RVyxp7wDA77oTXfhvglVLypk6ffZ038
Mqo7Z8+r8hl7447JI+tXy6yIfdBj/cvc4zlL4r0o93fV9mgZ+2K/62d32mvl
xH6YuF3zRvmEBbE/cmd7cqaPmRMHQP3orp/LuhnxPkR3/RWV4M94P8oKWq7H
yU2JFZgfWufd/RkHYkpZr2f5vQlxEEwfCMNtiYyDMWjT+F7/n8bESuy7NfjB
2H3GQOTHHddcLhltMQ+Y/G4uX5Q/R3oIDEu8FdOnDUkPQWvIyOiYNTEXii8W
z3nZTNJ4PhQfTXxYIStj/gNi5g8gNnxs9Ocgtv5BlA/GBwY8YfpBcTxcGAzM
hitf+5XFF4ZNLmFTU8b0cNhazT+oq6f5+HC0BToVuI0w/RDOeGvvNWuYfgif
2rb3TkUzPULij8Bv916o8TrN4ouU6BLmoiR6FBxD8t8u32B6NJY2BjJOb2d6
tCQ/MeL98DGS/MZixvCtglUVy3+sOF+cSpIfleT84rBs2H/qqa8B6XEoGu+7
Pt0vIz0eave6iFvHiBEP56imGXXrThofj8Wub9arLXZssRCPVY/6Ey1HiLkE
eHTpbfM7u538CaibLz0eukLMJ4jHCxKdS8T4aFBl2YA++RNxrka3by6brZ+I
SZvFhUZjYkHCXJI4PkiYT0LzjGz1qi/tT0hCZ0dxo2cmrcclI03t3VHitKnc
8kuYT0Zpm0L5+RWO/MmQ6X5StdDwDPlTJP4U8Xheogsp2Oq3OuRPlfhTxTqf
ipbBWfmXds/S+hKdS0OM/8neeU9d2n8adBz2rMnanlL8aai+PD0k/5F0IQ1V
J9duFF3bRv502G9MfhWwSPlEurg++HTxeQgS5jLE8yMDPrV/rIQILP8ZEn8G
RpeMktSvUz1yavH5QC2uR14trmdBLan/THG/QyYmZnY//seAmM+k8yIWMnHV
Oeq7vcPs/8wS90dkiXU+C7e1yzvc+pk/Cy+qnM3DjrL+mi2eH9n4qdnP924D
9Wc+G3njTgM+PPVzIRvnXdYzuPdZf88R93vk4OHRm3/7LBPzOZRf5s/BRdWp
tfmd7P7IReiNpF3u9sTIFd8nfC56lK88OXGEdCEXisKSC5pu5tdAVWp8vGmU
2EGDgEKld60l3VfQUP0RazR49+zlwuEKC/wLadEroA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/GneU07YqnzWtMlZWbLvOal9nM6r1OXoMLylSAZs0QlAsVc
BpI1TWsmEgYmpGhJS0JlKVZU0AUEaVISIYKGEWqgpkhW7P+82DlwOHz4nvP8
n+fFCSmtLCiTMMbU/+7/T35JC59ZzHo5bFpRerUWdzUJ3AyDgktO40AI2RXT
M73nRrO5PTFiuuFg+RFM9kZM4o5fsZHbD5NrOsdjh7mD0PDpS9iVLhk5GAUv
3Uo1cwfIcszqSt7Uq7lDkdx7/u3qpf3kQzC+Nhf2LgaRwxDqIin6HcgdDlnk
k56qskByBCQlRZ+/jwSQFfgQt+hW+NWfHIlf3Yr0UYH7BPwD9eWdF/zIUWju
yHCSTfmSo2ExtvXVmaXkGPTPvurotvqQY2H0nbq9XsUdh6lH483XrN7keGQu
zUx43OQ+ics+99ith17kBLQM7z468W0fORELx+XRF4/sJSfBEmDqHlv2JCeL
+iloK8Lfr/nzfhoVqrZxjx4PslJkwCpcL9/ME2w2AEJ1VNJ0I5mlYF0Yu7od
u4d6Cj4GrCyZPN2oq9DUrk+sk7lQV6F9vqZOtUFmqTAPVZoUZ12pp+Jg9l2r
rp9/nybqaaht2HqhH3CmrkbEsKNzXCtfX23/PkuHJr5hZF7hQD0dfZYZ6bsg
J+oZKNZFDVXLd5S2niHqmVhO2PqjUtA8g8gsC7LM3ATpAL1vyELNYJLy6QNG
PRvuDo9rl+7sos69apvHcmi9dZovMtMguuXnRsrkJnUNJMHhW+6D29Rz7W3I
tT8Py0P9/enn0jl+/jzR/vJh+78l1PNF59fa7x9a0Tyt/XkmtbT/BZp/htZh
7C/88RHr
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2EYB/CTmpcUM9Npak5HlqnM+7y3x3m/bO7iFLyRRgQustQI1PJo
ZUmZmUKRgiTCQkuwIZkiTKE0NUgqy1YYTSQMl4mhjtSMPe+HcwZj/Pg/l/O+
27xLyuSnzSiKyt99//8kL45yYLhfxQOTVoT6GOGYux0xBW0+N9s7NN5oa1gt
LJ2rkRA7QF9A/inK4IV2glm/r5PGB8SuYG1I3c5NIPYA+2m+XfRnLtoLlgfq
hl77E/NAkqMbK231RB+BuyU/5uOHDqOPgkHtf/+KLbEvFMmXuqeKPNB+8Nd8
WzPV744OgPEEjaDKhpgP72fFb8sz3NBBMPhqzjvs/CF0MOg6z1xo7HVFh0CR
3581FZc4FJrfOdyaTndBh0GIS2dxQQMHHQ6JHd8cXzQ6owUQVHhVPfLYCR0B
olGFpz+XOBLyVnUCn62D6CjYLK7YqhsgjoZH3RPOzbOO6BgYGb8xv1FLHAvf
2wXhulbiOKhfKGlaeHIAfQIKrLoeuicRC2ExkBd67jgxwM8vx64F1juYTAPs
ULKdk5X7MY+Hi8PS2MgNe8zjwczLz2jba4e5CGYGP6x92rDFXLT7fNEGXz3J
E5imE+CN28pSm8M+zBNh4mXcpcoha8wToarWOKrqscQ8iWk6CRpaVNHVXCvM
k6FFX1EtWkfTybAZcK9GfdYG8xTW/BRWngqhTcvr8Vo0nQr9fWVt/Hysp9JY
+9OY86h0CNBYWArukP0sUxmsPAN+RRm3RXxyvkxY0cxsXXYm+zNZ+8XMelrM
Or8ETP9fM8wlUNEbI3zWRWGexTSdxaynpMBNFUdxevaaDCzTUubzaKUgux3s
b3HdAvtlTIOMdV8y5n1pZcz5lJxZD3Lm+Wg5qIc/ciY9sF7LMqVgngcUkBlR
+1zPN8d+BXO+VgG25k+rllr3YH82qz+bdV/ZkJsX0lfO2xGa+lk5pWT1K1n7
lcx9WiX+3jZN86gczH+bDCzTOfj9Lwr/AQAydpg=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0F1oUnEYx/Ezp9RyulnObJqprLS5WbmcOud8pnPqfGkMhV42ooXDWiwo
axCDLCijUfR20YJYVOCFi61ojSEpaxeLbqK3FUXQGwYxSi+0ZhIVPv+LnQOH
w4fv+R3+HFnvwa4Ag6Io07/7/5NcAv9k/G6/HIpKm4e7HshmeMQUBHIVb90T
MvRycGT7RUctxJXg3Du6Z/iTFM2Hh6rBd8kIsRA8rtlOhYFYDDWPDYMfIuvQ
Uohc94b8cQlaDnrhSE9rNXEN9HVfNLQE16I3QPYC/5zyvRithK/yxPwND3Et
DPUwy2fPitB1oNXEKPb9arQaTi8zS7kK4s3ArnoVSl5Zg94CJU2q6adlxBpI
K+YkrH1CdANEYy/f/FxYjd4K4z4mM/NdgNbCft0AN+wnbgTG1dHfjnAVWgeq
OWH29kc+Wg+3vpzqtfYRG2DH7keOndtXoZtglz25Ij+xEm2ERPf6GQmbuBnY
pXeOfbvMQ5sgFIwmtglIb4HUJnnDwEbSzVDPU2auPatEA4yLxqaeuyqKDgPM
c84EF70c7K3gHTtvC0yiw61g9RUaWe1c7Bba3gKcQxrji5Nkb4V6k9qXTJG9
FY7EO5v1v8i+DRjS2jw7Vo69DXgLfEFaQLqN1m2Q40yfKGjRVDss1l0aih4o
w04zZYdo/LXgiZiF3Q5u3fGpz+pS7I6lDjvgcMxovneTwu6EH4b8H4s6Zy52
J/7vEuwdSx3uwPMWiu9TLtreRetuWidOYffg9zPYPbTuxXNQ1F+APOZC
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQNioVt3b8xWcoDwPtjv2rNz+nIBGJ/B4UrqN06N
nYpQPodDglCtq3ocjC/g8LB8R58OC4wv4vC0xExNaJEClC/hcDv0n6GPK4wv
47A8ZvnJezfloXwFBw3m5PczpWF8JYcJEfYx9ilyUL6Kw7ufEhwSp2WhfDUH
17UztBbZwPgaDk0y9YITNshA+VoOPJkyC/mlYXwdh9jUlY/tCqShfD2HWxFy
aTP3S0H5Bg6vHl/4IS8H4xs6NK85JBwaJwnlGzkcd9zA9eiQBJRv7OA2m/Pj
cm0Y38ShxPiYbelZcSjf1KH/skD3GS8Y38zhtGbeBpk/YlC+uYPZyqBYr2oY
38LBRZVP574gjG/p8JR12rft00WhfCuH5Nt79ix/IwLlWztUX63kZUiA8W3Q
+LYO5xIjPn6+KQzl2zls/CQ1vyoDxrd3eLznb4O2uRCU74DKb3BweDTbzPT2
ZJi8o0NJxvJ9/mIweUcHSHqByTs5FFz7fChRESbv5KDppyzimisIlXd24GZe
W/VqMpTf4Owgu/rPtRhzmLyLw8lrKl9+88DkXRy4Fv+IczsKk3d1uGQ/iUX8
Lkze1eHHEva6J44w+90cfMzrtz/Wg/qvwc1hqurfSIb5MP+6o4ZHg7tDX0Hp
quhgEQcAkM64/g==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQNioVt3b8xWcoDwPtgnvMnKkhCG8RkcHhzTErHc
qgjlczhIthg0vAiD8QUctH9ofbzyVwHKF3G4zmH3iW8+jC/hcOzntkvTbGF8
GQfpVov94UfloXwFh5fHp6wulYHxlRxScv9t8kmTg/JVHJa1Gsu9PCYL5as5
yGYpOzeLwvgaDovz5UWW1MlA+VoO5fuMnc/vl4bydRz4rG8ozFSF8fUc8oue
nM9dIgXlGzgcvrjrOxsPjG/o4PzeS72pWRLKN3LY/2T9/oemML6xw+HlW+aY
z5KA8k0cwtNW/PjFDOObOvSV1TfZ3BOD8s0cbh/fcut6MYxv7nBVIydx2XZR
KN/CYenUYsGdDjC+JRrfyqG96kjFjzkiUL61QwyHVMMMSxjfxmGq6t9IhvnC
UL6tw7vcI1+Nv8H4dg6/fjgvKteBqbd3cDoYLKctD+M7OPQVlK6KDobyGxwc
oj7dNlP9C9Pv6PByWpHjWnsov8HRoVx0NkP/Mpi8E6r9DWh8Bmc0eWeHjZ+k
5ldlwORd0ORdHLIj2AOTp8PkXR2ajofH/vKBuc/V4XfhgnrfDFEHAFlurBU=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU1EAx/FppZWamvPtas4eunzlzMw0fzrddD42TSHLcj6RZQ/CjDLy
Mg2FMtSGkDQpQ+3hKhPx7cJpBYkwwZBeIg3TkjLMMqms6Jw/3IXL5cP3nnvu
Pfe4Z51IzjVlsVjiv+e/Kz0cUtt7Wo/y8F9z4Yoy03p/NjULZ6vneCk97sRr
8X64RqlJp7bBiLzIOm+ZS8zGpLo2M/sutRPO101kTKZRuyFdm8O5YEbNRVut
+7q2jM3EPFRfqypid2wi3gK/Yb2GP8Uh3gaOwkNYak/tCRPVfD8n342Yj5xF
w/WqBldib3SWMvWcDy7EvhhqN5/VyKn9oYtnZ6Q2OBPvhNRN3hnIoQ5AwHKO
s/aGE7EAwUMlxfXdjsSBmNyRO2DhTb0LQXeSD0uKHYiDMOZZkNnUYU+8G4Vd
A1ydhDoY2a96e5tn2cR7cMtwMUuYRx2CIxWimbBBO+K9OCTWrl96uJE4FJcq
G7dqVtEehsYQwbNmNe37oDRkVRpabInD0eOiUnd9tiEGmjwkLwMHiBlgyo8n
OO5F74+Aj63nlzo97RFIq9PctPem4yPhE+abop2yIj0SwpSfQWtEG0gXrjQj
xAPXlo7ROGvSo6DvHPs6vmhBehReWFXk/0gkz2NFw5TLX7K4Z0l6tFEX4XaE
buiJM53fyCyx0fuJYWk3cObkDJ0/BrIC/vMFZ/p9MXB1ejddXUO/LxYfX28v
81PSHov5391pSnPaJTjtpbpa84h2idH4uJXrycQhNCC+fIOcrm+80frHG61/
AkbDa1Y7vqHjE1CY39wvdaD/NxGivhkF9LQnou9p+cRiCe1SpJcKDo5PEzNS
mKWatM3paJet7JDBoPAK+VVO9hMjw6djgwuCb8SPZVAzY+es79P9loRIX7nq
lJwYSdjPCh5ptSX7l0nC2wNXyi9/Z+MP4cUYmg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQNioVt3b8xWcoDwPtgvTp5q4SEK4zM4VD9W6dyx
QxHK53AwChW75xUG4ws4MJiWf/nKAOOLOGzrFg5cuUIBypdwmKuycrmQH4wv
47Dw7o/QqvPyUL6CgxTTlAdsPDC+kkPKu0tKrEVyUL6Kg/F8zQT5jbJQvpoD
R8qjqUvFYXwNh/65XDtd02WgfC2HhRuuG1RdkYbydRxO7f838aw8jK/nEGa8
SbMqWQrKN3BYWXrLfna/JJRv6HAv7GHlEW4Y38iBccKlfy8bJaB8Y4etks/u
f7kvDuWbOKyxXnLM64UYlG/qsFrwnYTaZlEo38whn/F32yprGN/cQfu4xNcl
D0WgfAuH+Otb4y5XwPiWDk+yNK3+tgtD+VYO69zfB5XzwPjWDtHu+7l+bRCC
8m0cmp4k9T5ZIwjl2zoIvThwaHUQjG/nEDlr7UJRHQEo397Bc+W6Vapz+KF8
BwcmBa1f3Kt5IPwGB4cPmy/+rRXlhMo7Ory3/PXPSY8NKu/osHFd/hS9aA6o
vJODzmYWNrM+dqi8k0Pxamv7TYsYoPLOUP3f7CHyzg7GvW+/Ox74CeEzuKDy
G1zQ9Lui8hvQ+AxuDuFRRuuKlP5D9btB/fMHar47Kr/BHdU9DB5QcxgYAISf
wkQ=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd01tIU3EcwPGTl3RMzaZbzpbNGbbNsbynqe23Oec1t8QSKyQMQ5hozBsu
tWkZBUXofBiKXcyyUrt4IZxGC7O8vKSF0VOtdZFKUiR1Xiv2+z+4A4fDh+/v
9z+ch+OfW5SR50BRlPzf/f9JLtaRvoEnah7YNCvpubtmLvUipsAg6D0e2OeP
doXHFRNHWZnEnuDY290yPs9Fe4Nva9f4tRvEPnBfM8lwUxBzYG+duSnTvBvN
hRHFhpMxgJgHtPJKA/uCH3oPNPrdPP31wy50IGQYf8kDxMR8WLEKqz31HLQQ
gn9GcacXd6JFwMjxYI5FEotBzSkKN8T4ooMh5/vJEpqejQ4B9R2tb5mIOBQS
Hn26WD/ogw4DRTNtrj2IOBxqLc81NUriCFh6Ss/ijOxAR4JavPJxcpSF3g/V
Im1z4SwTHQWWGgb/zCniaHjT+ezy+Slv9AEwBclmOjXEMXAi97NFNO2FjoWX
KlOzzshAx8FSm0v1FynxQXiXt0Dj929HS+DbPl5YoYAYoCOWl88f2mazDiA+
czXSWeGBXQqqAuH4H7YndinMrxuza13QlAyym7puMUWky6BC8NqapyQ9HkoF
jfqGbtLjN89Tcrvz5dA2eruMXkLenwD3pEPDr9ju2BNgyv1SvjUdTSlgwb2/
ZjXCDbsCZnsm1qqYNOyJYBU1VLYXoHWJMDIcV15idMWeBPWW4rOyRRfsSdA+
8J41xnHGngyHr4QEOdU5YU+G39HL6zLxVuwpYPt/HLCn2O2ngvbc8gv1A5zX
pdr1NLv9NKi6/naQZXbEfgjojl3aH/ot2O1MpUPWsdCHGt6GxNbTIezqzKLU
ZLWZUoIDV7hM71jFroTijhhJdyuF+6rN5wHxHM6r8HsXbDapcI+i/gJ7Nw/W

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1FtI02EYx/E/Ol20eczmIctzeAjNdC613G9zHuZxS+1iJpGkUQsrRAi7
8G8HLyItKztYaASVqUhWlqKGEZYpChWaRJmlFZmZkM00Wwf2vBfbYIwP3+d9
/88YzCd/35YCK47jkv69/3+ylySnrbNV7wuTZuU5YdbllSJmDr/6fXq23/Ih
L8PQGYjrspkd4edQOy00eJNdMCnjd4efZ3aDURV3p1vJ7ImdY1P3qj94kb3x
PqpXPKJi9sX4kfHCHa1ryP6IFEsrBqdWk9ciYCF3tAvMgdgmLpReafYkB2Oi
vq/vj4B5HdRCrn4eq8ihGHv9adfJCx7k9VjQ3VVM2zCH42JtqXSuzp28Ac76
7Fe2M27kCPill2zl85gjMZz7Lvqz0ZUsxdOaZu2XQOYo7JEV2fM5ErIM12qK
nTqwkrwRVftLGnOzXMjRCPIXTs4nrSDHYKLrNx8icybHwnC8xTVvzom8Cc/l
pwWub5g34/BkfuVkM3McPob5RhQFMcuh2Rs88MPdkQyob7Y0Blx2MJkHnKZd
JLMSe+oKdD+JmQmcEFNXIKO5KqGgzY66Eg2KR72P3cm8Er3fHbJ0B2iei8el
EdHCdamIejwMdh3lS1LWVebzvApW3sGLoibWE6ALqU4eOsjOJ5jfxyVi0GN2
6qzjcuqJeNY+PDf6k/Uk6PvaH7zoYOeT4JdybkTXQPNcssV+yTh11Lr9bR7r
angZBwc2zrL71eb7cCkWPcViv1Tz5/Gp5vNcmsV+aRb7p1t8v3RUVOtjDnkJ
qWfgRudLSb+nDXULc5koLVt8qG+0pZ4J7YnwEMExAXUNvkUvGpWh1KFBmqzs
/kSoNc1rYPp/sDK5R4Piplj57ascndfS77UkN53XIqLy67yiZ8FkXkv3G+R/
AQ+OJy8=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQNioVt3b8xWcoDwPtjbiM+YISUA4zM4XJuQ6Bix
RRHK53CYz2znOD0GxhdwsApKlFX+pgDlizhsm9NoLtwP40s4sGY8lrxhBuPL
OBwM1rVW3igP5Ss43Nn2TFVTAsZXcjgsIiWQ5isH5as4aDn4z1m9TBbKV3O4
bvnm1IPrMlC+hkOH+TcBX20YX8tB7NaqJu9GaShfx+FruBdD+GspKF/PobHy
bbmiNIxv4JD1p2nrkUZJKN/QQSg75BbbOwko38iBccKlfy8bYXxjhyLJ3Otv
68WhfBOH3T0TlldvFIPyTR3kPXwtxVaJQvlmDiaXestVd4lA+eYOus+lG7hY
YHwLhydZmlZ/24WhfEsHbVkxyfREISjfyuFK6jdOjZ2CUL61w26pKXN3vheA
8m0cSjWnTJ60Cca3dfj8b1dkEzuMb+fgHPLHjNWND8q3d1jhePjoMUleKN/B
Qdlr2rWoFVwQfoODg85mFjazPnaovKPDxnX5U/SiOaDyjg4THxdXO32HyTs5
LN99XeyUDCtU3skBkp6YoPLODkwKWr+4V/+xh8g7O7y3/PXPSe8ZhM/gAlXH
wAAAJwOUdA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU2EYx/GTRIkpeZ33y5aariHNlZaX/Hmb97lZYsYyW4iRWqaJZQqT
UgslKS9/WBY5SssSNLupyDQVw0StUIiIUkstEosMUScVvc8f7sDh8OF73sN7
znn4qlMJaQYcx0X9Pf9d6eAlPu5szRDgvxaCnLPyP1oakjk8tTN/strAZzZE
wDF+5lEp2RSids2Y4qsLsyUSQ01/VJaSbTB8wb+2WEh2gFXxkPBevTOzC9JK
72bkzDkxC1A4MDolOUB2RfS4w1BJkyOzOyr6WxM1Mw7MHrjhhbdjB8lCtMdz
Ktdqe2YRrBwPC/cbkL3wrNNgJHezHfNOFLVO1MjSbZnF6MpNXvF5YsPsDV2f
c3n7O2tmCWorT2bfLyHvwtUIa6+CCR7zbjxWFqQmZZJ9kJ7xJVRrQvZFz7aL
HpzAinkPVjUb+TOjlsx7Ics1PV/bT/aDdkfI9wc5ZH/UuOmSuVsWzAEID5wu
HFk2Zw7EHT/JYGM9eR/EHfbbJ/PIQahKW6hSNpKBpZjPhsWxzGqgW+nW47SF
ejDMZ7W9zQlmrAfj5bjrrxVjZi4E/OD0y3lrpqyHILfZP6itgZkLRZx0oH86
kHooyr3T3l9PpR623uowmGSaf7t0mno4kuse3rYSUQ+HPFM4tGhLXQpji978
7LmtrEuRdMi7JUfAzEXo9Qi9/UfqvV+k3v6i9PYXhTzP6qprbdSj4di8Oq70
pfXRMNIspUj76fkxCFOf1YnLqMfgzPHG7ngefd9YbErc8GjhBX3/WMx4/jwn
ltP/jYNqUNAhUTOr4yCW1j2PHqb1svX3q2UQLVxpeVpJ6+NRJytenjJi86OO
R9HNN128T9TlmD7h6acrY4YcStXklGiWnifHfFbfouQ3s1YOmyNdr69IaR4V
6+cXCqhknk1rxmy+1QoELPZ8qEhh1irQbDZv4/6I5j8Br6Y0Ogh5+AO0TiNt

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlXtMjXEYx991IdLk0nG6UHJZqkWhq5zvCal0OZdO52rG1rDacr9Eesfw
D1FhbsvcisLksiKX1yWFZVrENDPLMBsOIjX39fxsv9+7vXv32fd5nt9z++0d
vaDAkOsiSdKqv++/L3tUposNtXnB6COnZkLW57pLasYSurzVG/Jvjyb2QF3s
pmP7FjL2Rntq092nAxkPx8OyupbrF4KI1Qh70zLuRy7jABxNeN7a4MU4CPV7
v1bodYHEwWhfqC4/UjGKeCwmvjq4ONmH8Xi8iNYUnDWPJA6BSXFNlI8HEIei
9HfHzrs9/sThSO0vHeoG4wh0tC0Jyb/lRzwJe1Xvm+dX+RJHoujk7hh7IuMo
nHpkWdthURNPhseGHf735o0gnoKL+yu1JYMZT4X7ipFhxfUq4mh8jOv9lRTB
OAbbRjws+7bUhzgWJUtWVtuNw4njUPvZ71DhomHE8SjPdZY7qoYSJ+Bq09YX
34sZT8PQt8rNGsMQ4kRUjkl7NuWmN/F0rJ3Q1JObxVgDjbnLkenP7AFdfuj9
r76ky4B1/+nDPuHMXovW+sddT797kq6FS1Bor2fNINKTYAsrTXmwhukCSzNw
oN2zp3Iq02eg8ctgo20p858Jr2VRCW0bvUif+be++A8hnUyfhRPaW413fJk+
Szg/GYG/Wu7HOgeSnizEny3kPxt5zfXX2i6x/FIwefv7bq0ygPQUmlc/0lNR
1fBEdS/AnfRU9ISXra/KJ3spDYXFvTfyqsleTkNRRdsV1UtX0udgS2le/LrA
/qTPQfh5t37RJcRSOgJTMuJU1Sx+Oko7l69L6mZ6Bs9yhpBfJs9yJp+vlCXk
nyXE1/E6dHz+ssCKDstrEjTnjkjkr+cZeqTHFNd1RjB/PV+food+W2SY22Y3
8jfwDINwvoGvTzEI/TPy84DAshFj0va0207QfihGOM+3/izyYfPLRouf890u
b9KRjdozBbsi7B7kn833S8kW+m/i5wsTn58ssGIS+p/D7w9yhHkJrOTw/ZTM
fHyYhX008/UoZr5eycLfT1iE+2zh74ti4e+bZBX8rWhuTFy94jLrn1U43yrM
z8b3AzahfoEVgSW7sD929P3PXMhfYMXO76fkgNkWdWZZ8G9Nn78Dnq6nC9+V
f+pj2UF29CgCS3NpH16T/9z/+h+RaeKo
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCwBWIQDQNioVt3b8xWcoDwPtgrv9fq0+aB8Rkcss4v1g/d
qAjlczikLwlluhUD4ws4VEx+sdr0twKUL+IgFmZtXbQIxpdwyD1//LKHLYwv
42At87eu+aY8lK/gcHMH67FH8jC+kkOM8Q5O4XI5KF/F4dup+H9P18tC+WoO
SncXP97wVQbK13DwjNlypT0KxtdycA5YpBw5SxrK13GYy5FQeemGFJSv53BW
6sOrKQIwvoHDjQ8LFu8tloTyDR24DyjY61dLQPlGDjILcp+H7BWH8o0ddvdM
WF69UQzKN3FYcfvw1LnXRKF8UweTS73lqrtEoHwzByFu8T3P9ghD+eYO2RHs
gcnTYXwLh6mqfyMZ5sP4lg6Q+BCC8q0cuJnXVr2aLAjlWzucvKby5TcPjG/j
EDlr7UJRHQEo39ahdHeAjcUPPijfziE8ymhdkRI/lG/vsOTk4jLuEpi8g8Pe
41bvNB7zQPgNDtDw4YLKOzp82Hzxb60oJ1Te0WFCC/OO+7EweSeHiY+Lq52+
s0PlnRyq6n8dzF7FBpV3dpD38LUUW8UKlXd2COwx1GZpZYHKuzj81JlUszwH
Zr6Lw8Z1+VP0ojmg8q6o7mlwdXhv+eufkx7MfDeH5buvi52SgZnvBvXvf3uI
vLsDk4LWL+7VfyD8BneH4tXW9psWMUD1ezgY97797njgJ1TeAxreH6H6PVH5
DZ5Q+79B5b2g5kBBAxqfwRtVfQOM/wyq3wdNPxqfwRdVfYMvmvv84OoBzyDr
iQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2EYwPHjpVmppTlPpjPntbIx0ry0dO7ZzW3qtBl9CQMzxXJFHxQF
83KEQiqzTFJMMbHApSWYXTSDLMPoQjHFDCprriTCcJbYtqxV7HkJz4HD4cf/
ec95eeGE5h3NLnClKEr19/73JBe959ZQnz4MnLJILlfb/C56EVPwJMesHesN
Ra+Ek/zgn9/3E/vAeInBpXeJj+ZCg7pZUXuBOABGbbfHmsTEPPCzTtyPMYSg
+aC7pugLsm1Eh8GjTf6ls1riCNAvWK8udAajo8Bhr4l4PsdDb4Z3TH5Rz27i
aBCPPEt+fCgILQCTpmrxqyMQLQRhinLKUEi8DWZbzQcGb25Ax0BHiyiqNoc4
Fjx4+Z/EZwPQ26HNV8Ix2taj4yCqYtI4oiKOh7aXkRrOKRqdAIX6GfmwN3Ei
tNS3Fz0s9UfvgLixM2WRd7loEdit8s4yAfFOyMmbNgs++6GToO9b4KXyg8TJ
0Gyqc5maX4cWQ69qLrvMi/QUmG5NiH/TSLoErFc8qj5KiQG2ZIZzlUd8nWYA
RC+GOkY/+GCXwunYgretuWhGCg5K58gtWYtdBr6zXNpCr8Eug0XvwZqleC/s
cjAOTCy8tnpil0N4WtOrvYbV2BVw7rjbwPt9aEYBNsH5iq7Dq7ArwdJv/FXp
j2aU0GAuPib74YE9FeZE9t8yIQd7Kmu9CgT97pyEepxnVFBebX+g78Z5Sg1d
Q5P0U94K7GrISKy+Yxa6YddAZfv4PdqEZjTg6Xa9/EujC/a05fNMGuv96aye
Drq6mK3uJ9yxZ4Dz/3PFnsH6vhZC1FoR3U32p2X1TCjuSZLc6KSwZy7fL5UF
rvxou2fPksTZs5bPU7vw/GacHVhmWB5mmdKx1uvwfOZx/f/+B2mrLVg=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwA2IQDQNioVt3b8xWcoDwPtjbbovZGyYO4zM4HMkL435/
QBHK53DYqHCtLDcHxhdwWC7E28ItAuOLOFy+5O52+oAClC/hMF3aeSJnDIwv
46D7R2beE0YYX8FBv2r1Ru9MeShfycHIr9p810U5KF/F4Yz9fY7nzjC+msO/
K1Mm3JwvC+VrOLC6/X7p/kcGytdy2P2hZLoyM4yv47BlXXOHuJM0lK/n4Lzt
1STTbiko38DBk895R9BESSjf0GGTY2fTz/8SUL6Rw8RFzBPe2cH4xg5PmbaX
TXokDuWbOCz7u0JebY4YlG/qoH4vcGEpK4xv5hBvZst296wolG/uoH1c4uuS
hyJQvoVDYI+hNksrjG/pMFX1byTDfGEo38rhueanSsMAGN8ajW/jMDn1w+SY
5UJQvq2DgI6h9Ln/glC+nUPxamv7TYsEoHx7NL6Dw2obpQyNw/wQfoODQ47T
hL18C/mg8o4OKxwPHz0myQuVd3Q4+pk/OKqQByrv5DChhXnH/VguqLyTwzfe
nY1/TGHyzg7ZJ3bsu7yTGyqPxmdwQTWvAY3P4Oog+EZE7IMY1D0Nrg6luwNs
LH7A3Ofm4LemzzV1K8x9bmj2u6O5z91h9jXun8tMYfZ7oLnPA03e0yE8ymhd
kRIsfDwd/jME/k8ogfIZvByWKXvdMjkEDc8GLweuxT/i3I4KOgAAWojT8A==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02lIVFEUB/CXWYrbjDqNS1Zmq+Y6mlpZ/icbl1HHWRwqLbNEjdLcpmzD
hvYFog/hhxYqRtOyJJMsNxq1SS0qwjIpI2wjM2LChNECKzr3w7wHj8eP/zvn
He67d+6WInWuDcdx2r/3vye7xNo7rQ3b/fBf5thfn7tfCwTMHFy0hmdFt+eS
7TEaEnp12TpmIQa+x+VkT2EWoeNKV5DdBV+yJ4ILZmfelzH7gLMtf9PxdA7Z
F2rB+qZ4EbMfom08W7uls8nz8bb3U+qrE7PIC6HSVV5+0eRDXoz6scSKJQLm
AOzIH8iyLZxJDkTQbq+be1u8ycGoG5HmKyKYQzFgvmxoL/Mih2Gysjnn/ZAn
WYITv/v6G+KYw7EpuQ1tnR7kCFQPDvW9tIjJSyHxuLR5w1HmSJysyPK48XMG
OQq/XPJjO2TM0QjdeKimvVZEXoYGy+lhTzAvR3LjD7kqyp28Ag+UxvP6Fjdy
DKZrpzSau5hXQhgYNvPppCt5FRwMlqx4E3Ms3L4YO+vUzECMJOWYSzZZD5yS
5A6ezxZSLsXOVmVMtMWFcimcSyUr+g46U74aplGBJqPEifLVOHN46r13Gx0o
j0NDfdHZ4Ex7ynnm1qDHtLJc18JynjkZalpfiR/5TKNchsBG2+mRp+0oj7e2
nmcugdc/Af3Ox7eOK9j8iaiVdpkeepH1iZgnr+zPqGXzJ/HmT+Llcl5/OZ54
m7+eFbI8GTa+AROOdWx9kq2/x6XA9ZtIbBaz9U2xXk8ulbe+qUi6Vn99wQUB
5Qo4uXeWFw+T9QpU9Rp2OeqoH5fGy9Mwyakms3WsXgnnAreR4yX0v6HE2gxJ
fakfe18JZUHA4zEvyo08cyqMDC46HHKQ1aus++lVCHJd/OPcc1av4tWrreeB
Gnv8u8dz01i9GvHtw9vwnPanUQ1/xTyRrJDtXw0sVXYVH6W0/6FB9fLwnpqL
ZL0GmQn3HSZukY0apEQduPshmJ2ndDQWl41m7CYjHYaPR7bE5dH506fjTmye
ZX8B2ZgORZlwX6WJnU8tdM2dvl3yGfgD6shPrw==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H1MTXEYB/AjiSRu3K5elbIW3d0pKt3ofivlFqX70n1Lm+H+oYywJtGc
yctsknTZvGRjJuttZCQXHSPMls2KzPyBzFYbGi3ckZfd5/fH+d3t7O6z73l+
5znnOec3f8M2o9NHEITN/47//+ynKr7hvlYeA69GdZcqSgfGApkFvNg4kDaj
az55Gs5Ybt+OKGVWwNimiL35J5qsRGfdevfwSeYQxJgT8h4kM0cgJCW55ml/
FDkaPfG24XehzDGoLzl7pL5yHnkB3MrwyxlvIslxaHo7W3FAwRyPj7VX68at
EeRF2PTjw7njF8PJalgGJb9IJbMGZZ4h54QpjLwYI/tr4+Z0hJITMdESmVoS
ypyEYVtf1eeqEPISPFTu2h39dS55KU7Vb61oOcicjG+eR71vXqvIKRArdWPa
OOZUmM65wqsTg8nLYNPXK973KMlp+FC2UPv78ByyFl0Vl+2aYOZ0NDpHG9c1
zyYvx+me5l3FauYVGHCO+8d3B5Ez4A5zNXV/UZB12Nmaruu8yAxYHUkdO2Jm
eS0CgTuS0vv3B1KeiSuZD3ofhZLFTNx9rP0cPzSD8iz4RC/yBLSSxSzE5p96
6bgynfJs/FSf2Nu8xZ/ybBxqKNfuiZpK+Uq5Rc5CDprdg6qnEVMoz0H1Ps/9
8hY/ynOxJnVf15BmMuW58L7PPpSv4vJVdL9/dN5cjyV1n75nSj+9FvVcnoeA
ye3VI42TqD5Pvp6Qz/WXz11/NQxHExN8D/pSvho15/vvqN6x+jXy80XOQoG8
H7GAywtpngLVF8r7FdbKrydyForwJc0zkaWh5wnOYhEahnbuyfpO85CKcK1j
m0tTMo3qDegLGx1xKWjeMEB93dcv5Ribp0E+L8nAzdcoXx9G7nka5f1IRq5/
k9wwcf2b5OtJJvk8BDOdP+59vjBz74uZqzcjSl+QpmohC8Xy+wNnsVh+vxJn
wSI3LNz1OUsWrn8rRq8//10TTN8XrHh+68XYqx8BVG9F+ZNb9/q7yZKV+35t
8u8XNjgSGvTPqli9Db3fZpkc2ymXbChsO5bjvMH2Bzuyzb9SpuTOpHo7t5/Y
YT/TfiFYTfuNZEflQlfjiU62/zgQ2frr5brUIPwFHyat2A==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WlI03Ecx/Hpo5KOzWPONt2RDkkp59ZcNt1nHnPuwYRZ2TGXCnZMLKPV
tEj+4YPoDlJIwQdBNqEVaE7Z1tRMaAQGXWo9iEoCK+iYR3Yf9Ps+yB/8+fHi
zf//+/H9y2v222qjeTye9s/zd6cl3OwL9tQp8E8fDcvfHR4eiiHzcMsRUiq9
cuYl2PVCLz5fRuajdcjgaZqRMcdjy5i9PbmVLEKc7Ys3O58sgc3aphMHpcwy
+C43PB+IISsg5c95BpDCnIrr/jvrtM5kZiVeTenkil4Jczr6+/Zdyksir8G5
hV/dKc1i5ky8jtzUDfeuYl6L9siyOlEsOQt5uaUqRVUSswqTgkjSXpeIORuj
8e4mWSSRWQ2/ZFt9OI2sQfDMBc/RHiHzepxqdiR6ZxOYtTi2w6Dv20TOwc4J
n+NRYzyzDh3W41+nYsgbcL9666eZp3HMuagJKwJqjrwRKlOH3zIWy6xHV646
7Okk56FhfGakWk7Oh2uPZ7BMSDag6kDlt3vTAmagiGv8oTrBzAFXV1ueaUb4
rBthqJi1W8XUjZAbd5889JN6AZKvfR+351AvWNQLF32/EKbQGyce0PlFeFw7
vzTdT70ITtdCf1QF3bcY9hb19slpZq4YndyTIytv0DxM/8+PMyHVHXVR+4F6
Cd7Xj86p55m5EmRVtnhC3TRvMwpul6dkSOl9M8xvJwZXnKZeCs3Ds+60APVS
ZNwVzV15Sd2CQEPm5/Jo9n85C7raDgr8SMBvChDUQA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlntQ1FUUx3+8RMMHJG6mCItGohCJKE+FLwiIPGRhFxaWXdhnMpJpYqNi
Dr9QM6ZsJB3HarIdJkVFMHI0itKfjZY9ZEad8FEONExgSEXZKBDaYzi/P87d
mZ2dz3zvPefee77n7g21ry90eUqSdOK/7/+/6kdTdLqjrWouxmkopVJ394Uj
PipLOBN8q9GjNZR4Ik72ztsbmKOyPypv/jbYd09LHIh13UcHDh5UeSZGDYfq
bbEqB2GdfWt40nchxFqYlKtlGV4qz4VxQWtS1fxg4qdw++uf867XzyF+Gsm3
nhuw3QkiDocufnL/mkSVF8LiOtabvGE2cSRyb38wIf3ELOIoeE7aEV8frvIi
rB2rO33hlSeJo5EfZG1fMkflxegZCS6qWzSTOAb66InSTf0TxEtw7P2+DyMs
GuKl+HvqmpTzGTOIYxH0Qwn8GwKJ41CzNaK/K0zlePgGexsuXJ1OnID+BX9u
jdapnIh9rqF95qbHiZPw9rmmzUWRKi/DWXPY+WA/lZdjTvNYlzkugDgZ6fKW
h9G7VU7B3R/n73y2zp8YMJoWt26cO22cZeCZ5VGGc31TSE+Fp3bhqF/zZNJT
UXWp/ey1T/xIT8PenV7t3ZbHSE9DzJ5fH6Qqk0hfgZBHl7+NH1L1FWhrXb8/
qmwi6ekIycpL0Bz3IT0dTR3XNd8EEUsZ2H7o2mean7xIz0DBG9ER3ru8Sc9E
Q2/1trQHvqRnYujUlYfbZ6j5V+LyrKGB/f5q/pUYiXzr5abnVT0LvyeMPkqL
mkB6lpB/FV5tqErcFqLGXyXEz8ali8s3b/qU9iNno6Z29HzVcYon5Qjxc5Ab
V/txbxTtR8rFeP95kp5L5z2WMq7ncZbzKN590ldT/f4hfTX8vFpqBvb9QXo+
je8jPZ/qM0K6jseDjs+XdTy/okN1c1LKR40Srb+AMwqE/RTweikFwvkW8vqi
UNhPIV+fUijk1/PzhJ7nk/U8vqLn9ZQM3D8wCPU2cL8qBkSe8p4Q+6Y6v4jv
B0WCn4t4/RWBpWIeH8WCn4oxL/tAl+ko+Vcp5v0kGbm/YRTmG7lfFaPg/xLe
ryjh4+USXGn//q8bw9TvSgnvd6lUyF/K/S8LulIqzDfxfDDx9ckmvh9F0KUy
fj4oE/ZfxuuhlAn1N/N6wCz4x8z9pZiF/rfw84EF73b5jRxZSixb+H4VCy7e
m6Y3vUj3qVSOlzp0y+KHp9L8cuG+LUfXlNcqR1bTfayU83xSBddRAVNEQ1bn
FjV/BV+PUiH4x8rvc62V67DyeFYrzy8L491W7idFmN8j6JKN10Nr4/6BjdfH
KrBs4/V123h/Kja6zzwov024P+y83lq70M92fj9Y7cL9IIx3C+MVO19vj6BL
Du4nrUPws4P3j9WBgMFAzZCG/CI7sMIwFuuTSex2IKGzw/1lD/2/Kw5Ut52s
19XQ/3+PA2bfxndmZ6jvASc2dN37whZK7wetE2s3DZ/xMBLDicHppa779cRW
J17fczisxYveJ7LAbifMO2JMN+7QeMWJw4kxl5reI+5x4vOvdncP16rvFZeQ
34U9pyZFnO1W87vwy4GNqS0pFN/qgl6K72wLCMS/0nnkMg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQNioVt3b8xWcoDwPtgfWPxUTVQQxmdwOHfxclPP
MUUon8NBQzZexjMfxhdw+Fn9bc0+LhhfxEH6Bcdt+9UKUL6EQ+a3M7HTPGB8
GYfY9OsPcn/IQ/kKDhlai5S9HGB8JYdCAdUPJnPkoHwVB66JZufOMsH4ag7V
6UZsfA6yUL6GQ/Y5Hc6iiTJQvpbDqdX8Z/Ydk4bydRx2NDfMk30lBeXrOUwX
st2/7rEklG/gcPm4DPMtdhjf0IH7gIK9frUElG/ksDJrroTOVnEo39hh6Z2H
l6/+EIPyTRxcUx9v7pkB45s6xJvZst09KwrlmzloRVsc3ecP45s7KLLcffD5
jwiUb+Ewt+FqFf86YSjf0sFwl7T6o1IhKN/KgWvxjzi3o4JQvrXDbqkpc3e+
F4DybRx83Y4dfWIL49s6XOPtyPjpxwvl2znsPW71TuMxD5Rv76DsNe1a1Aou
KN8Bld/g4PBh88W/taKcUHlHh/eWv/456bFB5R0duJnXVr2azAiVd3KApB8m
qLyTw/Ld18VOybBC5Z1R1Tc4o6pncHEoXm1tv2kRA1TeBWrfN3uIvCtU/0cI
v8EVKv8MKu+Gym9wg5rLwAAA5My1lg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQNioVt3b8xWcoDwPtg/Pbqb7YwIjM/gsL151WvV
g4pQPoeD6GpTLrMkGF/A4SCvrYQ6N4wv4vB5Rv1r2R0KUL6EQ0Tl7EL9OBhf
xuFtxu4L11/JQ/kKDt32NydJG8H4Sg5zyotKM7PloHwVB4dXDtdCF8lC+WoO
nxOWzDXjgfE1HH7/1KoTmCwD5Ws59CbbS/x9JA3l6zjk1/inuvrC+HoOiipG
Fz3PSEH5Bg4Mk9u7ZirB+IYO+5+s3//QVBLKN3I4Fbf+0z5zCSjf2GGh0hyZ
gk3iUL6Jw0R3cb2q62JQvqmD0iaOWUd9YXwzh5l987IOlYlC+eYOwXOmSFcZ
wvgWDh6vru/j6xaB8i0daudd3iP2UBjKt3JwtX1Sc/6XEJRv7RDTbBx14wWM
b+PQ3btUdS0zTL2tw97j7fd/1MPk7RxsjHza+RIEoXx7B0XH9M7SfwJQvoND
eJTRuiIlfgi/wQGo3+qdxmMeqLyjwzfenY1/TKH8BkeHKO2JHucquKHyTg4T
Wph33I/lgso7OfzUmVSzPIcTKu+MJu/ssHFd/hS9aA6ovAsqv8HFAZIemaDy
rtDwYIbKuzoUr7a237SIASrv5sCkoPWLe/Ufe4i8m8N7y1//nPS+QfgM7lD+
M6i8uwM389qqV5M/QuU9UPkNHlBzYcATzgcAso7Ebg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtMlWUcB/A30iVy53ARFJSD1EFAAgIFEb5wDneEcwXO4bCZcRZLk0sk
Mmp7Ix2al0iUCiuR0tSMag3lIvAqqagTb0lulTZtVKYOhx1BQar5e/543rOd
nX32fZ7z3H77Ba0q19scBEFY99/3/1/28TF19Hy3WomnGk0O+jAi6bEbs4CR
e2fbk74PIs9CX1XGzAELszsGqs5uyXdg9oLK41iDdt8C8hxMvldfMq1hngeP
0doL2y/OJy9A/9uOf3i6MSuheyt5sK48kLwQvdXXcz2HAsjPY1bpzV37fJlV
eGbnWF9A2TzyIqi1bcHmlrnkcGiu1z1RXPUnL8ZnrbHmlVHML2JYbLF3bPIj
R+FCaWbuKwfnkKMRX5C+Z7MTcwya319bcWijL/klfBTf03z3hA85FveP6g3B
ScxxKN9W66do8iYvQebtn/pct3iRl+LRuLqtJpw5HqsGld0xooKcgDsKs82+
2ZO8DDd3x8X+3MSciI/7v6wxhTMvh0ZcPxXV4EFOQmhesFfa68zJsH2636Gu
lRmI8FDdb7nk/tQi8PcvL2yIrCcLKZgWdNMrq90oT4FLVfSyK/UulKdi97DT
xP5YJ8pT0bjh2c4bJbMpV2P1YGfflS6WqzHssqlsIo/N1+BAysDJU35kUYM1
qY29rntdKU+Dxx0vn1EfspiGL858vs6pmuXpvMV0FFqi26uUtF8hA18lKstU
A2z/Gfx5hExo1yw6948fO38mzC1f7/UOZ+fPQm3o6QlbPsuzED/U03rqN5Zn
Y+xJt7n+OZZn8+OFHP7/xBxkHWw/FPIJWz9Xtr9cHBltjPQ/z863gre4AnmH
t6fZOtj95eHkmJvBUulMeR56TyfcU90iC/m41Hn1wbVxdv/5CM5uHrYcYO+j
5Q0tLGEfZA6tZ+O1/HtLWtn76WTzdfz7izqc9x+9vdOdLOkQs+3uwxTJkebr
ZfP1fC7qYXfpemcyls4j6WX1YeDfGwbZexj4+5UM+Gbu4aOXc9j9GxGxfLGx
f4TOAyN/v6IRb/ZoE5eO03qSEWrjZNzMdLa+Sba+id+vaOLrVzLJ6reArw8U
yOqxgB8vFfD7EQr5+0Ahn4uFfP1IMgtFsvlFcFacqKn4i9VjEUYilTFrQ6lf
SEU4M7zwwWNn1j/MuJy8Y4bvr2SY8aPN7qjqIouyXDKjzxpyPNCJ9SsLwgJ8
/F59mQwLijP6Zz/6lixacOvYlBi2hCxZYH03xnLtTza/GL+/Fpow1UD9EsXY
FTJlFvaQxWKkHjcEhs2n/ioVI7DrjSMN51h/tUK3NSpsxkbKYYV7Q2XpjTay
aEVc0w9lWZ7UvyUruivCHxocWD8v4XOUYKvvxR32Sm/8C8L42H4=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WlIFHEcxvFRs9RF2zw2dc1jMTFX11zvq31cr1U3W6/MpAxJkqI0tSwl
Wu1FFmRFveigYj3RTdHMrCzUJNLKQLQ1Al+EpBFK2guvRCv8/YlmYBg+fOeB
Gf5uuQWpecYcx6n+3H+f7BJldHa3H5NgXbMK37nKwWYxMwdDWsA9bY8b2Qxa
z/HlfZnMQphc18mkRsy2ECd7rLXrXMn2cLzk4jsWxuyEN4Nh5vUzLmRX2NTr
q37KmSUoaasNO3zUmeyOz087Hq80byN7oE9VfquBY/bEhbKKYsVeJ7IXVEW5
L4c7xWRvVA0dF510Z5ZBaDpxeXO2I3kn+tW2ORk1DmQ/VN/+WF6qYpajvbXg
pizbnuyPRv3op4XpreQAvO9Kt3B3YA5E04PJNukBETkITYVDw/nVduRgBE1P
jj/cxByCX1ZHFH2xzKHIGes8OHLGlhyGsrPSKcN25nAo+9KcpS7MEfCZEmst
NjBHQh18vmtCZkPeha7ChiyZHbMCuroBu6sGazKwmPTVrEJN1gIbM4w6ZvtZ
j4LQ20/8YW0L9ShM+kr8T+wgc0pEyNUXrQ6xroTApKXs+w3WozGaN2/u+Yz1
aFh/632lT2U9Bll3WnR23kLqMTjVrYkIWbSiHgvLInn4SKUl9Vj4RMrSeybJ
XByi01eCTOPofW0c6gZrTwtK2D4eT2av+ToOsR4Pg2VV/lIy26tw1yBYaggU
UFfBZXXoXcisBfUEXk/g9UT4X5lZiOo1p56IgdeRpSXPzagnobF7TPTWyZR6
Es7dH3kh+mJCXU3nRdbyzO1G5n55a5FkTbHeeeaSYezqtSzQr1BPRrE+XPGo
hqP9Ht6eZ07zv6Gh85uj93nu1eBH6PKqUjZP+xT6/yXap/D2KfQddPX+829j
uRoU
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBWIQDQNioVt3b8xWcoDwPtjzTbW0K2OD8RkcNixT3X1u
lSKUz+FQsXp65SYfGF/AYZ5L7MIzHxSgfBGH5Jfiad7dML6Ew6kU601rbGB8
GYetcxevsz8hD+UrONzZ9kxVUwLGV3LgLK+ZIdkiB+WrOCh/eLDvyh1ZKF/N
YcvVSQzO1jC+hgNX3bEs2cUyUL6WQ9ihK6+vC8H4Og556TfiWHKloXw9h79p
0eXLP0lB+QYOdU9WeoqpwPiGDrUbr0/1S5eE8o0cbqRPyV+3VgLKN3bonOrO
Kn9BHMo3cTh4eCnTtUgY39Qh6jxv5syHYlC+mcPO05HbwiNhfHOHeDNbtrtn
RaF8Cwe/YoHqaUdFoHxLBw+vnlubImF8K4epqn8jGeYLQ/nWDtsLlkXqicL4
Ng7emz96BZrD+LYOGz9Jza/KgPHtHLp7l6quZYbx7R32Hm+//6NeCMp3cEid
u4ypeoEghN/g4HAl9Runxk4on8HRYZmy1y2TQwJQeUeHUs0pkydtgvIZnBwS
CmN/n3oB0+/kUHDt86FERZj5zg6GbrN2ep2F8hucHU5WutikqMHc44Im7+Lw
eM/fBm1zmH5XNPNd0eTdHHo3c2rvuw/T7+YQfK2z55IszHx3B50Pfeu290P5
De4OcR1uL22PwOQ9HHSfSzdwsUDDu8HD4dcP50XlOrDw93ToKyhdFR0Mk/d0
mLvDJnryOpi8l8O9iL72nu8iDgD+/NQW
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd038s1HEcx/FvZZJDUuRXDqX8ilA6+fXy+47DHemHyVSztbJQSm1ZX63F
tBBqbcwfURmaYYr046YdWsNoXTVbVoxWU5eKY9KPeX/++N53u3332PP747P3
fb5OR7KTMldyHKf89/t/ZodVSkd36wlnLEsbWps+oZg0YOYgK+nNrqx3Ihuh
ZYqv3idnNsdimyYt97sjeQPq3Lrn/G8xW2M0ZclHHsVsj82SgBtDjWKyI47W
v//8eNKB7Iwim1lJSCzzFky923bJpGATeStmRkIqU3rtya5Yl2XYVePK7I5W
3ubT6HE7siesO9W6nm5bshcKz0/nO9kx78BM3UGV2NeG7AOxTO1QWWtN9sVg
TLrolz2zH674PHR4o9hI3okPHpk9Ik/mXagZcpEZlliR/SGWxgdYNVqSd2O8
0MI15yizBAekZeYfn20gB0DlET7dfIp5D7ZP2fHGBsyByLes5sruricH4eq1
Oy73VzEH43ie7sGK/RbkECz/v8yhCPKVF5llrCMDZ9yqKivazJfNA5Pezn4n
3VgPw+mmwNC226yHwTTL4ktxLpkLx3m3vvnMRNbD8YdT/snIW0s9AvHRveqJ
YNYjcKZbESTRmVGPFJqPxANtubftAOtRqH9Rd1aUx7qeuWg0hD1X99qYUo/G
if7Op6+6RNRjkOpxXTp4jszHQNs+/LvAcg11Kb4FLCyFexlSl8Lv2vRcmIp1
GcRLAy8lWmPqMuHzuFgM2Go/V5mzHovNsTc1qQ1kLk7v/jisdHRfEDWZUJdD
Y1p8bD6BrV+OJ317vrqOsx6PWdOuwsVdZD5eb30J8Gw3MPQvXU09AeWXV3WO
HWLvT8S8Z8WFe1l0PZ+IfnVwft4jI+oK4fqgZ14hvF+l0Hu/UjhPKIXP55XC
+aiUGO58/fOtjs0vSTgP6JlPEs5HlYSE5tKozA4ylyzcD0hGi13zw5E42n98
MjY1LWrSdtN+ViUjR/Oj57AT+x72/pt30ZjuogX+ArueS7Y=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2EYwPHTVjlZiZZu2mZuo7R0ibrKUuce5+b9MrrZ1eZQu0yJLLE0
bXTRDzpLLQRpEZoa0xYxpaViChkqfVEppZvUVkQXWWU5N6XbnveDHjgcfvx5
nvdw4PBVJ3bk0CiKkv29/z3Jxdrd2X1fLQCnrJKkCrvp+ApiCrLKL166o+ej
GRDNp2cUJhK7g58u98fGLzy0J4TQ3zCzGoi9oa7yniAzjZgL6ZEtVbppPzQP
JipU9doAYgEM+YYrDDvXotfBC5OxY07vi/YHhrVyfRWfeAO0W/uqVQe46EDI
tlluXG3koIWgYyjPjk6sQQdD757nFn+HDzoEHCKRgX2MOBTKfNnN3997o8PA
h6M+Wp9PLILPHbrJED0bvRkU0x1DJhnxFhjLe/VwMJuF3gpPzU3zEEgcDm0e
U97+Ri/0NuCZva437SPeDg63I5J+OXEEcF/uBfcaT3QkHB7vzBw7QxwFTZbL
qthcYjHYbbGNRULiaJjKf/xT9Gs1WgKlN8d6WG+JAYTWasODK2gNgDRYea1A
SXoMaI2uQb2Tq7DHQGgXJ+BdIZqSQo6uhVZyywO7FEYltUvZr9FULNhuu5RZ
Ysh8LDRHiAZbdWReBuaeeU1QOOkyUJ485Bj+SOblEBWWUuGmJPvlcMGi0lra
SY+Dgy6NDRw56XGQGvdkwCJ2xx4Pm8TBux59WIk9HkZMz6YnbEzsCTArrD3X
mueKPQEGB8RFp7sY2BOhtXucNcxdhj0Rvx8dexKU16gjSvxcsCeB1TgyX+qF
+6jkhdYkg0j7dSamj/QUqDGfKpHOkPmUhedRqVB83t6v1i/Hnrro/DRg0u8W
f6pbgn2RqXRw/t807OmL5hVA4wXamW1zkv8EBb7frNMaBWTsDzMUCH473afA
/d8kfwA8Yhui
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mlIFGEcx/Exs8sjb9e0XI9MbZV089b8ravruh67a1mYBWZJgUVpSUmE
QxAqVKCGhhKYhvRCg1qsVVE88kjRMFMiqLT1hVHJSlqumlT0f144A8Pw4fvM
zMN/xjP3YkbeJo7jFH/Pf1d2OGe2djzN98J/GeN099uvBNkzcygQv2183uVJ
3oZ9dT0OpWeYbaFuD+yUb2V2RMUn+GY0iskiVIvXpJeUzO6Ibq6bME56kMUQ
H5tXFkcxe+H63mvely/sIfvAw+lrr7JzN9kXp4e1ERFKZj80G7vv5ma7kwMQ
2zpm3dTkRpZgzKHe1mTYRQ5Cj67hpXkA8wHMJpSVzJ9yJQdjekXPtZSIyCHI
yTpqqsl3IUvxYsTFYi3HmXwQcsnka/NbTuRQ7B8ULT2acSSH4YE+JrvqCXM4
TuR+NkjmHMgR+FJdKGuJY47ElkwznbHPnhyFnIKTq8NzduRoxISkltrkMMfA
TWSYq6i0JceiyP9eVeUz5kN4NeWzuGrF1sch0M5voXacdaDYf9CUpybzwGNZ
X/+AqzV1GeqmLE1NoZbUZZDe+f5L1r2dejyMuvHfN5zIfLygy+GxPjoSYdxB
XY5x/eTiu2V6HpeA/h87Dx8vsKIuMJeIzsGoeT8D64mYsi47Z0pn+1NAfmQt
zEJhQ10h6EmC/Schf0jfNdHG3q+EdWFI9MRNWs8rkVXb8tBJwuaTDE/Z2fKi
dTaf5I3z4lTQnA8YWXJlXSWYf8rGefMpaPJWvT/Yy3rqxvV8quD7pG1cz6ch
TTHQPxvLerrg/nREjnXUD0yzrsabuMrNLh/o+/NqfHPIyvtZzv4vDYIVtW2q
UTI0qJm5bfZxgcxrkKJbUGnD6f/sFpjTInfIq13Kk6HFyrK84arEEX8AQz0d
pQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAWIQDQNioVt3b8xWcoDwPtjrHrZa8VIIxmdwWCgxofDh
VkUon8PBQy9sw7UIGF/AoTZvyj8TJhhfxOFue0rOlLUKUL6EwwGv6iTREBhf
xqFf7gdHxDt5KF/BIVhDhrnGDcZXcmjb6Sg7q1oOyldxON3x/PLz5bJQvpoD
d9J5r9hrMlC+hsPv9vr7a0RgfC0HeYMNCwtTpaF8HQdFFaOLnmekoHw9h3kL
TCMTDGF8A4cFMy3V2mMkoXxDB9f1D9om7pGA8o0c+r4neOReFYfyjR2CDTkY
bgbD+CYOs1YedP66VgzKN3V403duk/0lUSjfzOEp67Rv26fD+OYOJpd6y1V3
iUD5Fg7BDBbnNgrC+JYOmwuKP0dVCEP5Vg4F1z4fSlQUgvKtHXZLTZm7870A
lG/jULza2n7TIhjf1mGZstctk0Mwvp1DeJTRuiIlfijf3mGF4+GjxyR5oXwH
h2+8Oxv/mPJA+A0ODhd3XP1y4wc3VN7RQdlr2rWoFVxQeUeHD5sv/q0V5YTK
O6HJOzkY97797ngAJu/sIO/haym2ihUq7wx1LwNU3sUBkv6YoPIuDtzMa6te
TWaEyruiqm9wRZN3Q5N3Q5N3R+U3uEPD4789RN4DTR6Nz+CJZr6nw3vLX/+c
9L5B9XtB/fsTwm/wQpP3dmBS0PrFvfoPVN4bzX4fNPN9UNUz+KKZ7ws3HwDq
rfNJ
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQNioVt3b8xWcoDwPthPX8b4PooHxmdwMD3yOjlk
tSKUz+FwxrZLL8YLxhdwEGe4dHXeJwUoX8RhnecSbf35ML6Eg/pcDtlqTxhf
xsF6zezLH67KQ/kKDoab+/MyOGF8JYcn1YZmR0LloHwVh4D33+yfN8hC+WoO
IY/X6b1cLAPlazj8LX9QV3xVGsrXcgjYrqVo7gzj6ziszBb9t2KlFJSv58B+
83zKbSYY38DhxocFi/cWS0L5hg57iiN/m22TgPKNHDYxLGroFoDxjR1ylySx
t+WJQ/kmDqc18zbI/BGD8k0d2D7wX5uYAeObOXzcHhSsbAfjmzs8bhTSKEgW
hfItHCTi91zqcxOB8i0ddD70rdveLwzlWzn0bubU3ndfCMq3dii49vlQoiKM
b+Mwc//y8lAdGN8WTd7OoXjj+s6AKkEo397B8tzuBcceCED5Dg6+bseOPrGF
8hscHHKcJuzlW8gHlXd0YFLQ+sW9mgcq7+ig7DXtWtQKLqi8k4POZhY2sz52
qLyTQ2CPoTZLKwtU3tkhPMpoXZHSf3uIvLMDN/PaqleTP0L4DC4O7y1//XPS
+waVR+MzuKLJo/EZ3KD8Z1B5N6i9DAwAD7C2kQ==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQNioVt3b8xWcoDwPtivXvHBtUMAxmdwOHK8Vnbz
HkUon8NBYpPGg8xkGF/AQf/4azaHfwpQvojD3OIVGWZrYXwJh4ULpzg9i4Xx
ZRwWMTzaw84J4ys4ZD7ZVDU5WB7KV3LgFdzCOq1NDspXcVi7J7B8xW1ZKF/N
If1zgVOzBYyv4XDz1c/tk3pkoHwth9ae4JOnD0pD+ToOm1YcT2rSgfH1HNjT
dp66WSYF5Rs4rCy9ZT+7XxLKN3Q4n+Lhk7xSAso3ckiIDPs5PVscyjd22Dpr
mWMfP4xv4mAkPj8xpk0Myjd1eG/565+THoxv5tDccvjO9AOiUL65w4U1ezub
r4lA+RYOHl49tzZFwviWDuxyLCFHLglD+VYOkfGHPKIiYHxrh9Pbtq4sKoDx
bRyOBByY3bBLCMq3dZi5f3l5qA6Mb+fg0lDx17BdEMq3d/B1O3b0ia0AlO/g
IPhGROyDGB+E3+DgsMLx8NFjkrxQeUeH2de4fy4z5YbKOzpsXJc/RS+aAyrv
5HBW6sOrKQJcUHk0PoOzw4fNF//WinJC5Z0d5D18LcVWsULlXRwg6Y8JKu/i
4GNev/2xHjNU3hVN3hUavt/sIfJucD4A/qm2mg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQNioVt3b8xWcoDwPthfLPI8eEEQxmdwSKoXmmu1
UxHK53DYtVThakACjC/gIL7lEFe+IIwv4rAvXyhK9bAClC/hcF+u5vjqdBhf
xuH0d9XfN9hhfAWHO3dsVCwt5aF8JQe9C+5OXd1yUL6Kw825P58EP5eF8tUc
OFIeTV0qDuNrONQ9PmlVXi8D5Ws5GDzlXdZwWRrK13HYMC8nLEYbxtdz+P9I
edekKVJQvoFDDPe+iNnCML6hw/NnRwW+KElC+UYO8bkb58+4KgHlGzssX33l
xvc34lC+iUOP1b8053IY39RhHs/0bSJXxKB8M4d5pStuGSjB+OYOp3+96Gpb
KgrlWzgk396zZ/kbESjf0iHCo1/g0X4Y38pB97l0AxcLjG/t4KSXMKUoQRjK
t3EwdJu10+usEJRv69D0JKn3yRpBKN/OQdNPWcQ1F8a3d3h9R71Fv0kAyndw
CI8yWlekxA/hNzg4bPswQV/qLB9U3tGhdHeAjcUPKL/B0WHvcat3Go95oPJO
Drq2eiH7n/FC5Z1QzWNwRtPv7MCkoPWLezVMv4vD0c/8wVGFUH6Di4P8v7On
LT5wQeVdHYx73353PMAJlXd1mPi4uNrpOztU3s2hdt7lPWIPmaHybg6Q9MwE
lXeHuue/PUTe3YGbeW3Vq8kfIXwGD4f3lr/+Oel9g8rD+M+g8p6o/AYEHwA+
8dUW
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1XtMU1ccB/CrIJABggpF3tiNDYHAeMuzX4uUN7RQHi0UiJkZyDIVWXAY
w5VMXdgmdphlgz2icWNCZVHmC8ZyEcgWCWTgBJJtmQIxk7mtxMF4Dfbo7/xx
b5Om+eR7fvec9pzf6a79h/IObOY4ruHf93+f7CUruN57tVoOi8yKMd8l56Tt
zByGfMIiY027yHaYHy2fishndsbJvMMZDxf9yC6ItKpa9W1l3gn9wqVfg8Ds
haHvmm6cGvAl+2HugdvsdStmOZrr3r2cq/QhPwfN3CfLrzd5k5+HUejr93/k
RQ5A04bvp/MG5kBM1Q872057koNx57SnXlvMHAKH5sTqvmkP8ovgWs40fSBn
DsNqRESXW5U7ORzrHd4xJe7MEUiS+ZtWBneSIzGaWma/4MUcBdOk94P2S27k
aBhT3ULqJ2XkGNiYnSaMlcx7MH3h+wJnD+ZYlEcn2vw04kqOw+rWlxX9Kczx
EIKUv5lqXMgJKLXz4N+PZU7ER/z9eqeuHeQkZHbPZ2himBWYbouO+qFlOxlo
nN3/zqxpm8U88HS9R9do60z5Xmxwmo2KWifK96IzQV4ZMEDmlHDYcafu8GOW
K5F+uavD/0OWJ4vNJ+OG+Vyox8hWyvfBsSY8/l6jI+X7UKQP76qRs/oUDD11
ytcfcaA8BYuOt0+uRZE5Fdom7Jc/i7KnXIVnM96b0H/+DOWpOPeG1a2fDWQ+
Fd8OJdbV9thRngbjzNHjyr9sKU9DcLe1TfRZMpeOEQ/z3HlnVp8uqc8Qm5eY
y5TUZ0ryLPwRu7KuDLGhPEsyfzbqG1b6qztYno323knZXa8tlOeIx/M5uNp1
6HxICXt+rng8n4usmIabMyFWlKuheTssyPqUtcVQ42hnvOLaRY7Gq7HZL3DF
vnNN8b8FNa130WJOQ/u1YTE0sLe6Uj/XsonqNeL5BI14Pi5P/HzkSebPEz9P
kIzn8mG5vzbT+vPhm5YdK+tg3zcfJz6+95XsIZtfYk4r/n2gldRrxfsjaHHa
WB133JftT4E4h8R8gXi8UCA5n4Xi84xC9H0T93vADDvvklwoxITjm5XLOdQv
XJHYKMK2Jy4ys4z6iy/Ca73qhD1LZKEIX3iabo5nsv4qxlvhB35sq6B+RzF0
rVcuuAaT+WIka9eit6hYfbG4Hzkdxm7d/3NqifoPOkm/6cTnXdBBH2RMGz1G
4zk97Sf7/nrJfaOH+pXA4QV3Wo+gF6+PK0Gp7cVWzxS6vyAxX4JHofKIV3eT
BUnOldL5YvWlUPU9PogxVl+KiiOG1bu/sPpS1Fa2f50rY/enATYFm7rNA2QY
MKgW2vgeMm9AmKr1dsYIWTBI7uMyzB7cHff3GTIk5stg62OtHRwnC2UIalaN
KofZfV+OqpcWjoW+QP8PKMeJEkXCl1oyX44nZ0evKcZd8Q+MogH0
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0VtIk2Ecx/GXuQ5oNCudztN0djBdmqd5qvbb1KmbOo8YohKVYHYRaXRQ
iFebF0UeqAizgg4289DMTE1CO4AYihdG7aIuhomCSTVKTb1wFfs/xHzg5eHD
9/3z8LxvwNFTOaUCjuPUf59/O1vi/L6XPSdlsMuqvJIu05mFzBy4Yd8b8aYA
8mbk1S/aQgqYXZHT5RrYb/Mnu8FgnlH2tDJ7In+gaP6jitkH0Z0S6/yMlOwP
j/aztVPRzDLkDl5bu33Rj7wTWrPPeN1jX/JujBWJDLELPuQgSLNT9lkUzMFY
Etc6lV3yJsthnFsy6D97kUORV2Ob/KBm3o8ys9/T3kcScjhsNwePfZnyJEdg
rKT753AMcyT6JLOWBYsHOQp9LUZVg4g5Gor2nGJttZiswETiYcnMsjs5BieO
L54P28McizeBhiBOxhyHhPKK5iPP3cjxaMmsWZ12Zk6A3NpgGmjcQT6A+63v
3BvN28kHYf+fzIdw61XbuXw5sxJnytqG9WJmoLKn+3JW1Ta7ecD54XKJZoTM
qaAZmivHJOsqlN41Cqrvsa6Gi9OTqq/XWVfDGKj9FPXWlXoiLuwdXSnVk/lE
pLWbOnbdEVFPQkFhhKlCRuaT0O3dNfBex3oy+q1NYV4TW6knQ+AfvOrSuYW6
BiO/RLmFp8m8BkOj8d+DpllPcXyfT4F0bWI81upMPdXRfCqaDE4vLMWsp0He
K9yoaNhEPY2+r4C61tG8FtlXw0OEdULqOkhTM+LEHRuo6+i+NqW9p+NH3Oqa
OnTWbj4dkfXffqter1DPQGVngvLZA47mM9b1TJpfovl15vTrut7xPC7L0fjv
P7U2Et8=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBWIQDQNioVt3b8xWcoDwPtjrHrZa8VIIxmdwuJYpOTFw
myKUz+Hg5P889ZU/jC/gMLXOgPfkDwUoX8ThZrWjr9gMGF/C4ZpHxo6nrjC+
jMMRffvZv47IQ/kKDvHpp6eEfJeD8pUcdMRaQrJMYHwVh7SYiZZ2GbJQvpqD
SIxkefRPGShfw6EpNGxZtD+Mr+XgeUnsZmmLNJSv43BOeIHAz8dSUL6ew/LQ
61tMc2F8A4ftm1utErdJQvmGDp6788U/M8L4Rg5xWl+/ZMtLQPnGDoe8V2hd
jBGH8k0ckvY9+PRvixiUb+qgtIlj1lFfGN/MwexTlIb3fVEo39xh6dRiwZ0O
ML6Fw1b7tB81OSJQvqXDkyxNq7/twlC+lcNU1b+RDPNhfGuHzQXFn6MqYHwb
h97NnNr77gtB+bYOkPiE8e0cHs02M709Gca3R5N3cHi852+DtjmU3+DgoOmn
LOKaKwiVd3QQenHg0OogKL/BEU3eyeGS/SQW8bsweScHw13S6o9KYeY7o/Ib
nB1+LGGve+IIk3dxiGk2jrrxAibvgqbfFU2/q8ORgAOzG3bB5N1Q/dfg5rDU
yvjE8rkweXeHyPhDHlER0PBqcHdQKWecbPYeFn4eDlWV2s+vqULDv8HDwTqr
aEbCFlh8eDp4vLq+j68bJu/p8Gcxi+LzCzB5L4fTv150tS0VdQAAWfzNnw==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQNioVt3b8xWcoDwPtgfzzrYXsAF4zM4JLY1t6xY
pQjlczjo6p88/8ITxhdwEGe4dHXeJwUoX8RBbuHR0IYpML6Eg0Uxy4Niaxhf
xqFuuuMPyS3yUL6CwxyeBdcXfZCD8pUcgr8F6dtbwvgqDr+3/29kjJeF8tUc
vv5KmaVZIwPlazjYfPozTfm+NJSv5XBUKLuF2xvG13E4YbC7pOesFJSv56Bn
53pvRTqMb+Aw/cjZpSG7JaF8Q4elm44u7rgsAeUbOVy/WnuqywbGN3Y4enDx
jQNJ4lC+iYNr6uPNPTPEoHxTh0WNPJuWBML4Zg5v+s5tsr8kCuWbO8h7+FqK
rYLxLRy0j0t8XfJQBMq3dPj1w3lRuQ6Mb+XQu5lTe999ISjf2sHGyKedL0EQ
yrdxWC+9Zvslb34o39bh6Gf+4KhCHijfzuHijqtfbvzghvLtHWZf4/65zBTG
d3B4b/nrn5MeG4Tf4AB1HytU3tGhbWK2VbU8O1TeEU3eyQGSfpig8k4Oxr1v
vzse+GkPkXeGqoOCBgQfAAi7mjw=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0llIlFEUB/BPQyzHNXXctzFb1Mw1UzP/M+7jVk5ijiliaK6Vkw8WCl8i
hKlhYgpqtDyY5priYEmahlIPGhMkIYkJIgwZTCjm2CgVnfugFy4fP/73OxfO
uW6511Pz9DmOE//d/75sCdNGxl4Wi/Bfmoi6VKXbpAUzhw/TS4/qxtzIB/Fr
O7vwew6zOaYqvr6X77qSrZDvqtUNPGa2RaHu55BcxuyIzOyFgIFlF7IrUowb
+hY8mEVQl4fWLBc6k4/AoK6pRfLRiXwUBjG/1bE6R/JxiOqvLimPMXvCxXfw
aVmeA9kbc4vDssVae7IP1BPx7W1aO7IvqrofBmeGM/tBUBd8q2/cluwPO4fi
gtZS5gD0xS2sKvSYA2Gy0aFO6LAhB2GkrVN834z5NIqCr5nyaUJyMLpvzKoK
7luTz0DW0exw2485BG+9JD96FVbkUIxE5G9VljCHQeKT06zIsSSfxZplRt5m
7WFyOIrKt5R66cznkBk7YbQ9yByB6pXchpVeCzJwItndKrqUzAOd7tKFwClz
ysVY332dUW1I5sWI7+5/4dFhRrkEXeJ30zN2JpRL0FhzYHQpy4jySMi9HsTN
VQgoj0T7vEDbGUTmorBp8uqOLsiY8iioRj9vfNlieTTcpS3z8i6qx0dDM6za
qbI+RHkMtN5Nlc9LyHzMvvqxe+vx+8zFYXrdTCYvY/fHQd/Vc1vQQ+bi9/2/
z5wUSk3jKftZU8qlsFizEmqEZC4BJ8N9Lk6ssv4k7D3PJSJd7t+vEFE/+UTc
7AmLGHrG+p+EkLmxJzPfWP+TEMVX7PjdZfNLRswbdRFUbH7J2LzXb5O1wfIU
jF/2mHQW0Pz5FMjma+s/ObH3cx7FlwwvXGm1xB8fsw+1
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtMjWEcB/ATRmRTVKd0v1EikluF8z3d1KlO535OHFR23GIVGWK8NTTj
zJTWplikSDWSy2hyZK5/2HE77nPpmJaZkJwjDPP8/njPu71799n3/b3v8zzv
83uD8goUhiECgSD37/nvSoen+lxHW34w/qtPNO+8/rJGSBZg/hVJvbgjiNkZ
j5729240kF1htK/imlzI7ij6vEkcdjaQ2QvPRXWn41RkXyxa8izm1JsA5kCc
iFn6+JKQHAx169mqvSn+zKGw13xvCmnyY56A9FH3ams7fZnDkW32HtPQ68M8
CZ++SfsHAsmT8cBsPxxfPZ45CnqXTl3NOPI0rLT4n25v8GaOxqOPnPOHbi/m
6QhIu+5feZgcg4B6Y9nETPIM5GRr7NX5QuaZKCkOKWgWk2fhSVXOwhazJ/Ns
zGpSLJZsIc9B6SHzUu9Cciw+xf74nRBFjsNeoblioMiDOR47ht2+41ztzjwX
9dadeYnLyfPg+1wH1/3k+dDnve2e3DOOWQTr6oi4X+Vk4EJhY3aUBzMHVBr6
KvXHx7JcjP/7g5kTY7jaqb3vGuUJfHMJuHyz/JVtO+WJMBxqHLKlzo3liVhd
bDvvpKU8CZF+nt4rcqk+CfdFFcOEL9n9gmS+uWTkFC0evNNDeQrWt53aLSuh
PAVT3MI/H7znyvIFWN8cLzpzlJlbgCDxit0bflOeiti7HXU3XlOeij3TDS9q
cihPw+aIm3ZDFuVp8PHq7tlfQbkEjSGSZzO6KJfgw4uJO6aWUZ6OsT2mrmYF
jS8dLkNbS3orafwZiJCGuCevpTwDSdymX9HllGfyzWXioWFgZPhFyqUO6yvF
bUto/+BoyrPg1/zTop9NeZbD/GX890PmsN4y/vNNMof1l/Pvh5z/fk7On79J
zv9eAoVDvcJhvgr+9zQp+M8TKFFmzTNaW6he6TB+JWzp75xLM9j+MilRaPna
lRtE+0/Fnw9U6NSHXfV3of2ogu3YiG1WMdWrYGwfGdn5iurVOHLslsc+CzPU
2GNsCGsdSv2k5veXSY33EV82R8uo/zTI142QL6tmhgayqXXBxV6sfzkNDkpL
f3SPYjZpoBTMudvmRv2thSky4WPLOmZocU603LZ1DdVroUvd5/r2CtVrUeA0
uOtkPP1PdFDWHvApifbAH4vviiI=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HlI02EYB/Bfbqa1Dstanptadqgtr0wr9btZ3tYudZv9EYUQaAdlGNrx
KzLolHUQVGQWaKd0UEnnOimjoKys/gtLTIrWQU4Lrdjz/vG+Pxjjw3fP87zv
+3tZ5JKV5nIfSZIq/33+f7NHXXz5+oWKKHjlznyu9QRkjGWW0Cp7vrRciST7
43zZqY2tZcwBUDgbdbFDmMehv1qxdGFDBDkIV9a2H4uPYQ7DIk9fLQ5pyRH4
9vlD1c5uDTkKNT/j35aFMk/C8iltN8Nrw8mTUZ+YGK7tCCNPRWB5ucmSxByD
pmTz69/1oeQ49ISmvj2hYdah9E63fkRzCDkeg8PrlhzVMidA8bKxI6MumJyI
DHX02f77QeQkFDTvsKlGMSdjW8JVTYdxAnkmhrpHv3YuU5NTsDGu5vAK93jy
LLhN7fUHUphTsVX5uM3/4DhyGvw0Suv9F4Hk2bjwPaShZhnzHEyb5PehN4d5
Lj4H2st/bR9LThecAU/BR//NhcyZuLUo+o5GxQx0zYhKWjFtjNcy0DQx/13y
3QDK9RgReLd61afRlOsxPV1nvd01knID8k61nI4+wnIDfgxcs2/xY/VZCA3q
7HbuJctZGJRMg4ur6PfSPL6fPA8n9fcePAxm/ecLuWApG1nWPym+2aMoz8bz
1lc/33hUlOfgaYi7Z3/AcMpzkLT7S6/eNYzyXDx6kF5ddc2f8lzEXVIOTdnj
R3kenJ1rag29ZDkP2oGnT1Ld1E/KhyPWmftsHc2T89EXt3d9cyXrX8D3kwtg
2pUQq6xTUl6IwlmbrnbqFJQX0vr6Mr15EVSKczU9+755LReh1JHYsjpqkPIF
lA+h+gXYcLT9hvo99ZMWCrlgycjPh5GfLxvhExHTrzrzx2uXkV+PZKI+9MAk
rNck1JuE9Zv5HGbhPMz8ebnMWHNmTubF4xLNtfD7gYXfv2yBNrcoTX3al+ot
2OasmF2rZe/XyveHVZhv5fu5hFwq5vtDsFyM5usd6rYwNr9YOP8SeP9/fai+
RJhfwu/XVSLcn1Jh/6X8ecqCXYIlG/++YePfj2zj+7tswv2yC+u3C/Pt+JrW
P2DQddF8u3B/HJT/ovmCZYdQ76C5kvQXkP6uiw==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2EcBvCTdDO7mLfM5WUry5W6yspq2Z5tzstyc05iLoeJpVnZRV0J
pbhMqWFhpBgIlkoYZGpKlrlaUyjqiySCRQolSplGlljrToXv/8N24HD48bzP
e3gv/Ixj2kwXjuPU/97/X3p8dndY2g4LMKNPkhS5skS+mMyhf9qSMWjlM8+H
/UfawYl0sjvcXXvH9y0ie4Ebtpt/NQUx+6KyvFWQpiavQG7XV9X+yUDmIHzn
Bz9Ux5IFUOmuTInvBDCvQqq5wBblRl6N11skx27r/JlDUDYoEqaeXMG8FhHP
FJdyBnjMofiiU3K6CT/mcIj7HuVHZ5HX4+fN8efnCpczb8DTx1EFxi5f5o0Y
GdLmnplLjkB1xdHjN8uWMW+CaYm9NG0zeTP0RR8VF774MG/BHKP/uuJOciT+
5NmDXR97M2/Fz9y6YlU2eRtqO3ekVrZ4MW9HhyTrW2EOWYywdzzTgtnkHdCI
6gRGX3IUZN3JAesCyTsxeki4/fc5T2YJEiKL742Ek4H660+9KwY8ZmwCZu4D
MyeFMfuGNdGHcik8xmw9TdqlLJehZDTj4ugtZpMMmbWNLqfrKJeDLz1gPvHH
neVynBBWVV5uZ+aiEbY05HNNH+XRkOimDWoe9RV4KxJEHBXS/Arkt7WaNaco
j4HFr6r2/iT1YxzHc7GO85lisSjHY+J8Lv0/ztGmOOhrmuu9QymPx8TQmlJR
CeXxTvMr4d/0a8AQSfMrHcdzu5zWvwtC9UovxRHqJzjupynBcT84FRpXKl9t
6qG+CoZ5DTU8BfXVyG8SS9obKFc7rS8R23otdU/eUJ7o1NfAagjuDnBj5wuN
03lr8MFTn/nVzGzT4JDx291ZOrofSY45kmA4G7Hn5Rj1k6Df2xO3J4XdN1sS
ZOHpVXnpdP+0eF+dJ22WMEOLtim/a6eymU1atMROagsWUl+Loqv9D3yGqZ/s
aCQjbvyFdXG5F/4CGMMwPQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzl1I01EYx/E/M01cvpUuM3Nz5MucrXTNl9zcb9Op0+mFNhwWJNaiMrCQ
QuzCf95IhNKaQVARZCBpFluZuYS0EVnDIEpIsgiEXciySaU5Sit8DjEPHA4f
vg/nnJTG5hqrgOM49d/972RLZB564miSYk1+beqrzw18BDOHA6qa9GlHCjkc
xc6ps811zDFwWIo8V30SchxumOdRZmNOQOjDRyqjgjkJ4bfnZzmXmCxBms1S
txDNLMXEoDxyuTqZvBMr73ouTd/cQU6Dt0vyo+1ZEjkDY6Ee2X0tcyY0bo/6
xfHt5CxcGey0uF8mkhWIWFWe8H3aRt4Dp+5Cx/JqAjkb4t6ujvQq5hzEVx/N
8w5vJSuxEGV2y3Yz78XbkzMjE0dEZBUO5WrCPk7Gk3PhOpW1VCtgzsPhD6Oj
fb44cj7047XJcjFzARonpC4lv4W8D3ar336wbzO5ECV86+/szliyGmdkPfbL
zhiyBhdzrDPXGpiLYLxzrz/1ejRZi10axf6n3kgyUH2322AdIvPAgFp6LMPN
5nWI9cWJ/KIo6jrUy23lr1uF1PV4/i26tv70Jup6vHk89f39T9aLIV6Z9OT7
I6gXYzFy5PwvFc1zJcHmSyCQZAaEA6wbgs0bMJnon+uJofu4UmQ92BCW272R
eina2gPjTf1h1Mtgm205p19ivQxfCwIregXr5cHzfDlMee3Ds4oQ6ka0DBRq
nbc46kYou74s6caWtWu9AsKQwbY5+8Ka+Yp1vZLeW6ReGTzPmah7qZvW9Sr6
By3+v/8AoVDwAg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlHtQlFUYxr8AAV1DQF0ui4GbNEa0cmsRgfaBZbktl91lYdlbkTPM1GDh
CClDmV806WDRCNI/jlkJRgMKkimXTfliVLDSMSFsmmlGh43IprQC3JCkmn3P
H9+3Mzs7v3nOc97nPfues3F7ranah+O4hv++//+yj7z8rKu/Rgkv3dPsfaHL
1BrBmMNuQWlWD24kDkRg6GRCgZNxMPbL3CmCP+N1uN42cHXk8xjicMR5btcm
ahlHIb1mJOT0uWjiGGg16bFNaxgrMTPbNKbXP0a8Cf4NRybNhzcQPwFdTN/F
jvEo4s049nOn+89pBXEcxrRn1I0rGcfDk+Q/psuJJFbhQfed6wdejyBOwIyy
Y776aDhxIpqXJqb6tYyT8NJUrErWGkacjAFhVd6Hv8qJU9C4b/HLmm7Gz+Cb
6Y5/EMdYjRPv14UMYT1xKhKcb3Wd/3Qd8VYUpe4bmFatJU6DpzPgDXdWKPE2
hM4Koz2mEOJ0bOhZmnKkMs6AInx6trUtmDgT5+4d2hJ5NYj4WTydqTKPzDxK
rMG3g9/Nfe+REQPjlzL31A8HepkH9rfWbHstOoD0LHS5bsq/ilpBehZkvqca
7xx+hPRs+MTELcp6ljRePZv0P7zMaZHc8tv9LOFv0rUSfw7qetI1nx3naP8c
Og9f0nUwvpv4lN/bfqTr6Lz9Sc9Ff29tu8rO8ueK83J5kvx5kv3zxXn4fETn
F6fJu5m/QJKvAHfTFh9mqxaov0JJf4WS/fXi8+T15Gf5i7D32MQX8tu0ni+S
+Isl+YphsSX17lIuU/0SeO+vD+klkvylkv1LEX/Gz1/9Hvt/DagZH7wwMUTz
AIN4XngD1VvjZcEAw464r+cj2LwZUZx7+ZI7kxhG/PVw2NoUQMwbxesFCXMm
id+EHdmHzgd9TPPLm/Cqy5Cx1UMsmMR5uDKsXju6Z+cvxChD55WO3bJ65i+T
+CU6ZxYzzNCal9QrcpnfjD7FyYEbeta/WdwfVy5ej3Isc8blqnpaz5fT/LD+
y+GKbP9g6C7zV+CTxwt/SBll/VdAY5lzlCjofvMVcAQcP6LQEQsVqOvvazY0
svtvwQ1Nm1/Yj8SwoMm9vcV9kvktWDjYG+acY34LPPqfAt8sYu9LJex5I6sW
TxOjkuaJmK8U1xMqxXk4q7gfWDGzRZn8ypOsvhVXpjbNPVjN/FakXXN9dPkW
698m1mETnxdvE+8v2JCRVHQgqIrVt4vrwY76F7sulMpZfjsmqxdWbh5i9e2S
/A4Exycqri0zv0N8PrwD77SciD3lS++z4EC2qqp9VxV7r534/eWL88kLxHDi
+Ztnn5tooPedd2J4Z/z9Mh96/wUnco7eCh1qXo9/AaXa7Sw=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03lI02Ecx/Ff0zxSc17Tuek2CxFdy5odZnMf5z2dHdYfmhJJYaBg4chY
WcOEjBrY0oi0A9dhasYcYmmHlVLSXx74Xwl5EJEoWjmHdrHvE+gDP368fu/n
+f7z8JMVle0/xuM4TvX3+fdmS3Cws8daEgGnZtWDEjs/0Z+ZQ4/usqzzhYzs
AeWFblPhYWY+qvKENyZdmQMRE5tnN92WkkPw3HFFJFYzi7G0L2CmtEtClkJf
pHg3wmOOgHbezft7XDh5IzaX5EyOtIWRIzFxdGK6QcwcBeWeAbfYCjE5Go++
5RkS50RkOX77VzVGZTMrcMvccLe6JpQcC5v5nKK2QUjegvsd/Zaa4RDyVlxa
Gh61JjMrUV7XXunZG0yOQ3jfJ/uQjnkbHiw3SyIbBeTtqDeqLH4a5h2QZOji
BS1B5J3QP3sjfatljkf3CflCLo95Fy4a+k7bGwPJCSiu5+l9lMy7UVD0eVz+
JYCsgnUu9I7hOHMiTDbPmJdj/mQ1YsIEwuIjzMCQ2uwa/NHPaSNQ4N50U5RK
5pKwtzT6ww8hn3oSnojauoayfKlrcG/AcspLv576KnPJ2KRSHHg15UM9Gf3z
vrn5J72pp2CD9vpofvM66imorXZ5OlZI5lLxvl9Voe/2oJ6KWdvgcmWQJ/U0
LMrNZx+Wko1pMJx3vC5pcaOejqvj5Wc0C+7U02FtL6tTHKJ5XMbK/cYMup+1
1DPh/D941DNR3pqg7mjiqGvh5fLY8PXaGupaKE3TC0m9i2pnzwJPGu3wal1y
2pi16nw2ZuIdvzSKn9Sz6TtbupU26mj/FM3P+d//AGOg6So=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdyn8s1HEcx/GviKvrcnI4P49ba6qLziHH6V4O5xw25W4i1rJZSqsVpalG
K5XtVOq2Rop+aorWpqWEdBFrarHd+Cea9YOlzjK/1vRj3p8/6r29995jz3dA
zv6tuUs4jov6s38vG3fjo9aH+VIsyqY+kLOrqkvAzIE3tKKkoCmAzMMRES88
08AsRPHPToF53p8sgtk7PK29ilmMDrHQ2zmU2QcP9Oe3TdRKyP7YAM2JylE/
shRlDW/bX0iYV8NFPLRgn+1LXgPHYGNoXq8PORCD51ysIz7M62Cypts+VniT
ZTj7bXfLwIAXOQgXTtm3DGczb4QlWbTDeMOTLIenszmyTskcgs+P78vlBjFZ
AcFUzVhSjQc5FKlTzb0tccxhCPGo3Zl12p0cDovux7WAZ27kTTi+Xa1qNjBH
IDW4TlooFpGVcPJzMLzsdyVHIuukInPwyypyFNpenRmeLWFWIc1abur3Zf/R
+OqakTtdzvpmyLXVT/R9zGrcjlT01F9lBi5/MNm9nySXAlUd9UVGGesx0LaN
7cE7F+ox+BQsVexbS+Y0UL5preseEVLXIKO68bqbjMzF4lbvzcP8wpXUY3Go
NVUVMUvm4nBPJc0LtDhTj/uvx+NujKWr21NAPR5XrPy5O2F86lrMyS4eq9+7
jLoWkoW+1xG25dQToKiYmIl5znoC+rxs42Yh6zr0dEUXFT7lUdehcrTgqGbG
iXrifz0RxSXznfkNjtT1/7pUD4kuRenesJR6EraY5OsdyhyoJ4Fv31g8fsmO
ejLSM0OaDkp/qRd7Mr4r5xc0QdOL5lLof1L9Gyvb6bo=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd011IU3EYx/HTRLS22Uw92ebrMisVaXPmy7TzU/fiy5IpRFLNJAmSIeWa
LATxWEEReCGFGwThC7hCFCzsZXYRMi0EhbQL6c4SSglbF0nUZBV7/hfbHw5/
PnzPeXhuTvalq82XJRzHlf97/t/s8GdmZqftaoQVEGw9ni8LCmYOT3qr1vJ9
2eR4xMZ5V7ZbmRW4eD5l9LaEORmqxtzQ9EgWORWZ65tuh5E5DYuywRn7ZCY5
CzZP7oA3mEFWo3Vjfsefz5yDt2PqWNetdHIumpxDwx+ep5GPQdsx6HwXx5yH
u0udfFeOilyA4fYiy1y/klyItaE14fj8IfIJmI3OjphgKlmDBu+9FmkCsxaN
y1a/98pBchFinen5fS95sg7u8ZHH6gzmYuhWBlxHfMnkk7gQrxQ9Zcwl2O70
/yzaSSKXwt4S19TuZi7DlPl7s0vGXA6/9c1D0XeArIfGpzr6qZu5AooCjWo5
lEiuRFuX7c/iV+ZTMIg3djV3mAWMH67/qJtTkBFpEThtWpjfqGS9ConfkvkA
n0C9CiGuKdTm3E+9Gt2z1orSX6xXQ5Y057q2yXoNJFl5v6UTMuo1kDu0+tWb
cuoG7Mhf9QeLWTdgSRnYeqDYR92IwLP3u70pe6kbIY2Z7Nm6v4e6Cb2PVl/z
6zHUTbCU9L34XEjmzFHdHPV9Lc6e00451CEh3Gtp32DYXF2kxbrI97l6XJ/Q
C09HOZpfj/D/JKH5DZH7iA1R3RK5j8j8Q/gLQ2PfwQ==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlX1MlXUUxx9eRPNKkMhNAeFC6lSIKcQ7xPeC8g5yeedyuTz3biUbLZSX
MEx9bJq2WYkwaGkNo+ItYOpaCooPMvKlaCmDMjfzpbXJaoD5AoRQ7Z7fH7/f
3Z7dffY953fO7zznnMfXWp71mr0kSY3/Pf//s58295u+U2V+sNFk7MS9qcAN
7owlDB4yNd3o9SVegv6KxEWDRsaukEJqHj2WGK+Ay/YLl/d26ohXonLYI7s2
i7EXmm7G7Tr00IdYh8jbP32aFsrYD+0uH3uf2OdNvAbzO/cGLb+1mngdDiT/
UG70Z7weF0erozZVeBFvxJ81bmE9bZ7EARj3DL/Z4s04EBd6rn45fNKDeBP6
88Z+X/fPKuLNML9+cr+TwjgII5e9HH5dzDgY18w9D/vDVhK/gsaP3tzRcfBF
4hB80j4Q/7hLSxyKt4+uGE22YxyGqnOXdIMp7sThWFNjVx864UYcAesVv95g
hXEk7h0PDblVv5w4CvfPP1P8wxhHo9+0dsBbwzgGS1umzQlDLxC/iqrS1v5t
WqbHYnXn3JgpjOlAZWdU7OnPXW2sAJ3RfqXrB11I12NBMizIVcSKHtV9mdHh
08+THocvrra8pakiVuIw5ny4dCbDmfR4PHE+t38uZBnp8ejx/PrbG6ns/C14
OSYw5+IfZK9swdDfLtnGnWQvbeVZ2Yr36soid/ssJj0BPknpEdqORaQnoLXv
Z+01L2IpUdAT6b4S6UnY89nIee1dB9KTULtvdqCsw4n0ZP48JVmIn4JT3eUN
gUVLSE8R9FTBPxWGI5v9HQ86kp4m6GlCfumwzac96emCnsGfp2QI+W9D3f3K
3XFPKR9FYCkTk2euP9vj/pyNkSncJ5M/T83k6ykZcGUopqaql+xh4O0VAwLO
ODqFfkjxVANmAo690/oGxZOyMBExOx8XSPbIEuqRxb8fVWApGxqHrtrxejvy
z0bwB3891aszsTZ/gdVsivfExlIOryOHzpsi/xzeXhXspVzY6zbOajrnyD+X
t1dykW8M6q7wWyB/wV7KE+LnCf55vL2aJ7z/fOH++UI/5/P9o+YL/VfA1xsF
wrwU8PZqAf++pEI+HgqFfhV0tVDwN/L9AiM/P4qRt1eNwnwX8fVAEV9vpYiv
j1ok3N/E5wuTUD8TH081CfkXC/1fjKMHHM7+VryU/ItxfEwz81WIhvyL+X0o
mdGmHxz6bhXtP5j5/amY4VwRFDXyLrFqFvxLBP8S3l4pgc/88Pfhk5SPWkL9
xuZP5vPVyfz8Q+bnVZZh9K9L+nEX3UcR9GaZ3yeqzO+bO7KwHy38ftBZhPgW
Pj/ZgpdSGseMbay+Fgx7TI43uBI3W3D97OijX6ZZvS18fe5YkNze3bH2BPv+
WLHM7VLNjgfEOiuqNzTUHztN30NY4avf/n71PLFs5b+nihVNd4/Y3Z4ibrbi
QWOFvivWDf8CStB+Lw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n8s1HEcx/Hr10Y0P3Lnzq8wlFwn+XFcdC8czq8jkUQOm4pqpF1XbXHW
yh91rIRMaohzFZswLUKaocVKq1atLMlqlah/bKEf6/P+w32377577Ln35/v9
fr5fp6y8hOyVHA5H9vf8d6WDl9TZ3XbIGf81Kx1UV5zpMSNzkHPx3IC2zYnZ
CNlHkOSzm2yOoMrmqpAFR2YrKHvUP+/eJvNRX/dQdjaRbIehEYlx47cNzI5w
TJ6Rn5SQneGyzlT0qsmB2QVufWYOoyZkN/C1OaIth+2ZN6Hcc0TP09kxb0Ye
f6Sw3pgsRGmuIM4605ZZhB+C/jWqNhvmrSic0kfyXMhe0KteS2vKBMzbsHTT
XpwqIHuj+FiH5+MoPrMPuIr94ukua2ZfCDsbkha6ecx+KK59ohTkk8W4ZTHD
d2vnMvujuvRa7sBxcgBOp0oDOxLJEkx80amSr5K342vp2B3pODnQwEHIUrg3
L5mSdyDNyEZzJcCKWYpazfNTZq3rmYHWiO8JalNmDVDdp1MnCS1ZD0ZvmusD
BxNmTTDGpZdWW7+1YD0EjRLvYV0t9RDMR380Ko6h+VB42PMEBzKph8Lrnu3G
SRV12fL7aWQwF3rZjv2m9cOwtmE+PXyQWROGjKP7fj36RD3c4PnCDeYjUHdj
mFv2gnqEwfvJMVnj5/umnLoc94dKJuaLqEfivLbRtWUV7U8kUpQD8r17aP+i
UPX+wop3czQfhRBRxuWCDOrRKM+eLU/TUY9GV35TiohLPQafKwuCW6S0fgyi
2+eidoqpx2Iq112yWEI9FjHioq4PIuoKaNuNPXonaH3F8u/JiYOliXXPdA/N
x6HCdTGFc516PHZx/MfaLNj/gXgoX3amPzvBrIlf/j/1x0OfP/r0YCkXfwCB
QAX8
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tMjWEcB/C3izocXZxUUpzKpdhxJFS6ON9OV90757yhYqadsY4NkYh4
V81tU+his5FlczvkEjpd8Ka1XGZUmJEZf+SSzUGztOQyv+eP3nd79+6z7/t7
7o/f2o06oy3HcTl/339f9njwN1qvmvzxX1aNs6Ey57OcmUN4F28aOe9HluHV
SLtcncTsCsf7O3Z/G/AlT8bqlcVlykPMU9DDK7afCGX2Qc2z5pfXO5VkXxQl
Vj6utWf2B7Tr+1rzppNn4lx+dahLwzTybBwRb7XP6vchB+J9W3NdHs88F1eW
WsItud5kFeZt97pU3DKVrMbT56lPCpKZg7Btn+1amcWLvAB3gmyUZhfmYDxY
ffnb7dAp5IU4VSOTdfV4khehSZyQUDfgQV6MGiHq9CQtcwjKyjv6jonu5FCs
SKx0fXdnMjkMw0Mx9UUq5iVQyD3b+tvcyOGoMlqrcs8qyBFY0OId8K6QORLx
tz7mo3sSOQqKD+Jds455KX4cbPBcNcisgV/0ugOFo65kYKAvoHx+KVkAzJH+
6wM7XCiPhlNBcERvqRPl0Ui7WBFnvEHmtOi2PBt8MSSnXIvD5XaWN6smUB4D
a2P3rxL38ZTHYEZS7fPscyyPharR3iGkwpHyWBTvGW43XXCgPA5flgyPatVk
IQ4lJ3vbPN7aUR4/1kI85HaXij9V2VCegOXZwQ0F/r81/3OJuURsMUdortVz
VJ9I/fVTvoza+0r1EnNJsPWdOyw3j1CeJKlPpnHQIyRL6lMk/adIxpc6dj5C
qmT+aZL1S8PeI6bwnUoyly7J03G1YWO1OkdGeQbudUYVbW0hQ2IhY+z+ihlQ
jj56GGZl+5eJR1Otn6pdycjET9XRXWc3sP3OHNufKPmf08F0z3K7t5nah8SC
Dp3fXfTZmydSvU5y/vS0XnReoUdha0Zk2JAz1esRYxgJGRdPFvWY6Ha3aNNH
dr4N2DGn66cxnc4/DHDaoBjYv5ndBwPtD1k0INex/rh3HLtPPJ4af4wPbCaD
R2Rwyj7nNWSBR4/mqL3na7LIS+5vFvK3Dt20WU5GFhx4m0ZrB1nIQtOmMyvV
7m74AwbYcoA=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0FtI01EcwPF/3pINa9r2zzZtblmUymozXWpzv12cl12NhmDgg2KKPki5
yhTanyi1UsQSX0rEmiguLaOYOgoD14wg6MKgfAjSRM2YPZRu2JX9zoP7w+HP
h+/vnANHVNlwojqCoijtv/X/Tz7a+sQ9Xi+GkNaUXlFpwpKAmIKYRTVP7BGh
Y+HrYY/rRy0xB+o0Qyu8WGIuXPF9UY47UtCJUDWntq7KiZMgw89a170RolPA
PzGjPyckFoPhdUXMh7K96FToWHjIb3Inow/AskzkpYNJ6IPQ1ceaLKghToOk
qvn8d24BOgNS6y5bJZXEEsiSOSn2Yz76CMCdlY9jk3vQUhgemWpniYhlMNdf
c+aaMxGdCTzTafmiazf6KLR21+e2CImzINqWnG6foNHZ8HngvZXDJ5bDq+DS
9dZBHvoYmBo5Lb0eLjoHKtp1y4qZXehcuNE5uH80kjgPZizTt5mpBPRxeOpt
+7RhJ1bAgGOW1+Ujzg+bV8KGY/ulBRUxgK126JmZRjMAWqbpl7QtHrsK3Pye
vkk/B7sKBInzS9030ZQajLoXngUF6Wq4eMgbqDaTroGyctnYWfFO7BpwvLx3
nm3bgV0LDwT3XW/1pGvDegHEr3LpNRrNFIDm5GZ2tI50Hfji2msDpjjsOthX
0usrH2ZhL4TxsYYeyalY7IUw61FcsE2hqSJotgef14/EYC8Cg9zumpdEYi+G
0g5petTVKOzFICwy5tAj0dhLts4zJcCOHG1eubUNu36rGT2+xx9lqBsgs/Pb
umo6EDJjwPnv2I3gzwn+Vkt+YjeGdVPYfhM0OvOUj+5SeL85rJshIiUtyHZu
4n7L1vPBEjZP+mLI0xY8l6L+AoIVE40=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XlI02Ecx/GfS9OcmuY2ndc88pgNS03LeezjvXkXjVL/MCoznGCksEij
0R9pEUmIkUeQFppnlkiapmRJo8AwaRVFZHZjOaEkzaNi3+cPfeDh4cX7Of54
vA4U787ncRwX+2/+X9kQqXsHbmm8YZJRMX38td9BMTOH3MHJEscRL7IVqp2G
353SMNvjdLb48kdzZgF83D+P+rd6kp2hEvSWj6cwuyFJbawf/CIhe0LsMzZq
KWH2xq5yhb6s2IO8GbX3E2u6v7uT/TAlzdszkcAcgKf+Q9cmW9zIgVjaUiVp
++NKlsFspnpxJY85CMu55wqk3S7kbbBeCS2cfismB8Ogq5vrrWQOQYzIt2Ph
oTM5FANNHg3lLszbcV6+fDhe60QOw6yd+oF0K3M4Jore9OsPicg7oH5lcbay
TEjeiX3KKvv3wwJyBApqeKW2ocxyfCiUypcqHMmRaLyuF1YZNpGjYPo/5mjU
Drdo1TLmGORfaeaVXXUgK2AvC3YdW2EGokLSKuz2k3VASXuk4naTPfVYZNd1
NgplZF0ssooCn/wSsx4HVWtXm2/DRupxsHEc0R79Subi1/R43HTtuPMslfUE
OEwLREaRHfUE3Hsk/xEwZUM9EeN9z3++/M2nngiDbeWR+Qxb6knQ6PuGJvpZ
X2MuGfUG/nxzGOvJ8Em5ZMi5YU1dCWPP+NJJ4QbqSsxELCzHBa2nroJ+NFpb
eteKugoSZXqEqM2CegpkPebrwy9YUk/BmYsaeZmEzKWuvk+XipaBF6LHbux8
Gv0fj3oa+Os6T3yrNqOejr05IV3HvFcUpp4OnmfgAr990WQug+6fo55B52ep
Z662LpP2f6KeRe9w3F8AkwTO
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz19IU3EUwPGrTmbpcK2ajt3c3SgrnSO3TKduO5vLzdlMbRFBoRRDaZWB
1tBiXCmlMCnroYdhD6sQEkcJQbpKKcNcCVGgL4HZYvSHcEi0Jk4rPL9g98CP
Hx++cODIj7XUO5MpitL9ff9+MuKDjwIPXQpYU8QwzX85PyoipqC9L6JwBOTo
NNguOTA91UIshDea2e+slHgTzL9++tM9yaCzoWvZxXecI6bBVjBX3kQTMzB0
JOS+fVGGVsBMZu6DT/dy0Fth0Xyn+9DHLehc6IxPLcZriXeA4EtRNLWVRucB
fTykfx+QopXQrHc8Y5KIVXBLpBvzhyToXRAVacWMjLgQ/BuC4a++bLQahikf
2yMk1kCa55o02JCF3g0j9OFTr7YRF0Fn/9sGyRkxeg94lB3e05HN6GJoG3nO
vLARl0DJCYO6N4tYy3Ep8HN4jol3G9Fl4Lcs1LsziMthonbcy46K0Dr4fZfv
+Wwk1kPoSZzNLyY2gNzYdOXsihAN0L5zMubcj2YBetTOD95G0o2wStWtNrZl
YjdCgU7lGAsLsJsgmclbSh/MwG6CGcHl5lgN6RVw/VLK47mj67FXgMxq14rv
p2I3Q0x548LAyXXYzdDd5yo9L+Nj3wt1VwvzeV087BxTlYn72EoYCMyKgzTZ
b4H0lKGObzeTsFtgQbu0YlL9Mqx1a6JZK2h6f0SN4zHsVZxehfcuY7dx9ts4
vRpaB8sMwz4KezXuC2Pfl2iWY8rO6Xa8i0zNf/8Bv13sGg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVzVtIE1Acx/E115xO8tIy02nbjJXbGM3anNf93Nwc9qKSRGu9BD5Yg0El
SVsxorKHNafTXlToQjqYm1iG1opQCOylJZQvFpOSoAiaCNXGsgv7n4cOHA4f
vvzPX3rK2dnN5XA4mr/338tOcdej6MwZGTJKGD7WGxbL8pg54BetKy4FpWQB
jvM6z8XamAuwEBc9F8clZBHk9/LHOq4wl8CeW/fjsYZZjNX062T//F6yBPkV
7febCpll6ArPjngtFeR9GBEs3XnjKCfLkfNuduCuX0w+AEfIOicvZVYgb2r/
lNJZRlYh3uNy6/tKyWrEfN9vGsf3kA9im+jG5tavErIG5um164NPmashfbnR
r69iPoTFI0HFsn03+TCiXv+ka6aYrEX2QuWY6ususg5S3vu1zbSIXIOi8Nue
xGVmPVQJX2RuYCe5FubGdXcsVUSuw4dRnXY1wFwPy7PPp7FcSG5A9/gE13Wb
uRHlofSKvYa5Cb1Vw4GhBwVkA3qj7Q36nzvIgOloWrfdQvYAoyvC5IRWSL0Z
/qtZ8/GTudSbsfSi8cL5JwLqRlS23VqxBVk3wqYctL7qY/MmJFVD7klHDnUT
ZiLOYfUJNt8C1UMeX+fLpt6Cb7WpLaOaT92MDq9GybvGo27GMVt15KzstyHT
LeBKFClhKJ2xxwJhVvjil8AG9db/7Wml/z9Rt9IeDucP2ke94Q==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU3EYx/GTioq3lrdcmpujTEWHurxf9ps6zalzSmpYr2z2Zi+kbJSK
OCInhVnRBawQkUicpGlolIazjBITuvgiQlKJ3kilsJU5yi7s+RP7Dw7jw/cc
zvN/OFF1DZX1boIgaP5e//7ZL7RqbGLEIINT68rYFsOAOIRZgE/MGUvvZBTZ
G/tuTgd16JlFSHyZYFvxYw5GQtMt+7EBKTkMrbVdOWMlzBHI7Rm2PF6TkKWQ
vT4fuKxklsE4de/o6UuR5D0wjLd/uGbfTY6G4r3465O9zDE4qSqTmI0R5Dis
2YZvJ9rCyfG46L/aLa1mlqNzbiVg2bqLnAj90/GkTn/mJHwL3NDPRIvJyajx
tC9Wp4SRFegfXHi38XkneT9sZvUhdTJzCiY+jUYs3Qklp+Kc45VF/CuEnIbZ
hbPtxlnmdGgbRS3XnwWTMzA6bI4MW2TOhKjjuH6pjzkLXpEeB2feBJGzUfdC
9khhYs5BUuGNh5r5QHIuuqf6T1XFMyvh6363efXKDjKgrLEf0YaTTUBT7PPN
+nIRdRWME7rs9B8B1FWoqU0eOiHbTj0PbtI4h++gH/U8SLbm59LXfajnY2So
4ar8sDf1fMTf9/BM7fKiXsD1Aq6rsZbh2MqTe1JXw/m9ulEvRGla24OPcnfq
hVBc+LKhsm4qnb2I5v3ttKmI6we4zlkopvP9pF7MPa9B42CWcrRPoPdruOdL
XOc1lbjOK5SiteftZOgKm7+UO38ZzJcNmS0SsqmM61o0tzmmDRa2H63rvoRy
bj/l3P50roaOvo9tdL/O9fxWzkKF6/nB2VThug8rZ6GS5v3uNP77D1s4Ksk=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H9M1GUcB/AvhMDiwBPuDjgF+Vn8mnYoP0SQNx4c53HA/YI73DmBdeLW
tSK1U6v1HeEANTTR5QCXYoMt0gYuCUn6RhiVk+Ja11YWDViksiBbAWaazefz
x/duu91eez/v557vd8/zxNa+YHL4chznePT9/5c+iooPh/qei8NjLeQPhAu/
un3IHFZMTFyMey+WORDTrTESdwFZitqXq+vGfo5hloGb/Ccv0UWOwKJJsXaP
krwG/odPvXbAuZY5Bm+ONDv8u6KZ4+A+2d85K0QxJ6DowumUrlzyU5gfH70s
N65hToKhf0PO15dWM6dgp3RilptXMqfhs4kri/4S8josp514tccZyfwMHIkq
ny3XI5hVEGS9ATW3w5nTcTTnwS61i7wB2Yj3xV0F80bMtY7357vlzBn45v2r
LW94ZMyZsNdOTaf9FsachQSXT1vmPDkbJZf+0BmzyJvQ5lhos/eEMudApWkf
1N0gb8Zs8t0DKgONz/VyHvRZrw9MryNvwahB6OCvUD8fw/bET6ODyIDjTLfv
K2dXPTYPuPNP+IX/xMwVIDdd3xRSTXkBUqMUkXU11N+KPX0ftBgOUr5VPJ5T
I6r3vseeRbnaa/5CDClPnhmcl7K8EEfSHTc7qpm5IhicKdf/iqS8CJcXjq9X
3ghhuQb7hgy52UvMvAZqy/3MFRrKi8Xmi3Htz5Xm7fUSlmvhCW7evVwWzHIt
ro7l/J40Tfk2+Mak3AvqZea3ocMTtNydEcRyHY43PvHR5I4nWa7D9tS3tOP7
KS9B8Evpm79toPlLsGpOplhQ0Pr0qGq/cE6eRs+nx52bTzeub6DnL0V3vO6H
jSOUlyLYGXqnuZ7yMkjCRlwv3lrJci9z5eL5+HKv3CBeDwzi5+cN4vclGMTv
gzPiIWd8WL2XzQcv80aUaj6/NpPH/l8wIragrmXfA1q/SbwfYII9oKt9dRHt
FxOSy+JlRc8zCybxfuXM2Lu7Z7hcwfYjzJgLq3L83cLMmzHVkZnxYxuzYMa5
d7+QH/PQ/rXgYvG8ySVh5wUW8fnhLUhOCJhZLGYWLDiV+G8V9w6drwrx+UYF
AqL9LKNu6legb6n1VgTYfSA8Gh+o5E9vovuhEg1j1h339MyoFI/nK2HTHpNO
fUL9Skib6p+d7KK+FRE7P3a3aqhvhfGoKtXvEPWtOD9zqFa9i/pWNPp9+VXg
29S3QXv7++GQI9S3oeng6P6lTurbxPeZYENh5y+hgy1031XhuyRnTfeAHP8B
NiiM5g==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU3EYx/HjxLI289KcLm9zZqnJSm3ptLVnm9N525wRylpgC+2uOTWp
KKcJ+SLBG2UXQpaWObUUNUuIGS3K8E3E7EVgoJA4IyvyMta6sOf/wjM4HD58
z+9cXixSX15QwqAoSvnv+H8mP86hkfHB03xwa0liFz12GvyJKajUdOuk3ZFo
b5Cpv5QsqIn9QK38NT7pQcyG6V2MHtcTHjoYGAKOnSoiDoWp12WKwNUINA+4
pplXejExH4pZi++tt8LR20Fb2HFcxyLeAUsn9I2mY2HoGNCxSoWdfaHoOBgd
LusQc4nj4VxG+oVrpSFoAfzgWryqB7eh94Cq6FLCdxsXnQDx3Z1BcdeJE+Gz
Y4zqrw1GJwEnlWdgXQ5C74V7rJuj7A8ctBBawk4u3p4NRO8Dl2ElepOVOBkm
ohpiKD5xCqSdMnQUD7PRInCsyk018cSpsHa08nfdyFZ0GuiuJmk/zgeg98Nq
18Yrc1JiMbzQRU+EM4kPQKwqiq0464+WQP2cvmmujxggYN7y0lyANgKEmZ02
XTLpUggJnp1vafXDLgWfMwH2xgo0JYPq2Pa21iHSZWD/tLNhdz3pclqXQ9aj
gd7ou77Y06Hr7f3zzKot2NNh2edZnVPIwq6AOzbm2gMhE7sCIlxT71KWNmPP
gOYGz7GZI2hjBlh/+h7UVpB9JkRl37Bpe0jPhMGB8nbBYW/sSng4Ps2ZDPXC
roRvIodLJtiAPQsilHkiTi/pWfDGKq6pek722bTnZ9P2OeD+fzGw5wDTs//i
QpsH9lyoNKdJhkwU9lwo1CYOGPh/JO6et/56Yx4weHEOptmJXUXbqyA3ufbp
rMAT76+m7dW0ff56Qz4kNX1dkVrW3Dbm4/csu22hmdLQ9hraXkPba/C9KOov
pKgfnA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/GjA6fOyvKSbZoXWoiTlZouNd1vm07nPWFU5ggDI52mWXRZ
lIeI3pVJ9qIshFGCumYqMjMM0+pNKGgoYWVBZqiRI0VsmFbs/xDbgcPhw/f5
P8/hwIk8XlNc7slxnPrv/e/JrmB977MuYxScsitLPsuaFAHMHFTHpoa8+iPJ
3hDppG2aMmZ/eFT0TFuEzIFIONx7em4wghwCS/rwnRtnmUMxbhZLZkTMEdhU
80DQXh1OjsLPD4mGpc6d5F3gV0L2NPgw78ZUfPVzfXEYORrdJ+sGNkZCyTHg
Dp5YfuqQkGOh0U2H/tAxy/H+bW101bCYvBeqamlKhZ45DlPrIwtfR3eQ42F8
ZBKfi2VOQLk0ziP9TQh5H+R3uxcNa9vJibAN+ma1LASTk9DWMvtEZmBWoFJx
ajOvZ96PieiqslZbEDkZSd9nP1qEzCkwXZR9m5QGklMRa79ptTUEkA/gZdFg
M9+/jZyG1YfCKzMq5nRoB+YqMbaVrESp0HxPkskMhHWsTZYqyDyQr339aibN
n7oKfgFD52vntlBX4VBJvLUuisypsbTef+SqkNbzatf1nAadEottPJfNa6Br
s7ZL77OeAc+IGIeow496BponRb9aE0XUM1Eia8wevUDmMzHWN7H8bpV1LW5d
E/R9MvhS12JEbJ9v8idzWbD3jP2+HORDPQtd1pom+VFv6tm43mhMuRQupJ4N
U73jhbHdi7oOIsFj0/xtD+o6et81pbPnuJrPwZmOVGW3maP5XFfzbuby4Pz/
PKnnuZ7H5bvtn0/ff4POL0Ceot72RS6g+QK3+UK3XojFZMe6Wr5C80XkWafx
338AP7kKFQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlHtMU2cYxqtzY6wiiMitikJXpFBgpdzksj5citxaSq+0QkbciERRYNqA
ZDFnLIJkgxg0ZhFNRIcwwBFhTkFgHQx1LrqAkzHjsmVrGBqXsIAE5LYt+94/
Dic5OfnleZ/v+97L+fz3leqK1gsEgkP/vv996fE0Xr917WAA/qdp5co7+8UX
XIkFmKlFaGWzP+PXYd4lHQtPJnbDu90TcuNvOxl7IHBxxhpRR+yNL1O8VnZH
E2/DpGuworFlB+OdyJIr/gqe8GMcgLn7n55NkBC/iT+7ZwvKS7czDoTWqffS
9L1tjIMgCWsp658SMQ7GM1Hsz5f9iGWYLf1BbS33ZRyGHSM1j36a9GH8FtqO
qw+ni4jlEKttJq7Am3EELAGxFydMXowVGHiu1+Rc9mQciYuu632XVMRReHHj
RO/c462Mo/G84UG3cow4BqXrFmva44ljoT9/RlQlJ96NyLH6CkmfB+M4NJTZ
2vfqieNRfcdc8DKbOAEv51MuVciIE+E4II1brt3C+G18dyw14b1AYiXyP1JY
J6bcGQMtcYq7rRcYc4C8T7TrdxvpSThyratOW7WZ6Umoduyrd3QyFiTDfco+
1KEjPRn+SfvrbCtuTE+BtiT4+xc+jLkUlCSfGtjUvInpqWhLGh657ePC9FSM
3nw0OzEvZLoKcy69Hy5FbWS6Cgfv3hx82Et6GprGhQtXohhzaWv8exCaGGb4
epLW34MUw1L0q2m0fzr/PFw6bLe0CbHzpGfwmctAR0JAcdCwK9MzYTl3tXmr
jPLLxFfTp8J975M/Cx9HFD1pKiQ9ix8vyMaqIHe18Chbj8vGzEqfpdqJdDVC
Nwf9fW6U/Gps71gaz4+h+mvgJpOLHqxS/TUoLC9YvDdFeg7mP3M67kii/uZg
MF/yjZ+Q+qvFj0VzzkG9LB7aNetp+fF2LSbDAxSHpbR+Lj8f5CLj8y/aJecp
nzVsz11TPx00nQ2qouusP9Dx68fp+P2y6+DyfkT8w2oWL9Bj3OVk8YKG/Hos
yBo/aC1xZn49xJlnx61tbzC/nj9PAgO//zBg45ahirKndH4DjknvLBTlsPzs
BtikZ043dlN/jLgiznwcOUT5G9fMgxFdos4bY1mUvxHqtNsjjkTym/j/D0xI
5SqX5bVUfxO/33YT/zwCM///ghlK82y+RkR+M6QasYfqEPnNSBt4egCj1L88
CF+5WvXsNO2fhzFl4wavX8ifx58Pex6OFrcO5njS/FjwR/8yFxLDGBa+zllQ
3+McMvgrzY8F32rtTVwf+a14zbiuZ3qY/Fb0lB2ZsVay+4qzwl3o1T/Zz9hu
Re4n8pANJ+i+24vurho/7yce+AcAM7kC
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtMU2cYB/AjMAtWBGapXGRARQOIVUFRBOwfFLnIpS0t0BbFkOguoEbK
xuIlHozzwxQV7JwxblnYjAyUqIiKGD3OwHCERSXqN+cE0Rg2S1CQ6mBb+rwf
ztvkpPnlef/v5ZznnMjy7cbNHoIgVP13/f/Pfmpze+eFCg3ccupG7Ef6tqmY
BVxqPD6tuSOS7I3z36z6LLOM2R9eg1/eeubLrMKRZ2UDjs4IchBSDv164kQ5
81z8dvDx2fpZzBE4V/tGeaAmnKzB8HBKbfujj8hR0CXaS3vmMy/AronILIs9
jByNB+fHyj59Opcci6CNg97fBjLH4eOwuqq7G0LJWlQ+qS9Y8EsIeQnaFPe7
Xd7MS/F8qMv/tSaYHI/iLU1vXZ5B5AScuvL3wTCfOeRlQPnlRw01avJy9Lpe
fH3gdCA5Ea1h/ZrY5yryCrTrtrzdXcm8EjFRisHxzNnkJLifx4fkVYjJn6fK
2BpATsadh1Gv381kTkGxNb61SuNHTkX2z63N808xr+asw6JUrenmkC8ZGJ28
Ztmn8HdbBD6PcRxruEgW0qCvjO19E8zqafLxQjpaUjSfRN+m+cV0TAmGqU3V
bL018K2KT+7fR+uJa+AREetStsyk+lo0pd3u6g5m9bXo6Uqtqb7mTfUMTMQ1
7D5T6UN1zsI6JNT9NZ4msfo6vEpyTaZrp1M9U24xE3FtXtMTDyuonsXNn8XV
s7l8Ni60bndobWx/OfLxYg7CJ/t6VzpnUH09N/96+X6FXC6fi3k5xx9am1g+
Tz6fmMedP1++HzGfu38FOLrf8+ofG1i+gMvrUT9g35U+TutDj517Xbcqmtl5
9bC3JOsuNgpuS3rkrth7ZUDrSXkDDIeWLvT6yovyBu48nCUD93yM3PpGhGfl
JambP6C8kcsb4Wy798+eQLb/QlT0XL3R36GkfCG6Rv0KrTuov8RCjPl21L5f
Tpa4umCS9ydMCBhWqZ3qWZQ3yftbMnH9b0Zo0MCL+gYyzChVNJ4MzaD3UzRj
aLEmYVsMWTKjM8TxXccrli9C0u+dP3Q/Yfki+XixSD5eKsKigOiRk/dYvhiX
nUcXh/TRfsFZ5CwV46c7P36hrCYLJcg/ezhjczs7f4n8/RRL5PdDKuH614K+
EOdLhz/1Fyzc87Ngz/f919V/Ur9InAWrvJ9gpe+fB+WtUHqe2/ny2DTKW+l7
N6Vz521yw0b7m3BbtFG/jbkt2eh87ylfSvOPUL6Uxg/p/gWj69Ru
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtI01EYx/FjF9OmZaZzmuUcGZZr1ryULvXn1tY0p2gaFlZq9GqgUZZp
SNOgKJwhyy6YQTmS7AImqWuVK7osQqGG4avCS9IFUzEvSWSFz3nh/8Dh8OF7
zsMJLSzOOrSAMYZ/+//Jlzjnob3FKMOcRpOku4+1FYm5GcpqR2XZ9lCyByIt
jen9B7h98LZAU6Fi3H7oedFeY2yVkiVol7RdUuRzB8Oj9+wPpSe3FCosTavP
CSHLIHGcntx3aw15LW53jh8On1hNXofQ+3mJlnjucDjCXGWfLMHkDTiX+ySv
oXsVWY7+LtFB01QQWYFr3837zdXcm1C267zcORtI3owr4mFnQRO3Ein24oBx
N+4o6Oo9x5oiJORoyFsXucfWBJBjMH5Gm6tVcsfiZqXXA2ummLwFXZrcwM/T
/uStkA741zXu4Y5D9HtzadgjP3I8Il5LJqx93Cq0TNd8lYB7Gyquux6L+1aS
E3DD6vS/8MGXnIjLfdVuH8e4k3C1s6k0R84NVA0WmgfvrpizCfD94nh+J4vM
kjEUKYsqWs97MuxBFxtsIz7U1TDoXr0cTCCb1LC+aTwuKllGXYNZljmbX7Kc
ugbeR5QqV5U39e0wOjueumwi6gIzLd519PzsneZdi70RtfruE7zrsDFBkd05
RPNMOkx62yp/x3hR3zH/vklgpp9/36RH7cDRk+qpJdRTUH5q5pmx2Z16iqCn
IkRviBM3L6aeCtHCe+XfLG7Ud5LHkua6wCwNI3Ezf9SKIeppgm4QvDcgyjw8
lez4RT1d0NPnz2MZgp5B/2LsL6cFB7M=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCwBGIQDQNioVt3b8xWcoDwPti7VUWfM+eF8RkcEvYmMWZv
UYTyORycTRK6iiNhfAEH+a56NZO/ClC+iMNPiTUtDrNgfAmHCOGb4efsYHwZ
B6MVpzfmHpKH8hUcJgndYVmkA+MrOVh53xWeUi4H5as4fFj3tbXogiyUr+aQ
KXoiU0wExtdwkBEMVJmaKgPlazkImyZkbF4pDeXrOBzQmn/JUxTG13Ngigm7
+WK7FJRv4LCZ/dKxXxwwvqGDJP8UqwWWklC+kUOzqEL9zA4JKN/Y4fGdoMJG
NhjfxKFyY+APjSpxKN/U4bRm3gaZP2JQvpnD3jfBfv6LYXxzByPx+YkxbTC+
hcNT1mnftk8XhfItHe5F9LX3fBeB8q0cfv1wXlSuA+NbOySdUNpl3CAM5ds4
+JjXb3+sB+PbOnT3LlVdywzj2zlcSf3GqbFTEMq3d0idu4ypegGM74Aq3+Dg
wM28turVZJi8o0MM+6JZ0q4weUcHl4aKv4btMHknVPUNTg7P9JWM8zRh8s6o
6hucHQJytE5/lRSAyrs48AgfKi94yQ+Vd3FYcnJxGXcJH1Te1SE8ymhdkRJM
3tWBSUHrF/dqHqi8m0P2iR37Lu/khsq7Ocj/O3va4gMXVN7dQdlr2rWoFVB+
g7tDVf2vg9mr2KDyHqj8Bg+H5buvi52SYYXKe0LDlxkq7wn1LyNU3gvqvv/2
EHkvB+Pet98dD/yE8Bm80eS9ofo/QuV9oOYwMAAAXFPXYA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1EYB/BXCSdquuV13jWLNTVSK3Ve9t90m9fpa4QZGmaMQBeJiiaS
vPqlDAovaLGUvGaZDrooqCmSTJOuo8IognAGCZGWWVNQKzznw/bC4eXH/zzP
8+E8QUXnczS2DMOk/jv///TzOD48fr8kGDtakYqXne1aXakZTCeoclMmg4jt
YfMtcdfFQmo+uHRTwa3NQGI3sPL65Ocd1F5oWnfsfR9D7Qt55c+Ft20BxIFY
aKwb21rzJw7Gk4K94R8k1CH4NPclc77Bj3g/quMfal0mfIlF0K+l1Ia6UItx
QexWPsz6EIfh45tSkXbam/ggFi6b5/ku1IcgeDQubBILiSPgF3XpXUCRF3Ek
2gVSO+O6J3EUOvxbJ28mUh8Gikbmm6s8iI+gYeP1gHDTnfgojIOvVkPOUUej
r7VcMArqGIyVhv05Zksdi3x7b+5GrBuxBEttZbIhqStxHCKUutG0F3uI49Gi
WWnJ76dOQJ8k6ml/B3Uidt6XWgpNx23bmk4BMaCcWCqGkZgDfl/Rexb8ornM
0pwM1Qdm1zVZfJLLkacb6nIPI+bkKL8XJ33QTfMk+HiZvjY10zwJsS/HO2c+
0zzZ8j6XbNVfgd65nkrHCmeSK7DNsNuFFS4kV1qaU1reZ1TQyhsnnLtovQqp
d/UD+9ppfYrVfCszqVb9UzExK/kuMjmRPA13ZNOGGeFukqdBPXhNoRkmZtKR
rRU/WxPS/unIPRmpLwum8zOs+mcgUzljWEyg8zOxujWWV8+j9VZm1AgXiH7o
jDRXo36x6OriIH2/LOTzunU+Cvp+WSiuMI/Y5NJ9yIa5l1e7KCOGlblsOPSY
TykNpH4qG6bHm1xoNK1nEernITx7mtaz0KuWc6qcyL5yLEpO8Ngz14mnWOjU
dRsmB7rfOVCX82vaDG74C+4fJIM=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlX1QVGUUxm8IiCJfxq4sICAjhSAIGMiHxMOHfIPL7vK17MJKMeDgJAiM
uIx6oyhwionwjyLLj5nCQDAyM0DoKoJEkw3q4Ew4JkMjTJaQEiSIVLPn/ePe
nbmz85vnfc4573vfc+6mwv2qIjOO4xr+e/7/Zz955sXerlJPmGg2KnO5ZWrA
ijGHrwqOLV78ZhOxFdRLM1cHdIztcbeuLr1sLWNHuExbjUe1exA7QUiuKZRp
GLtib9Vy5fycO7EHfql5LXZAxdgTJ0pO1vu2uxFvhs+GkfTOtYxfgkXPb4qE
1I3E3nh0z+XykXpXYh8EPAz1mF5wId6KiWFZ4oyRsT/8qhUdxh5n4gAMjPYs
WK5jHIgk59ujQ3EK4iCMnywub2h3It4OO0H9uZkT41dgW+2Tda95A3EwtD/b
7P14Qk4cAhR+e+fDg4x34NiR/A3n5mTEoWjtvSMfcWUchtVu5pprN18kDsfU
lseHApWMIxAY39Kd/NN64p3o13ldcbNmHAnfjXJF8R7Gr8J6VYfx92YH4ijc
Lppf493NGDCU65dGpol5SNZHY/20cLVdxfRoVHSdb1AamR6DH8Y2zy2tY3oM
Ktojor4+Y096LHJbOk7LthLzsVDu8/nxbwXT45D0ZWeb1wk70uNQ1avcGfqP
Lem74Bfpr/n+gQ3puzBmU1/yNJ2Yi8e8Tfebz4LXkR6P0uHv+m91W5OegE/G
rJ9+EUzMJ2D7+38uRAtrSE+E1rcp8UY10xPRdz38kfckxeOSYHMgKOJWLcuf
hPMu5y7dTKF6uWTEap6FWMRTvXyyeD2XIqk/RaKnIlsb1HnAk+0/FStcxoqh
ksVPw9nogcEhBfOnSfzpcPjDUT4rZ/nTJfXvlvglzCnF8aCUnJcSXZ37j/vn
WZlYUMJ4dPFKaZsl+TPgnpgWJm+zIH8GmiYramIWVpM/AzNhi89j/Gm9kIF3
mkrDa9xJ51TieFCJdV4l8aswPBh5sLKH6uHUEr8asxdGlw/L6P3yamS8F+hr
XmdOfjVSdxy9NOm/ivwamOafGfk12HrB3DKkkeXXiOsRJDqXKdl/JvUzMZ8p
rk/IlOw/S1J/lrgePguHP7t1WT5B9QpZ1J8vkD9bzMgWr+ez6X6tRJn8Ep3L
kew/h/qXI3+OJH+O5PxyqZ+emuIjV5yPzxXHF3LF58Npxe8HWnF8XivxS3Qu
T3w/kCe5f3kYfGKn1pZTPwh52BfzQZ/taTZfdOL+hA7p5xp3FV1k/aITzzNB
h7AbvaeG7rP5pcfDuy+/va2WGHr4OXj/1TLK5p0em6KLG6qeM78eD7Z5bn9j
C5uf+eh1Pv5p9wzz50v8+eL5KUh0rkAcHwWoLGnt3y2n+c8XiOe7UIDmotlm
XSv7Phhwoaziibaavi8eBmgfj4d4LRPDAOMh36kxL0cTGwxoLKtqy1MT8wbo
rJz5j8KITxlQez1bv5hKLBgQoH+rte8s8X0D7N8tf/3XM8TcHoQ0XytJWi/D
v5FlMXE=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1I01EYx/F/C52wVlZq6qxNLZWSlS8zN6399j61jGpDHVokFJEXYtJF
dtEctiLwoiYENcIMR5kvZFSmDWpFyyLEQqmwoqIso3IluY1lL+w5F+7A4fDh
ywMHzkmtrd+xl8dxXOG//f9kK8F8fehqXRrCmla2O3zNMUJmDi0Gj2O2O5Uc
g54XrRcfbmeORah/vLrBJyHHwTT5YXjQwZwIRfHrV1My5hQc8z7wl7vFZAmS
zbZQ/rtV5DRYog5rt0mYV+O+Ke90oHYlOQN3azrbVV0p5Cz8OO9aJ+Mxr8We
NtMNY7qInI2Z+pGtloZkshQDQ7yRRj7zBuzad6E52ppEzsHE7eOKwGQiORfy
W0ffxEuZ83AomNk3/GgFOR+dE2+fjfkTyDK4fl8SZziZC/BdHpxTS5k34nHw
00l7Zzy5EDudbaKmHGY57E/OJFVmMytg81bUBLfEkYtQtdtjtFQuJxcj2rzg
2vS9ZeRN0Ls/H8DoUvJmVPM7zop0zEq40ktf5ntiyUDjlSJlfwfZCvycG6yy
8VlX4ctEZst6G+sqlFzu7VrjXEJdjT5R982nZWSrGhpTqCBKv5i6BuPCE/sD
5ULqGowOjM089wuoayO6Fm6v4lvW+0XUdfNt1eHcuCDgkrF5Peyn6hRHxHzq
eoT/M4+6ARWW3N6DaX+U4W5AXuvXWdWdQNicMaIb6b1+US+Zb2tJxHxpRC+F
YGFP05TDR72M+kfqZXQvjvsLKRDsUw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2EYB/CTt3SKTdLldeoMsTlWuryX+2/qnJvObSalfRAEIVJUsgws
dUEG5ZRuVAhJF/GSZKlNCSvUkG4UUZgEfomFglhpdMFhrmLP+2HnwOHw4/8+
73me93BiK+vMVR4cx+n+3f+f7BKV2iaGqyVwaUUp6KqJE4Qwc7hfcc5hexBL
9sXsxx9Lx6uYhZhvazPUC5iD0bE4bW0YiSGHYkDfHbRSwhyJ8YoWxexqNDkG
Y2Lr4kwBswRlD3Ozi6+JydsxdKMn5exyFDkenn8W9I3xzAmQ2qefnmqKJEvR
vdjz+bs9gizD8oEBzcghZjmepx9rF74NJ+/CaIv3THMicxJao5yK2towcjKs
pQLtu3uhZAVOO+fNPn7MuzFw+HqozLaNnAJbV6+qcwtzKq723uyXiEXkNFQa
dvRvBISQ06FdmnsS2B5MzoB6qkScGM2cifH63jJ5yFZyFoSypIg3ziDyHjQM
ZilHbgnJe2Gskb76GcacjZx966nemkCyEmMr53eGv2YGel7cbvQ/SrbwzKnw
+Fnm1wR7AOUqxOmufCjvF1Cuxprs4sm+Gj/K1ZCNevmkdm6mPAfN3e8fiT55
Up6Dvok50ctIb8pzsb88eeiIxKl05bn4luHYUMt/uczlwd/zbtPSpU1Un4fC
tNZxu5z24zS03odyDc5cqM48Ec3en8/L89HU6piqvkPmtBgeqrssP+hLuZbX
f4G7LQW8/XW8/nXu83J63vx6uP43D8oLefMV0vfkKC9yt6UIHjFSh//gOp2P
gZcbYLImJXq1eVF9sft5WYqh6PjyWzW5RvVG9/OGkfpZpXl4+aSRV29yN0zu
6y08T5rc9+fMlC9QvZn65ri/D5wt+g==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H9M1GUcB/AnQSwRAYVLgUDOIgg8ApLfdO878CB+ycEdB8eBjI3lxFUq
mGHMb03BAgw4aorFXGYSRgbmj6Dia3BkNVnkspqusnPY0hKrSWBCtfs8f3yf
2263197P5/l+nud7zxNa9XRh9QLGWMN/3/9/+UdlPjnUX6OGS1NaSdfYnunF
zVB7J7dL9U4o+V4cd65u88vh9kHztUN3em+vIvshPG7DftsB7hXwzrRnBMRw
B8Hx1cun9oyEkFchZTgz7B4Vtxrmvg9ebTEEkx/EpfXa77u6HyCHocXRbz58
LYgcjkaV+puYKu5HcOPZ5QnHewLJURgetL/S6cOtwUD9kTfS7AHkRzEyMTjt
sYQ7Bj8UX3lu1HMlORZ/7Peca7l5PzkOdQlh1SeruR9Dctj7373bqiKvxYF9
3Zs+3e5PjkdT/eiOv1/3IyegK/+FWedi7kQUscTxfl/uJJx+5u1Sjf9ycjJ+
Phi/9pJ9GTkFqbG5TUsrfcmpCFzh/KW9w4echjzDmONqGvfj8L3hp5pSLSVr
MRPV8fzRzfeRgdXZr1209ix2WYKQ69C22+3Mj+U81ynHMz2ske1Z4zs8Kdcr
x7N05XxSOqJOuHvE71tEeQaODn2r+iJoIeUZiGv9bVonz2hd+TqlpXW4mTQ7
p9dMUm6Ap1tf/a/2W5QbhDxTaSlTmD9LmD9LOR97gvqkjySYZQt5Nj3vNtXn
YNuxFO3Am4zWl4OQrLwkVS+tl+UK689Fu3PbTv003588TJ2YuNvgz/dPMMtX
7qckmK1HbsKu006NG+WCWQFc53+ByyhAQ/eFj1RX+PgCGFtiIt33uLssFyj7
ZUalYVSuTzIq55ONyvlYoVAvWCpU9isXKvtlRUL/RcJ+C5aF8cwk1JuE/k2o
3zV7tqbXg+pNQv9mNLbXJO8Mof2GWXgfZoTMnf8ycYrOg2xGzbkzn1z4kM4L
K1bmKFbmUjE+/iz593DnEqovxkWvvRtn8r2o3qI837BgTZrGNDxJuWRR3gey
BdcvP7w7+kV+P5Qoc5Tg1FRbdMB5mk8qQbrpn/iFBrJcAsef3kXWLdQPK0WP
bsQxtpKeh1K89fnh7Z61vL4UFmvse1vV3lRfinlmnK+sJTMrjqWqN4aPkGGF
1+Zl1/duoX4kK70/3r9gVobm2OrLByt5/2VY4xt+q2uC15chaXzo0NhPvF4w
s6EuotPeMcDrbQjVPflS3Ryvt2EyWh33VATdt7INWstftvxAfv+WwycqJnB8
noxyNLceeajPje5vqZz+v2S5HFXn1INxEr/fK7Ao2N00+jUZFdBrKju3VvL6
CuV8cgWubopIvtvE6zdAf7YoODLED/8CYT73HA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XlIk3Ecx/EnjanM5j1nzmtmaU2rpTPvj9ecumkHksoiM5allmRmNSmH
FGWgoQuKhaQWRpmTFSYlHSopQUZCEkzp0k4jlUpKKiv6ff9wDzw8vHjzfPkd
AYVlm7Q2HMfF/33/fekR5nT1mEsk+K/phEF7buyKI5lDAi/wKe9mALM9iocO
DZrUZGd0mRJjNn/2Z3bH3EHbHdkXyCKU73S4l6sgiyF4FOYYbfFj9sebTr8n
ol++zBJU/ezYs7eUvAxmZZnM2O7DvBy58ukpwZSYORiLxo++LVGSV2Lovj9v
pt6bWYojQzGKSiE5DM/H3hWdPreUeQ3O7vbkWsTktehXuW/LafViliH7WWiB
w3cR8zqMZPblvwogh0N6YzFPXu/JHAFd9VxvyVUhsxwpQQLpCxdyJL51H781
a/FgXg/xaC6cG9yZo9CkH9E5mdyYo2HQThs0l12ZY7DKR+hVtJ0ci9fn5RGj
BnIcPrnlaWdryfGYPWXy3PrVhTkBfNsO3UcDGaiZKKybuMasBybHVhxbXePM
eiLaAjMs4X3M+kSoFQMPJuKoJ+FAyBlD43XqSYh63NM88JJ68sJ5+mSrnmL1
fwq8RePvGxqpp0Jj12r0TqX1pWK/ubN2g47Wr0CsTHVCUEBdYTU/DaEuwTPG
YZqfhsMhgz+02dSV+PL7dl6NHXUlLj28WMmvELCejnlu43xBhRPr6WiPlewK
7mfmMrAlX2Yql1DPQJ6xo8VDSvMzrc4vE0tKXSdP7qOustqfCoo7H4oxTPtT
Q9vUZlPVTF2Nu5qgXl8+3W/WwvvWZ0EVWd09HuaGP6w18Dw=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02lIVFEUB/CHtKFO7uWaNZaM0urWuP9dZjSXcRalqA+aZUhqZVqmtDzb
LCJpEYJC2qNQTIeMdFokGVPCREWJFipHogXSbHHBpaJzPswMPIYf/3veuZx3
75LsndocK0EQdH+ff//8W5DRaGjIk+K/hqP7fKtSTC5sAT71K4aONC4hz0PS
kf0jlzPZ9ig73DXSMbGY7Iwak/XJ43fYrvD+8PnCbgXbE7ZOT0t2ffYmL8aG
gaD+gmVsKaYnapLlWxaRl2K9Xpa9Qe9F9sVIT9T5jDZPsgz6tQ5er+ew/WF0
zDtqk+xBXo4y29brv43u5JWoHCi85+XCXo0rocesTafdyGvgcM/gdtafHYDq
A57bbp53JQeicjQrsaBvITkIcvhYYWQBORhS/byLxlR2CLpru34sLXAhr0Xz
ruWjOiu2HK6ZD3sqlc7kUAxu9wubqnAih6Fa7Cuzq2OHI7td2hwosiOwKeGJ
9US9IzkSYzfmHhyMYUchXtw3tabCgRwNP5WPs6KADZT6PRvPSbP/bxHwcDV9
OnuOLMRghYPs+8VuzmMQ+sJwpe0957G45ZP0Kugp57EoqgmP1l/jPM4ij7PI
47HHoI6Qj82nPB43Oq7vtSkmCwrUREhzZa12lCtg/GGn21hoS7kSkt0B4b2H
JZQr4T3d+Vw+bE15grnFBFzqtxm/FWxDeSJUtZWKnEauT0S/5ETuuIosrMPt
mFZjmxvn6xCXPhkyW8n7S0L3g76fL8fofWISOt2Hv1TZc/9ki/7J+C1pKp8M
5v2nIK/9wePeJq5PMX+fkIpHz8K+yUy0XkzF/eEzq9w7ub8K+bFnHs2/yvNT
mc9TSKP7xvNLgzrf//kvN56/GqcCct5cyiJDDYN7VXXTEH8vtfl5aFEjVdlm
HIzkeg0k+Y5fTxRyvcain8Z8vy0ai++rxYygmckqpvXQWvTX4uMqaeAOPzqv
LVoUNdw9qS7j86szXw+d+XpRh57oc7MWvuV63d95VrwbO8T3Ix11CUPaElu6
T0hHR2l8xFZfspiO8c1FU+WNTvgD3p5U4Q==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIk1Ecx/GniWkOcl62ls7bqAiVmZpu3tpvc246MygySy0qMAlfFDMs
UuEpSikq05ERSRetJHTrImpeQClmlOyFiygQwiCkC+YjWtnSWbH/eaEHDocP
33MO582JOXxsV5mI4zjNv/l/ZUNW2D3wpEIJrwRteY3afF/KzMGqKXnw3RZD
9kfIkMcvsJBZgqA9H8rr/kSTQ3H8xU675DqzHHz3kdbzmcwKhCXMyWcGo8jR
KJh11rhnIslK3D16JuKmiXkDAoWLDV1NEeRNGC+R+TW5FOTNmJy58dk1GU6O
hbtfU7JUzRyPH0VmruhbGFmF0kMH7RPbmbfAoJ5OKVatJyfCV7Q0uPGcnJyE
O9f8/V+61pGTUddYkV4dxbwVI5een6wakpFT8PD25OO4/cypMLRMBPddkJLV
2FEpqW52hJI1UIzvhaSROQ3DcfqpTgtzOiL7KnvqR0PIGYgXrth7G5gz8aXZ
orNpmbNWeBusZYK1tD2YrEVA2/wBoyOIDBj4U4uJ9WQeqOzI0D5tlVDXocA4
4viUReZ1mPX07zvrx7oej8I7e135gdT1uPeqrUp8Yi31bPQIVxPCnGQ+e0U3
IHv3QqqvkXUDxp69nXs/L6aegyiPc1QjBFDPgdA1tlgrXUPdiOk0t0evWk3d
iPaBd7LXCl/qJtTeejMo++hD3YSi4iS7Rbmk9fZciH1sp79aV1HPXb6fy4P3
f4io5yH58tQv3fBvOm+GKDrWLe5Y8Jo303t+Us9fvp/Pp3s57i8gbeXw
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2EYB/CTZmpeS53mpXmJCpHh/Tr10ek2L9Nd0ySitL64StRE0cQp
pJAlWZEfWgV9yPAycCJTFzYjKQoRkVwEFSL4YZpOjXlB7cKeNzjvgXH48X+f
9//unBNWXiW/6sAwzPm/v393cnFUI8YhdTjYZc185/IkEnyJGdAu8F4KBsPQ
LlA53fBeJyH2Bp/rw9WjS6FoX3g+8W3y7X3iAHgT4B3kFU8cDDPOT8NW+7no
UFhZ4beOmE+iw6F86PKI7QzxKdBX+GsLOkLQpyF6faCyfSYYfRYubFiOb9mC
0JGQYR66qBcRR0HrJaGh50YgmgegtXzVjZ1AR0Oescp/8xBxDPDH52/P3glA
x8LyFX3bxoA/Og60htXOEFfieFg3yBURGRx0AvxY7q0r0fqhE+F7aVfH3S1f
dBKILeYJz07iZFCXOssqenzQKaATrcnr3YlTIUfTsB/TcQydBnVGKT952xPN
B4FyL9FJSJwODqGRu2797ugMmB39/OvLths6EyLyH8+XvTqKBrB5jLXuJeB6
DQD3YPpTspXkWTC16aUoqyZ5FrVfNnjUxKbNtXlgng3TgVbLI28yL4C4ez+3
skyumAugsWV3Ut13BPMcsA7P7jf7kTyHvZ7JhZ2oB7d6r5E8Fz5MpdffHHfB
XAjt3erUJq4z5kJqfxEUJrUYFnmOmIvA/r07YC6G2v60TP0LBnMxez2TB83P
5l5zFsh8HnDFkhROnxPm+RA1fPhIYhfpz4fuxdqm7C00U0Cdv4DKC6nzF0Kv
0cz5GEz2l1D9EvZ5mSIoKYvV1YT/zrTnRfj+9+xmimEtZfcgm7eEeTG4OQ42
Wh6uYy5lGyhrpOx5kxR7ySVj5yCj5mXs85hk+H53sF+O8zacp6yRU/2UGQXV
r6D6FVS/gupXUv9fSfUr2etNSvbzZlTsHFTsPo2KOr+Kev7n/vsPw/+HNA==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XtIk1EYx/E3Z83byvttaipWm8rSmZq39tt03ndJW0YpVCKECqUIZiNc
FqVmYtQ/KhYlKqR2M1MrU1JRiDKVpCAwMgKVUkEtR0XFnhO4Ay8vH74Pz/nj
+B0/mZFnwXGc8u/378+Oq6776YMCf5i0JKv08Suo2MrMYa6lM/tWjx/ZCgpZ
S3HtQWZ7NOsLi8R8ZmcYS3m5mpu+ZHdk75LW6VXMXtBGNuk0q9vJvhDxchfr
hcz+sO5u/lRT4kMOwLhEO5zS5k3eiZDljvyL415kET63bhrR6ZkDkeH8TDx6
T0gORlb+jtYAIbMExx5nlgVd8iSHQH1IH7o87UEOxQ35RLU6lVmKj8ZerrPc
nRyGhUdNMyF33Mh7sLxVNyTezRwO/4dWDSMqV3IEHOrUnFzKHAnd+81VlXoX
8l686eivOj/tTI5CxWhWjjGdORp8H8sDw5NO5BhkTlfVTHozx+JI0oCN8b4j
OQ6m92Teh/qBtlJdMLMMa9V33XJWHMhAYv9cPibIBiCbf7tBqGRdjsvSvA+N
R+2py6EtDHy56kHmFCgTj67naVhXQFDouFBZxHo82mP9T4iGtlGPh53Ti9JT
c2QuARa+gUbbdjvqCai7wOudybGhrsRE79uVdz9sqSvxynNp/ro964k4HHQ1
+fVp1hPROG273hpO5pLQPxr9TTTL9idBUCyNmaoQUE82uz8Za4K+cz/DyVwK
CsZ6n0/1sf0pCLvy9bt80Jp6Kpa6Jn6ddSEbUhHcZbklopZPPQ1jI3GlJU+s
qKfR+1hQT0d6ZHnPrIRHPR22vM4z89eWZaauovvWTTaosBhl/K2QfKGupj10
DGbmNBvnDRqz/dqN8zCzQbtxftCsc/v/+w+Po//U
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1oUmEYwHGnzX3oNmebzWbNSYq4JVPLfWj56OZHamEbW2AEa7GraqNF
0ALpMByLYNLImyxWENuiLWstoZrBWrkuwsHYRRdBIkJEtC9jJhLZwucN9MDh
8OPPc5734q3t6W/vpdNoNM3O++9LHl5nYH72vAgy2tSFC0LR11xiGnjFN+7e
m6tFFwLf3UB96yLmQOqjRMakEVfAoGQw79mEEF0FK+xu17SVWADhpT5jZbIG
LQR76kU0fpJYBOzt6Nry8/3oA7C5Mbloje9DS+DLY+7MTTOxFBaHYfRTnwAt
g4cXOGeZY9XoemjUdL6tu78XLYd08XDPeA1xAygMk+KJB3y0AvjCUFcsn1gJ
+fR0UOyuQqvgstfvKlrYgz4EHXfSMYeA+DAEfJN6TxmxGhztieqnQzx0I6jj
TqktUolugnOfg8GpHxXoZli/+H5bldiNbgGFyffKGuaiNfDmw0gkeZ1YC1ql
faS0uxx9BA6WS7d8Kxz0Ubgy79A2JUvRup35lnVpjI0GCP0s63BeQlMAJQNK
zepQCXY9nJjxGHsDaEoPzroxy/JVFnYD0IWyFGuazBvgkf5daIlP5lvhlpvx
MnKmGHsrqEbXfukXirC3way/3ys/XYi9DTaaU38MciZ2I9TP7WKqPQXYjeAa
Xw3yogzsJmAxnlz7fjsPuwky95mO3ZxtygynnEr/gCity3QLnv93xpQF93/F
fizbFHECuzXbVI5ptpz/23L22/H8W9jtOfuP/+9/AUaa8ek=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd011IU2EYB/CTpmmLmDZOfnbcamJmklpu09yeza/5MZ2byzSlKBRJK9Eu
RC1PYHZVNEOCiJJujNSghfmRxi6yUtGIaUZeRChehJYL/BpTK/a8wXlfOBx+
/M/zvM9zcaTnr5jKvRiGsfx9/r3JYS29r19UycCjZc3IoI++LJCYgcszltSn
NinaD2pUHazZQCyGTd/2VPlWBFoCXOvLldBu4iBwj3U75s8Qh8FpxddIpYg4
AmyJrjbnTQ4tg7OODE3z0gH0IeDEK519QBwJFaVWlboyHB0Ftsra4e2JMHQ0
jLhrAh+4Q9Ex4Hw47H89nzgWjtYH9zQMhqCPATfSOj2zEIyOg6yQqU/v0ojj
Qc3Ku11vg9AJIB113lIeJj4Od9bO6S9N70efgGKZsuPLKeJEkHbckGgnWLQC
nH0m80E1sRIuzA4NdS5K0Cpo2Tk65nefOAl6NRXrTdXEyVDyezZRvrkPfRLa
5ZvFzGPiFEhPmW/66ApEq+Hi1fVXO4qINSCOiQud3A5AA0yVr/pHDaB5gPAu
9+dSBcm1YKyOHl8JFmOuhYBFCbvM7sVcB8Pvk35Gze3BXAdVH/rfOAZEmKdS
OWUmDTZi2po6q/0xT4O7Ld7938p2Y54OrdaqpEZuF+bpkKto7puL9cY8A649
cgyx39F8BnB6g4p95oN5Jljn6hp1a6Q+E7itiXHlMumvF87L66n5sqj5s8Ar
Itol6iJ5NpQcseon60l9tnAfJkc4D58Dv1SuLV2sL+a51Py54PkfvTA3QF1X
ssb2hMHcQOV5VP884b5MPtU/H4pK4p/XyrY1ntwICbeX1rT2DY+BMm/Efd0e
2404/yrWFwgNlPkC4X32AhB59zT8uOfEehPOiQco8ybst4D1Jup+s7AfmIXf
81Rup8wUUvtT5gup/Skzlv/z/AEHf2de
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1EYB/A3KQh13jbnbFbzkk0TyUwr0/bXuTmv85KhJRXiwLwUYhfM
ijeiKIokRexCH6RomZJFF13mpcJUovLCphjzwxaxdImQSprQBZ/zwR14Ofz4
P4fn8JzXv/BYts6J4zj8+/7vbIlzX3Q8LQ3AsmYUCa9HGjkJM4e2C4+mNr3x
J6/FwZM9qxSlzB7Y8nLfoLOQWYTrVmFlpkFGliBQPyFvzWX2w4/ijsHRyY1k
GY5WF1RPpDMHoMH5kkl6bgM5CGaxvfzAzfXkYBifzB86YvEjyyHU6bJyIplD
ccfksvAgSkoOwyfzsxzzlXXkcDj/iSyxT/iSt6LpW/iYLY85AsrppvryIgl5
GwbqW7Km5D7kSOSfnVZdmxOTt+NL3/Px0UrmKMy1XTTMj3uToyGzetffy2fe
gTxNjYelW0TeiWpjlYA7zLwLd3njaffHQnIMBqoSY4uCmXdDFff1zOdFL3Is
1J3fSzDkSY7D8WJ9l1bM8j241a0/lRvGrEBIRqBIVc7qAUGZ19TlCo9l80BV
SN+CTkvm4tEqbWkbTnWnPB6edpF4RuxGeQJ6f7rn7K9wpTyB5u9CuRLzAsP5
pSiWK/Ew/l3ve18B5Yko7W/vGjFQPe9gTuVwXgUnWeiiSzOZU0O5dyl6jZru
w6sd7pe0sh+fhM6+mGm5lZ3XYKjdODv2i/XXOPRPXlnPJ6+cB5eCzLLQD3O+
bH4pkEqsthu1bH6pDnkqvGw9b5uz2fzTMGAKmv3tSubTMKyoXe1jZnk6Gu/3
e9eY6P34dES8km62nGDvmYE63UxdgZ7lGYhQ3zakfGS5FgWFFmuYjf4fXgvN
5GiX21UR/gKO2wjg
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd01lIVFEcx/HrkmkzybjkuDuOS6I2uI46LvfnzNwZZxyVTCmLaEOJDE0l
SlMaH0qIckmDioSyxQdxcNqksoUiyhYqCx8KoyyUDFHDFjVsYf7nwblwuXz4
nv+59zzc0O2VhaWOHMfx/+7/T3b5FF+7ZS2Xw6ZpvrRQ2dcgYuZQtL+0380a
SnaFl/5Z5bYCZgmKvvZWGL7LyN7oVlwp23mG2RfCr7hUq545EPlSp5YP30LI
MowqH4qHtcxylNzQZhWcDCaHoz647U7dSuZI1K57bxTKgshRyNF5Pbl6IZAc
jWDJ06rkkQByLIQdGsGlmFmBE71NGx4M+pPj0Dfn2Syf9CPHI6LljW6uijkB
AzUlC8rrvuREOLQOLX5pZE7Cu7BdXY8imZPho5JVixukZCWm+ArDx2XMKWjs
fLnFb48PORVKf7fzM2dXkdNgCXotjx73JqtQVxszPhzBnA5PkXRgbMCLnIHY
6WZLfwtzJoTMz/Uv5j3JWbioSnzc3cnMI/5mwOrRvczAjyMW6eZZD5vNsOvZ
OHW3e19xLNlsZ04NkVNv3UQ7m1cjI8HU5L6VzGkwxB93lo6wrsGlMOPbpPsS
6lqs8YiaOf2KbNZicDh8dkHM5oWl680Cdqtbb7ufc6eug6Msel7UI6auw3P/
6YkOyQrqelgtlR2KTa7U9TjcVq46ELKceg6m0uYX1QoX6jl0HgfqBphSDvZ/
UjhRNyxdzxntutFuPheJxyZ/Zt+b4209FzU96fzlLo66CWuPxsc4H3KmeRNs
/6Mj9Tys35hgqZb/ofk8Ou9vm7l8et8M9Xz6vjHqBbQPx/0F0hzvFQ==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU3EYx/HTvCTM5rR50lpu3qJ0SN5mumy/adM5N50OKUZQBr5aZWWg
aaB0fVGmozdaL7oQGkqFXcxLmZeUlRFUtLwQQUFFJBlZtlVasecf7Bw4HD58
zwPP/3Cid1aWVog4jtP/vf892cWX3e7vssfAq1mtanv2/IdgZg7PHn/rbroe
TQ7Cz+kQo9XGLEX0vQHcdSvJMpwfeDU03MwcAbvkcGWYmlmOEUQdiR9XkJWY
7AkYe6NgjkGFWlrlaYoix+Egzx3NW1hNXoPJ4fK6C2bmtYjf05fo6pSTE5D6
UN+8y7WKrIJEM6FsjWdOwvuuQzVztSvJ69HCzzjL2yPJyWgxxZUGNUaQU/D7
geLkrakV5FScLXa/3rHIk9OwjbPyFgdzOhQGcybfEU5Wo2+vat4qYs6AfHor
pA4ZeQOiequ6T4wvJ2fi4mVneJMrjJyF1vvt1WUqZg3WFcXK9LtDyRvRFmuc
ShuWkrMR+knGz/IS8iaMfg2x2vYFk7W4ohsZHYtcRgae9ryYm/gh9roBsDt7
Bp73kjkdzrnE7rZ01nWwJToMT2pYz4FzNLv6QF8Q9RyobvoHqk8vpZ5L3yOA
ei5MGfV33ib5Ud8Msd/V2o9nllAXmNPD+3+KqOtR1anR3rjEUc8TzAvM5Qvm
83HcYc+qU7D9DGjvf8k/krP9DCg5lZzof8yfeoGvGwoE80bU1nuG7B2B1I2C
8xcKzl8oOL8JW2wp1/bHLGq93STY3yzY30z9i/d9rggiZYJH3PmL5ouQ2jgz
rxt0Uy/G50zPQk7Sd+rFgm7xnYfFtzdYfOcHmd/RfMn/ff4AlAoSAQ==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1F1IU2EYB/C3OT9qVrN02pxfsyJ0rHR+pGZ7Nr+mc7kPt4FdKFJ04YVg
pqKJR9FMNGmoFyZ40YeCmqKjDA06XVQiGGRReSEUUReGNA0SJfviPId43wOH
8eP/nvd9nuccFldZbb8oIYSU/73//YqXwvlgfrpKDYJ8+qnK9vp4iWgCXaq2
xdahOHQQbI3P1b1JFy2HD51RL+TvY9GhED06qGvtEB0BHZstq8vxolWQUvS0
V9oXg44Fy/elqzsb0Wg1WOOjHBGNoo+C3jMfXT4WhT4OQb7uYz1xok/A5i1X
wWezCp0AhcuKlSvtkWgNhGc9uruwrkRrwRDYvSr3HkGfgqp7jco6jegkeF7r
aag2RaCT4euFmbbNiXC0DlwjQ8nuYNEpMMBl3wkxKtCp4Fzx77reFIZOg0sD
ktr9ulB0Ohi1Ff01FYfRp2HwyWi9U3MInQG5XMNuUmcIOhOmIidml80H0Vnw
0HfzpHLpAPoMSGITdmTjwehsKEv0mF42yNBnYeitbHskVbQelpS+tX75PjTQ
5gB83le7zWF7MTeA7sb6loFHcwYmN8LCs+z62rkgzI1MngMarzQgrTcQ8xyI
MVkyFGP+mOfS5nLB1pOUKO2QYp4Ho/PvFIsqMc+D4vSW2U9aP8zzoXn49WPF
RzSXzzxfwOzPmJiY/U1wzVOV2RSD9ZJCuh+uEKYnq/u157FfUsT0VwQyv/uN
a317MDfj+/mpF3Iz5huCSTFtjjGxMLkF3GXJkzXq35ifo80xJiV0PVwJMz8r
XR9Ymf2sIPw/SIT1vJXpz0avBxvTrw2+Zez8Mmp/COZt+D1tY312uDyepZ+5
TYT9wE7Xx9np+fKMiYN+X+DA8wLweca8g+6HlNLnQSnzPZXS3xPP5MRJG5xM
/056XjyTExczPxc9H86F9X/B+bnwXPFy0wY3vZ77n/8BsAxyng==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0V1IU2EYwPHXzUpaw5VzLrfZnBFzjeFc8zPdsw9n+zQKGVsGYcgGuxjk
RShkp7zJiyJwdiPeLCaStdgkVCxYBUU3i6xG0YUXw4wobSNWW6IVe96L7cDh
8OP/nvOc8576wcCZIRYhRPfv/H+lh6D/0UrUL4OCfujOa70CL5eagG+pse9F
tB5dAc/vDbqa3NQ8ILGEqZtNzQf5uCrvnJWihaBhXzC/dlKLIegSX4luHkFL
wacINViBWgaTO+WBpek69FG4aPann65J0Mfg08dR4nBSy6E/zu5iwmK0Aq6P
JaZkP0VoJRx/PLFnxkutgvXMQls8Votugrphk+xd+jBaDWOSmnBmXYhuhsr4
2TBLSK2BZ7Y5xZuBGvQJ8Kv+rK2+EqC1MHKb/95SRt0C0lT11F13NboVIpK3
MsUGH90G+d/G0GUldTtsNGZG1Ker0B1gb726mFJRd8LAuMbz4csh9En4VuUe
yk5Qd0Hhf1J3A0+pFiV2D6J1wGE/GP06SQ2wUhucWd7iFcwAPBTdX1y1VWLX
w5OXHZvy1AHsekhyb/hyTi52AzRY7yQ9c/uxGyDLXb62rcX1xAjTSU5uVsvB
boRoJBBUnavAbio2YwLlQvnellv7sPfg97Ox94Dm5vdf+nhOV+jmYjNmYEkV
ec78NvZeGJ7v1MVCBO/vBZenOXJJtov9FO4XC3uJiaV4PWPB/SvDbi2ex1iL
5xFbyXxbyf32YjN22GrP7xhUWXw/B/Y0Pt+B/TN2Z0kvMenDOYT8BcVD9yM=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HlMk2ccB/AKGBggK0flHKcSRisKCiJyfEuhICLQUigtrUMiWyYk7gA5
xsyLwzmmjkOWOeYWQTLcJiyOaGQIInNyBfCI7HBOJ0aRjdENRECObdnz+6Nv
k6b55Jvv8zzv+zx9vLL3KnNMBAJB0b/f/37pszrtXPvZXG/8L0NUqVh1okhI
FqBkbmLXhtNezBb4YmZltYmMLER1nfB+5IQnswM+C2zVtVWSnWCvnDsTFEl2
g//OUNuBbg9mTwRf7J1ZGnNn9oa+sHJFmJi8Bj5hx46/V/QCsy9+LPvAqum2
G7MfTsuyRUfjyP6IKrN0Pj7syixB4d/SxNSt5AAUdHiUfB3qwrwB3yU6vJTW
4MwciCd2T3df8SUHocW2/+HjBifmjQj4+JtJ/YIj8yaIHIPFgwfIwXC/8uvs
jR3kEFw90l2479Jq5s2omL/2pfOiiDkUMsmtYdOD5C247FPuJ/AmhyFl/Unv
fCcH5q1ofe3NKW2RPXM4YiMelA7P2zFHYE/+7PkVanIkz1HIel3/rH/MlhnQ
mTfUucYyc0C7S+2nbZNClkuxZaj95NV7zJwUn/sk/Lypm/JoaOqa60USyqPR
2Hdqn1W+DctlkKkWQlbKmTkZL4/BskCxnJX/PMtjeHkszhuq1rsMUj8WHT1h
f/qNWrNcjtzeC50326xYLsfMqrayhWDK46AVV8cPFVEeBxNP/3mrryiPx8aj
E0+lXc+xPB5zkprSpjxmwTZjc9tQVW564a7ekuUJxvNxCfBYGhwINVC+3djc
dhhary++LaLxE/FudW7YWx7mLE/k5TtwtmVvbUCmBct5FiRh0MUwXiuk8ZN4
z5ds/L64ZKyLCFBderiK5SlQa4Na3vBm7x8pmFr6VnPAnPaT564U5EVXddjU
0/4ojPcXCuP94xQ4HJTzyydZ1Feg+MWeuZxkOj9K4/MHJfpG1kw/s6bzqEQM
V7QYeIi5S8k7v6nG5xWpCA9KPGSTRf1URKmndUmu1E/lnV8VvKSvVBQsUV8F
V6fRseoaen6V8XxdKsw2mu9/IKX/UxpuRNWYOd6h9adBKAl0HVqm+dMw836L
o36a+jwL0o3HRzqvnw7LU7M75d9TPx1Wps0l48eor+b11fjDXpMzU8HWx6kh
73i8B9epr0anbu1ldytafwZGLy5y4s3MyEB9Y6+ocoT6GWiJm1QWWrP7pisD
fcUx4bt96f7RGBsa6LLvj0rGmDkNSorFj0bWsvurS4NzUS/PlubRfaaF2+0M
CKuZoUW5WV+/xUfMnBbiSvlQ9AD1tbBrvvWqYT/1M7HukStnaUb9TMzPyhoK
JdTPRPz4D502h6nPs0BnvB7oMLQr46+pn2j9OiiOBIrNDlJfB3GP05PG36iv
x7UzHRXvjFBfD4PiZuWHIez+5vTwMrtzb2qB+nrc/b2pQH1ChH8AqqPzwg==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XlI02Ecx/GfOjya88ptmrfOFGc/8j469nGe85ipHSpIEghhkBlhYYi/
tCAiZ3YgkccfxfqjVYqJpAnLiLTDoZV/lAYhSojlwlI0tYN9n8A98PDw4v0c
fzxBR6oKK2w5jsPf+W9lQ3agd6D7WDAsMqtCFiJ0SmdmDoeOvxOHdQWRHSHv
rzg7cJDZDZWpd+ekjsyeKJyR8GmPAsleaM/rcPm5n9kXXat+ph0ccyAOdzTu
qy4OIAfDy9i4VKb3JyvQ3dlWY7Bh3o6WScVyTaofORwNvvXuV7p8yRGY7hwe
/i1ijkS34P3lY6UPmUeQInpM83obeSde2piSwwqYo2DSLTWp273J0dAMVMkX
bZhjUNYcefNTlRc5FqFOo8X8jJwcB6NLwuCQB3M82kyhGvtLMnICGs8/m2w1
SsmJiJ+fnTI4MCdB/bTIXxngSU5Gu/C+1vXBVvIu3AhdL+E6mXfjtPQW16xn
3gM1X379ZDnzXvSd0JfwUmYVLP/tQQbGVVdF8il3iwVgZELx45czmUvZbCEF
+pDsD7FDbtTVWNzoL2lwIAtqPPQx9I3nuFJPxeCL5G/h087Urcyl4fmia1Fp
NetpWJI8PrcWx3o63Oc9ZWaZC/V0aA269IpeCfUM3Bm5XSM+xXqG1f2ZmJBc
PLqipf1CJgI23rxKNG+hnrX5PSELpcqWrNEzYuoamHvG1uukTtQ1iOwR2cfr
HKhno+BylFJ0QUQ9G3Udb5/IPttRz0FuQn3fNE8WcmAbGLEqvremsvRcxDR9
XU4xrlgsWJnLg9jufu3cte/U8+heNrSbLWixkLS6oeZn6Xy+1fn8//0PEKj6
UA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlntMlXUYx38JeEMQEEguyvFkDfGMBcQd5OF+Ebkdrofby+EcOA02FiCm
5HilZF1NlGyz2o7RvCFuyJwgo95yhNWEkoVNWp7F2kwNMCcKoVbjef94HrYz
9tn391x/z/u87xZjQ555hRBi9L/f///VP8+Ci0N9dVpYprm4mUvjUw9dVBZw
/WR2S3/fFuTVcCZz95NPTSq7wB7Yv2nCQWV3aLif7nykW4O8EbY5NE28Gqey
L4T2eM3d/cMPWQPaGdvWzfEqayHwx9SEd9/bjLwVbg4dv9F6cxPyS+DbZ/hV
7FDZH5QXJ/beOuqLHAA+jebfOq77IOvAz3jgn49iVQ6ElnWVUzWyN/LLUDae
vmZ4ygs5CJLCZ0MNgSoHg21xQPS2bUQOgbumC+1/n3se+RXo6KyLavVTORSa
F89og6I8kcMgUffzuN1BD+Rw6Lj2sVexTuUIKE770OX3r9yRI0EvIsb6XFWO
gszwtkvTgRuQo+HPY43xvXEqx8C9DSXm+XfckGPB7bbyTU+eK/IOGPLu+mxw
1gU5DnpitBb/K+uRgbLMWMRDYv5SmEOKM+rx8Mmk48LJUEfUE+Ca99ydLpe1
qCeAYXtn2tjrqp4IIR/89SheWYN6IvSdb+gKLF2NehLTk+DqSOye5suqngz7
2ha/rju7EvVkpqcwnbFIBV2//cqwQ6tQTwW/tF2RnmcdUE+D2cjFpwmBqn0a
5L4ftN3+oD3q6ZTldDg1dMPze1/VPoPFz4C5/p+e7PfAesRO1p+d8ELGsUnD
aWSRCYffshu4Va7qmUzfRfstMxZZtB9yFq1XZFN/cjbtt8iBuqsDX04Moj/I
gRWagEXHnnV4Pge++K67xbEZ71/JgZEH6/WG11AXuTDvNHhgKRQZcsGpMTh6
ot0J7XPpeSWXzUcejQd5kHXuULL5omqfR/NT8lj9eljQHXnjVD3WA3rWDz10
Tje1JjzCfih6dv/5+HzZoT1jOZ/2U2EsCmg8KKDzIRfQ+VEKqH9RiPsD/UEh
rUcuZPkXsvkuovMGRbS/chHtr1IEp+OvjHzrhf0VxeB6z91zzhPvF4rZ/TFW
itn9ldD7gBI2b0xXGAsDTDq9bVnIQv9goPMiG2B4NGrGf1rN38DyL4XdQzkx
EY/V/Eth77bRBXM27ju5FHLqA3546IWslNJ6RRmtB8rYPiqj86iUMfty2h8o
Z/WXs/rL6fMuKug8QQXbRxV0XpUKWH5fr0D7SmjqiY678LlAe8ZyJT2vVLL5
k+i8aiR6HiQaX5LYPpSoPyvTFebPJtH8RBXO51Lccvwq7P/CMkMVPS9VQZEh
+Hyj9tmyLldR/1bGCrO3VWF/55fthREc7Xr33Tl6H+MbWXwjzU8yUv+ykfbP
aqTPp2Kk92kzsv1TTe9fwxiqWf+r2X6ppvGs7LzC2FZN8xEmun80JuzHcxjf
RONJJva+M9H7tproPCgmVj+zF2ZqrzHT7wMw0+dFMrP9aKb712qm+1Bh523M
n6ih5zWMoYbuA4mxzNhaQ/NRamg9NnZe1NL9rqml+UEtfb9KjGXG1lq2r2uh
PuHwsPMJ3Fe2Wig53nvCQ6d+D1rgwdPLJe2rkDUW+v0HFrpPJQs+T+p+tcDa
7scVKSP4vWm1gIsuyGfsGbJigbI3Qwy/3HaDfwEWBTv4
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQNioVt3b8xWcoDwPtif2cPq2cIB4zM4HIk/wM6x
WhHK53C4KJTKvTYUxhdw0C21nSTACOOLOFyYtP3s/i0KUL6EQ4zAcS7ORBhf
xuF57h7GibwwvoLD2fUTFKt05aF8JQcr77vCU8rloHwVh1u7Z12vviUL5as5
zFtgw37ZHMbXcLCZ+7UmeJ4MlK/lYN/IJTnjvDSUr+PQcTZXrFAFxtdzuJ9Z
XWNRIQXlGziY/crdv3e9JJRv6BCfu3H+jKsSUL6Rg7JvaVhDLIxv7LBV8tn9
L/fFoXwTB1FxU+2zTTC+qUPbxGyrankY38zBRZVP576gGJRv7vCUddq37dNF
oXwLhxaWk6c4potA+ZYOtfMu7xF7KAzlWzkknVDaZdwA41s7nKx0sUlRg/Ft
HNhCGTd/OCwE5ds6COgYSp/7Lwjl2zk801cyztOE8e0dXt9Rb9FvEoDyHRxK
dwfYWPzgg/AbHByu8XZk/PTjhco7OvAWGVlfboLyGxwdNq7Ln6IXzQGVd3Ko
qv91MHsVG1TeCU3e2cHHvH77Yz1mqLyzg7yHr6XYKlaovIvD8t3XxU7JQPkN
LqjqGVwdIOmTCSrv6mDc+/a744Gf9hB5Nwdu5rVVryZ/hPAb3BzeW/7656T3
DCrvjspvcIeaCwMecD4AAg60pw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0nlIk3Ecx/EpI6Wi5iyv6TxamUfpnB0euY/X1Klzh5KGlUmiFlZkh82y
UZoIpZimIUYhHXRoVJaY2dTsmDVCLQklLZPsQuywJMkO+n3/cA88PLx4P19+
z4/n55q+XZ1hzuFwVH/vf0+6bJJutlzb6ob/GpdmfIlrPzCfzIFSn6D3a3Rl
toS1ftpifhKZh3TtoSmtGXkBwM19YHXWhdkOijTX2pQQsiNsAsI+dl9wZnbB
hqbfJ9znkN3QnxOvqVYJmUXAB/Ql1TkxLwFfuMw3yIq8FBNDw3ts1zsyeyJH
ZmXdaBAwe6NLP11udCYvx93ggVW9Wx2YfdF6PVYYbbRnFuNuAn+w5RLZD2MW
nRWnZWQJXmRWbm+ot2P2R0udsHa/A3kFnjQlzhbZ2zKvRPPjlFtrU2yYV8Hw
rLBot2Eh82pkb57I83EnB8C/59jexbcXMAdCdVTsxS0iB2HZqEA3m0sOxsgW
j8BfxdbMazAryezG+D0+cwgmz1oUjISSpah+fdRs8DMZM9/XAZ+sUzK+l1AP
hfi2wH14N/VQtD4sHpo8SD3MpJuYE27Sw02+JwIZp86b55+xYj0CPdLjXNuX
zJxIBPvFFc9Lox6J3GtXS5Ra6jKcXyTv9+/gsS7DWx83yTYP6lEw9Im+Tc2l
+ShI135LVQioR5vMR4P/rq3jspp6DGSt77egm+ZjEKHL+yUupi7Hjr6vHZtc
aX9ynAuUPLpwivYXC7GspllupB4LD5HFyI8o+l9xSD0sWffiHfU4vK/aGVov
pR4P7/HShqYyZl08xnI6JyTfqSvwczK8bq83Ow86BbT7vEb7FtP5SEAh19Bl
WU09AY4DyeCVU1cirF0j9HJmhhJ2G+/0lMrofSWSo8t4w3rmNiVSLR10JwNo
XgVFLi+/6j7Nq9Dg1OvmOUrzKkzNy5S2R7Lz3aZCRO0rfnMJnXc1djV3uNyT
M0ONI8Zq+2RvZp0a/Prn2eMFtL565n44Gqys6MyK4dO8Bhd3GLuzSmleg+4r
T7+Kcmh9DTS1lQKtmNZPRLlT9qeaNwvxBwoUPag=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd039MzGEcB/BHF6VEfnRS6ceRH2mXklNXufdVUunHXV1dFAmNOWlUmoRj
GCP50dja/OjH1kRZrKmOHBa3Zv5gWH/RbGWmYW3UjcLu8/zxfb7bd9+99n4+
3+fzPM/3G7StNKvYiTG27d/9/8kveU6npcOkgEPfNSe8l+T+dOZmKCh5+6eg
JYjsiu0DblHB6dyeaD0QbhscDCTPQ9cyWUxDHbc3pvsvmtEawu2HpQ0jo65n
AsiBUFdPpjQP+5MV0KjKCmzB3IvR1v0sTLV7IXkJru/w0j4960dehsJCbL7S
5EsOwcuq/qLG+dyhOLY16cHVvT5kJVT2kseP7i4gr0TvQ3+D7Ks3ORxNTjeu
BKu5I+B6pNa3v3A+eRXuxDQ/T/0sJ0ei3H5LEa7mXo36wM5ZQ8NeZBVC8qP6
ejO51yDydU1lcM88chR0YTcV5d7c0XhVlPdjdGAuWQ1Tnot++1XuGDQ027xq
380hx8KtaWxLUt9schzcZW1VXy5zr0WQdueZiglPsgYWn7pr3d+4gehXlpvP
P5LNwMHlL8aLM3muxcb6tgavUJ5rMTrRs/G4C8/jUWHRxUaNzaQ8Hu88Tu8a
z/CgPAEXTsi6Pmx2ozwBToEhdvfbMyhPhMnW1fum253yRPSNzsretI/n66Q2
r8N46KXqlj3TKU9Ci+W9vN9vKuVJOHXRpD4U4EL5etj64irLe1wpX4+O9tI6
ZT6ZJaPqqP2JqXUa5cnS97EUIU8R5k/Ft2j7RLyS54LZBgQkp0fLW3l/glka
Dl9/81A+KKM8DY7/0YnydKStOfrgk5Ln6UJ9BkLvO09Tnaf1mjOk/bJMob9M
YX900vHQSec361B2O0Zzr5E5bBVyppf2Bz2MmyLa9ysmNY56wVY9nf9vh1kW
9ffTYWRhVc3IL611nOqzhHphPMsW6rOF+mzpfFbBzCAdD4N0vWaDdL1Wg1Cf
I9TnSPsxC7bm0P85hfYvF/pz4SucTzrT/uUK30Ou9HytwnhmlH6vMArnZ5TO
ZzUK+5dHHqL+8+i9jP0FNCORvQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIU2Ecx/HpJLMsdZou7zfKcplT57zlfnM33eYwQ8IwkZFFF6uhQRjF
aSQq0hulIEkSsxlOMTUrk7C0shKKwhZoQZcR4qC0TEJrVPT8X2wHDocP3+c5
z3meE2M8VlzpyePxcv/e/550BZcMjfQfjsV/zcskHy+VZvuSebhYc2fYaIlh
Xo2MIedBLzXZH5OpJrXoczRzEIw3Dun5DWQh/DQtylAxORwjV/Z4TfZGMUej
xpg0MeVJjkW5/dHSw8RI5njUXY3kiowRzJtQ3r8rcbg9nDkB3d0rHfu/hjFv
haaxSxsiJouguDXXLGkKZU5C+nLV6L2+jczJGE32iLL6kcUIPK57cPS0kDkF
jn0D5m89IcypuHz7S1OEDzkNMxM3p99UBzNLcH1m/EKbbQNzOhSi1y/4dWQp
EieEPzo/BDFnoNVwdvnTGnImdIML2p3SQOYsXMtKfdLVJmDOxitZs1fIuwDm
HFS2WTxPtZN3QMmd/C2uJ+eizLujNUxFluGpLX5xxZcM1/EckJOir19fQV0O
wez9MWsxdbnb/Dx8d94tNXv7s56HdUcEjgYTM0+BGPmBxhNO6gpY4rTTaWPU
lch8PtL++D11JbYFJCy0vqSucv1+ToUthrggVRWtr8ZU5ZJPwjB1Nar7+xqL
aqlrINu9WGYIo65BtTVbNtBB78+H4+3mc9vNtH6+2/4LXM+XK3A7fy3MduN5
ew91rdv6Otf9cDpEWH/ZyqTU9VjL762da6H5evzs9D5jl9P/LnTrhagw7V15
NkvzDa7jOQNWlXgMzo8L8AeziPJM
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwB2IQDQNioVt3b8xWcoDwPtj/TvaNtpOA8RkcbD722t3c
rgjlczhknq99ZxMF4ws4fOU+tm8HK4wv4jBhQeyunn0KUL6Ew8STpxQfJ8L4
Mg47wnUXJb2Qh/IVHALXrv0y3QvGV3I46ql3vblXDspXcRBUnR928ZIslK/m
8EYsciPTXxkoX8Oh8MqZcK42GF/LoTNib8zcc9JQvo5D7KucR++FYHw9h5jE
hHUPfKSgfAOHzZPq9CbMloTyDR0YRTo+//srAeUbOTi/Wzk1NwXGN3Zwm835
cbk2jG/i8D8ruePEc3Eo39TB6vXjhvXTYHwzh1krDzp/XSsG5Zs7LOBnkvrj
CuNbOMzsm5d1qEwUyrd0SPLTXPGPB8a3cjig7fR2TZEIlG/tsPhJa5JzGoxv
41AuOpuhf5kwlG/rYOg2a6fXWSEo384hoTD296kXglC+PRrfwUF29Z9rMeZQ
foODw26pKXN3vheAyjs6RM5au1BUB8pvcHRgUtD6xb2aByrv5HD0M39wVCGU
3+DkMKGFecf9WC6ovLPDxMfF1U7f2aHyzg5V9b8OZq9ig8q7OPiY129/rMcM
lXdx4GZeW/VqMiNU3tUBkj6ZoPKuDu8tf/1z0vtmD5F3g/KfQfgNblD9H6Hy
7qj8BjQ+gweqeQ0eaPKeaPo9HYx73353PPATKu+Fym9A4zN4Q/3BwAAAGN/n
aQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1I01EYx/G/Mk2ImXPrn69Tl61SWbr5sjfbb9PNrVJWskwbNUorUDFd
QanQbsoJZQjSRQWVvWgOFksNwQvTUFhSl5p0EVQE0SIZkU3slT2HyAOHw4fv
w3N1co61HWiK5ThO/ef+fdnhHeOTgWYZolo2PHDeqti1iZmDtm/a1DiaQ07A
0dNLzmAdcxKs0h59OJJNliA0XJnecZc5BS7LqvKOjTkDeUfUovmZLHI2VNtn
Ft7ImGUQisbirl2SknOh82sX2yYyyXI8PF4z4Iph3gFNOFhoN2WQ81B38t4T
33w6uQDeF618ey6zAkOOxbGS1jRyIT5O2W5cj6SSi1A7sVYYU8ysxBmN1iu+
n0JWYXJQerM7jbkY9TL17VcHt5BL4ORqeXs/Ty6F56zhq1bOXAbHUlyvt2sz
WY1D1qtJb6ckZA3GDSe+d7cwa9EQfl267YeYrEPwfKW+Uc6sR0hc3/StN5lc
Dr1yX0+iS0TejUzf2oKzjNkAd+BRr72TGdhZs1VibiV7sG7eCGFL8idvexJ1
I6otc7Pvy8mcCaKQhF/mE6mbsCD0norUCKlXYNj4bHYuleypQEN+v/XluY3U
KxHwtw0oDidQX2fOjM4Lq9PNI/HUzciyVmv4kTjqFkT/byx1C4YmF/nnGaxX
of+du8u0soF6FQpGBfGlfWTOiv2Xi/IFFwXUrf/v42xw+3SGx4McdRvqGpT+
DtkvQ7TvgerK5xXj00jUnnXm9uKLZvWnSfGB+j//BucF1aA=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tIk1EYwPGDrSzMMNvWps5dtKxpW07b2qbt2eZyzhwuLCxGVrRwmDTK
L5WuN1sSVFYMLIigLJi1HNQQiQnJMoTuQxKMQR8KuyEtIquxomLP+bD3wOHw
4384F+neg1tdWYSQmn/z/0oHf9tI5G6HDNJKGCZC3uNiATWBD7tS58fuS9GL
4ZW9dSjfQZ0H6uplga55CZoL4djEa/NtagHwHz/yjVmpi6BzeyzhjIvREmiX
D5bYgFoGd0q7LxWcLEaXwvXC02/sMyL0alCNhoZlGuo10PI2pPh4owgth4c9
Q+WBp4XoCuge9656LqBWQOjFEYdOU4BeD759yslknxBdCe7IBffIjACtgkTZ
ZPFCN3UV8Oz7NbOjK9HVcFkbGZiL8tEb4MTVl21CD7Uabnmexdr7eWgNhERT
Mvl7LnojNCuvyboE1FrY0Ra17mxdgdaB35XwOwP5aD38vJntfWekrmG5FjzT
36J7pNSbYK29hGvpXI42gCiYmnZqqAHOqFzxK7vz0mYAmg/In3wXookRPsfL
fMpe2o2sboLcQyr9VG8udhOsq1W0PJhFEzNkSeTJnOBS7GZIhGO/e3hLsNdB
1bm5H8ZxNFMHFWHOInV/NnYL9F3s0B0ToxkLOM5WlnNOcbBvzjTDMqmHw0G9
4d4gwV6P70kZ0t2K9/9Km2GZNLB6A+QsGD76yf8Vuw2+aJN/TIp57DZWb8y8
j2lknb8lcz/DMmli9Sb8FyF/AXA07ZM=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02lIVFEYh/GbllmjuYx75jJWqLnlkrvzd3TUcRm1kHIIKsEQhzQdKdLE
K1JiUThatJlYhoWmVqYpqZQWGCLlQmBUEoagCE4FmkNqi+8JZg5cLj+e95wv
h+Oalb8/24DjuLg/398/WzYZnc8fK0VYl0Z8lKvrHhQyc3B75L1Q0elKNkZk
3ppiUsFsDn5yJd/BgNkK165XnBzqcCHb4aM4KHMig9kRUfXtzX0LzmQXBEhi
td+imUW43WbYJbjoRN4J14LQ2YKlHeTdUBt775nzY3aH7PDTiUqFI9kT86eF
we0PtpO9EG6yNne2wYHsgxvfTZR2lsx+qGmY0k7l2pP3ojd0AYVqO7I/qq7G
b3J+Z0sOgNOrzz/HUpgDUfd2l8zogg05CBbVci7an3kf8i+dsRfWWpOD0fj1
XFbMcStyCJaPqVbKO4XkUDj1qLoqh5nDkHlkIEFxiDkc88LM7MUqS3IEinLu
96faMEdiTFyz0faTBTkKcX2zuRhlFsND7mYlPcEMCAxbi+dqyTww4ysKyPNg
PRqqlnDxk7vm1KPR5Jb4IXCAzEmQebP1jrUX6xK0RIhy3AfNqMfg3pvGU4Ki
bdRjcFDh31YoYj1W13wsujTVvg4jNM9JIX94WZrdaUpdCuVQd/94j4B6HF7/
MDugKDChHgcDF0+toIXMxePWe8FyUxDN8/FwXh0ZDtFspZ4ATcfoSqn1FuoJ
WDTtKf8VxPbLMOKgmbtiTvO8DOppVYlkaTP1RBSXaV8qm42oJ+r1JL2ehPNq
ZViJM+vJuvN8MpKDy55N+xhST0Fp/XivzRcyn0L3tYG6XNe8XG9/ql5P1T2P
S8P6+zdYN/TMp9H9rIn/+UUaFkK1qxKfmXVz6XQOLaT/778BXIwUIA==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtI01EYx/F/imjOy6o1pzl1I7tYG+ZKnTb3c+o2F1FoYW5ZJK0GFTIV
LKUILUgwsKTshffCLmJ4yRhbpli2IKxMlCCyRtANxHtqeKnYc9504HD48OU5
PJLcvAyzB8dxsX/vv5cd4cEuR/spKdyaUOsjW3TZfGYOg5GPeEWdErIP2kz3
L9hMzHxIup/iyUIEWYC78s4TlhpmEc68cQ7pVcyhsGXJmnK/h5MjcLSubL/1
ELMUace9ZBnPwsgbsXJ7NClKwLwJ3zpmcqx5YvIWLNZ2pY73hpKj4Jh/PCuU
MW/HUHRVtaVmA1kO2dng1mJ7CDkal8vrVKES5h1IGTdsLi0LJsdAIjq2NPBR
RFZgeE+f0SVh3glhQkS+3/kg8i7cUjpujvUJybGobm68Jw1jjkNF0Nvrv6zr
yfHY5hTN3nEJyEqcvOFR6K9gToBx6kNs5NI6ciKOXNH+UD1n3o3MkfKKd2Jm
FdqnQuqLLcxJqHZVrBqdXEtWw6Tr8f3dxgyYa5s9ShrWuH0RELcsjhyOI3PJ
UL52NLz4zKeejIKWRHVHE5nTYHrZnl3qzboG57Y6F8z7WE/BaU1ld0BjAPX/
zKUiyxjzMF8aSD0Vg7bhmffzPOppCF8eeBU/4Us9Df3TgZlGqx91LWQq+YGe
r/7UtVBcHZtL7l1NXYfKS562TzlsXoeX/aqiQrsPdT2ufSko0cx5U9cjXL9X
KXzgRT2d9ltRu3s6/b/gNmcAz7O1+GfVJHUDzXHcH1tp1vQ=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQNioVt3b8xWcoDwPtjf0F42QVUSxmdwCNM9se3u
DkUon8Nh6d3DDh9iYHwBhznTC6a95YTxRRwE7ySbnz6kAOVLODzrPn1tVj6M
L+PQ/LVh03wVGF/B4dWBs+yBK+WhfCWHhbwJ0fv/y0H5Kg4Hbee7KXnA+GoO
Yf+XRHQ3ykL5Gg6LrFPmL38iA+VrOWS9qS//FAjj6zgszhFIZJsoDeXrOUx8
XpDS+FAKyjdwONV49xi3LYxv6MBZ6Cvw9KAklG/koPBy89Yb9yWgfGOHq96H
oh4qwvgmDqLiptpnm8ShfFOHd7EHtyceE4PyzRxuH99y63oxjG/uMOuU0K4F
60ShfAuHfMbfbausYXxLh9poe5stITC+lUPy7T17lr8RgfKtHfoKSldFB8P4
Ng4/E4v/Nm4VhvJtHVxtn9Sc/yUE5ds5QOIXxrd3cNv7MsvhoiCU7+AgLfH4
xcRJAhB+g4MDj/Ch8oKX/FB5R4fwKKN1RUpQfoOjw3+GwP8JJTB5J4e9x63e
aTzmgco7Ocy+xv1zmSk3VN7Z4cPmi39rRTmh8s4OtfMu7xF7yAyVd3HwMa/f
/lgPym9wcWBS0PrFvfqPPUTe1eG95a9/TnrfIPwGGP8ZVN7NgZt5bdWryR+h
8mh8BneoPQwMAMwowoE=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0F1IU3EYx/HDrhQiNJ1zTlOXyUzT1NQ1Z/tN3dQ5etGsfEkkGEq+NBnG
GLkOBsl0pgSxJWQgpJiCzhkSpVddOEtrIQZ20YUSQom1lkg2e6H/c7EDh8OH
7//5c3gSr16vMAg4jlP8ff996Ymqevrc1SzFf31VKUVOZ0wYmcPAl02hdyqR
OQRbc/VPGivIYejbr9wW/k5gjkSLo01rdpKjsVzTmdqTQY6F1aHeFc/EMydA
slC0aBKTpbj9euCGx3CYOQm9Xa0R1vk45mSEeF4krwjIMnRVXRypPRvLfAy+
3bZ+z5SEOQ1D22ljkT9imNPRMRdvmZSTT+DBoCXHPyRmzkRXy1bv6Pto5iyI
Jc1NjlZyNgIv43tn1kTMJ+G5P3H+s4ycAzmOCOCLYs6FxrDutjvJeeix1osm
/EJmOeyit/d22smnMGZc8jbdJStwZ8khvpxGzkdnrUo5c4GsRGq/drnwVSRz
AUp19rXpavJpbFxLUQS6I5hVcPliHlmayIA+79bsejozDzxWZC+MPjzEuhrF
vDmQ2R3Ouhorhp1Q2TNmrhDKLH33wQbqhfCsJvn3DlAvQqK60daxH8Z6EUyu
Sds5C/XiYPPF+JQhzW5Loa6B6pK/7oyEugbHw2XfBr3sPk4bbF6LuPFfq3V5
NF8S/D98CUzj+arpYZovDT7Pl6Kh/cre4ibNlwXvgy9Dnzs0df4j7UeHylWb
/V0c7U8HTcHGzTc/qZdj1jhSnS6kXh58ntPDbTR9rzFT16PG9yH3aCACfwD8
cOfq
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtMjXEcx/FH0cUpFZ0jdJfLKk2RSup8Tjeny6nO6ZROJLPZGBtKSTQP
qzVUboVVSky66JAWKZcTy2T+aSmXMTNbjTGZFqULdr4/2/M827Oz196/7/k+
5/njuG3drdlmwnGc7u/975NdsuS2zpad7jBqWH7IS1uVa8vMYceNyVrHTjey
Ba7Wf2nz3sVsi5zXPT+k1sz2WOw01L2swZXsgCJJgttsFbMjSt6VRZW/cSG7
4rZz8VB3NLM7UmOjxo9lOZM9EH+9NHJbmxN5KYqONaXcn3QkL8fgijmBLc7M
nsgpzq5RXlhE9sbzUNT7Vy4k+6DqysLUZ08WkFciv6E8YGMIsy8kJwIOND9w
IPuhYPqtxsySeRVO9tmeeB4zn7wa1Vbnb9u/kJH90VAzeNMrnXkNPPb2vh6T
MgfgoUulw0VL5kD0vCgozO6RkoPwe++lw6rtzGuR8bJtc1+uPTkYLb9KPzmA
eR0u8v15Nvp55BDoMh4p01KZQ3FnT53OR8osx6dzmYpmOTNgljyjdfjxXKN5
4MGmJV3OEjKnwOhx/fz0ETvqCkTwuZO+RWQuDCvsln+v6LWlHganpomBTQGs
h6NnwGPktxWbD0d0g75xSZUN9QjoKpprpd5sPgIb0vz0me6sRwrNR+LHVIfu
qDmd56Iwzamnt+xjPQr1isfdTxZYU18vml8P60y/4L6jrCsxan33yIS/FXUl
VpV8/akwWFKPxnBr72S+lMxH4/THrINhP82px+Bpd8j+fR0W1GPQ294/8uqX
hHosThWYtr9Pn009FpUDkrE6f9bjhPv4ONG8SnieV4l6vGh/PPIOj3ftbDSj
niDqCRjzPnPo2i72+xKFRqJwnk+EutjXa2bhTKMNos6phR1q5Ff33ZN9MKV5
NVyUqiBZ4yyaVwufh9MI3y80oufVoEW/u8xnI9mgwbeg8akwH7Y/SbgPSbjW
+VL2zJH28SIbkpDVFCy/dZmjeS2M/38mNK+FiavnuKRpQm6c10Ji2pz3+ewM
mtfS/lFj55LJg0Yjmb6XLl5kg+g8l/LffwAxr3Dy
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQNioVt3b8xWcoDwPtg/Pbqb7YwIjM/g4HD22GPt
zYpQPodD7x6rOrZYGF/AIT5adFELE4wv4tC72/c4yyoFKF/CIcHtl9FCTxhf
xkG99eGskIfyUL6CQ4bWImUvBxhfyeEe63/e/+vkoHwVBzGeM/Ovv5OF8tUc
Dl1PYbrrBuNrONjM/VoTPE8GytdyYAhM+7LzlzSUr+Mg6zQjodQVxtdzuBUh
lzZzvxSUb+Ag6f5bSsUKxjd0iEtb2MjWIAnlGzmkqhoy2p2WgPKNHd4bWPlu
+iIO5Zs4FEnmXn9bD+ObOsyw3D3t7SExKN/MYVEjz6YlgTC+uUNzy+E70w+I
QvkWDsFzpkhXGcL4lg5Ca69mfqgTgfKtHGKSHj3WeSEM5Vs7ZEewByZPh/Ft
HF5OK3Jcaw/j2zo81/xUaRgA49s5eG/+6BVoDuPbO+w93n7/R70QlO/gAIl/
KL/BwWHm/uXloToweUeHx3v+Nmibw+Qd0eSdHAzdZu30OguTd3JYamV8Yvlc
mLyzww/vpxyNPjB5Z4dHs81Mb0+Gybs4GO6SVn9UCpN3QXO/q8M69/dB5TxQ
foOrQ1yH20vbIzB5N4cA/QVKJRLQ8Gpwc6i+WsnLkAALP3eHtrPTJSN0RB0A
Xy60Nw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIk2EUB/B5CXMS6Nrm5i0nq15smpfyUtr+3uZlljU0S4x8leUlow9Z
gkG9FfWli9AiMxkFkSOm0QQbpukUTamgpoWQJbSMyiInkqlgN3rOh3rg4eHH
n/NwOEdVfthg9BSJREm/75+Xjryos9t2MAJ/5dau+nzM0ScmiyAeG6291qZi
XolE/quR3032h5f/fMyN7+HMUpR4jfDhVrICz3W3uSEDOQSalKrFSk9yODY2
WG366jXMEVB9sHAjj8OY1ZBOuAKaFeR12DWuuNPIhTJz6Ii3tpwzhzBH4mKF
VrHsCmbWoL/05yS/gxyNDtUZ7pU5iDkGhXO22u4xJXMsCsajynwXFMxxGE67
J3YNkOPhkFp9+OlA5k14ai8Uq5XkzZhJXvqRHi1nToCz7dmc+pCMOREVEz09
li9S5iTcmjpbnnGAnAyfMO/CwdHVzFuwd/9ATske8lYs8keWT3WSU6BxX7pr
bySnountBY/JWQnzNsQ+CF7vOkrWws+rvWHaFMAM1FVZegvkLBcAo7nV8/hN
ytMg+egYsBqYhTTsrI188k3pz/J0bNc9GppKZRbScT7O+LqljPIMdAddMXfN
UJ6BqABu9rqT8sx/+xEyUVO3cN+jmPrNQm/p2v4wP+ovCy+M875cF/Wnw6j2
snfgG6rXQffwUw2clGejuc9SX6Sh+myYjG5TqYX+z8GGULmykqf8P4tykZ94
0v4ums1XyEW9rEXU2ErzzsPp4eJ9S/lsf0IeJO0vq90naJ96JJgGq3IlbP+C
Hu9XXJ23N8nwC3oX2pY=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtMjWEcB/CnCyLdqCMqp3IppFQqlZxvh6JOl3Mtl5GhkYymnYXQmztT
KuYPM1v8YU5oNDUrvLVhs5nRMJs/cBKhdbSRWnLZ+T1/PO+7nb377Ps8v9/v
ec7ZCdu0y1jsyhjb/O/z/80fleVO+63ScDjl0HQY5nht8ORmaFT3T5/ZHEb2
QEKQtem4jtsXiScibY6BULI/SiI+OLobuAOxMTGkyLiIOxg79aVvnjWqyaEo
6s7UVPXPJIdjfcUZl5QF3LMx6ZjaY2xjCHkuAq3fy84dDiZH4nfFu4PlL4PI
8/Gs78NAqzt3FHzH2U/5rJtBjoZ9Vmf8pfvTyYsweGWNrI7jjoVL3YuxvupA
chyKdB3o6JpGjofkM3RkQwL3YmxP2uktWVTkBJRs+bEnJiKAnIi8ct/K8w/9
yUmoLbPa1pm4l+DTvMG9sfqp5GT80n30qM6ZQk7BoZ5NNT3X/cipCAq0f65v
8CUvRVj61pPWMe407J33eLg4n3sZcjMfPexJ49agOeh62wudDxmwtuuXLvnl
7bQELEyLNj/o9aI8HX7f/FUOFc/TFbkWO7R197wbea7FK68T24bzeL4cWddu
2uZcpH7ScrQ66mJmPKX1bAUK18bd3B3O8xViPZahqJ8hzssysebCjcaAKDqf
lCnWYysV+UpMntpVUdbH81X4+jbiSMwhnivMshTzZynOlw3X0Pkjnk2TKc/G
T6+71aMJZKZDVIv7+MTaCZTrMJA8MqaNHk95Dg5c6u5QvXejPAfqVbnJKts4
ynPF9VIujtWXplSqqR7LU9TPQ05SVZs9muqxfLqPPxpnno+r7a9VT4J5fT0M
p2MXuB91dxp6MZcUlvWK+Q1iDgP2VY10ltr4vAZxvWyAo+X57wMBE2m/EfX2
8krtEM0Po+I8RvG8slG8L2YSDROc/2eutN8k1pNN4nzMjOGohv1Xd9A8MIv9
JLM4n2yGp9uNfV/OutB+i3jfsCj6WxBf0z+ULg8771+20O9l1GlWgPKmVM3t
y4z2F4i5VCCeT1asZ4XiehSK/SSF5UL6Pn5S/9XkXtqvsLSa+jD2F3sqjQw=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0HtIU1EcwPHrg9TW1HQ+VvO1RG3GfOdrtt/mnFPn3LKSDEMie2mIz1Kx
rmEoPSxzFKFFVGakCWpSatkiJokZiM2kB1qDoiRcWb5oWuHv/HG9cLl8+J7f
Pfdcn33523MsKYpS/Lv/P8nlurO7ryOXDysyiQf8PAVhdsQU6N8G3ei754O2
hazdDlcMcmJHMA7UzH+a9EZzYJKXqz9QTuwO0/6dzb5cYh7ISsO1wRe80N5w
8Gm8dWGPJ5oPdc1fWE3OxL5QZR78aVZ7oP1geDymMOUyDx0ACkOjOWt8I1oA
u97o1nhwiLdAv+hd5GjuBrQQJDZnPzh2cdHBYMGpnVkyu6NDoKroQdDLZOJQ
OGw/v+Noixs6DNKvLhvVPOJw6O91sjVpXdERcObEXre2Xy7orTAx1VKS0UQc
Cc82VQdQfOIoqDCUsalsDjoartGGcod2Z3QMDJbJRPv9iGPhdc6sXUDPerQI
5E++HoER4jgQhSpr7LOJt0HJZm3DpU5HtBim3vtXB50iBmDnOU3VFqBpAHWe
YOg3l3QJ3B68VcoqtscugbuS5/oBLhu7FCy9BYus1nXYpZAZWK94dZyFPR7G
2LWHFlS4no4HVVtdQk43mZetmpeBfsYhPbMATSUwTSfAxWqrRxNZa7HLwWtp
eCjKhKblEHb++5xEZ4c9EUxdI+ZKFzSdCPXGogrpnA12BXS052uFe2yxK5jr
qSTmfnQSNI6xFu5EkPMlM89LJ8MLfdyx4l58H5UCmnMhgdanrbGnQEZmaHsh
f1m80pWgjDz50Ci0wq6EotZYcedNCudTgWV1v/xbgwX2VDzfAs6rmKZVuP4H
9rRVPQ3/9x/saub+oIbK66OPXT+S71Ezv0enhunoxSWpcBbnNcz3gWbVfhpc
/3nFOg2ei6L+Asl3JAA=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1EABuARiJb323Te0qlhaiunaVPL103dnLtakZrVTKeFSbSKLAqG
f3QqhuGPWlholoHzClHmUlO8gD9iXlZoRBciC1HDu5hd6Jwf2weHj4eX93zn
O+cEnb2Yqd7BYDBEf8e/N32Yx5/1dBaz8V+LScEL4TURDtQMTOVP8hyeBxHb
wca2eXz+NLUL8h6teD3cSe2B72xNUX9HILE3Ko0z/E45tR/YhkFpwefdxIHI
mueuveJQs1FQst0lKQwgDsH+YtnXSYM/8R7c1IXE6hb9iMMQn24a0QZSh6N0
Rvmx4oovcSSmswIK7/X5EHNQW/rtTAOL+gDGxnm/u/NZxFEIN7e62d31JuaC
J5xEV7sXcTTOm0M59rXUMTAkNA2LZ5nEB8HustMPSaljYTK8WQop8SSOQ/6M
0dg850F8CB+yasqr16h5EP142+tURR0Pkbh6uiubOgGb64LGa5HUieBzVHUa
lTvxYZwU9u3a7HAjPoLe3NDXAfbUSbjc2a5T3HAlBvxbtsy5ccRaICi5SHd1
24XkyZbWWpnBR4q29FdUOe3zkciVlDup6PwC9PjU1Xcv0L4A+1zDfupNtJ+C
bH1rg2ckzVNwIofbpmE7kzwVjhpuwkSZI8mtzEiD2bHi3IaM5mkYWnI+mnPJ
geRCmF5MLb9btye5EE+TB4eGWbQvguDYVqxNmhPJRVbfT8f1vSMbajldXzqq
uOr391V0/WIoLoSPrbBoLsbS9svsMluaZ8DX+8ts7R2aZ1j+L0Nitb8Sq/2T
WuVSPAkWT8cM0L7MKpch17ZR75tK+3K4zfYPtGTS85Fbnb8Cq5VtXqeWiaGw
7GsVlvenX4E592z1qo7eJyUex0ePNtcTQ4kIfyarKI9Yq0RD06jnbTPtK3Hr
wYSR+ckdfwDVlRqH
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tIU2EYwPGjM1DnzLzMS5ZuurCtJJdb3ve4zTm3Oc3sokFYuAiUbmaK
IUw/WGglXlBTk1Ac1jJwYGxNCpyisTRKkvASmCRahEpqbmhU7Hk/6IHD4cf/
ed5zDuvStSyNM0VR4n/3/ye5mKf7zX0FbHBoRcQxssLrPYkpmGKOull0LLQr
6JOqr75VEXtBX5WQF2QLRfuCZSS/drGHOABoLeXlBilxMKyfZQzrpkPQobBs
HFIWhxCzgX/ZsNaZdRAdDpWc8xdmWg+gD8ESnzXCtAejI2B5fOil30liLpjz
N1zM+v3oIxDyZ8wasxKEjoSOJ4KcvCjiYzBz6jZz9lEgOgqc4nim927EfFhg
d61r2gPQx6FuvuiO+Lc/Ohrycs7YmguIBdASa276OchEC+HdfNc2cIlPwJjk
XOC3TT90DFjkvzpYA8SxYLUvVld1E8cBr1Y2Lrb6ouN3OQHulg2VbrYTJ0Kr
usI+706cBLaLRdsV/T5oEdQ86Ob00ogBmufuO31Z9XZYC/C1TSiYbkBTyfBR
VO/iP7sPezKYgxofm5a9sIuh+HBjQ70BrRUDo9D7x70bpEugSB8vMnSSLoHM
Qq51PZB0KXj4DJZcX9qLXQpHEyOz3ywwsKdA2tMXzzjtpO8yJYMavmamLY+c
LwNdmGIqepCcnwr6BPaVCAvZT935Pkq+c14rB0n2lnCPzBN7GmwwTBVbAg/s
aeAcyrXT9WhKAbm8Ovl4KR27Yuc8pYSCUePrCRPpSlA/f5ii6Sf/pwLGTX78
RCVaq4IPxk9rnzdxnkqHtkm6TScg++kQpmiazO1xx66G0eHEkluvXLGrobxj
YoA5R8OeAXRab9n3BifsGfj9WyJHz8S+6jBk4h5F/QXD9QqH
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdyl1I03EUxvG/Figuc9O9uZmpZDgnVs7lu3vc5pxWKzd3UVGJtSADIyas
3M0cKHXRQIRIMKL1ouVKCsSXCiudFlGkIAhdZEy6iKxFc5XkVuH5XeSBw+HD
92Q2nTHbYjmOU//df5eN2Dr06MHpLKwpqAnlWIctAmYOLdevjbtGMsnxeBmx
C7xHmPk4sRCdPLWaQRZiqe1bQnM/sxQqq3OvzMqchmPeBsVxHnMGZkziK77D
W8lZOMvPDhb2ppO3oeNt59334S3k7cDR57qlOuYczLd7eH3v0si5WK4cT7lv
YM5DQufEbVm3nJwPx9XsaP2MjLwT3jyL0BzDvAuenjmnw5hKLsCzV97yxk4p
WYWkp5ZbsVLmQogkauVrt4SsRvqF5jshEfNuHDCH5YNuMbkI+t6F5NGLInIx
ips1BZckzCVQTkuXb34QkkthsvOdl/3MZbix2NGkO8lcjrj0jQ2TsynkCgQe
r7qURcnkSvSM9zmsecwafNyRpWpRCMhAlKuPNrYmrdkFnFdM/7Lt51Ovwj7D
lH+xguyqwqDcNzy7h/45Lb5Hxg6641jXQvBZKA6KN1PXYWZkLjT/k0ddh0PK
LuObc2ROj/6qCf9UaiJ1PcKJo+2/1ZuoV8Pk81TbhlivxpPp0i85AdYNiM3I
XeENkF0GvPBXOFrH4qnXoCtgd2p/xFGvAW/DvbZP3THUjbAPlGkeejnq68zV
/v/vql3X6/C1ZCWizQ9r/gDwmM71
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVzV1I01EYx/F/OXRmptV8Wdt0my4ya6TbXFPX/7fNqZEpRoKQRRR6s1bE
gvXGtqDoIrVASFLowkCiCSNfmFqQZctC6GWI1YVssbKIImlRmyyp2HMueuBw
+JwvnEdx5MS+9tUcx5X/Pf9uNrktY/fu2pRIaom/0nHgRlTIzOFWTD4z4lWQ
hRCo3070NDJnY/al8LLsh5wsQnfYZ/d1M+dj1JK3YqhglsLVa4qJRwvJcoyI
Ph5aWCkgK3FOdbrIYWcuhiMUbJrzy8ib0djw6PNrOfMWuCLPKp1uKXkrqr8n
rheFJORtePP4C59VwqxG5+y7deGpTeQd4OaOn7R9EpPL0CQ9PK6VMZejcHeg
oOdmPlkDVfrzVvWHPLIWHqHGFX2fS9ZBOSzsC+xlrsCroRfRYnsOWQ+FYCEc
TYjIO6ENdjlVk8wGjPEdsfPHmCvhzOnnrg5uJFfB1prWfLSXuRqpLatGlqY3
kI2I3P/tKdUz70Jb2kCfxLqezEPmTcy36ZmBMyUz8fam7KQ9gE8y5A/uyaJu
wm3TdOCJOJO6CduN6v0PFsmcGT8zJy4kdGupm3HtYsp46OAa6hb0z2fEB3UZ
1C3QdH39ZZpKp16DpwGj89SkkHoNmjvLSgWXBNStOOtefmi7k0rdim+G5RWz
mszVokHv9kfUKdRr4fBW8cMDHPU62hfnk72O3tnU/29PPf2/yP8B/eTDPw==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HlIk3EcBvA3DaxUmtOmNjM3rVzasTSvrD3q5q27kDQ0K7TDNBWz3IJ6
C820JCqKEqULErIDCzGzbI1S7A/NDqEgGpVOOzUP7D7o9/1jvfDy8uHh+b7X
730lGwp1uXYcx2n+7H+PtInSmtuatkrxT8OKLONJa4eAzGHDHmF9RKuEeRrO
DnorTelkAb5ea/btdCC7wWqf/zG5wYfZA0VN108fVJO9cLGr7pdoeC6zD+76
9qTXfPFmlqJeYai2BJH9EHl+S+dI6Rzm+VipyzFv7Pdi9sf4qjuuV2LJC5Hw
SPSstFzMHIihfFFY4cBs5sXQzJhS8zKHvBTybr8bzpOezHJYB+4LxqTkZVBd
tew/csuDOQj9di07jr5yZw7GyfC2Ex/MIubl2Fv/MNuziByCWp/mmQPWWcyh
iAl82mNfQQ77c//l/pyUHA7J1BeW0e9uzBHY9dTgzK0jr4CeC+tuciFH4k2e
LOJHpSvzSlhlnw1yDXkVrsR90u10IiuQdH0kURtKhm3OA10GZWTOfMqj8N41
I3eiSsjyKDjaXza+PebC8mjE3h7KQy8zHw1Zqq+bqoDyGFvzMbjgm/g82Cxg
udLWvBJPciem+7dSX2VrXgXF6rHMVDHlsejq8xv75kR5LMK72850WGh+HEoa
VyiunaP5cRB7vB48cpTyeDjnC98dKKY83nYel2A7j0/AIhf/kdpe6idiYIk0
aJuMzp/43/Ul2ZpPgiRqU1XpT+onI9PhXK1YRXkyRn/ezNjnQHnKf88nBcJB
k7lRR/NToeTLfsgrqZ+KdcVZ3x4MUq7GqTsNO9MC6f2psX1zQ7taxMxp0J45
7663IzM0EATKxd2/aJ4GJU1XqzRGZpMGRX2j5vUS6mvx7/9Bfa3t+uK1yMg2
x69JZzZpYTQEWPvm0frVQXtIHjC1ghk6VBrvlU3WMfM6DGsfHz4ewr4Pkw5b
csbLliyg70WP3ks9o34FzNBDWWcRtlYx83qMt1S0Tjynvh7Vu9e6Xxqbhd83
ykBY
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tI01EYx/EpTGZprprLpabOEp1reEnnNN1vTufcX2HWpJQiTAaVhjmI
IAL/Lqgga6iBVERogbKiiyFWBssuJFSWZWGGgaztTYUOa17SrPA5L/SBw+HD
95yXT9z+uh3WQIFAkPXv/L/ZSMt7+u7WyLGkSe3l844348HMAmQ8+1ZtuRFH
FkE7cjjGY2YWo61/IlU/GUuWwFhfrZE0MUdAZB3b25HCHAXuju1sc1cMORYH
4pNbhV83keU4LfNn5ZmYNyPPZtZlX40mJ+BVUpnEOxpFTsQZtV9cmsyswEm/
y1thjyQrsarOY28Y2EhW4enQw+mgEOYUbHEMG2brZeRUxEVULbweiyCn4XP8
oY4XCczpeMJ1KYb2bCBvg7LnWvl8n5ScgcYrb/fJjjBnojn64PdL7nCyGnUB
v085c5izYDQ1jXZXSMgaDFbt9k19Wk/OBnfPZypTM+egRN3Q61Yxb0fbeFPA
F986ci7cjxb4ZDVzHtqvD4Q7PjJrcdHVeaxcyQzMcB5RYwmZx4qug1iZGjm4
uJa6DsNWf3DiA7IgH0eTLrS2dIup58Ncq3j5S0YW6HE78mbvOy6Muh56y3ym
0LCGesFy8wXYmquyuLyh1AsRakvLeW8n84UYuv/h58jMauqGFf8NeD4VtrOy
PoR60XLzRZhVtpzorA2mblxu3oj0cz+mdY9ZL8bxhrn+GmcQ9WLEGEs1UqeQ
uglL+xNI3YRdlWm3bPJF7VLn6B0Nz2FCM/cnX+XV/gWUqNrb
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtI01EYx/E/u9RgLDa1ad43vISTldPNluV+u7gtWwVhZFIR0rqgXbQF
XXFFiZUrLQIRsRdhUk6jF2ZgNF9FyxtDo1DCxIpqRIqUl1ar2HNe5IHD4cP3
ed4dRfmx7U4ex3Hav/ffy458R3fvowolIpo23BgXZN5bxsxBxRf/PNimIIvQ
UXj1qN/BLMX3WstA/UwqOQZVdcbg5xbmOJSb6wK6POZEKKP7S5r7Usip2NOU
4WkPJZOV8Hb1PBvQMKehIujMFNYmkTMw7HvuOzyRSF6NV/zBfpmAOQu2K+3F
sTkJ5Gy0BD17PfXxZDXGnK7k/QLmtfC9f+ib1K4i58A7Wnp6vDSOrIFr7O4L
2ZtYci6aty1M7AvLyXkQupJUNU+YtZA1bOWMGmYd/KOXLp/0ryTnI+Adnk07
wrwO948PBg5dZ9ZDIXj7bjYUQ16PbsOB+XOVzAXYLYp3N+mZN+B2+q9d3J1o
8kZc87Sld/KZCzG/+YPogiOKbIA0OydhKCwjAwlxU58ab0ojdgOSyqhgXRWZ
M+LxdMOa+MEV1I0wl4R0QiuZM0FSrSkYuSihbkKZqtE+dEpM3YzGqRNnTXPL
qZvR3vta/jJRSN2CFPsWvfwB2W3B+daRp/JJPvUiOPJreqbUZHcRIv+VR90K
XmrWorgjZIh0K3aWabqqleGIOdv/dtuQ6/k6Z+xboG5fsm/HN/3ib5P6B/VN
EPM7z3y5NUN9iblimv9o+AMBptQm
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtI01EcxvF/Wxdty7trXprTnDnTkZtuLZt7Np2arQvdiwqJhCi0SGtU
UBLhC2U1nVPoSgMpmhZNJXV4mRiUI4KI9bIXk6VdNKWUZkSFv/OiDhwOH77n
cM6Lk3rs9K5KHsdx6j/z78qGaG+P5+mpNCzqq/61pNDsjWDmIK/wnXW4U8lh
6KhOf9KzlTkKNbp7t7xTUnIcBqoaHCYHsxjqOK+8dj1zMmwVoyd9d1PIUuR2
3ag+Ec6chs/rciIPmiXkdPTudvKHGteQM6B22u93+5LJmRAfHQ9ri2fOwszt
gfDLO5LI2chXujhBdyJZgcF9/vGMhQTyBtwsVZ4X72fOxePoseCkU0xW4tNx
99XZjtVkFYYjNAMjMcx5iLZt5wxKETkfvtBEQ317PFmN+ldtCQeymTXIe2O1
yPrjyBsxVTX6XTUXS9big3z2Qu5O5k1otLbLOvnMBRg8LPNKBDHkzXhbORee
2RdN1sGT2HKnbzqKXIhz8hZ7s5tZj5f+9G8LQrYfSBIHJpqaqdcBwtgRy5nJ
SOoG5OgUe4aCq6gbwJNmhQQuIXUjbNf4ve+PrKRuxNryVv+hh2SuCC+e6yy1
/WHUi9AUqLlknF9BvRgpZdu0okfLqBcju2vpcvV11k144HknGktm3YTF/8qj
XgKz5sqzgIJPvQQ1rgK928lRL4WA33nxo30J9VJ6/0/9Yi/713VlUFm/zBuG
f1DfQudnqP9nrhzT2tAvoyJIvZzu5bjfZOfPTg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tI01EYwOHTNnWm5nRzmndnlOYa3m3e9jqdl03/2kVDpS/GypihaSRZ
4QqzC2o3069haJZmTDPNIDORWZKWiYLRhZQUM5qG2kZ39p4P7sDh8PA7L5zj
V1C8W80ihMj/7f8nXcLs7sc6jQjMMsiOjy1NfeJTE7Dqampz6vRDcyE0W/he
mUPNg2D7COkEi1oAm0bKhrx0vmg3qCktEtXlUHsC48q+/HHZB+0LX+ZGh2WB
1CKIVr3j15d7o7eAtrPhfOOEF3or5NeOGVjLnugAWInv53ckU28Hx9W+VIPG
Ay2GoNF5W4ZxR0tgxWah5ZBuMzoY1pylQl8f6hAwbNN7Wx12Q4fCvoOtP0xs
6jC4eYPL1Y+7osNhYLCZNZlLHQFv9Q+mp8qE6EgYMc1fqm52QUfBzBnngJID
1DuhivP8BbdRgJbCrpqQIM456mj4eYvjN/eKOgZGHnbfKS3ho2NhkZ+rXr3o
jI4DnjjEY/SPEzoezs4W1M62U8sgkPEXKI5QA5wI1BvVmTyztQAt/srp8Gdo
kgBtsaLCgEFH7Alw36O9Z1yFJnJwWhQIDcJN2OUw6XCh0Mg4YE+EHXGSvf2f
0dpEYNrrFOpu2pMsehIMfXfck3fUHrsCdB3F9ZJ8LnYFDA/FlR/rQ5NkqKg0
DWjuWmNPBnEXxzqyzgZ7Chi6Xv867WKLPQWM4munbhehSarFfCpUX9VEn/Sh
82lwpYrd+2H/RuxpoBnuffLmkR12pUVXgr+yYTKvFU1UFu9XwUt3w0I9j/b0
9f/RWphkgB37XsXC9Q3YMyA9qrJnRsLGzkBZW4yss4lgZ9bfJ5kQVvt1LeGp
UWbumdiXzCZZ8E1q+i2XrJoNWThHyF8MggTh
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQNioVt3b8xWcoDwPtjHVs14fkwAxmdwuKi6hbt8
syKUz+Fw0r3vu04IjC/g8LVrEyMDK4wv4uDAUnxMcIkClC/hEFI56X9GGIwv
42A3b/2qve/loXwFB2d7a9UmfhhfyaFd8puFnZcclK/icPlL2o7uflkoX83h
ZSTfFIfDMlC+hoPCr61n7j6VhvK1HBKnhGzzUIbxdRzWna8MtDKXgvL1HMra
mZI4dkhC+QYO0p1W6++owPiGDsq+pWENsRJQvpFD3/cEj9yr4lC+sUPukiT2
tjwY38TBIWnb9UnlYlC+qcN7y1//nPRgfDOH+6+Xl4bPEYXyzR2ss4pmJGwR
gfItHM4lRnz8fFMYyrdE41s5TH/Yw3jvoxCUb+3wTF/JOE9TEMq3ceDNEXrd
USgA5ds6vL6j3qLfBOPbOfAIHyoveMkP5ds75DhN2Mu3kA/Kd3CYfY375zJT
bgi/wcFB2WvatagVXFB5R4eN6/Kn6EVzQOUdHarqfx3MXsUGlXdyWL77utgp
GVaovJODj3n99sd6zFB5Zwdu5rVVryYzQuWdHQJ7DLVZWlmg8i4OTApav7hX
/7GHyLs4hEcZrStS+g/hM7hC9X+EyrtCw/cZVN4Nld+Axmdwh+sHADq/uuc=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlHts01UUx3/uiZbJNkYdbGxjOkKkadjYBnvAvt3G2JOt7bqur/UnSgyZ
SmAGlYH8WHzEhJl1on/4IMQhQxglFQ1rpvgjBmUkM5kLQyVGTYli46OKAYfg
Kz035txf0jSffO+555zvufcu27zNtiVBUZTn//399y8+o+O9iVBvIeIUq3ms
zdF0PFOwAv/O0sndJ5cRz8PpJ0LBSIvgdJjeHZm2RguIs3Bw/cnk5IDgbHyY
nZ6zoFRwLqL6VKr17XziAgyc95hd0TziQpT2PPDgqibB9+GHfUPVY8GlxMtx
2WNMHf4sl3gFTO0j1x6eL/h+RHPWfjGSl0NsguXRosqtjiXEZuD16JfB8GLi
VVDnvp8bXCi4GC/cmpkN1WUTl2Ds0tJvRg/fQ7waE/uHRvtDRuJS+MvXpXw1
tYi4DG+93JcRhuByZJ64uDX2dBbxGrh/u1xedHsh8VpMPlVf/dBywRUobng1
3DyVSVyJM96is3kGwVVQt/v+vHA1g7gaA1c2D14ZE7wOW944ktB/SPB65GRH
rgaG04lrcHhyZKfh8buJgbQdJVUzA2lx1oDXZg1zR8oMpFswtSQWPZB+F+kW
PBforezPTyW9Fvc2vzLrPir0WphOJaWUvyj0Oqwe/OmGRb+T9DrMmYZ3jz5C
rNTDur94ZdKzSaTXI7+xrcJ4LJn0DXy9tgGh4LYDZs880hsQiPT1196gfFqD
VN9G7Np782zvsRTSN/J+lEYMPZM4/rVP1N8o9d8k6U1S/ma+XmvGUctH5z5e
TH4qLTh3bYHdvX0+6S1wrww0fvqk2L8VH3xS+fOKiNBb+TyUNmT8mGWMGWle
Whtfr2zC9PjF3z//Q+TfJPXXLtXfzueldPD5oAOxU9O39ywSfnfweeod+KXi
5l+1ZvJTsXKGlc9Ps3K/dKuU34braeF9t8qoH9ikfmzoPT9+ZiZMrNukeDvX
YZfi7dx/3S7538nPFzp5P1onRicuGS/kUj96p3Q+HWhds/d0xJxI8RJrDn6+
dQfi720CxXdxhsRaF99P78KegzPvG78lVpzoO15V886bCsU7pfxOvp/uhNNd
EtxR+HdNPL6b+r0eZ3TDkHhiV/SlOyi+W6q/W7pfLu4HXFJ+l3R+XPy+Km5+
PuCW7rNb8t/N61E83A94pPfEw+epe/h7oHh5Pnh5Ps3L/dC93G/FJ/knsebj
9ek+yf8eaf49fL3Ww/Ppkq74eb2QWPNL/ful/lU+vwJV8lPl9aoq+fEr9afS
/t/F+ZBK+9Kn/8//APUWLq0=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlHtM21UUx38MNtDCQDY6nvIMojyUTVYBO76wrTyLbSkttGNEEzZjl5CJ
zK1I/EF8Z86hiygafCVCIEKAwMaA+VsU3JaxDYkoyaLBERZH3CCpPBYYanru
H/c2+aX55Hu/955z7rkn+oVqU9UmSZKO/vf9/89+6tL+oR5HDNy0kFXh/OT2
WABjCYcN818dGoom9sGLNxMCByoZByBa/WXw7EoU8XaoCuwnrrUyDob3WlLm
P3sYh+Ns4tabvZcjiaMw3n062pnMOAbTFx7baGl8lDgOrkbjj19sZhyPZPXi
N83HIogTcLWx5t38G+HET2DJb7BhLY1xErp74uL968OIU+D7gdYx8mco8VPo
un7CmKFhnIpPW5xprtYQ4p1Ibpg+qHIFE+9CrL7WIlcwfhpBxYc0c2d3EKeh
VhNf1V/FeDcMpqWw7kY1sQYtUf3+c7eDiJ/BH/NttdbPGafjYuwbCVIM4wwE
Vw7/fEq3nTgTj8d5zy7nbiN+FokR6pDDzwcSa7H0XteOCtcjxHug8vzOeecj
xlnYJx9fT32bMaDXjY3OagPcLANW286ul2P8Sc9GsjbF/P2cH+nZsCU25V07
riI9BxPnfnH9tkIs52A8dOHOmYCHSd+Lpls1dTnL3qTvhfP1+xcdHVtI34ek
Pq8tu08xXWBpv+DfL+yvQ2zBx1O2dmJZB8elcxcmB1l8udQPvqTnoj37h9Gx
EMpHyuPXy3n4bEq1+m0a8+djoW9ivT7oIdLzhfMLhPwL0NNVfSbF7kN6Id5q
cmTURbL4C4X8inAv/f6DnBSqh1yEyDx9urpjM+l6nmW94C8W6lfMnyc9J5wv
sGTgGQbhPAPqWyeH1TOeblYElowwnkxN9HrTi/xGXpeNaBv6VX0lnPZTjEJ+
Jrjnzybym/j9ZBP1rwf5BZZKBH8J319yCV8fpUS4HzMfH8yC34xd7/+9nK3Q
/StmXBrVvvrKeeYv5fdDKa/LpVhN+vC1tiPML+iShY8PFuG+LPx6xcLHK1mF
+K30fjey3H4rXx/FKtSvDDWdmVm9X0vkLxP8ZYK/jPp1ya1L5fx6lPPxyOVC
/5QL9bfx9YVNeE8CKzaM/JRxN+EWvWfJjoGF00+Gjm8lvx1+RwLn3znK5pkd
EZ1rUwc0NO8UO3Qjf72ECTb/DqB55qTH74uB+BdDZczY
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tIk1Ecx/GDFom2smVmOk2lhlgtL7nlpfbzMnXOy5bWaKaUUAiatyEM
o3z0hWnYC5vRixBLIgxzMkWyLFRKol7UC8EXCt0khaSLaIYy7cL+J/AcODx8
+PL8zzlhJZUnznswxnR/978vX/4nB4edZeFw64d2tjZ4alDGzVBxt3NEGgoj
e8FWZruXX8ztC8kwU9S5Fkr2g57FH47p4g6A95SpO8PMrUC7WXHZ+W0vORT1
JWdvvfXlDscplTI6UBNC3ofX8rGK7qZgshLFVyZ7H3xUkCOwLHvc4IrjjsRS
yET7VGsQ+SCmJ6oiyp8HklXQjVdcurGfOwqjUS0Xqq7tIUdD1/ehqe1pADkG
jTMjNQ153LFQ3Lk4V/BsN/kIXt18aJqP4I7D8Od+xfv7/mQ1pFrtUoKSW4Ok
n2PvWot3kY9CbX9Rqpdzx6NjKKnQ7vAjJ6DxpbloNZs7EYfmgiTvTdxJWDln
XWsY3Ek+hoEq66LFxn0choGFLJOGW4tPt9Vx03Y5GbA6+1qMdTvcloA0ybYW
fZXMkhHc45o8o+E9GbJy+XxztS/1FFh7ErX9XWQpBYvrT043buE9FakFLvXm
9G3UUzEpay5dyZVRT8P44vZ8S/VW6mnwCI1c9ekhMx0sB9oy39h8qOvgdFS2
qwq9qKcjW1P/aEblST0dZkuMoyb8t9bdM2iey20pQ+iZ+B6/up6imqUumOnh
49lb98W+QF0wyxK6YGZA7PWvv5JHV6gbaP4y9WzhfMEsR5ifQ+/mK1foucL/
ecJ8wcy48T4wCvOMG88bFcxM//0H7UwXdQ==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzntIU2EcxvGj6bSObitNLXXq6Gq5ymWmNvds6rxNDSsCqaiRZShY3ioL
PErRBRbJULGIbEWXqUUXkTI1y0thRn/5T9QgL2AUWaGbonZhv5dwLxwOH748
7zlhhsLsXFeO4/D3+fdmx29XS9vDfDkcGlfXG0bVrVJmDk/MtS6Wp2FkT7wN
sklrspmlyDsbHPXsZyjZFye9rzz4Ws0cAJk41v4+kjkIbddz3PqbQ8ihaAg2
iS7Oyshy8GtDXs8WMq9Af1y9rfl5MHkV9nf0uTXYg8hrMGH9XOa/lzkcUsmM
wTwQSF4PvYfSvf/jcrICVZYRqSmbeSPOxB+IkNxbRt6ET4Fu1kWTAeRIVA11
FlVmMStRouxVlQ74kzcj89327jt5zFEQjUsGq/P8yFtw98OrmmuDS8nRGHGv
nWytY96KIwcnTmxYzRyDFvUh++kCX3Is9p3Xjam6fchx0EdXtA4pmLehve+c
1V6xhKxCx56VXTKeOR729BHPSj2zGsbHC9d1WJmBqmGDcbhpscMCEKY5fKF0
Tkpdgwxdb8+wiixo4OXz8vjRMQl1LXbnRN4vkpMFLW69uVnGl4ipJ6BAe7ld
fIMsJCBCpdjZOepNPRGZTZeSclvIQiJ6fkl25Bzzop6Eq4P81O0onnoSyium
u/ItIuo6VA8Vn9LaPKjrEJKSEeNncaeeTP/3W+3oyXANDZ/mG2cc5lKcegqK
G+PUj8wc7VOhNH6zaV5MUU8Fv6C5/IvpB+3TnPZp1F1on+7U053u18+3oJ//
PS4D32Om57SKSdozj1LPpHvoCE7mspz6f/8BsNX3iw==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tMjWEcB/BXhVJZpHBEdVxGtZB0lb5FV3U659Sh3jP9Eba2XHJJFPOa
ywwlNJvLENmxKNKi23j9YcJqw1Rj5rYZuZ0wnCSXnd9je553Ozv77Pu8z+95
n+f3+OetMa5wkCSp8O/v3z97vE2NrfUFWthljZWfB1aGezJLqN/f9MKh2Z/s
DE3F45EtecweKCrRTzjqzDwGVU+1Nxpq/cjjcHjfJW2ujtkHJ4daludf9yX7
oTf89McAf2YtSgdqV61eOYk8BW+3V8y7WDeRPA073HRP5Hc+5Ok4Uau86Exg
DsBLW7Wj4egEchDUssZZox5ryMHQFr+p7g5hnoVO/5i4JNN48mxc7f4SOvr2
OHIIEo+79FkCmeegcM+xvrVrx5JDETXtcs/FMm/yXLgMVrpEhzGH4V7/m727
z3mRw7HsSVub5f0YcgRCH5QVT21hjkR5YVGNOZM5CvWfNadK8j3J0aiqbvc6
0DWaPA8jzv7ITbw1ihyDO11Tvv50Y56PzTNu21ZkeJBjUX3n7EbXDSPJQJf7
nnybzt1uBfjm3rx9YK4b5XEoaG+6/rDZlXLBUjzkwIPJnZtYHo/7TY++9vxg
+QJctVbM1HRQPWWBUH8hJqce6ZLPj6B8IWxBh7ZYVrpQngDD/tmBTrucKE+A
pbXb+67PUMoTsf5CdOyVMxLliXDwC+h3vTAQa8+TeCtJWCKH1K3T/qY8GXPK
PnyPU22UJ+NTZP9gfPA3ylN4Kyn8eCkVro61Jb2Hh1D9VKSFb7v2KtiR1rdI
WN8iYX1pQv00mq+P8nQhTxfe1wm5Tvi+DNjvtwPVz+DXI+n5/YQeQQ1Ow8LK
h9N4PdpvxRRvaHG2W9Wjvm5NZbCZLBn4HAZYG+7/2upF56cY+H5QBUtGvp9g
5PtPMdL3klUjP7+UiYqdjk3PllL/IBO+gx33IqysnzLRobH2VnqQVWG8lMX3
GwQrWfBNTo/0rqH9UbP485ZM/P7DxJ+/YuLHqybh/BYL7y8W+k2wKlhawhuC
FcEq82t6P1uony3cl2y+X9Rsob9zaL5htH852H2wIKrUl/VPDt9fag5KtvXf
LKih8ZLM7w9k4b7L/PpUWbgfZt4QrJipDj2q+f/3/wG9zvD8
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0m1IU1Ecx/HjetHSLaaZTqc2R0TJmubSfMj223yYTnOhRWBIQxgULVO3
NXoSrRcaPsRUenghRYWzTMHAbEkmSFSEvRAq3wRBNEqTWYGmaKvY/xC7Fy6X
D99zzzn3cJNrTlVYRYwxw9/735NfMYdGxoZPqBDUgu5aX5i/SsLNMHl1nE3e
SyaL0aYI+BLM3DLUOLNNkp9KcjRsHW/avde55UjVWN2teu4EOL42hF1wbyEr
EThZ7ewfSSKrkCWSj73Qc2+FYy12ylqfSN4G42N13WBLAnk71lwfG+1vFeQU
9IotZ6Zn4slqHK2NyllSc2uwrO4677HFkdNw0Tbf5nkvJ+/CTOSPuOMO7nRo
uxOHG2/EkrUYnQg33pyLIe+GP3vlt0HDnYHMb74PD9ZvJmcirfqS52l/NHkP
Ouuc949UcmchyWt/1PJ6EzkbBo2lp8HCnQP1QufQ6BXuXAwZ/RUuCfdeVL67
3D6dyJ0HxzHPuDkmirwPv0o/i5vLuHWw9vaJzt2KJAO+VJW2dge5CVDIP31x
d8mo6yG1Rc211pOb9Lj76s7pCMdG6gbszNMcfOaTUjdgUeptXs2QUM/HVPzC
bI8snHo+nf8G6gV4+TzP5Xgipl6A4P8ool6Iw1XpQw2qgC7YC6HtmF/STywH
zYro/BepF4WOZ0bYB3J1D28zmt8o6MWCXoyIdYNnZ7vDaP0SQS8JXY+ZaPx3
Wt8k2F+p4P1SiJQpKxEDq9TLBN8nMNsveF9gVh46X1N56H6Ymfbroy4wOxBq
/PcfqEkRoA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0FtIE1Acx/FtFiqbl2xNTU2dVppizbtLt9+m87INiTQEsZsxjCyiFKNM
GhZZVLoYlD1kF0V7WEaQzrxAJUujQitvmIiiZHTRRepyhFb4Pz3sD4fDh+/h
PPyDC4/v1vE4HI707/l3sxHtael4XCzGqqzyAssR+5KImYPJW2+8ujuCyS7g
fpOtqTjA7ImD9Qved1yZhXg9L66aMAeRfdB/ZTZ/7SFmf8RYlK3xQuYgRLSP
2QbKA8lixHX2Li5/3kQOxeLb2hvJm5m3wEemM6yUBJDDkJPDz70/4k/ehl2J
gpkiKXMkuHPG3yv7/chRGB+bKaqp3UjegbIqXqFLmy9ZAq404mmfK3M0Zswm
iSTXhxwD03DARFODNzkWdYKbrcIBETkOH3uejA6XMMfjtEE4mMVlTkDywvPx
q/s2kBPRb+q6fH5ISE5CZU/eXruWWYpIa3WzuWY9eSdUKdNn++xe5GSEhzpP
2zJYT4E24Zx5KopZBqPOaixoYu/l0N1u5JXfXUcGwrNDhKpjZD3QGKIejX3h
SV2Br2NbL2yvJOsVyMuPbj4p9qCuxCM/k/m9hqxXOvRUNLyqL+OXulNPxZDb
pcNL2W7U03BUaehyv8d6Gh4oui0vfVlXIdtUrdK1kPUqWH565OSfEFBPR1eP
dDZsiqxPx7u2wfmRX3zqGei1pJwqbXehnoGL14ul5YHO1DNRUfehUzTpRD2T
9kfmZCHm2neb4tmSfLU7mKMG3+nhmS/GH9TVDl2DuST7sjLqE3UN/ctG69C1
//sfWsvsOA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzFtIk2Ecx/E3RYnePORpy0M7WGI5Rs42tU332zt9Z0uJopCG2VqIF10U
20gSwrcuEuoqKwKlLgwsSgdGJdMkmZmdDEJQrIsCKyqQ1RDZUlvF/k/g/vDw
8OH7PH+V6+SBlgSO4/R/z7+bTc6hhyODJ9SI6Yc59cU21QDPzKFtbyg0N6oi
r0fhm/52oZU5HdXuSPhtGnMWPnsNRRm9SrIcU63Nwwtgzkd2nyZgGlOQlZhb
PGq5zjOr4bgbuNlzbgt5K1bXeYJNMwXkIji6jsufaJiLUfzSdeG9J5+8A+Nn
75Tcfp1H1uBaw7RJsZxL1qLpmNP3sZ55J7ptutPyxs3kUjz2HF42PJKTdVh9
qrj04J2MXIYKFCYglEPehaFXsqQVJ7MeXn9AOW7PJhswm9w5WxDKIpdjrERY
6HczV8D1XD1cJmWSK1EqdvvtUxnk3Rid7PwQ7mA2YumiT3ZkcRPZhA23ws3i
BHMVRnKv3vAH08nVyJPPf73cxWzGxsxA26lvaWQgyu2POr1kKc6cBWe2T0Za
9tF/yYIG8dnEpyq2T4D14IohSUylLiDFrTNOn0+hbkXPDB/p0/PUrQhW/vot
aJOp16C+vGNoXptIvQaee0bz/V6Oei0aHTqfWx01x3ptXBfjukj7l2LmbOQv
1G3gEwfav1/5Sb1u7Xupjvay2bPWUpw5+3//AYjZygY=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd029I00Ecx/FzUi5t/TH9TdtyblaE2ZgrU5tzn/mnzWUGkqgjCoJFsAeV
mpEg28yeyUJHQkEiZagbilpiqKQZRVajxFggYsQeVPZvQVaMkop974EeHMeL
93EHB6c8eabcJmKMZf2b/1c+hIrhsUG7ChGFDJ2eby6xhJvha+u8QuZTksUw
BZZ+2sq4N6F0RLOn8kMqOQFLaYvP1W3cSWi0uvXDh7jluJLyS1z1RUFORe1A
VMxAJrcKV/svCXWtKeTtGI05frl9YRt5J+SD1nmWz70LSnun51SznJyOF9Ov
bvsnZeQMSHX3up583kpWQzfK+vTLyWQNLCFhsNnGnYn74ylHoz8lkbVoCk7U
uI5w78XHuzfeaLxS8j646x1NeQsCOQsd53vmNCru/eg965857U4kZ6NF+rLt
xznuHJgtLXND1QnkXDRc3P0usIP7AK6XucLBWG4dqk9Mma1VW8h5uDbRfaEi
I56sR/z7ySlf+WZyPgyV34+VybgNqLRq+2tUG8lAj/Hho8fJkoidgCg1PRzn
W0/diK7pW/VxdRuoGyGp0epmm2g/K0CapT1g7YmlXgDFsv9ZTojMChG6M/On
MXEd9UJ0j70WnsrXUC9CXHRfw6IninoRGjtmx4W30dSLUZrtGAmqyc5iNDjC
D+zetdQPQmE+nCt46TznKjPTyvucppXnMfOq+82I/AcR9RLU+nSGoZuMegm9
z29DpFtoH2N/Ac7Hy6E=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd011IU2EYwPG3RbWcLJ3uw7ncXJGyxmqzlXPmeTa3ObXNWF9oGZGMAoVF
3kQaDIsC6cNNERMMy0piOdDI2kYgdhONeWFRdBNk9EEkW/QxNmSr2PNeeA4c
Dj/+5z3vwwun/KTH5eYQQph/9/8nvUSHHkemO5WQU4JZMXLq43nUBBb56x8c
nipHc+GVsF0bd1IXgGAuMFHxU4EuhvBrvubCTWoJZCx1j56ZqWUQqFWernwu
RyugtaIv/SmfWgnvbZ6U61QZeiv0OwXuwYnN6G0w6hp72vFOhq4Ez8U+73wR
tQo8vS1uq6MUrYbs0pawf0iK1sCtcX3rCS31TlDfGxerrpagtZAdDnUsfZCg
dfDlyUOt9iB1FXg3JS8d14vRu2DEEBlenheh9VA44CQmHfVu+H59YYZZFKL3
QPiMOnmAQ10Nx7hS74ihGG2AslD37JVoEboGtLbRUFNMgDbC7bsvhDfeUNfC
n/6guP1XIXovuMfuc3rGqeuAt3bq/LdBagZKJR+/+vwFaIDugJGZuYP2Auzv
UkV/l9BuWm2vCWYTAzukMT52M3AUqjQvkI/dDG3bffaFczzs9VB1bTlpmtuI
nWVigZTa3zvZRbsFpoOeIc1RLnYryDOxaHUiD7uV1W2sblv9PdIAl32dNT3y
DdgbYDLyVvRStg67HY606YJnlVkm1+14Xj9yJo0QN6QzZs1n7I04fwp7E2s9
y6QZz5fg/s2s9fvw/FZwPcvEAbn/k4PrHTjfGpzfydrfyZq/Bd8j5C+rYfna

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQNioVt3b8xWcoDwPtgffbU0fik7jM/gEJN79W/M
ckUon8NBWEtP18sNxhdwOG+ux7HnqQKUL+LQ92B97vo+GF/C4fyTtUc6rGB8
GYddF5inBW6Th/IVHOy14txM+GB8JQefc3FsN8PloHwVB4dXDtdCF8lC+WoO
jJKzws9flIHyNRzOPNhy254PxtdyOCqU3cLtLQ3l6zhUeYn/kyqRgvL1HGLO
e3LuvS0J5Rs4eEpduXjMBcY3dDjuuIHr0SEJKN/IweF+XbSgG4xv7KBWc/3i
YXdxKN/E4XLOnZ0nUsSgfFOH95a//jnpwfhmDjZfD97riROF8s0d1sleVtJ6
LgLlWziUi85m6F8mDOVbOhi6zdrpdVYIyrdycNv7MsvhoiCUb+3Q9CSp98ka
GN/GYbfUlLk73wtA+bYO66XXbL/kzQ/l2zksObm4jLuED8q3dyjdHWBj8QPG
d3D4xruz8Y8pD4Tf4OBg3Pv2u+MBTqi8o8OHzRf/1opC+Q2OUP+xQeWdHHQ2
s7CZ9bFD5Z0cqup/HcxeBZN3RpN3dgjsMdRmaWWByrs4LN99XeyUDCtU3sWh
eLW1/aZFDFB5V4faeZf3iD1khsq7OoRHGa0rUvpvD5F3Q+U3uDlwM6+tejX5
I1TeHereZ1B5d6i5MOCBym/wQNPvicpv8ISbBwBqAcu1
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtIU2EYB/CT2rLU1NK11NLNCNM1vJTmrf2d5qZ5mbuWRlTSBQyiTExN
PETZxRK0KEoqE8pKkiwquuFWDrMoisqiL1GDLnazC6Uz7cKe98M5gzF+/M/z
Ps85530nX7XBsNqD47hV/77/f9lHar50vatMAbcG1Q2Gy3J7IDOHw4fKkzde
kpO9wa13HKooYQ5AZZej4b43cxDk3M+fsZ0RZBkSzDV5IWbmMAzMOHkmZgJz
BGztEmmbNZysgOqhVrOnYSZ5Fkqzy77aX84gz0Zxc6msW8kchYTCPklsZRg5
GvtK1bLR16FkJfRXouVJmcwqpPr+GdjaGkKORZVxj/LOn+nkOIxcfegvqWKO
x9NPvPcHp4ycAPu9trQV9czzYF1zesjlyTwfSxULWp9bppETET/t+Mpl9VJy
EvqebN9R0RdMXgB75PYoTsGcjK6hxvcyBJFTsHxX9vv0nqnkVLyd860qTs+c
hpu9O18O1U0hp6NHb2vhrzEvRIm2e5LrPLMaWfyW0bidgWRAnrF2d8VYgNs8
cCoy98W8W2QuA0uPnDsRrGR5BkJlzndNzSzXoCNNsS7qtj/lGpR3pKovtLE8
E4Efg6SD0smUZ8IjItrl0+FLeda/+VM+RznJfJYoXwTHd39j8UaWL0K/3651
wwV+lGejOKZJ92CLD+XZSNj36VeGbSLlWgwrm7e2ryfzWlTXuexlZyWU6/Al
2TWmUZF5HdznwYPyHJrnt9qd59D9cZTnCs2LzC0WrscvRu2xxzekrzwpz0N9
U1lKTfgEyvMQrstPlp4dT3m+0Hw+2q8/k94NY3mBcD2+QNS/ED6e56oH9o+j
vBBFe+NivHZ4Ua4X9oceTc7yGs0vNo8eXZ0bDqhKvN226UX9i4TroQh5SXVX
nCo2j8i2ItHzN4j6G3DHkV65+Rr14w0YvPhotDaY3p/NAOVFL0liI13PGUX1
RuG8vFFUbxS+b84kvF+YRP1NiMw92F98ehLVi8yZhfsPZmE/3iyqNwv3M2cR
7mdY0NLvM3xqPtvPFuF5sFkwN11l6n7D9r8VfpviUx9vY/VWVM3pHV5dyM6r
FX39s36M+NJ5t1lF53+J8P8BS3CUf1rt3zkVfwHdXITf
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtI01EYBvBlF2ybNnO6TU23ucpmVNPM22rPps5tFall6SIVSZIsKi9Z
BPZPFkIQuEAzkahpZFmzq5dEsq0ZaQZ9sMQiEQkKWUmYSYFd8D0f6sDh8OM5
nPOe9ygKj2QV+fB4vPg/8+/KRnD2w567JUrMa0p3rPDAJY8fMw8/BxR9+XcU
ZF9IHhWd6tnNLMJIwzWXZ05OFgOLyvoDWpilqBHsUPC3M4dhb95obPt4BFkO
8ZrEbzY1sxLtjkzd48ZwsgolHWff102vIK9CTKfztjKeOQoDxSGRruowshop
GY7I3MZQ8lqMm6tmvL9CyOtw+UpcboGGeQOytaP7VaMysgbDXs53ckJKjsFT
ceVJ+VcJORalssNvvKeZN+JF5y6+SsYcB8cZ4b2WzGDyJpyrypPcmg4ix+PD
4vqZzovMCUg+WNpQ8EBMTkR4d1lHzWAgOQlLshfcn3IvJyeD3zybZ/QEkLUI
lU58tF8QkTdj8t1q2/pq5i0QBroqj35aRtbBfMN5c2UTM3DIUNvrf9V/3hzQ
+yzpc9SEkHI9rNF208sTAsr1aNW7Pf0yP8oNiJgbGkyY4lNuQKSl/rW1lcxL
gY9c/UPQRudxKai1Lewa28fy1H/3c6mIPe/9ru9bSnkaXnUNT4/MsvvT0PK8
+bignOrlGVHRk6FNmGX1G9GmVRZHudn70qGN2VbjX0D94tL/658JGmNjt2WI
+suZ4Ez/klUpZP03IzffZbLmkDkzDE92hkdHsP+yIOxtDkR2MmdBebdL7raw
/92KscnrFXuagvAbpVTXKA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0GtIk1Ecx/FjKxtaaKbLpjm3ZS2TpTOvq/ZzZnvmpqkR0gyMRIj2outC
JGujXpUVsQjBcOAbpVmgViqaiRCGYVFWiPmiGoWXLsvKrEwr/J/A58DD4cP3
nOcPR7n/UFH5IsZY1t/v386XbPftzma7CvPyG0pm+4zKIG6Gs6Ze9/cmJVmK
mRHBvqGQOxQV7lFvyq9YcjjUDa5SfRN3JL65auztBdzRGPtcV2X5oCDHwtzv
mHIYuFWQBsrlF87FkNdC7X/V/WxkDXkd4n6UDHWBW4P7X0J22Y5Ek+Nxotrh
EWqiyAnoifc8NUdwa9Ef8DhzfaGcnIj3tb6yjluryUnYNJfUOiHh1qGzPuba
SXkkORnSU5ei+ktXkTejrSfI5JmQkVPgGlPee2PmTkWdo3E4UcWdBp8rTHO4
LIKcDiG3erhlTzg5A7bJl6lxv1eSM1FVN9gle82tR/Ok3FN5gHsL9p5Jtg2N
hpG34uDx6TsBxdzbMG15K3VZuQ0IG+3p9RatIAPndeUjtftC5+0Eim26m0dV
IdSzYNt4WXhUEUw9C4rZgYfp/iDqRgzI/eNXQslOI+wP2rsHO+g8y8bU8g7X
TMoy6tm425f5UeMjs+1Q5159YWvk90VmOXjS/vzr0DSfnyPqO5DQujgw9eJS
6iIzk6iboBDyMmTXl1AXYE073ebTSqgL9N5kZsYxr97QUs+om+l95gzzPRfB
khuV4+4A6iIzy8LzTouoW0XzrQvnsTzaaTlFZvn4lPFz1qh9R//PF/Wdovsi
s4L//gNFJfAt
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtIU1EcB/DbC1+pU9fanLZ0JeKrrDQtre98rrnm5jZNU6JIFiSVkVRk
dK2ohEotK2j0BhMMKqK35tUyCbGyh2RRmr0oTBaWqZg96Hf+uBtcxofvOb+d
e87vLGjV+qzC8RzH5f99/n2zj8x69fbltcH4L8firqf9n+RTmTnY1K29o/VB
ZFekNSUNzilglqBN6q60/5hOliJ0V9SIoYZZDq/TG9fF65gDUJ0TsP1yv4o8
HQr1wxYXFXMw/FTdjx1F08gz0D8sd5W3BZJDcNDU03c+jDkUrRevddjCAshh
CK8vn3TCpiRH4Hev+tahan9yFNyKl0o+NCnIs7HJEd3gq2GOxrjKJ2Ofy+Tk
ORCkdS4rv0wlz4U52pXrMjPPQ0Of2ZB5TkaOwcmS2pezg5ljUefTLw+5MoU8
H0ETX/cMjErJcVimrZD0NjLHY2drTsGInnkBtp98Wi9760deiCMzf+Vyp5gT
oJ+/4/q7KOZE5K5o1uYtY16EY2/3j3vzzZe8GPeMgp2/xQz0+eUWDpaTeWAo
44NrmZ7lGvzvD5ZrcCd/ZtM0D5YnIYXf8it6rw/lSch3OXtcmUrmklGj1r2c
1yyhPBkXlReuP8nwpjxFbD4FRUmVDV5nvChPhU+fVOaQkflURCZGWRo/elKe
hlrN3Zb7CjKfBrXuaGderTvl6Wj3d3yplpD5dAxHHCo9X+RGuRaqsfa2OAfL
tajcPeFGdwGbvwRzD3z9qRFoPL8E9k6P4ZoYD8p1GPS8WTYaM5lynbgel4E9
VWsXbFO5UJ7hVF/v9Pt65IVXaR9uYfWXotNz35phA3s/J3MG8X7xBvF+cJlo
GfA25xWz9WU6rd8orgej034a0XHj+fcXQzReMIrrcSbxecCEktvGhLghth4T
rjkqZ/m3kwUTJvs1b97wmZ1/lvj8kSUez2ch2TIaOymNzXcaz5lhLApr+6Gg
/oIZkT6h3453sH4zI0hjKy8ZIwtmPCscdAu9yfrTgvBAmcK2kvoZFqf7YEGv
PTbm1WGyYMGDrSkJq0PY/bIiNfF96aMRNt8qvj+8VVxfsGJ5eqP7yCV2f7LF
9xfZ2DzFzlXUkPlsRH5S8u4T6f9AyIZkb/Hq7rNS/AHOG3Mj
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l9IU1EcwPGL01VOzTlbVrbpKiuVkbNNp+Z+m9s03XR/vGT+YwYKIhop
PuQevEJmVlojgkICMUjUtEzFQrL1IGLQY0b54INQUElGoZuI/cHfCc65cBkf
vufc84clXrjoqg3hOK7s7/vvlzxyfmpmvEEFO1ozfNU/2WqWEnNw7+RkRdJU
Ino3LGy3SAeqiKNhcKSYX+KIY8Fzvav811QCOg4sozqbupI4HqKCgc4hMXEC
mJqGb5gblWgVKAck9qVxBfooVA15KqpFxElQ42vVHWk6jD4BlRF12v7H8ehk
aLRKZZMLh9CpUGM38Xv1xGr4WKaou//qIPoUBDTieYuZOA2eBmN6VasH0Brw
BD8He2TE6bB2fF4RVh+HPg31i8fUEt9+tBYeKO7O9uUS6yCxvyPW+FaOzoC2
9s3XDcPEmfBdv7ltUhPrgf8Q1n3Nuw+dBd53lyM5Tyw6G1LXesemb8nQOdAz
sSdldjkGfQZeznctB9qJc+Gb7HztejexAcIfBqqtc1I0QI7G1hXlQQsALSPZ
hmcD0diN0DrjyMkMRGE3wtzPve7ySxHYTRCSkLwpGUELJuhblAQfaSXY82A9
8kXHlpb0PLh9RfR8uSocuxlSJ0LFut5d2M14H2LsFrjqa8jyKkm3MN0KgzPv
5W/iw7BbwZbRPr2iFmHPpy3kg7LArpcP43iugLZQAM6baSmhnaHYzzLrM+YK
wbfS4jVtkF7IrF8E58o1Y82q34adXgTpPasbRn9wx5yNtmADiWi07cudH9jt
tAU7nv8T9mJmfjEzvwTHr2MvYbqDNjAWHPT3/Q76PJyT7uDE/w+H9+Gkx/ud
9H44F30ecOG94SO46P34Xcx8N7O+m7lvN/19v5s5fylz/lLmPkvp9fzMeI6n
O/DMfJ7ZP///fH8AVTdvRQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0G1IU2EYxvGjlpnTVFJz822uiJjDnObSrHbNveksp2JJIykE60MflJCM
QJxhGlHDMKQIJZqGkIq5rElBUqRYTTLJ6kuRRokZWyKWsrmK3U+w88Dh8OPP
fZ/Dk1JZXVoVyHGc9u/z781O7KGhR/dOSeCTS5kbcck6HMbMIbW7tzDYlkIO
wUX7+ZqWMuZI9LVExXQ6xeRoLH/8vqBoY47D7WaDZxTMCVgaabwVMpdMFmNR
3O42ipgl6Bq3nhHUJpG3oaN8QD9+P5G8HU0Fr6pNqcw7kGkcD06vSyBL0Ymx
I4c/xJNlePFk7aojmTkN3TMNS6ENInI63AGLJ+0mIVmOMdVA6MzTOHIG0m4M
OivcW8iZaJY/THpXzLwL2qpZ2+XrseQsNHa8PiasYVZgwTIxqHwTQ96N/sQp
ifRbNDkb1i8XKtUnmHNwtHJmVja3mbwH/XpnaV0Ycy4iZfL4CW8UeS805rMe
eQvzPni5Eu/x2gjyfqjL3Ir1uk1kJR64WneKHMxAUa9FWzUU7rMZ6FE9ez4q
JHMqTNrfLr3/LaCuwnL4cKM7K4x6HlqbguyfKkKp5yHzyo9fqpGN1NVwiFzz
1yJZV8Nlm/TUx7Cuwc1pwcqdLLZfw9uv9d9n1vrv43S8rkPymuNltot1PbYa
2qdNPez7eshs64IVlg3U81HfOfU49nMQ9XwIgvrOzbcFUC9AuSmj/7TEq/T1
AgSKpauCu26fOYO/zQaa/0m9EM6c1bW8tK/UC3n9gL/NPHMHaX6ZOs9cEW++
iPd/Rl430n2tUC/23weezTyPFNO9sFPy338AZAEjoQ==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2EYB/BTOq9pq+nSnC2HXbzkyuVd8z9NXZq6i6O0IioXiJVlfQgs
OFYEQlqSFd1bUmalocvQrFiZZkmSl0yCkOhGoTQhtcJFhc/7wXPgcPjxf897
nvPwvAFbi/SmmRzH6f7d/5/skhqbWhsKFZiSLdGY09/vImHmUHDHbpa1BpBd
sOihvTp+O7MYVYNFdSIxsxfeXzy9ZdvNhWQfHKi5VKzUM8tQ7fr489chOXkh
RppK7z8PYVZgj7kp0Ni4gByIAocCk2kZ82KkzH7+q2SnP3kpIq+eNN/tkpGD
ITGZdAYVcyjuPbONJ57xI4dBUm092/B0Pnk5XpS+63BPYF6Bt1JRbXe2Lzkc
zrL8TwnHfcgq1NzqH5wYnkdeCbPigmx3I3MERj2NbUFK5kicq32cPFYnJUdh
uKK7MbHXmxyNgvyx/colzDHQKq8o9vl4kWNhGCg71usvIcfByTjDYmubS47H
tVhVZ81F5gR8eGDnQ6KYV+GzUqHaFTSHnAjtjuCuMV8xGUjOmYwUpXpOmQfO
D7j/uh7hTrkahZ3Nj/payLwa4x4tpZMRsyhPQk/z6x+DP1mehJfzbd+qxG6U
JyMvpFLTvZ/lAnOrceKIQ/PQJlrPrxZ8PwXyPy+7om0sT0FDfVFV2AYXylNh
s/TYD3q7Up6KUIujU2SFM+VpOFpZGFsiJ/Np+B7z+09SmBPlGsg1mTHSmyLK
NahpfSN9ISNza6av5wXm0gX7pwvqyxDkGdPr5dZCVT4yobay+tcK/j9T0F+B
uSxBf7IE/c8WvJ+NG+q29g5fD8q18CgOj+s7RIYWuefqzN6hNB+8FuvywuuL
FbOnbNUK5kcH/1uTAxujaL6gQ79p3HVpC5nXYViSaxovo3m06lBucQ15NMTm
Uz/d0CMo0PnjRBrNO69HhmU0XRdFtuqRu/mJJm89Ow8GnFpkz+Uuk2HAsi9+
vJsjnR/egHr/PkXwF7LVgKy94pLT7ex85eDV7Ydlhwe88BfxvU6G
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1FtIFGEUB/BJy6xd77bpuuUly0u1uuZtNfO/q+vdddWVQn1QY580JK1A
JZwegiIErR6KROiCiZqgZGZmbkSKmkKElvbQRewipCuppZZd2PM9zAwMw4//
+c433xkY35LyHJMNx3G5/+7/T3bJ8rr7Okv9YJUlXjdgcUt0YeZQEJETMNXp
S7bH+luntNx8ZmfopLO6AgmzO+x0pra6Xh+yB0LCyzfXm5gViFT9Huh1ZfbB
8e7rl5pOepP9gL15X5wv7ib742Cc0jjwaRd5H+5PXOYSYpkD0XBhW+vCOQU5
GCNtTi+eDHqRD8Bc1x3qMi0nK1FYXNTxPoM5FOO+cZrkPE+yCq6lxmm7eQ9y
GD73tKtURuZDcFhq/JreuJMcjr7ZLsW7Zhk5Ass953tXpneQI1GiD2rZkDJH
oWaiyoErcidHw7xf+629glmNQns5f03NHIPx4mOL36fcyLFQPfIK+HjalXwY
w5P+S+tSF3IcgvR73HUnmI+gKmho1ZTlTI6HoSx4dNmTGXhgqQ+RjzlazQNH
88M6KvycKNegTFvf73iT5RrReq2wnteiRfPs+aCnA+UJsPEJXpO0SSlPwJ3h
22ckp6gfl4j+oZj5wBmWJwrrOR19f+rH63BjUrLaHCGhPAkvH04svflJ5pPg
vTE2Gm3ZTnmyaP9kjMktc1edWZ6ChpnKGu2PrZSnYEG9tqFV2lGeiuratael
rWQ+Fd4pmWpZ6xbK03C377VsREHm05ARVdszo7SlPB2VbbHxXbc4ykXmMmh+
f+KteQbONr16LPvA1mcK+/GZkNjeq567solyvdC8XtQ/S9Q/i+bxy2rOIDQM
dP4VqjcI+5sNovNlw/r/sLEa2aJ5ZAvrzdmi+eYIc4jM5wj7m0XmcoXvB5H5
XNH+InNG4bxgpPWLdH4j1XHcX8XJRGk=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlQlQVVUYx2+U7CAgvlhEAVHZhEAEQZA/+ybwVngLDx6ODMxAyhpBTt7I
EW0hQGpGygmtZHVBU0EkrjAPJYNJmZimMJ1AB9OSghxBfFTjOc3ce2fu3PnN
//vfc873fecct117pXlGDMMc/Pf970sfkeJCX3ehO17QbOTed9sC3hZRZnCv
yt50ps+NsCmubGpa2KekbIOzcR8k1htcCdvj9nyjWVcrZQcc82hvtUujvAZf
hYlPpBjWEXbFZOd8y3sSyu7QWT66pT+6lrAHatPuGAaMKW9EgZz5PqXChbAn
nhj96hc+uoawN/p3/3IkOIiyLxqWf64fWXAm7AdtXvvUjmLKr8HkZJ209rkT
4QC062/nRigpB2LF6+wewwNHwltg+3WfY4M35SDcXexhTu13ILwVG8zGlH73
XiUcjO8uyc09HCmH4HHooiHaT0R4G55Z50dejVtNOBSzkvGPPg6mHAbOJ/r3
rlJ7wtuxtrfsYu2NVYTDoUkYMF88a0c4AsUTc4O5bpR3YOrKc9YnhHIkfFxE
jvm5lAFdifbZtzO2L5gFQsf6Wobv2hA9CpttPf9svkmYjcLJ9ck/BQ1SPRqZ
6sDTpe4riR6NL0e+eMOi3JroMdgc4ScfuG9F9BhcnK33dxqleiyKouv7rY8T
ZmMxYXWoYCGNxDNxuNnzw/yPTy2IHof6Ay/33NGaEz0e65M/mVC3EWbjofZp
SBx7k8QzCbAqDdw+XkPHT4DtI3vRrIiOn8iPZxPRFjWkH3ak4ychrasuLu8C
9Sfx18MkI0a+FLwins4/mR/PpAjyk4InVr3vLG21JPpOgX8nzjh3XbqVQuKZ
VFT0icO3PaV6Kh5ObjrgX0Pzn4ayzu2R507Q+qQhqf10x4bPqD8dFV5NRxrP
UT0dqfHD+ukI6hfDqsju4aESwhDDLSr/cIWBxov59ecE8YxE4Jfw/89K+ONz
Ev58GSn//5Dy18dK+f3ISdHn1HSs9zH1y/jrhYyfP1YGZ4epmYZG6pfh/cC8
yU911C/HMiNZ1pVTvxxVXtcW8tLp+HJ+fTg5vx6Mgl9fKAT1FDCnEOyPDH7/
I4Pfn2wGf79wGbBcNVhZ/IDWN1OQ/0xB/jL5+eAyoWo+dXy1L12/kj8fKGHk
6r1o0Un6k1ViwbdxX2uRGfErUb1/8WphhzHxq+B7/hXj4DoT4lfhYENh2Fvr
CLMqgV+FUafZ35ps6P5V47o+orL8sinxC5hVo/9a2B+eU2Q+nBr6uZUydQnd
PxoUXu/5ZryX7F9oBPnT8PPLadAZ7l7gOUTzl8XPB7IE/ZPFj+eyBP2jFfi1
gv7RYs5wWVVjQvtPK6hfNj8e2RAXed/425H6s2E3ww12Ssn5zGXDpXNpIiuE
MJOD+/7uW/Z4EUYOyrrPHBZX0/M8BzXTuz6c7qL+HBwdaK1U+NLzX4eA+Obe
5FHCrjqMVMWG795I7hfoYKx46fzsENF1OnT/5fR5dQHRWR3qiis6NDJyP7Xo
/r+//gGUtCOD
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQNioVt3b8xWcoDwPtgvu2QSEs4L4zM4mC84v+HB
JkUon8MhpPfrf+1wGF/AoY5L4FL/NwUoX8RhTmXUo6WzYXwJB9Yt20w99WB8
GQfPletWqc6Rh/IVHO5sPxT16pYclK/kcErahj9EDcZXcaieo7QoJEEWyldz
MF0trhu5UQbK13Bgl1U72/lXGsrXctjYIPnidhaMr+MQfvCFI89yKShfz2H/
Ru8erlOSUL6Bwx/GT+k7omB8Q4fb89MLO1dLQPlGDhMfF1c7fReH8o0dRMVN
tc82wfgmDu9iD25PPCYG5Zs6xJvZst09Kwrlmzm0sJw8xTFdBMo3d5DbWbyt
/bQwlG/h0N27VHUtM4xv6bAvRvWgHLcQlG/lULza2n7TIgEo3xoafvxQvo1D
6e4AG4sffFC+rcM33p2Nf0x5oHw7hwktzDvux3JB+fYOP3Um1SzP4YTyHRw2
rsufohfNAeE3ODi0Tcy2qpZnh8o7OkDSBxNU3hHqHgaovJNDeJTRuiKl//YQ
eScHbua1Va8mM0LlndHknR1q513eI/aQGSrvgqq+wQVVPYMrVP4jVL+rw3vL
X/+c9L5B5d1Q+Q0w/jOovDuavDtcHgAt/MIT
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1IU2EYB/CxrIk2nTqnc2pzmYil6SzN7//m15xzW2Goa5CtLNNZJCoV
JSettAJzInphJdGCmaV0IWQihlJaF16YWRdKkX0IVgrrwkKkoue92A4cDj/+
7/s8zznnjbCcPlDB5/F46r/3vye7JAeHRh5XK/Bfq1lVl/l34sXMPLzXCC5M
DUaQPdG7KVPVbWYWYffk8hZsyMliLLQcs3Y+Yg7GuZNdxp5DzKEQ+1qabCJm
OY43P5t11m8jK9C+/35A42w4ORJHi75jKoU5CgkOe++V6jByNKZ1YRnO4VBy
DFacg/Z4p4y8C21VUkPQEeY4WD/YDFHjIeR4TBodM42ZzAloaOFbPJ9IyUrI
rqUOzkcyJ0Iqq67srgkm78HbNxdfXU9n3osau0Vw9VQQOQnhrVV9PwOZkzFk
Pl9eYpWQ96FueFw+oQ0kp6BUc1P0cUxMTkXsVxnn5cGchrLD4xpTaQA5HWuF
nz0v6fzJGZjJ6vAIWvAjZyKsf33OnMychQjViWv1GyIycENZMd9TTuYAWfDi
kq2D5Sr0pysqoyd8KVfB75tYsirxoVyNgr6BBztusVztup6XDfvLew3edbSe
y4bQ6r/ceobVz0GJSTlQq2D7c9zq52JO2Fr5Sy+kPBd8ecxv7/6tlOe5msvD
6GTqj+hFlufDqm4f9bnL+udDWKtMe91E9Xga136cBtnF60mb81j/Aph22jTT
Z70pL8B2bdecyeFFudbVnNZtvkLXebhC6B+25VYMsf46xGbEFY99Ye+ng0M1
8fyFlOVFrvNwRa7reXq3/Xo4N56WNQnY9zVgJKTz9vAK+78Gt/NhxJpd0PhJ
RecHRpibE03vlvzxBzYT9R4=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ltIk2Ecx/HXZVK9GbZs2lxzG3bQyVrzkHPW+5tzujYdo5QOdtOgIBcU
akZGMIKKii6ibiyKaIWgHbADWLO2Cy9aqISG1UVJtAwWMS2bNWdW7P8EvQ+8
vHz4PqeLR+0+sGWPhOM405/v758NWcNDf49Hg6QmBLenPjDAM3PQ3rzlSLuv
Ji/Avh3H3ryvZ87A6EDJh3BcRc4Eb288MnSVORu6/crGgJVZAZ929+Dbl7lk
FValdsxpc5g10MMZPd+mJOfhSeu7WunQSvJqDJ91nslfw7wWElVBnO9WkAuw
62tEOh3LIRci+t05FVMx6xBRzgoHm+RkPfpf2y9ZPq4gr8fW3oQ+pZjZAD6o
EtYdzSYX4fODK2P6rixyMb6dtG63GphL4NHNjA2HZORSlMoX+iavLSdvQMKX
qv70IpNcBl/4hNuyl9kIKZ/VN963jFyOcFN++ewpZhP6XcHL3sdScgU6Ap2H
GwqZN6Kl5+5pV/tS8iaERvOmZhYzC2jpNgn3rmeQgUN+V0XZjyVJe4EbIV8b
30rmzEhvNphGjqdTN8PzrPfpyCOeeiUG5RORixmLqIvMWRA1xn9V6tKoW9Dp
fyV7rphPvQq5tjqjrIvsrcK2nYY7zZo5IdmtdF+Oushc9f/zvdXg591uj1xI
oV4j6jVIvncJdRu9nwR1G913nM7fTPNoeEXm7KJup/Mnab2D9ovR/g4Unfsy
bQ7+pF4rWi8yV/fPvwF8GNwa
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd01tIk2Ecx/HHZVotSVM3zeXmKUXN3GxLV2u/edymlikRCbOjCCookWFa
YWGjgzPUlEDBi6A8UCA2a40ggyiTLNM0Yt2UdKGUlmFpagf2fy7cCy8vH77P
//9cvSFHy3ILBYwxzb/3/5c/ov1We09JKJya0TYHXPoT6cvNUHwqb/JzXwh5
DSItHhGmg9zecJjVUQ+XZGQ/lFqG6mw3uAOgmpLmfI/nliDY7jP6sU5KluFp
R2PDgdfB5FA8MYVtfa/mDse+yfb501c2k7dgesIz3tovIUdhKeaatOt3EDka
9cWBe8VHuGOhVHQz4b1N5DiU9FSWH5sNJMejvOBcf3gWtxwGe5l41o1bgZuC
9pYIdQA5AWb5/eDxHDF5O0ZKHbbnx0VkJVSduSZjNbcKA6O1FysG/Mk7kNd2
PahKzp2IQ+PWgpFKP3ISipoFJ70SuNUY7LN2nij3Je9EmmbizKuFjeRdeKNt
dBd/8CFrEKIrulyx7E3ejSlHZO22C9xaFwNXFYWO1sPkGrjM62DovNsV0baB
ug6Pnqm/Rn1aTz0Z+TEN+qFKIfVkzPQOL531X0s9BdLll4OJM+uop2DOy3Z+
UcnnU9E6Jpy/peTzqRh+8PbHu19klrbyfE3ayn0sHWHGlrH8Dr4/HdNJC8vJ
cR7UMxDb6+6hqvekngFzQ4m6Wkpmekj12UmirtXU9bhtHxe9kJCZwaUbXPYb
IVx1p2qyyY26Ec7/SUA9EwJZ9IKwe1Hr7Jl0/pvTLGula1zMsum+OerZSLB8
+al7PE99D93D2F/is/K+
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtMU1ccB/ArQqqiDqpQhIJSZRStYMHHJjK+IBQsr9JS2hKd2K0xc0ZR
XLZBRipxA1aHia9EDIk6B0tQDBgh4OvK5gMSzWATFR3LMlgYmgDKSicqY9n5
/XFPk5vmk+/93fvL755zwu27jQ4vQRC2T1///dMv0HzpctPHKvyv0cQOsfdv
37lkAeMm989VF8OZZ+FZwoGJs/lkP/jkaHumXi5hXoiyct+xkePkICw/9YPC
HkNWoqBhZsTV9sXMS6BUewYVQ2HMqun7K+tKosnLkNH8lUvpCmV+G5GyqEn7
dSWzGiMee3hnKHk5xrq7gr9fGcKswcaW4cNrXMHM0Xjx+5en8+8vYl6F/hDv
3+a4g5i1kCk/HEw4RI5F8dHGL2aLCuY4hP3Y7+nJIq/Gw2OFBed+CmReg8j+
3NOf+JDXwvzIp6qyNIB5Hfqt1RUHJxYyv4P04QfX5rvI7yJdf7Cv2UZej4Ln
j9dGvF7AHA/NaHVj6yHyBtjvqNrjnOQEeM7KygaS5MzvYcc+T8sMCzkRc771
vK+76c8MuL9uVGwZZ3aCy5MgHxI7GoyUJ+HPGFXcrijKk1HcEJ/YfMaP5clw
xTqenCxkFjbixZt2W7mMcs5CCiwFsY17VW+xPIXLU6XPc6ZK3yfo8HnU7X8c
OZTrMG+n/GnlHsrTsFl2piYklfpPwy8O92x1G/WfDk/G4Kz9mWw+znSUD9i/
GThH+SaufhM2xGZWzC+kXI8U52evtRWU66XzEjKw0l89VtNN/WXgcvDR2rYR
6i8Tnb3LxifnUj1nIQtPn0QeiCmn+ixk6W7dHEig+mzULdX3re6gPBu6q3/t
QDfV58B35vmS4SP0/Bw4auu8Sk9RboCfRhtyb4oZBu5+Awr3bJnsGmIWDehJ
POyt+JXqc6XrBbnceuIs5qK46UKVoYTqjdJ5wojQhle9m9dRvVHar2jk6k3S
+cOEFaGBi7Zvo+9pQmtRnS06gO0P0YTv1sfdqa+l/ZCHZwtsDncVM/K4/jmL
eThxvf5Ts4bqzdJ5wCztz2mWrifRzM0/X7q+kM/tJ84iZ8Ei/f6wcOvNIu1H
tEjfJ1i5/q3Q6mra9HdpflYk3zCFrVjMziPRiqCtV3qqdXQ+2SA/f/+j0TJm
2NBepJkwebHzzmnDH/vl6qIPAvAv/BGj5w==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlG1QVFUYx6+8KLVurATrwoIgNqkLg4qCsEj7521FcGHZFxb2pckmPuQ2
aYqmKHVrtJnUTJApG6txFKHBdCYcDdpsLk2A1oBDJOk0lQz2QSZlmRQBEavx
OR/OuTN37vzmf57nPOf5n/ssfnmLrSZEkqTd/73/f9mjdV4IfOVPxhMKmh4Z
Gsw6NWMJ51qTD95uWUwcgdgPLSeKrIw1MNo2JSyZSCKORneXoV7dyliHpcdV
/VcdjONhVGlKXw9lnAR31cp9vpRE4mQcHJ9+eKxuEfFziNn/1zX99wnEz0MZ
/2GrR8d4GVoSZiP3+uOJDbh65ZfTfYqeOBWj+qwbpxYxToMmfORApCeOeCVe
Kgga5YlY4lWYbUtY64llnA7D0NmoiGM64tVI+6R9zDezkHgNfnusD3hqGWfg
rq/r6009WuJMFH56M6rz/RjitXj1lfu7VixlnIWUXt395uFo4mzUfz74rXb4
WWIjPh4+NOeP8SjiHGyunbw4x8V4HX42NYYt/H0BcS7Ml25vxgDjF6AKPVs3
epSxSWDwLAOBuKbPOsc0pOfBYu7pvpVLLOdhwd/R2qD2GdLzMdBx7d71SRXp
+VhS8tGQ+4unSS9Aw8j2PfkP5pFegMvduW/WfhNBeiGOD6mmWjJYfKEQX4QJ
dec7MxnzSS/C6g/uPMhTniLdjOD5gUf1McSymc8nrYc7paG4fxfLv17QizGV
2ri39TUWXyzk38DXI29ASJJhWnWG6pFK0P1PpN39BquvBH1xwdEmDau/VDh/
Kd5r8Bv3JBJLGzGWPT2bnzaX9I1ILLZka9vCSbeg4tCqlLD9YaRb0Br4Vftj
PNPLeJbL6P6Ekl4u6OXC/lZ+PwgsW/l8ihVP5kUIxVcg9XzY3MzDlA8VqHt7
usvfxs4j6EoF75dk4/sDG98/2cb7pwgs2fn1sAt+2Xk/FTu/n+Tg64GDv5+y
A/7LHd8NdrL9HYL/Tp7hRIFjJjPcTP+H7MSOgHVd1iSx4oR6W3rO4Ltqiq/k
86NSOH8ljuwL7fjTR6xUCv1z8fXCxa+XXcL5XYL/Vby/qOL9kqv4+6cILFXz
9wvVfH65GomzfT9lBVn91fy8kNy41Gu8u2yE9U9g2S347+bngeTBxeCRFXF9
1F944HKnn9uWHEnxHpR9ebio5gL1W/Gg+cqpnapaNr+82L28d6qmnOYbvNix
vOloYzubd16YXPe8ZXqaj4oX2f2BEz032Xz08Qwftp/JMbWfZPECKz4+n/Qi
JpvnvXUrLwr/Ahun9B4=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd031IE3EYB/Ajimw6U9OcbrW0ElfLmqapzfadqfmyzbm5ykwwIYiy7EV7
D67o/cXQjKgoisLeLXtB0qJpqb2glMH+CILo1YpskZVmZkXP88ft4Dg+fO/7
3N3v7sKKSmwLBwmCkPd3/3fkbaTjRkPtknD8l9uwO2HLfbOCLSDx0NSoruth
ZC8s7Vad9zex/XBgaP0Q9Zcx5ED4Tj+2alcFW4E7Kt1Drwy2Cqrga4Zh7Wry
GDQ2Fj4dqmKH4/Et/daM2aPJ4zBN9zxfXj2KHIG49W8ifGXsSHywju94HKEi
T8DP+vj8gQ1KshYHzU/16r5QchQGZNuKjqvZU3Cu7Jnh6P4Qsg6txiuyl00K
cjRaSivWlqSzY9B/T73n+rNg8lTkbepK3fttJDkWcedsBZkb2HE4XH58cdPq
IPI0bG87FDJXy45HkUVz9rcPOwG1PeXvFQgkJyK50T56opo9HVp3eU3d/hFk
PeqWV+dFBbGT0JP1xmuzKYA8w8MG+Gl1yvYBfzIwyT/yy5Enfv8tAmWaqgOV
V8mCEQ2hVcdufubciLwjl04GaTlPRlmDVR/f40t5Mr7Lb27+FetD+Uzcbk3s
inxFFmeiV1u58UzxMMpTpBZTcL85aU1pvRflqVKLHhbS4L72pH9TEPfTUFtT
UhWVz/ksxOz79MPo5HwW1L/bHsW7ZZSn46zxbnNLiJzydOn9Chk46vLurY71
pjwDbaHuD1V+3M+UPq+YCZd856JeC80TsnD6wanV3qW8PlnS9RRMmDMvumZl
+HDKTbAWT3j0LYRzM8xpLc2vk3j9zdLzBYvHfAsuKy/WdWRxni21mO0x34p1
mtbehdlkWD3etxUp4tp+3Q76XpxWJLQ3nGh5wf0cKBWvOisquZ8DeXHAx50r
uJ8jnefMgWFO93yLkr8/Gx64xnX3+ZBhQ0Cns+mCjSzaoI827fAt5Ovb8HZy
eMwyDfft0FjGBqYu5b5dmot26XynXTpPyJXeH3Kl54u5Hs+fi8IVBX0PO7nv
wHLX16YFYfR/wYHvu2uCC7q578DhO2fWOLSUOx2wu3bt7RjF/+tsTHqnFGWD
A/EHcMVnxQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwA2IQDQNioVt3b8xWcoDwPti/aeFhNWWG8RkcDvZorM5c
qwjlczjc/MZeZegB4ws45D82q/vwXQHKF3Ewfyt4u3AhjC/hwLegKM/SC8aX
cUidtEHn7hN5KF/BQXxlWdNDUxhfyaH3UEcq2yI5KF/Fgc3g29GaF7JQvppD
unPM/IOmML6Gw6PzR/cvyZKB8rUcbD79maZ8XxrK13F4/EBns7URjK/ncO7u
5uC7nVJQvoHD9s2tVonbJKF8Q4eKBsHp5RcloHwjh1Nx6z/tM4fxjR1E/dLM
n20Xh/JNHKrqfx3MXiUG5Zs6zFLYyv/suSiUb+aQfHvPnuVvRKB8cwcPr55b
myJhfAsH780fvQLNhaF8S4eCa58PJSoKQflWDt+61onHfhGE8q0dXt9Rb9Fv
EoDybRx83Y4dfWIL49s6TGhh3nE/lgvKt3M4cdS2vGQXB5RvD3UvG5Tv4FA7
7/IesYfMEH6DgwMkPTBB5R0d5D18LcVWsULlHR18zOu3P9aDqmdwQtPvhCbv
jCbv7LB893WxUzJQ8xhcHAJ7DLVZWlmg8i6o6hlcHYpXW9tvWsQAlXd1YFLQ
+sW9+o89RN7Nwbj37XfHAz8h/AY3NHl3VH6Du8N7y1//nPS+QeU90PR7OHAz
r616NfkjVN4TVX0DjP8MKu+Fqr4BwQcA3uzj6w==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1A1M1GUcB/B/BwKC1klCchIgK7sIr4Q6ASG+vHjAAXIcB8e9sBzbFQum
1mkW5Pj7subLYqlXK+pM3Crj1dM5OIj8RzWvOVLQmluWKzZnWgpWgiyh2v2e
tuf5b7fbZ9/n93/efncr6jeZXSpJkrb9+/nvmz2x1aeGfI3JCGoyd+CSO/B2
DLOE+tZob5Z/BTkCI8eutUa6mNVQG8/syw5jXgqv+1iDvieJvAy+FzNemzYy
x+Pcb+PGlRcTyUlIf+Ow+5VFzMkoPPLLtV3OBPIj2N82dO7UyMPklei4N9Iy
mMCsRRH2TEkb48kpuFkf+uPxX5eTUxGv9od7DMw6DPd989Foh4b8FHa0vfPD
C91x5NXY/N7GioCyjJyGmf4oa3zgIXI6Glp+ev6oivlp7PCefy5ucyz5Gehv
27WlV2LIepzvHt676/ul5DVwRmjkdzOZMxCeEGr5avxBciZ8tzUfNjcwZ8FR
dDpy9ng0eS1WG9r9xlHmbFx03Vmo9S8h58Dl/VjVcoT5Wbh9fXtNzcy5goEb
lx/b/eROddAyYGpKOftXHFnK4y3noW95d/946QOU52NVjs5y+upiyvPRGBj4
/II/ivIC3nIBCix/6xcY7qe8EMNnsm5qJxZRXgj7EweKv32V1a/jLa/DqGby
ukcdSbkBBybcLfnT4ZQbcDf14OufNC2kvAi+3k0enSOC8iKkv/n7dJ7C8mJM
nhy7tz2GLBcLeQk/n1yCt3aHDFypY/Mbhf0JlkqF8ynF1iFTdsYM238Z5qXK
+Q1b6DzlMljtab0vJ7PzLccfc4O2neHs/MvRlZ3coP2S5euxaol2qn2M5eux
uCn6xp6X2P1VwNbe0xGTyvIKbH3cc+jgCZabeMOEIY3H67/FxpuwP811+f0N
ZMUkzF+Jkk97Ox/9gAzBciU/XqkU9mcW6s38+chmvl8Us9AfVUg9GRqmb6P7
RxWaW2e/aOwMo/oqJBaXZ8Z2LqD6KtzKnJ3L11EuWYR6CwJf52zbMsj6xcL3
l2Lh+0mq5nNUC/0qWKnG2MB3f16aYeuv4Q3Bcg0S50bPZkxSvyk1UCWlzEZ1
0e9FsvKGVehXK78/xYrg/72K6mup3+/mButr6X7mg5YFK7VCvQ1la1r7J3Qh
NL8N2w9f+Cz2Z7IsWLEhKqSn+fqh+6jezht2fj2yXZjfDnfX2twTRyWqdwjr
d9D93qF6B71/iuqF8ZKTzyFYdtL7rlK9k+ZlT51QX8ePl+v+H/8PzHj0Eg==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQNioVt3b8xWcoDwPtgLeIdpuAvD+AwOz96dWme3
WRHK53BQPremyikdxhdw+Mp9bN8OVhhfxGFGQ9LxqDUKUL6Ew5KWIxNmBsL4
Mg5h+yVby3/KQ/kKDp6nSr+V2sP4Sg4R3m6/OovloHwVh9Cm6SwTN8tC+WoO
XAH+Z+KFYXwNh/zO1tbcNBkoX8vhb/mDuuKr0lC+jsP+XZP7pwjA+HoOPvs5
ty2LlILyDRymC9nuX/dYEso3dPi0OPKAvBGMb+TwMuJsxbsKCSjf2OGISHml
widxKN/EIeDLlpM7XGB8U4eldx5evvpDDMo3c5hzXtWTrQvGN3fYflqc9U8C
jG/hYCbFufjjAlEo39LhN1+6/UFXGN/KIX0qUwmvsQiUb+0wt+FqFf86YSjf
xmF7wbJIPVEY39bhh/dTjkYfISjfzsGloeKvYbsglG/v8ExfyThPE8Z3cOg2
Sr0zO0EAwm9wQJN3dJBd/edajDmU3+DoULxxfWdAFUzeCdX8BieHhMLY36de
wOSdHTT9lEVcc2Hyzg6v76i36DdB7WNwcVhycnEZdwkfVN7F4eKOq19u/OCG
yrs6nJX68GqKABdU3tVhQgvzjvuxUD6Dm8PEx8XVTt/ZofJuDpD0zASVd3co
Xm1tv2kRA1TeHU3ew4FJQesX9+o/9hB5D1T1DJ4O7y1//XPSe2YPACXCyhk=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XtIU2EYx/FTm9d518yW5i1lqVmaLW3Wfs7b1LwkGejUSpiIiVpJll04
SAtSJ6VSUBMqC/NKWpIlRS1QLBQkBtE/5QVRo5oZoV2kwucNPC+8vHz4Pg/n
j+NbUJapXctxnOrv/fey457VN9Bz1A8rMivPSETlZgdmDpeLJ0tFbb5ka1Q9
/t78NJHZCbzOkH9p0ofshsL3/WK7C8weuFjjr7P3YvaELHBCGlbjTfZBya/B
cCsLZj8M3Dj0Ybp4E3kzVOPXnmmavciBsNyWFVE07EmWYbFi9qrcnzkIhsDS
hdHajeQQ/C7UVLZ+lZJDYfioz9fXMW/Hwrju1kHTBnIYGj4Vyc4rmMMxFHPf
dsLoQd4BU4oxZ9yXOQLGlHtBY7nryTvxOe/FoyOD7mQ55FKblvmb68i7cE6j
jH54gDkS6uS6d73ZbuQoNPOmKsduV/Ju1OrvBnSJmBVo1Jobc1tdyNE4fCzv
56sZZ/IeuMw8N3ZkMu9F9VSBfqqTWYmtzrL562NOZOBEh0LZe5vMAx3RfkWy
l47UY5DU1t0eYCDzMbgz3HJSUuFAXYWF5SfZ1VZsXyXYj11tPhantwwtadPZ
9+Ng52qsLJ9lPU6wH4+0zvp4bZ899XjYHw9XvKkmcwnwXh55HWm2pZ6AsX7T
t7eLEuqJyAm+oh49ReYTMSI1zzU50TynXm1ejaWQhrOtJTbUkwQ9CT3dZU2h
GmvqyQh5ILaU11tRT4a3OjXKvd2Cegr214UFi3Vi6gJz+yARdVXNNa6hLjCX
Kuip9L846mnU55UrPQ1fon4sq0KnV8yl0xwdXmAuY/U8Mv73P16p/F0=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0W1Ik1EUB/BHqdmLxVzbkzaX27KcpdlmzUxtf3VuusKWJSFUrHK1KaTM
WRJFo4S1ksQoNA0Fexm1IHRpyyJMjYpAMsNFRGRW9KEPauaC6JXu+VAXLpcf
/3sO3HsUuyuKrOEcx6X93n9OWnxx152OciX+alznSagwKngyhwO9yq3agIJ5
Fs60X/PsLSML4RXNq50rJouhfXb4fLJfzhwN53G7rWYHORab033GmLE4Zjke
lm95Gq4nK9E/rEk8617MHI/iY40zGvwy5mWwSx7ZeTFZhaYLdS/G9sQyL4fE
4W8dDkiZk3DZd/L0ZAp5Jax9t8xt3YuYV6F/qCckiCSrMeJqnu46EcOsQUiU
zsvjyKmIiC19n1Ufzbwa14OyN95LC5nXoHDQPOC1kbWY6ZStOBrgmdPQILN/
ah6TMK+FvfRLTUoCOR35prqXnSVi5nV40t111VG5gDkDguIw/3i/iDkTA+be
FlcPOQuVI5/7dinI6yH62NvnK4pi1kGYpJYO/iQDVR03POZDzC5At21qe6GU
8mwosvd5qn8IWf6fuRxkaja651uoPgcfUpSp+xOpPhfJUaqJ5iGqz8UpjfVV
i4Xq9ajyZeg62ynX/3ufy8Pjkfipb5HUPw/PrdOzVbepvwFzLn7daXhAuQFO
m/feJp7eb4S6R5rwtprZZURifMS7kJH+Mx+No3Vhrycoz8e5pd9LuDbKC3BQ
0sLVX2F2FeBI6/BdfpRyEzLKHE2Wm2xeLhOCAndQNknz24D7S2pVnFKCX3ns
0ME=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU1EAx/Flk8w5X83pfGxTLPKRZStfufz52JzTzZlJTs1iJApKOvCP
sJAblZiFRiKGJhgW9hz2h+YmqamTlVipaP+kRtrDkphkko+kwnP+0AuHy4cv
nHPvOcdXV3wsz4bFYiX8G//f9OFntHc9LfTDhqwx5znbS6yO1CykfPMPXzT6
EtvholDLTdFRO0Pm8EmWzaHmweNm1dSkSUzsgYJrGLQ5Q+0Nj6+6fBdHajFq
d8zcVhSKiP2wuKr6bTstJPbHcpQgt5NHvQcT3MqCZbUP8V6EBuRtEzV6Ewfi
h4492TbnRRwMwRf5SJqeOgT7zgmelJk8iQ/Ay5xezFZSh0Jkrhh/91lAfBBT
Xuxp+yUPYgnkjTsXWoOoD6GksmFBr3cnPozCkNXp0Zd84jCUB5c1nrW6EYej
4ZWrqdlAHYEHJcMjBdXUkchU1Dh/7OERRyHtemgQ+wr1EeTYeTK3IqmjkV9n
U8qVUEuhs/iZJMwu4qOQSWcvvFlxJY5Bd87uF0IONRD5uqt58IPzhhmAW+T6
vVJPzIqFpihw6JeA9lh0WG/s9xx2JD0O6sfVsrx2LulxMP90Ss/SO5Aej0JL
Z/eYkUN6/JaeANH68FCE1Z70hM3zsWRwmefxrXyyHiPbsr4cKvmgeVZKv08O
n0drEznhLqQnYqnK4H5ykZhJxL0oiaW1if6/AtmJPfYrbcSMAnfuWtxqJmhP
gvZUnyIrk+wnk4QdQvbxgVG6v0o0MeNlTgbalcitlM9JB2hP3mwmGU2d0dm1
BnpeKagYrhdkBpPzZ1JQauwT9yvpfVBBPONW16KlXQVr2lhNXRjtaujUAffX
HWhX49Ll/vf1vbSn4urK24eCP7SngjO2qF8vp/dTA+OQtuOElhgaPBtyt107
Tcxo8Hw+XZ3aQtyrQXB7S8ZaFx9/AaTLDXU=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQNioVt3b8xWcoDwPth3+Sh5X2OB8RkcroSe/n5u
riKUz+GQyB68ptsRxhdwkJ7/0NTgtQKUL+Iw8b6DWtBiGF/C4WQdsxCjD4wv
42Dc/l686bQ8lK/goBD+zqPSCsZXclhX9qNyaYIclK/ikP3lx8ovi2ShfDUH
rZWtDL2/ZaB8DYcbfYLXHsjA+FoOUdoTPc5VSEP5Og6v+ne6WR+XgvL1HOYt
MI1MMITxDRx8dji4as6QhPINHcQcH+esKZOA8o0cwtNW/PjFDOMbO/wtUvQt
tRCH8k0cFjXybFoSKAblmzpMlM18M+uxKJRv5vCbL93+oCuMb+6w1T7tR02O
CJRv4VAuOpuhf5kwlG/p0N27VHUtM4xv5WC4S1r9UakQlG/tsC9G9aAcN4xv
47BM2euWySEBKN/WYb30mu2XvPmhfDsHwTciYh/E+KB8ezS+g4OurV7I/me8
EH6Dg8NZqQ+vpghwQeUdUfkNjg4/dSbVLM/hhMo7OXAzr616NZkRKu/k4GNe
v/2xHjNU3tnBuPftd8cDP+0h8s4O7y1//XPS+wbhM7g4hEcZrStS+g+Vd0E1
j8HVgUlB6xf36j9QeTQ+gxtU/UeovBvU/GdQeXeoOVDQgOADALU/tFY=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2EYwPEXNafOW0un5vKytMRk5P023bPN65y7qCVqQQhFYGGmEWXq
zMzAZM2MKCsiu+ENrMy7zGzRlyCTwCQQWWlB4cpSG3bf834458Dh8ON/Hs5z
OJzg0vK8/XaEEMXf89+VHvxd/SN9ZUKwySKRWE5PlTpTE3ixKHCt6AhGO8Gj
V82D2WnUnnCRM7wh8EsQ2gtmigraG1qofUEjHF94HEEtgLrXs2G1VwLRQdD5
dbvP0lwAWgjt3efknDjqEJDNXx4vub4FvQ0+Frm3waQAHQZv+pd7qrnU4XAk
I+1E0wF/dAToQ9TXkvWb0SLQG0p4DS/90DuhyhI5xpNSR0IqP7Tb+tQXHQWF
jt/e7o6ljgbBzcOLBWM+6BgwTXTMGEupY2HsU75K3cFHx8H3gcahlVlvdDxY
tNP6S3HUCXBVVW81u3ihE4HH9RldGN2EToLmljuhPfbUybCW896pXslDi2Ht
Nqf2nZQ6Bcb3hE4EcKlTQRylbHLftxEtgcquZMmDW55ogLtbFbMxT9A6YHUp
+PuaPxhaaZfCsRGNOGHNHbsMusTCg2GTHthlcF86aXrm54ZdDqZlj/ziClfs
clhxG6pfj0WTNFZnmaQz79elw4Uz9oNze12wZ8CPiNZT9w45Y88Ay8OpnzXe
aJIJz00px6uGnbBnwllDWVJ1IAd7FkS3fF6VGul8FhjMldWyVdqzoa+3vE1U
QuezYSnR+ksmcsSuAO35yB0OjQ7YFaCMrxswi+yx54Dt/7LDngM1N6ZH+fO0
K5nWsUxy4WSddaKsE5+ny2W+D1Ex99GpmPsQNXMfnZq5D9Hg9yY2g4a1rwYK
i6N6jwp/S/7byDLRgl1QuJXbtW4zaJldx+pGVid5uP8KzufhXoT8AdtdKMk=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzl1Ik1EYwPGjhi03cSs3ZzN7HVHDlrnZZpb6Pptus23OimJUy4tZV8Ui
gwihmDIMMSUadDEIa7WmhIM0v3BUIBoEXXgRhgqLIotSTBg2ReyDPSfYOfDy
8uN/nnNOkfvKyYvphBDD3+/fny7Z6aHx55eUkNRP/o2AzPeJqAkMF84G0yJF
aAFENZ7lUAO1GKolZ/iZNQ6dC8H2wCvPU2o5jN3rHW+2UxfAuymPSZrYjeaA
syT6R/TUSvDF65s2uwvReyDy8ImuY3EXei98vDOrBiu1ClRv3e1z1wrQxdBY
6pc+CinQarB0hK15GuoSGGgJPajy70SXwsSN+7d6ZNQaCFi01+XOfLQW2i4v
dYZn5OgyGCBBb6eY+hCoB7dk6rvz0DoQ9ZWfiPbI0HoIcEM5C1+l6HK4eY6v
fHGK+jA0zUWj4cVcdAWIb1+9EAtSHwGX+9Nn9bcd6KPQNbht/8vYdnQlJGxf
BK126io4IFGtBKbF6GpwbQ0GFCYJmoesx4lG8yQ1AO+MuxwKtBfgx/w+38E2
Om8A51ltpFmZg90AvYaJyan8bOxGWM0ea93QibAbmV4D06Pv4x8SQuw1cNeX
MRo7n4W9FpYr1jeNJZnYa0GY0d/y3Z+G3YT3/+aT3YT7V5MmZkjniteFzzaw
m3F+BbsF9y9gtzDzdcx8Xep+cgzfgcvLmFiZ863M/bbU+7w2pttT7bVDWdfS
L8PrNez1zPmMiYPpDuZ9Dcz7GZPj//0HjNP+3Q==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtIk1EYB/AXb1m2pjnnZZpumqyyMbVNzcseL1PbzW2axkpCwRBUNClM
E33tAn3oRkp9MKIv5jI1BSWHpMthhGAkyxVqRBf8IEma5t1u7DnE+x44vPz4
P895DufDKyyuNJa4UBSl+7v/fcniH+8f7C0TgVMLCm91vjjLl5iCqZ6H2rZh
IdoTbJr4yIYzxN7wuv7p480dxDzYGFrh2rvC0AHgf3GuOkRNHAxblTXu9Yuh
6DBI0fYsacKJReBzoXpVWrwPHQGRfT/vxXWGoCOh5GtThR+XWAz3JfB24kQw
+iD05VDFES0CdBRM26vE5bYgtASaaudrhAJiKWxa3nA9agPR0SAMKNoe/xCA
joECj+WZfBlxLHg23BKMnfZHH4G2mU/2yTU+WgYPzpunpCJiOZyzjITZVH7o
OJAWXm5/buah48H0Y1q+f9sXnQCfW+Wy6ea96KNQ5VgaKRISJ8IBXThPWeGD
TgJFwfIpnYA4GZ4kiUrFNi46BXSdN5Ul/Ry0AlodXuuPZF5oYJoGuH3FdeBj
4S7MU2E8aGGuxRtNp8J61J369vKdmKdBb3dli+SkJ+ZpEK666zCZSX86ODjX
Std1OJ9Oh8PJkrzhWXKfDPD5xuMv8PdgnsGsp5QwusTNNZ3djbkSVjiWpi0Z
msoETnVMov0SOT+T1Z8F5lTb6MtAkmcx51HZkJ63JXfPJPOzoezVwJDdQt7n
GPM9aJYpFcTemF9NteJ70CpWv5p5X1oNEwOTy+/XSK5h9WugffAdfyzYHXMt
1DVuvCjr8MCcZUoHodnaBH4H1tM6Vn8OK88Bw/XoQ25X3TDXMw16cP4PXLBe
D5q4xmdfJK5OW/VQYIrprhb9Vjj7DfA9YeNXmmTWaTCAl2tX3VzzotM0y1YD
ziXLyOo3MnOalVuNzPOoXGY9/PcfofUvnw==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/HjnHOp6bxsWS5TuyBOLDPnvKzz29FN52VlaqJYiBDKjLIy
td60yijogmZYiL7QhEGyYEY3zQpTLIP1KqQgC4VglXYxykS0Yv/nhefA4fDh
e57/83DgRFcd3nNAwnEc/+/+/2SXquTuoLM2Bh5942s7sbVdxsxB07dXc60r
mixH7/Gh2/sFZgWqGiqrxyajyGE4v/lx18tW5nBYyppyZjTMarg/lDY6b24g
RyHj4nCn8k0kOQaHZlVdnwOYN6F6rk44q1tP3oKpV6NPeq1qciz0kzee3bJH
kOMwbHrU73KtI8dj6sL8hCKIOQF+y0nWL5NrydsQUlv8VjYbTk5EgzPyasm7
NeTtsLh2j9hrmJOgw0YJfqjIO3CiJey12Ys5Gdq2kRpziJKsRbP0xbj8ehg5
BUWczuUMZtbB3X7U4OBDyamw1s/f8yoNIaeBL/1ZYYkIJqejrMPRrYxXkDMQ
EDrcWOcOIusxtzRQdsaX9Z041pfO9/cw86jw7emIMLJ5WDnPBixzhcuV9Wye
YaVtBhwUWoYCuwOpC8gsXtT6mMg2AUNjabOx0wHUM/Fr9cPTi8lkWyYkUXEL
/n2sZ6Fc05rjavKnnoXRuaCi8iOsG5F0eea34ekq6kY8H9U31g/IqZvQ0uz9
4P0+P+omxN+RyrRXfKlnwz44oRpX+1DPRuGlRI30nJR6DvJTTt2fTvCmLjJn
pu/HUTfT+Rd5T8+l8/3x2JYr6nnw93ac/NTmRevz4PnfJDQ/X7Q+n97/TusL
RL1ANN+Cr6kLS0LCR+oic7toH477C9Rv9t4=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQNioVt3b8xWcoDwPtiH6jM39nLD+AwO2szcv9OX
KkL5HA6XYsx79pjD+AIOu1q5PkvcVoDyRRw277U6aV0L40s4sP/Rsf5qB+PL
OGR/yn3aelweyldw+Pb+0RITExhfyeHWsgJRpj45KF/FQVGDR5jlhyyUr+YQ
eF1iZb8GjK/h8GQZ49HQahkoX8uBX2DHpOJ30lC+joNo5MVKQysYX8/hfmZ1
jUWFFJRv4PD5YevCsKuSUL6hg6pMRvSiQBjfyEHh5eatN+5LQPnGDsIF3gfz
amF8EwdRcVPts03iUL6pg87WxaF/dotB+WYOKoUXb/4UhfHNHRQei05dHCkK
5Vs4tJ2dLhmhA+NbOiTf3rNn+RsRKN/KIbDHUJulFca3dkifylTCawzj2zgI
rb2a+aEOxrd18PDqubUpEsa3c9hqn/ajJgfGt0eTd3DoKyhdFR0M5Tc4OFRV
aj+/pgqTd3SI4ZBqmGEJk3d0OJcY8fHzTWGovJND9dVKXoYEmLyTQ4D+AqUS
CZh+Z4eYpEePdV5A1Tc4o+l3cVApZ5xs9h4m74LmH1eHexF97T3fRRwA8U+i
+A==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtI01EYx/G/zksxrbV0WU7dppVpaN6dlvttXjZvM43IiS+kEIRRKUYM
LV22UrKCIVaYJCQlXnqhsMy0UGIZFb0J7OJAyihKqoXiUsao2HN68X/gcPjw
Pedw5EdPVtT6chyn/rv+7Wwkh22To0YFvHKqrqUL3kaKmTnocnrqTg/KyRvw
UuoSdVcwi5A4uxQAj4wcAm1ai8HZxxwGfY2815DDLMWCYN7kfB9FlsFhe9Zy
LJNZgQbRTmdqbyQ5BjalfCTch3kXorO6bnSYIsix+LiYKVeMSclxsLvrxT3u
cPJe2MVGi7CYOQFfRs+YVpp2kPfB/7j5hOfrdnISHjx9J0+tZ07GnTF7f8fr
MHIKigcuVQo3Maeid/xHZ8TGbeQ0BA1mlE/1ScjpOG954rg+HUrOgGwxtLvf
wJyJmWhLLKdgVkI6XwmRNYScxXM2Iica77e/2Erej/H6u4aEUOYD2BMT+Mml
Zc7Bo9n2hd+tYrIKp+oGHpdJmAHVkZVqffgWr81AxLB7rjqDzKnRmVzruFkj
oq5G43C2auw2mdNgybHbktjGugbLnoeGtkDWczEX3FG3pg+mngv9yNX8WhuZ
y4N9efOhqoYg6nlYDZ44504jc/moirfqXpmE1PN5vQDWxcZmjSuQegEGJt9I
nkv9qWtx0WrMao5iXYum1vUZ41AAdR2idKVKyRCdN+tQfjkp3u+CH/VCCAX3
mr51+VAv5PUinL31ekryQUC9CClXvrvU02sqby/GT+W6R5Pw2Wszz1wJvf+L
egn1Veql8JXFrQuH3dRLeV3Pu6+nf7Ep4/UyXj/4338A4Gb5Zg==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlHtMU3cUx68gkwko8igUi9D6mlKZiEhBGV+KFuRln5QWZthc3RbIyJQF
oxDvjA9mXASte2h8YZQKilFHFMu26xzOzWEynSXLljjDH8tAYxO3YZHhNJzf
kt9tctN88vmde8/vd87vqN+sM7uCBEF47/nz4p/9FLZu7/kaDSbIn/uLXtvU
GMVYgHhOk6G7qiYOxd4fFzxcX804En/vvjBJCGEcg92dQc13u5OJ46F0xUd9
4WKsQmBfVVuOinEy3J66P6Jrk4g1uNkxa1OfZxbxHBx1q7sHxhOJ56E1dFHK
0GLGr+Dn4enfKT9VES+ERzXX5RqYSazFIV9Y4FQG41QsGGvMDdQlEC/GyDpd
f8uwkjgNT9PTu+LeZbwEh5tU60/ujydOx93ib5z31YyXIvqaelHc0TjiDOxs
rcneksR4GepHT2vSshXEmUgejD1wwhFLrMO6X3t72x/EEGchctf7b91rY5yN
qtAE8bMsxsuxttnwZ8630cQr0FXwyNwQzjgHaYaDPUX9UcSvISVRoXz7Dca5
+Pzr9gabljGQ2Dnmq8qcMcEi8Hj8imPblEjyeXAcPHs8Vkss5qFW3/LltOPT
yOvhybvWd10ZQV6PoOSFo2Gd4eTzYXcu6dqgmU4+HzMexCj8Cha/kn+fuBL5
1rFlIQbmV+HczDOXbhez+FX4wGtcoXvCvIH/nihjoQDOlNbCW5vCyBfAF9H8
TqCM8hUK0bI9+PK916eSL0TSeP9NnZ9YWI2Adl9je+3L5FfDf/Gnf5tiiYUi
nO+qc6dWhpKXsVCMksytlwZTg8kXY+K+BZEvkfkSmS/F5q2jV2s6XiJfitbB
jVv0I1PIl8m+Xybza2T5r5HlZ6R+pfUwot07oPhBFULrjXw+khEbO5fnXmgT
KN7E5w8TkgpLsxQdLN4kizchLPjs5qH9kyjeDNOetJTJOyZTvJlfL5r590lm
2f4s6E/wD7kjqV6w8PURLfz+JQtfb8HKnwessvOyoubG5a/u9FD/SFbc6Mtp
qL/Czs+GpiN3ehX32f5tsnrKvGTj6ymU84xyzC76xOf0sH4s5/cnlSP944cj
eRLrPzvfr7Dz+Yp2vt8lO/6J6PlwLIPdjwrZ+clYrODvk1Qhu78OPBNMz6rr
6X7Cge99c/56Gs7miQPeBPfhnkc0PyQHhn+bv/3VbWy+OJF1y3vs+u/EcGLq
iSdrDX0s3kn9QPNKcsLi+2jP7UQ27yqhT612b6gmRuX/8/I/NdG88g==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIU2Ecx/F5nbFIzTXNS5sjLcVWeZmbuvbb5mXzEiZdyCaI0CuJ6VAk
oxi9sAtOtI2Shb0ImuDI2JZBaWQmvaqEomVvitWbSmMOwnRMrdj/CXYeOBw+
fM//eTjn5HaYWs7G8ng81d/r350t0YmpaXenFBGtqD+MbnjM25h5cLt8iy9d
ueQk7LMm5rWdZk5BgWJwIn9NQhbi0mVBMHCTOQOLwcqlawrmbPQ8nx/wLYjJ
ErSN5lvHw3vIUvi9gdk3J5n3YkHWPG8YzyHnwxu/9bFvM5u8H+JjdQc+y5kL
Met9tWQayyIXge8carmykUmWwdN/b0xlYz6E9daHmuUE5sOQh849e/pgN7kY
M8oAzCMZ5BJ0XXUEu7vTyaWYcjg1Q8nMZTg/LHxviBGR5eh5PCd5Ub+LXI7S
t9a+vCdCsgLGji9fi76lkZXQytrt5nbmCtzyD8Z8Cu4kVyLyv5irsHp9Mr3t
VypZBSP/riOrhvkIclxhn7GcWY3eArvthieFDGxPm+vr+p4csQV4tDJ8MPP1
Duoa6I6H5Qm1ZIsGvdPNVYo11rVIXRaKVkSsa3HbJ1h3lgmo6+CeNNllZ5Ko
61DkjU+UD/GpV+PinXczIn8c9WoMjHRWXBCzXhNtSw3E+ialaCKBei19j1jq
HPPqIIi73//DFkO9DrGSwpDAFVZHuh4l1p+/NbPrEVv0CChDm1rZKnUDzQep
Gzjz9Zz5ek5viN7P0hD9PK8Rp1qLJ83SLeqNnPObOOc30XuxdfS//wD6rfWV

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAWIQDQNioVt3b8xWcoDwPtjrNxuEmbHB+AwOl5b5l23e
qAjlczi4rkp58jsAxhdwkDWaVfvgnwKUL+LQ+zd25+nlML6Ew0NuY9aQOBhf
xoGNo9/xIzOMr+AwSegOyyIdeShfyaGQ0f/p7Qw5KF/FobFwzd6lJbJQvppD
51Yb8ay1MlC+hgN/88k/DWIwvpbD+69+X74pSEP5Og5lfZsXVJVKQfl6Dvv8
he7tXiUJ5Rs4zK2VSVs6WQLKN3TQ2czCZtYnDuUbORiJz0+MaROD8o0dvm5v
3fntliiUb+Jwcc35zyq5ML6pQwvLyVMc00WgfDOHn4nFfxu3CkP55g6R8Yc8
oiJgfAs0eUuH7t6lqmuZYXwrh0ezzUxvTxaC8q0dXt9Rb9FvEoDybRxW2yhl
aBzmh/JtHcKjjNYVKcH4dg66tnoh+5/xQvn2DnuPW73TeMwD5Ts4CL4REfsg
xgfhNzg4HP3MHxxVCJN3dMg+sWPf5Z3cUHlHhwktzDvux3JB5Z0c5P+dPW3x
AcpvcHL4qTOpZnkOJ1Te2eHD5ot/a0Wh/AZnNP0uqPwGF4eJj4urnb6zQ+Vd
HZbvvi52SoYVKu/qAEmvTFB5Nwfj3rffHQ/8tIfIuzlwM6+tejX5I4TP4I7K
b3B3eG/565+T3jeovIcDk4LWL+7Vf6DyHtDw+w+V90TlN3ii6fdyKF5tbb9p
EQPUfV6o7mHwRnOfN5r7fFDNa/CB+gsGfKHyz6DyCD4AGAP6Og==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1X1M1HUcB/Bf6BRF5UE4kEOEgyXaeRQIyFO8eSaePO6Bu/txztNiIx6U
RKKpyS+isFUISLVkNMuGEYqpI+XB+HVT1DbaSKCtsdKhaJmCw6nHUqr5+f7x
vdtut9fe38/9vg+f+17w9p26YhdBEKr/e///yV4KY0//qTIVnmkm6VLpjw2V
S5kF5ByN99N2BpNdUd6S6RhNZfbA2I3rFftuBZG9MXghJNDeyuwH34eOb5uS
mAMwf1B8vGNoDTkIlrV1czeXMaugf/ea405ZIDkUPu/dHFPaV5Ofh9jyqt+g
mjkMdQG1nk3fBZDX4y2xef90GrMaK6NsJWc6lWQNtnqM3BKm/ckvIrAqTTV6
fxX5JSg/iDs5EcocgdR7nZ9UvOZHjsSuVRW/3q31JW9E4IHSzgc+zFHose6x
mcoV5Gh0Vg6PlDT6kGPwu7mx4aNH3uRN8Dox9vrMfuZYhNY8dyh6eiU5Dpat
9izRzByP3Jjas5Ma5gRc0MptUp8XORGV47P2bcHML6O4vcNl7xFPchKSTA+s
+UpmYCpcFbljHVkClH6Tt5tbPChPRr9/a3vvNFlKhuXwiS991CxPwddXjr7p
tnsF5Snw/NtbMaMgC6m8pVSUXT73w9VeN8rTcHHWXS++sYzyNAz7z/zV6rGU
8nSEZH86Ln5DltJx/lLcvbBJGi9koG3czdERRd8nZaCpfsG5P7aw+kyMLz9Q
4shfTnmmU30WPx8pi3+e8Ao/H8nJQjb/PCnbqT4Hp7p3tmqKXCnPgUPdsu9Y
+RLKcxH58d1HyTJZcrKQB/WZhYuiGxdTnof3m8vi9q4hC/mYjp17mqJZRHk+
9ccCyjfj7S+uDiiuk6XN/HhBy68HWqf90PLnI2uRf7wxvbiH9lMo4I0CfD/T
FO4/zM67gO8PuQDV/dqETY9Zf+j48dDBJEZ071K5U70OeRlDF28kUr/JOnjd
lu1dOta/esT+3H9k6Brl0Dv1sx4bPMPuHx5h9XpUr2s91HKa9a+Bnw8MmBcK
5m272fMNcAlaP+fWxdZvwIZEjWFwiq3fyPc3jPx4ycmy0Wn/Cvn1opCfj1SI
k8rjZ3/JoVwuxJ2JtfXhdWz+JnwYUTzRZmPrN2H2aZ+lbjH7vTpZNqEjJPu3
jXZWb+YNM//7l8yo6opPOv0Vqzfz+y1YsLrrn3FrDO03LBgtfrgkrJftv4U/
D9nCn4cgIiEit2GFjdWLyDj/ZylGWL2IzweP1RjVdJ/JIiYHnkgvxLD7rQjP
/r/IKEK7NLbHvZvuR6mIvy/lItT4tAkHO9j9acX2y6q+SIkMK7zcfAemBli9
FY5tVU/e6WH1Tha2oH7hlZ9cP/PGvzxT4pY=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1Ik1Ecx/GVgalhS6dTp1OnlNmy1NRelv50Op2bXgjOMge6EMsIzZLU
yB5WNBK8iKUkY0YUelGKXrgyHzMikQpGb1ohLpxim3ShOUS06IXO/6IdOBw+
fDnnOXCeWENdSfVmgUCg+DP/rjRCS4dGBs/I8E9LWf6rGarrIWQB6vY52tzj
scxbUXnDkTpeQxbi5VS8Z2MbWQS3rKHm2UAMcxjElxYbojTkSFjulnvK30Uz
x2AhydYpl5JleMMrrql1UuZ4JHy83ePTHsW8Ew+6msTumUjmBBhb7R0yj4Q5
EZHCYd9bKrIcyzMaW2dzBHMS1IHKxyU3w5n3w6GbbX4RQE5GXFGjjtOHMacg
sClR5zCLmVNhlXY8tWSSD0A+dK/0x0gocxrGoi1hVj9yOuram8ODzSHMGTg5
zfO930TMB7H3q4Tz30I+BHvVseWVz8HMh/Govud4Ugj5CLrGei+WyoOYFRDK
kyX2XzuYj2K1rV+s95AzUXlOv/HKRc6CIkVrCqwkA1llnopiCTMHBPj0tSya
qWfjQ/WqX8Iw9WwY5w3t8w+p52B3cZwo7yz1HKhG3bV4S10JpyU9bdrM7ssp
MTph+rJ2he6fi/qpledVsdRzMcf/5PZkUM/Difwx//UB6l4WqLB237d1Ppu6
CrUX1mybyqjn//89Lt/r/AKv/QVIfiLZ5Wykrvbar0bF1dTyTy7qhRj8HnGn
5RR7H64Q0uHzNtNrei8NggLE/AJPXYMKg3NO7qKuhZWbbNneT12Ly93v+dBZ
6kUwTpTp17Xs/+CKENQ3eXqpVYTfYuzy+A==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQNioVt3b8xWcoDwPtg3OLZNdOeF8Rkcfp9SPBC/
QRHK53BIFbK6rBcA4ws4CGVOeNX3UgHKF3G4y3ZD8V8PjC/hwJrxWPKGGYwv
47D4v8jenvnyUL6Cg+jcXUkyl+WgfCWH/TUZof/ey0L5Kg7z/hrd/OwD46s5
XHnNf1xyugyUr+FgGiVR9uKJNJSv5RCepbpMRRrG13HY/sMg4qO9FJSv5/B7
1asL7TWSUL6Bg7znUbnJ8ySgfEOHAyKr2RNfiUP5Rg5tE7OtquVhfGOHeTzT
t4lcEYPyTRwWNfJsWhII45s6PGWd9m37dFEo38whM+Vrhb46jG/u8OuH86Jy
HREo38Khdt7lPWIPhaF8S4fpD3sY730UgvKtHNhCGTd/OAzjWzsY7pJWf1QK
49s4uDRU/DVsF4TybR0+/9sV2cQuAOXbOUhLPH4xcRKMb+/QbZR6Z3YCjO/g
kH1ix77LO7kh/AYHh2+8Oxv/mPJA5R0ddDazsJn1sUPlHR3kPXwtxVaxQuWd
HKrqfx3MXsUGlXdCVc/g7PDe8tc/Jz2YPBqfwQUavjDzXaDhwQyVd3UoXm1t
v2kRA1Qejc/gBjXvmz1E3s3BuPftd8cDPyF8Bnc0eXc0eQ+oOVDQgOADAL0e
xPI=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIU2Ecx/HhGwutps4575epeKtsqcvU9pu6uU23boSbKGalQiYKqxdZ
0kyytDBMIfCSF8jQ5byEiTptE1JWJFFglL0wTQkJygtSWVLh83+hBw6HD9/z
PIfzf/zPFJ3IteNwOAn/7v9Puvin+od7CwKwqe+SgdG8cicemYP1F/6W7B5/
5h2QWxPXRFlkLo4O7R1Jsifz4Defv2jt9GMW4LT8l6hVSfZCwXLh/I0JX2Y/
tFyrbhSEkQOwMaf5ejLdhzkQxl3d9WqbN3MwRAOmrgAxOQR3mjNqBhu9mMPw
8VbPIp9LjsBDY1X18n5P5n1It36ROj7yYI5EpsOotsGFfACWyMq84ip3ZhFk
3TMVNWYB80FMC8+3TQSTo6CvM5XutLgxR6PkorDIKCXHoKN5oSc8i88shq9C
HcvvdGU+hLky55Dis+RYvH48Ulk+xWM+DK3iLnf2GTkOgmzzm2o5OR6TOdql
lfcuzAnQZY8pMrTkI0h9sqQ6LiZLMNsQEz1d68wM5Da1211pcdq0AQjVCHmy
QmaOFLapwNV1R+pSeBt/T2WKqSfiUmhd7b0+LuuJ0BvjJH1tzJwkrGwM6a7b
U0+CWj7+/HMC9WQoO0ydQY17WE/e1mWInRxuGZ+h9TJI0lczNZ70fTnahaoP
UWPU5dDVd7W6RtD6lK3vG1Iw7FHXNPiNumLr/xgU0Pd2Vx4rof2V2+ajxFqV
yS1rlboK4d589/wcNk+DCrbLyfHngmneqXB2cDMvmJkNqfiZo/9T1k89DT6D
+qc3X1JPQ+mDt2b+J+pq9Evyfly9wM7boIZi8d3o7tt0/hpUvLrvro1wxV+W
TPIM
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1Ik1Ecx/HHxSwbLa05taaPWyVzldV83aY9vz3T6SRvmiJ4JZVSaght
F7UE86IWRlFUXkRGJdTacr3gShQhk1YqIiOyIrypyBVICZE2nFbsfy7ywOHw
4XvgcOCvPtC6v0HCcVz+3/3vZEtZExh81KxBTD8E07j93JUUZg6GI3bHwQE1
eQ3uh5fu9FUzJ4LvbM/Ki2aSFagaGu87eoM5FSdeXmh/KjCrEOju8QuveHIm
3vdLgx95Zg2cD3uMh5oyyFtRvctYH55JJ2ehM/5rcivPrEWIW7ZE21RkHQpr
JntHn28m78AD6YQtLGXOwVjHdFBWsom8G8ppYcDZlUbeg2ij63jDZCpZD/Xo
nLsomzkXs2cSvKfPppDzoL7ZoTBPKMn58HwYudo9lUwugD/9tUY3oyAXIiA0
LrS1MBdBHLZnbOeZDfjclG2MujeSjWhyLjyJq91ANqFYv88tr08iF2Nnknbu
WiiRXAJfseawdmQ9eS9s9/zebdeZBViqFwukVjkZaBEvDslvkU+tMGeGxzzy
Ipi2jroZof43P98tyKiL2FLZNVXnWUtdRO752XnzswTqFlz65Dgpzq+mbgFf
UWVQeqXUS+Fqjww3e+Opl+Lu4FvlmIr1MshW9bq+XY6jXgaHzyQ8vs1RtyI2
vxLq1v/vc+WordP7j2mWhVgvx3dDZEnM+RUzVwFJpi4i8y1Sr6D+hbqN/vOb
um1Fr6R3OO4PkMTSgg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tIU2EYx/HT1LwMa6YtmysvZIaTpXmZM22/zUvTXTRLyFQIowtISSl0
kWxdFEFNLIkiiSxypiWYaOHCjBCcZaDZUvBCGhFeSEIyp0jFnveP7cDh8OF7
zvO+7x8nML8w8ziP4zjVv/v/k13CrA5TW0EQbFpQ3Bpv9HrowcwhJzozZLQt
kOyGD0NjZtNBZgFczRdLf80GkH3QWX9V5l3D7AtDx4lHZfHMYhhzjeaJUX9y
AA5PRVlOBzMHYc3aook9tp28A5oX5ZXiym3knfj2fnZx0Com70KF7LdAJ2EO
RVPD45PXy/zIYegLNxVXDYjIUmjfuHc2ZjOHQ+laOS5o30qOQFOp7ozaj3kP
8mrC7k0U+pIjYWwZHlma20KOwtt3T3iWbOZoFEhXJofMQnIMphqGswQiZhlC
c2J7u9M3k2OhLxKU3On1IcvRI1HNPzvHHIdcN5Hhrpx5L/L7groiDd7keFS3
u0u6JzeRE3D0bN5K/w8v8j7MjoXc2H1NQFYg9Wlrc3D9RjLsbQC85nyEC8IN
1JVIPLQa45JCNihh8aw4taz3pK7CfQt/uTGaT12FI5Ja9ccLZC4Rg68+L478
YT3RoSdhQLQwUyfwoJ5kP49LdpifjLB25/UxN12pp6CvN+F8cZcb9RS0tRbW
SXPI3H74q3VyYbMLdQdzalx+8Om18KsTdTW0sisvp6VkLhVG0xdhv5h9n2r/
PpcG2//Do57m0DX28wwa8J2eX5q5vY66FuW1BXEl/nQegxa100UlqiV2Ph0O
VEVInMucqesc9qd3WF/v0NPt1zOkgxcQauW3rCpsPQOR1fNLyp5lm5GBn3Lr
mkr6XfEXadwJvg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU2EYx/GTyyYtbV5Sl+ZlaJgua7NNa15+6pz3qaEoYinWwLyzzA0l
NA3tQlIYLF03SEwoBQtJMxplk/IWMdSgoFSwEin/mJFQWdHz/uOBw+HDl3N4
3/c5/sVVh7V2HMfF/L3/PdnlnjMw3F8mxn+txNQLeNUrTswcyk8aP9X1+5Md
0DxmXWrIYRaCk+ttqxyzGy4t1S5PD/qRPdH71aSsOs7sDf6IrVRox+wHndrw
eb7UlyzGmHbZt7PZhxyA3Ksay4XZXeTdcLaNSqZDmYOQOCip7m31JgcjxOPN
hP13L7IETsq3fh2BzKGYiEaP3LSTvB9Glyhz34KILEVhRf+ta9OeZBmaFsy6
MxnMYajoKua3VHqQDyD/teOJjjl3shziBw6dlnRmBVTXP7oMnd9BDoei/UVJ
sgtzBFomjaI8CfNBFM4OHLUa3MiHUJbHzzpmdCUrIVV3DqVMupAj8bQg8JmP
gDkKqkbDL2mrMzkaHea7+hwJ6zGIybUVaLxYBwS83rqldnIjoL3RbVd/m/VY
XJRp35uKhNRjcS9SXBI0sp16HHLzZX06MbkxDutc1npRDevx6IkdsYyKHKnH
w1EnU1qbyJwK8dk/FfZqJ+qqDT0B+SFXkqYMAuoJeGmJ0tc8dqCuxumb1ifu
czzqakgebt6iaONTT8Tls7zBD0e2Uk+E7+/J8YgVMpcE04xgrVvOvr/BXDJm
HM+VrGnY+pOhud+WoB1g60vB3qjQbPMi6ykb9p+Krld3agU1bH+pODWcGRnx
g8ylIbM8eHxVxM43Ddtcn+urv7D307G4TxxWuYfNJx1CidRrap3NR4N5k0L+
rp3m26hBWnjDo4VQ9r9kIEC/qV3xzRV/AK7m8D4=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzntIk1EYx/HpDKulqem8X6k0lS3N+yV/Tp3zNjdTiMiyKCgUKrXSInwz
tRJBnSJ0I8KwwozSUpcao7wkZpmSwkoM7A/T0vWHgualwucQ24GXlw/fcx4e
96On0o4b83g82d/v358dYcaLjmfZHliXLqpTucPskICZhwfVIaKIBnfyRnxK
9+02SmC2QFttOb9jxo1sjYwYi1+VZcx20BxsKUgOZHbCyyF+nbLVleyG87LK
D3UmzB6ISV8O2iB1IW9HXmF51kihM3knip2KLKueOpG98L2uu1CudSR7o7NW
XH4lgNkXj3rGj0TudyCLgNvT2idqe/JuzJp219yVMvvh61I7r6nIjuwP0Y3m
ucxlW/IelPm1uYwpmAOQLfo9MdwvJAfi8p2hw/anmYPwue+5diyPORjvJutX
4M0cgvm2UvWC1oYcigrbIdXCGeYwnDw2XyD2ZA6Hxkfy83GuNTkCLuq81qsD
28iR2Dd6vWLYmXkv/KQ31YmDVuQoDEepTGzHLcmA1ZTmdWMamQNmvniWiIst
qEcjRdrb8y2SzEXD0W5yqlrFukTfnARnd9XWqJpZjzF4HwNFjvfAvD3rsVjj
Kdey8rdSj4XlD2uhTmhOPQ73++vPCfLJXBxyJFVd5vdYl+rf56Qwy/UPHyk2
ox6Ph9FvenrtyVw8XFcHB0J0m6nL9M3JcMCnWva+QEA9AbdGBYsNgWQuAV19
YbNek1uoJ2LU7NqJRTmbn4hWXZXYYZDtl6S/D5cEYzfvJUEje5+M7Lftr0bU
bL6BeSmoKuG3T2Sy/VIM9pMbdDl0LR9XLtlsop6KsurssIuuptRToazw8zEp
NaGu0DcUSA4uapsU8em+AgJ+04XpGqN1axS0/3LU+nsl5kKXViWihXVDSXPp
cAbW/Pcfr0waeA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd031MEwcYBvATRToZAhMqFBGouvFRYaOKVEGetnwKlLa0VAgz4oIzfDij
3ZyyjZsax+JHwI/onMmGGJ2wyQaZU5Stw4mbjiU1G5rMxD8kTp1j3VApBMtc
fN8/7po0zS/PvXfvPb2LW/OGtdpPEIQ1T7////JHaf/6/Fe1ajyTJ+tE5SfG
lGC2gP07C0d0X8aRFfijq3ZRSAU7BIdU1uOjU9lhOOUrH3a3xZIjoLU3FKns
7DmYN3TQ2e+NIcdiwbSPJpOi2GoEKoS152xzyfORiJKjHSeiyS+i9UlfQ89c
djxmvNdfE902h5yIiFVDikPhbA1sTX0/OzOiyMno1gcE72tWkV+Gf7243ncv
kvwKhrKbGoer2Kk4XDTfqtgTQdbiyqrOf79dwl4EXd6v6OqcTV6MlrzZyVuv
K8lp+DTYTzWRw16CmPxinbI9nJyO136/cOHkgzCyDuNe47HNGvZSVCpU4mEd
exmG6394pH08i5yByu3aiht3XyBnosbpPTPFwV6OpGhl5OtV7Cz0Xv7glreR
DWwYHOmriiOLkOV6JJjmheXUh1KuR5bjYaUpiiwYsCXh8lh1SQjlBtQZmntn
ts6k3IiFmcm27+4EUW6EX2zieGDH85RnoyKpJf+XtwMpz0bogzClR8nzOTDa
JtL8c8liDsY0+945Wfcc5bnUpz/lufhbN+4zJE+nPA9bG8e/r20ni3loub2p
wTAaQHk+mndMPXvr1RmU52NA5bl/IIQsFMjyAni63U/eDefrr5DtvwLHf2p7
K9DJ+xfizfPmjHQv718o7UMokvVTJOuv+On/sXQ4/jb1JRbjM/3FS/2RPG+S
9imaEOMbuJru4f1LoN3z16jeRfuKJXgcdO79icXcv1l6PMxwn/3t4Q0v349Z
en8u2fGCRdoHLPjxUuZmZ4+C5i3QdE+bnraX+nZZpPsIVun5YcVgUNO6MRP3
YcUZT3OKaoD6cFllz0cpOjLU6+IvBtN8KRwVqac3qsmiLHeVYsTXU74tgJ5X
wYbOqM+/uVbI8zKLNkwKlsnVTp6X5YIdmzqWZXUdo/PBjoWh8f8ccfP7YMef
N1/akbKN7JJZKMOu1OqbH6/m+TKY6xKvPorkeZldZdJ9BAfKj3zRGq7heQcK
Tp1uX3CU93dI93M5cCdFrV2fwO/vSuT23quBm4yVKB38cPe16Fn4D1cdiAY=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ltIk3EYx/EtZupFJ8/H5dbUqSVty+nU9Oecx03IUoRlNzYjZhKJGr5d
9GqMEk0vhCzQ8lAMKowhFqYZmaWwiDBalkWRlJKWY100SDvh/7nYXnh5+fDl
//LA85dUnTxYvUkgEGT+e/9/6QkpHxmz1UixIWf2subOWt0OsgC3tvjqW25K
mP3QLNZ355aRt6OKa/nFCclBeCTIzHANxDCH4cfcqH1ZQ46C3BEufTqxkzkG
FUblUJ2ULMWIT+Bgt0XMLIPPmjVBuxDNHIcaiyzr1B6yHI4jz+SJtVHMibDX
TrVMDUUy78Zh7ljKUjw5GY0dw31cQwTzXrytrhebRGQFdKmrKcbkcGYllH9M
4Q/7wphVmN9lHpiOI+9Dk63ULedCmVPQc+97W7Q/WY3LmrFL3yZDmFPx8sS7
0RkTOQ2/637G+j8JZtZA1/MxYLSVnI7yNz6tF86QM7x6JkrbFUkiSxDzfhhd
8+rY9UDmLPTyr7htQ+RsVJ5TGeeWApiBB9PnP7jPMvNAV7Wzq9JKPQcL4+t8
Uir1HGzcF+pa3EhXzVh7qWuxuVw47HxMPdfzf3wuFhNcTYoDNI/Oq+vg1n/2
azbQ+TyY6913hRXU8zznEeRDcT8y/lMD9Xyv+QvQf30muNNBvcBrvkLPefhC
HHK0ts9G03xFsLkirnHHqRfBVywqm5qlXgzZaWGXepV6MQq/vp7Y2kb70COp
M/+51s7M63F0fnzcukLdgDRztvJiKNsnb4B65cv727603xKsDYokiy/ofAmu
dFw1TzYG4y8vhO+R
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtMW1UcB/ALdDDkIRWoG7BRhtOBrGk3eY0h3wItb/puKdNkkuBjDLcg
iAKTKzr3z4bOoYlbZua2AG4MQ1jHS/BuC4/MmMiIzMQ/UCFMF5UuGmkRihp+
5497m9w0n3zPL/fcc87vJFQdMVf7cxx36L/n/3/2U9hcI301O7Ahd07LyYH2
hiBmDteXL15UX0sgb0aGy/eKTM8cAVevNsvyh5Ichde3yiZMnzFvwQ82n6ZU
xxwHdfc7a77peLISZ4J7PXI/5h1YmvQUXFZvJz+B202zjjuvbiM/CX9l8krI
1TjyLiw+/OSXu4ux5GS80GG9UZjInIIu273rqbUxZBU6b41OHJraSlbD2Kcs
sg9uIWvwo3e7rU3NvAdxF2rvW0cfJ+/FWYN37uC6gvwM8neGp8zJmVPhq1ve
GTweTU6Dcj76o0tO5nT8E/5Szk0dc4Ykz0TygYzxMQPzPlSVJ3X7QpmzsHpJ
lnD/2yjyfrhyXvS0HGbOxtc3XJ/XHY0kP4vRyRNzntbHyDmof7lrzKBgBjyX
g95a0JJ5oG2h6tRCj5xyLfL5N9Y0J8i8Fm8mTXqrDRGU5yI08lbj0V8fpTwX
f/qGnW1BLM8Tm8+D/LcohVsRTnk+ynvaddWuMMrzsTtbZf1qkczpkGddTduk
p/G8Dn+HDb29mhpKuV5sXo9zsyHeztQQygswPfjdX997yHwBPng3YHDu+Uco
L4Q35cOWrsPBlBdiajy7sX54M+VFYvNF6Bq5p7gTt4nyYqT0ywLT2oMoL8Z7
p2v2NceTuRLEF5ZlKq7QeL5Ekpfimxj3g44Img8vMVcmyctwev615txlVl+O
pcwVX64qkHKJOYN4PC8xZ0RT68rNmis0Hkbx/HgjNu4H/w0LRoQEXGt6cMaP
6k3i74NJvD68CX29RzpUB2j9BJPk+83iHGbJfphRMzU4NjNE+yeYkVj88Wxl
N1sfi3g8LDj26cyXip8CqN4inq9ggemk5mnZcRnVW8WGVbKeVvH+Cla4+6fX
jkXT+zgb9p76fVkrsPfbJOttE89XsEnOp118PmFHWN2erJk21g928fkX7Fjn
TOsH66nfOAcaRoz7MzyUw4EvYnsG7pawfnSgTD8xvpBN/Sc4sFu+6+HZadaf
FUgqT4zS1VJ/owLbrq7OPpfO+r0CIzEd54eWWL1kPOek9WX1TlSf7/RvvsDq
ndAMxz71cwPdL4ITpemtA/Mqdj9VItDm1+++TTkq0Rh9jnu/MxL/Aiz9soQ=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQDQNioVt3b8xWcoDwPthrGT3tCeGA8Rkc8l9NiVi5
VRHK53A4cPRSK3MkjC/gsMG1x2PCPwUoX8Th9Qoj6U8LYXwJhxNXeb9+dIPx
ZRxajx/74bdXHspXcFBlmflfWxrGV3KIMd7BKVwuB+WrOPC/N7e5/lgWyldz
YAi/4PVVE8bXcLhkEvXp+XQZKF/L4XFUmUuIBIyv4/DwhKjH+yppKF/PweVe
9T/hq1JQvoHDDyO2464uML6hQ4tdoi7/Skko38ih5ti6e1yfJKB8Y4djJRMr
8j1gfBOHhUpzZAo2iUP5pg5qNdcvHnaH8c0c9r4J9vNfLAblmzt0/rqwSvKv
KJRv4aDIcvfB5z8iUL6lg3VW0YyELTC+lcOvH86LynVgfGuHuA63l7ZHhKF8
GwfDXdLqj0qFoHxbh4TC2N+nXghC+XYOJ6+pfPnNA+PbO3Qbpd6ZnSAA5Ts4
lO4OsLH4wQfhNzg4XOPtyPjpxwuVd3RQ9pp2LWoFF1Te0eG95a9/TnpsUHkn
h/Aoo3VFSv/tIfJODtzMa6teTf4I4TM4Q9UxMAAAaRKY7A==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n8s1HEcx/Fvyiq/z6841KEaiaKcH/nxOtw5h3OiJQnZkGguPyqtrW/6
o1+yFlHS0KlRaphrSaaUX7VsZp2iqJjSbKSS1UU1n88f13f77rvHnp/P9tnn
+7ZNytyerMUwTPDf99+XPuY7lC0N6XZY1LR/YrVTukqbmoHYvD1gusaWeAUy
jSdjqyTURnh9kD+2aYpHbAr7EWf1dDW1BbJSVrbFiKitwS1Jm7/et4aYh6E5
eWkrj9oOu6I+7akVryZeC78smcC7woZ4PV7WzyakfbAmdkCoakZh6U69Ae+X
nS190WhFvBFdTd09eTbULhixCxp9EMEl3oxyBTfmWaclsSvUS2ZS78dSu+Gk
Ge/4ldMWxFuQM6jo5rxaRbwVyrKbgkJDancMdTUNDmSbE/NRaajFVQupPeDz
/fFwQbwZsScSBpTx/UdMib3w0XEmz1VmQuyN3cFtOj/rjYm3Qa762r7XltoH
otaJ/ejjEPvCf+e3OKkVtR9sbqtVcR7U/nDmOHwp6zMiBnJbZD6ecwaLZoHq
HsUh3RxiRoDAaDVfW0S74L8eAGdfl+i2cX3SAzTXM4GY1W8+oXbXIz0Q+llu
2/rzyXomCPaSElVsjQ7pQagRPOnotKRdqLmeFUJaVyhMVtIuQkbAhVaDKno+
EUJq795aV25IejAWmMiFxBxiNhh6Ju2H5RO0izXvgxXDq7elsvMdvZ8QhIs6
O8Z8aQ/BObfkN1cTaZdo3jcrQQu3+FrzFO2hsBWknsmdp/tDketYXHSxkfYw
6C69c/RzEd0fhvyxpPNjdfR/hWuaDYeOYi5e1EG7FI5Se1PhAdqlGH34m3Xy
oPMRoTk/bASe31PWZsnpfMkQxXj2NnDI/EEGpX/K3LEMYlaG4ZjCUwU/iB/J
wJ8cf1u3nM5vJPhFT/eFGBMjEjcuZXOaQcxGQutyxS8xa4Y/8cMeHg==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxFy1tIk3EYx/E3GdLbXMx5bOlOlcw1lpunuaz93s15E60liIFWUA2K1xAv
RMpCDSqpJSYSBlqhQWBDVFw0VtLbTUE4AtGuOhPWRW2V6DbCDuz50wN/Hj58
/4/+WFuDP4PjOMvf92+zyW8MRaZFA9KKOzteL35oVTFzGC6dbS4J6ckb0XUg
szeviVmJhqBy24PfOnIupJZg39sp5kLsqmiTDfiZizDaHYufUDHrcDx08+qt
di3ZgFNHpszRiIa8HXpjVo4sUUwuAS+fCYgCsxGz0ffSy/NFZBM2+H7y1Te2
ks14Wv9oJhpVky0wdH6++8rGXAa+fb/yk7SFbMXR09O3hxcLyTa8S2oaL5Qx
l0OxMvJl30gBuQKXrouOLi1zJbIHvJxgyydXoUrNj3+/k0euxptD/ZcDa7lk
OyaLFwymZeYapBLusU4zswPLpT/OWH055N2Ya9khaeQqci1Wr0wWHF7JJu9B
RD00Go4pyXvREfHV2hObyU5k6Ewp+f0sMuAN9nv8IUXaPcCqItz7q5J1AUuK
vpNJL+sCHj9zfDN+ZN0F8fnDuYWwnLoLSfPguXutPHU3tOvzL+zxTdTdKL/2
dU14wnodYjWpdZclk3odznanJHGCzHlwMGDdKbsoo+6h+6Qz3evpH03Pf/8B
0I6vWw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/GTZk2n5nXNXDqHWi7RcqnNufabm/O6aVGIYhHiKPASlClJ
sUP0wqAUnGU3Krqw0pQ0TMxgBiluRVGBvgjEknzRxQy0vNEq9n9euAcOhw/f
c57/ORxOTMXRvWYvjuP0/47/Z7ZE+/sGe6pkcGtWc1Hc5NoSysyhcaplMqo/
hixAm8Q+c66UOQjqS/fbs1ak5DCURSsOf7UxizH0Tn/lciGzBK6WsoXakWiy
FMNT/uFNWmYZVHb7hOpaFDkWya/edsmnN5PjkdLf3SVLZ94Ksy4/VXpTQpYj
afnRAcOHSHIiQg4GhjvTmJNw75Nlzs+yibwd9p6C837OCPIOrMnYNvDGlzkF
6yWVn9UtYrICC/3CEsnoRvJODEhKa0bjmFPRXG85kzkhIqcBFU/GWxuY0yHr
FVwdNjLvQmfwjDj+cThZibNrHU5Bexg5AzM1L+YVv0LJKjhO6jMr45kzYTXP
WsttIWQ1hN5djV+sweTdcIzFzi37M2ugKZkrN0UyA9PJMkVtApkHTiS0WVt7
g6hroXw9eGtkksxrkfeguyPu+gbqWTA9bM429wVQ9zCng4vb4zpUR9fzOuj2
raT5GAKp6xH8LUw0KyLzetx13KkX1rGejeJq+cv5CDY/26MbMBbQdGTRxOYb
Vu/H5Xg8Xw4WE1tP2ap9qedidFjdUPdUQD0XjZal51Ud66jnITrXqBR1+FDP
ww/l0p+sJNbzV5vPx/FOlab3Nke9YLX5Apy+8f6Z6KM39ULYBsdFTgnbv3D1
PM4I9//pRd1I3/enxt1NUFz4/ls7tOg2b0JJWUr3MZmLehG8pPIlYecK9SKP
+4tpDi14mPfwUDG977TmL9UpBCM=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQNioVt3b8xWcoDwPthvXvb3YakwjM/gsPOD9Lsr
mxWhfA6Hk/+KBRfFwvgCDkrGzXWv/ytA+SIOufdXvJoxA8aXcNg5acXuIh8Y
X8YhN+zih5g78lC+gsOBOaZsKqIwvpIDZ3nNDMkWOShfxeHQLMXHR6/KQvlq
DtYH95gWmcH4Gg4HVC9X3p8sA+VrOVw2mDw9Y440lK/jEC9w8TnDeykoX8+B
YXJ710wlGN/A4YBBZ1pBlySUb+hwT5rlPtc3CSjfyOFlxNmKdxUwvrED/4Hg
pUwSML6JQybfj5Dc5eJQvqnDGuslx7xeiEH5Zg7zSlfcMlCC8c0dOP9N4bQ2
g/EtHJx1rp5nbhWF8i0dDmg7vV1TJALlWznI7Sze1n5aGMq3dthesCxSTxTG
t3FYuOSEaP81ISjf1mHv8fb7P+phfDsHrsU/4tyOCkL59g7FG9d3BlTB+A4O
MeyLZkm7QvkNDg68OUKvOwoFoPKODv8ZAv8nlPBD5R0dBN+IiH0Q44PKOzlM
aGHecT+WCyrv5DDxcXG103d2qLwzKr/B2WH57utip2RYofIuDvIevpZiq6D8
BheH8CijdUVK/+0h8q4O7y1//XPSewbhN7g6cDOvrXo1+SNU3g1qDhQ0uKGq
Z3BH04/GZ/BA04/GZ/BE04/gAwCeAs0/
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tI01EYx/F/XmolS11zbm6ljgoJW2vlmjm337zMrWkXQ22mZBfRMLCZ
IgyqVW8WEqT2alNKe6FtaSl5QelmRJc3gZUKXQgjXAmVFjINZsWe80IPHA4f
vuc8707iser88hCO4zT/9v+TLVFB33BPlRxB/dRvmzD6PnHMHF7kVV+J9CSS
eVCeuDvVc4A5CqbF/lzdXAJZiGdHI4XtLmYxCgZKpt8amGW4ViQ72/M9npwA
f03h9XAJsxyBBa9Fc3wDeSMGD7aHPmxYT94MYYmk/vC8jJyEwpE30+MC5i1o
vXd1scwtJSfj1dfJH/1hzAoodNkfOyviyEqMOVxzfU4JeTtmWxXGQT6zChPR
s5KTtWLyDrTJW2Sne2PJO9GYE6uwj4vIKYh4/dsWOMeshjpu9c2ZGzHkXVCW
Xuq43ykka7B1SupYE8acCuuREVPxoXXk3Zh0q1PeNQvIafBbvvAu5DJrUVvZ
8WCfiDkdZbbSPy990WTdMuuRaKi4XBeIIgNS8WdfYxPZATSoyt+7y1g3LL3v
MGBU3xQW+4HNy4DA92jEm092ZCydx2XCq5VXJj2JpJ4Jq6urLSaZ9SzwTwmm
nTY2Pwu/AkPWi6tYz4b5VrdnUwt7n4264f1ajX8tdSPuSG8PjFpYN2KM76yc
38unnoPnT9Pra4d41HNgP7/wuMqzkroJ8aa8VJEnnPoyc2YE/0cIdTPOeNP0
ve0c9T0oKlZ118gX9cG+zJwFEaFd9m/NK+g984z+L3JJ3No=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd019Ik1EcxvG3LZ1t/it1mlrTMWXomDnTqTP3uLnpnItKTFpdSGmpg6RZ
RBvklIogKIZS5qKLLpQUByMyUIMiKjCiC9FdGBJaQmHlMCjHcBn+DuEOHA4f
vuc9B1442ac7j7XyOI6r3Jz/VjbEjU8nfTYptrSqtX7K71cnMXP4POu2tE9l
k2NQ8DFeqGpjTkSX91JLTzxzMo4sFA7kTmSR09A0L9+Bc8yZm9+vP1xOZM5C
gWPUZ26XkKX4IhvsufdmP1kG262BmwlRzLmIDaWPfz+7jyxH2ljDVcV0JjkP
MgHv+J8MZgXGNfYWvzaDrERgRvNi8X46+QCE4aKOlYW95ELUrYp911qZVTDE
8EO/fGnkIhg9uwLD+cwH0T6XoxS5U8nFcNekKh1+MbkEHerz8a5GZjX0itkP
/Osp5FKcmZ+aGl5JJpfBOXsljmtmLsflFA93ZyiJrEG9uvvZkpK5Al/v2qvG
tMyHsOgpKZ7v20OuxCnBo8EMw26yFqbH3pGcBwlkIMwdDTdfJLsQ0auwtjFx
oleQSL0KoxXSNvkr1nWIs6s0M71x1HXgZeUFRaOx1PV4/rb8h3yJ7NLj9VpC
g/UC69WQbLx/V7oqpF4Nz5xofahYRN0AxZOd0SW3BdQNcHQHX9pGoqkbccNt
K3dKWDdu38/VQFJrKROPRFGPMFcbcX6EORPcS11O3W/WTRG9Dj5vZ7/yZAz1
CHNmDE/6xdOZ7H4z/Z+QdqvXY+v98ajXo8mq8tqlYeqW7XZZIOKPOb71Bagf
xs+y4IZOuUz9v/8CKGzopw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQNioVt3b8xWcoDwPtiv3r3szkI+GJ/BYV7qewef
NYpQPoeDsPuZ/ER/GF/AQWKLlR7PBwUoX8RhUdus/XnLYHwJh4KNm+d3+8P4
Mg5nZuz3KfggD+UrOLwyX/BOSxHGV3KwFeAP3+4pB+WrOFxuuh1dM1sWyldz
+PFka/DsqzJQvoZDzmqP7WpSML6Wg9iLKAYFJWkoX8dh5ieebAkhKShfz6Hk
g+FeIUdJKN/Awfndyqm5KRJQvqFDQcesj4WF4lC+kcPungnLqzeKQfnGDpdz
7uw8kQLjmzjIe/haiq0ShfJNHVpYTp7imC4C5Zs5RH26bab6VxjKN3d4Oa3I
ca09jG/h8Gi2mentyUJQvqXDJftJLOJ3BaF8K4f/DIH/E0r4oXxrh73Hrd5p
POaB8m0c5P+dPW3xgQvKt3WI0p7oca6CG8q3c1D2mnYtagVM3t7hrNSHV1ME
YHwHh6r6XwezV7FB+A0OUP+wQuUdHYx73353PPDTHiLv6BAeZbSuSOk/hM/g
5PDe8tc/J71vUHknB27mtVWvJn+Eyjuj6Xd2YFLQ+sW9+g9U3gWq/xlU3gVq
Lwy4ovIbXFHVM7jB+QApKLJw
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIk1EcBvBXMywvqcvb1NSNVVPnpXXVNJ952TRTt7kKDVGLkaSUikZR
H6ZEaTe8FJEhZElXuwnVTMyVqUlkXlD6YFZo+kEQTcs00Yr+58O7F8bLj+c8
5+z8x0T7j2j1lhzH6f5+/r3Z47r7adOTHDH+azLS5ntPmIOAmcOJYUmZ0Sgi
r8DWrAl91h5mR+gLPYTH533Jzng1nSlZV8Hsjg7HkIiaUGYviENjOwV9PmRf
rLW6uhTgySzGt/hkP6XemyxBZEWTd8a9NeR1GBxzbpTOepGlcKyf8JLLmP1h
c7r1lkeVJ1mGmKETi6v7PchByDgsCJuVMYfgw8WfF6JqhOQNaFCUlcwtuZPl
yL7htvaMC/NGlF1WLffpdiNvgnfpobszLsybUVzTnSHMcyVvwY1iu4Y6DfNW
HC937o+3YN6G4WKBNO+ACzkUCzetRGPdzuQwWHtb6d70riZvh5/EemRWxRyO
faoWm/nHAnIEfp596JY+40TegbyB6ddZIpZHonNAMvPbjuVAUZM6fNuvVf9t
AJLqL8bqn9pTrkDOW+PLvkZbyhW4o2htaxeyPIq/3hCFHmP/zMdftJ6LRnNH
2IR02I7yaJSfWmb8nG5DeQzaph1S0vJZHoMB+9LsuSS2fywCI4J0LaNs/1iz
XIlEZXvbSIQj5UrY5wrGS/PJnAqBTtKp6h6Wq8zyOOxNkz8sEDtQHodo3cKW
5UqaBxfPtyGefx63E48865/3JrD+Tv48uQSzfgLsC+Tb+0rY999ldv9dSAuo
iOs6xuaXiDlZ5cnbuSspTzSbbxIsff3nbe+zfpLZ/smo67x51LaQnZ9sdj81
cqPKm1fVkqHm9w1qPJssD/Z4T7lJzf89OA1/ftBgevFFaok1m7cG98PF2dJW
yk0a/rw4LVKrH9S6yGg9tCjyu1RV2cD6WoR2NV1v/0I2aTE+uP5UcAmbfwrU
uf7vfghZPwXn5PrBa5msb2ZTCkSKg2VFi6yvw2iweONhP/o/QMc/z6BDb2Sl
ldsnyk06XPl63mJoSoA/g79I0Q==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0FtIk2Ecx/HXc7UtNU1dWfOEpS5JzeU85G+bh3mYSllYKDFxFFhoybDS
i9fQ6MJO5pUWCIEdLLLE1ITMSeKUyjBHd5mKaHiq1NpSqdj/CdwLDy8fvs//
f/H4F5Yc1tlzHKf6e/792ed1tL37WXEArFpMfDjc4Thhx8zhcaFuUnbPn7wJ
02Ei/lQCsxviBpdm60f9yJ6IkHyvF+uZfaBdXi8RejL7oqzVzqU1QkL2gyBE
MrBWspscgOS5s8+z+3aRg+D0clKcmskcjGVLUUNIpS95L2pqjxiHeneSQ/F+
ZnzhhSOzFBci+8bK83eQwzHTk9bYYBaT90PsWh/bJGeOQKBGf4wv8CFHQm/Z
89Q46E2OwpcwnUEgZT6A+YLeDm2/FzkaLr2Bd6Sz28kytLjP+wS3MR+E8WN1
jd7IHINa7+G6lXPMcuSpb7iN93iSY5FfOD4hnfYgx8GsLVurameOx/GTBvWJ
POYEGx+C8WJSfFEwcyJKTT8MWv9tZEB3t9m+osndah4wmoKWfgvJnALyd91N
/WNu1BUQehjKS2dcqSuhyl2VOaVspa6E6Hxk3MhlEXUVTKKrp81ZZF6FfQnh
uT1TrCfB3i/UImgRUk/CzWqHzs8FW6gn2/RkNJoE5uZoAfUUPFD0vekXs/0p
kKy/HYpZZPOpWBF1Va1Gs/lUm/1qFA90vhrpon28Gh86R5c+/WL702CW1lXe
P7OZehqu3CqOrZC4UE+HtM3RWXadzKdjQW5ZV4Y7U8/YaD4DErVG7vXIiXom
oq7N/VS8NidaeybdX7Ga09h0Db3HKvUsCByeXPp6+xt1G3PZtG+KerZNz9lo
2JjP+T//B0p5Fng=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0mtI02EUx/F/arE2XMvWnLmms4ubirkt05Vrv21eRlmoIWFUrqhXBSpu
GaIxpFpBgmQF0YhoMssKU0opg0QQU4uEYotuU5lQjkgYK6eQFTvPCw88PHz4
npdHcbym4mQMx3Gaf+//z0ZS+XSg51QaopozmPPDrgUxMwdlRXw4b1BB5iE9
6cCb0RpmEcJZdxzuRGYxqqc1yXvHU8lSrNr//uGHWmYZzH7VzISUORXaj77m
DHsKOQ2Fwbbu1n45eTOu31cplZGN5K3YEhTNVR1mVuLBzbOJ37/IyBl4Pfnk
k0HInIUT8wFX291kcjYauGrD19AGcg5KX67u81Qxq7HYNTvhbEoiazBifMyf
HpKStZiMyCtbcpi346K6X+4rSyTnwsHTngsFJOQdGJjplfk9zHnwBzvtB13r
yfnIHJGGO6bEZB3kz+r7nOPryDtRpA80vV1IIO9CrTc0dEzBXABr3ZHFsW9r
yXrU93RfLmtk3g2+e/5o8TCzAQWaUqfQygzYVdfar/aKonYAwc/p57e1kDkj
4k8nBC/VsW7EEle+ZLWtoW5Cx6j7jMAmpG7CLa8g4skVUDdj054b3kP3+NTN
eDWsb7A951EvRIpln07StZJ6IcqvqDPjLsRRL0Lz7XcvJFOx1IvQOeCTjMlo
nytevu8oRvSeY6iXQBD7qHG2fQX1Emhbf/w2DkYM0W5ZbocFP3ULf0zZvwx/
AXpRy28=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQNioVt3b8xWcoDwPthPn8nj5CAG4zM4MBzXPal8
RBHK53AovbVWkqsAxhdweOvAIv9RDMYXcVgyhTVXbJMClC/hwLegKM/SC8aX
cXhUEO2Qc0oeyldw2K8R8fKhJIyv5BDc/ODn62w5KF/FYULSi/uOu2ShfDWH
d8u1p9dxw/gaDo1mWu1enjJQvpZDWU/pfI8Z0lC+jsO89zorRb5KQfl6Dq5H
86onqcL4Bg43pt2w1zwqCeUbOnBpN8dyfpCA8o0c1lyJqLwdAeMbO1SVKOev
dhSH8k0c3lv++uekJwblmzrMOiW0a8E6USjfzOGgcosGgxKMb+5gENu8fO8K
ESjfwqH6aiUvQwKMb+kwt+FqFf86YSjfyuHltCLHtfYwvrXDUivjE8vnCkH5
Ng5ci3/EuR0VhPJtHSJnrV0oqiMA5ds5XOPtyPjpxwvl2zswKWj94l7NA+U7
OCh7TbsWtYILwm9wcPiw+eLfWlFOqLyjw8Z1+VP0ojmg8o4ObROzrarl2aHy
Tg4+5vXbH+sxQ+WBSQecnpig8s4Oxr1vvzse+GkPkXeGhtczewBGGJgm
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQNioVt3b8xWcoDwPtj3+J+yiheD8RkcMqZv9zl6
VBHK53BofS79KDwHxhdwEN9yiCtfEMYXcZh0tVCoeqMClC/hEPjx5audETC+
jEPYfsnW8p/yUL6CQ/O5hPPc9jC+kkNM+KqLfxfJQfkqDn3/OBv/c8D4ag5C
sdzh+k2yUL6GA3fSea/YazJQvpZDfnNTwyFhGF/H4WDM/3uJftJQvp7Dv+iu
dM0NUlC+gcPL/Z6zZ/2UhPINHQri6g6q+MD4Rg4lllYdwksloHxjhwe/djCs
rYfxTRzeG1j5bvoiDuWbOtz+L707ugTGN3M4wGe+95AQjG/u0FdW32RzTwzK
t3BQ2sQx66gvjG/pYPYpSsP7viiUb+VQG21vsyUExrd22Gqf9qMmRwTKt3GQ
uR3hIDARxrd16CsoXRUdDOPbOQT2GGqztML49g5Ca69mfqiD8R0crLOKZiRs
gfIbHBz8igWqpx2FyTs6fAi83D/VDGp/g6PDxTXnP6vkwtzj5GDz9eC9njiY
vBOavLPD/dfLS8PnwOSdHeLNbNnunoXJuzgITvBjcDQScwAA/kaedA==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtIU2Ecx/ElpGleVum8p84KK7G8lV2mv02n8zLdJhIsCTMkQqEUu+Ct
Uy+CKPOy4Yu8kJdsiShqYsvClRhZTStLulBUmFRmLRJbZqPC//NiO3A4fPg+
5zyc8zycoNzDqjw7Ho+X9u/8f2WHIKt/sCdfiCWZ4kKb5Z+6nZh5GLo2Pfy2
LYi8An5qvu5IKjMfUs2B1zNfAsnuaArvy9ZXMXuhLnAx8oiM2Q/Q21VaZgPI
gRgf/+h4PYlZiEx9raW+Yi15HebK0ofmev3JG5BR1z/90J05BJoto1cFV/zI
m/DmrdeZDCFzKKQH4qX2Wb7kMDwsub+/xZN5K3pLLjeKND7kcLy0GGc+jHmT
I3BosPpQ/wsvciTOLk5M9sQzR6E48q7oqNGTHI2Gga/n/B2Zt+H7gCozOFZA
3o7zno9q5ws9yDH47Xow7raUeQdy0zfqLM7MO2HYLJntLHIn70J508RNwbs1
5N2QhOVoi3KYRTC3OVRMiVeTY+HUat6XOLKKHIfTU7mVU53MwKCPtlH/jb9k
Duj27Rx4kupGXYw96oiuIiGZEyP5alfH+gbWJdbjOQlciiJ2TZx2oR6PttHW
YyuLXanHQyceHrnrzXoCRn64ZaoLnaknILJy9qfY4EhdCqOP6bOW70Rdip6u
w9qwvSuoJ8LU9/hPuQeN5xJxpiZ/Z2mAA/Uk3BsRHS++QeO5JJv7ZdbzcTLr
+XjJNj0ZwSl1k2od6yn4FVpbdqWA9RSb+VMRIJPvEHQsp56KkpMLt/M77Kmn
2Tw/DQEW44MYE3u+3Ob95Jh30Z9ajKbvxUu3+T7pUG+ukY2dWEk9w3o9uAw8
vv5s7rmZdYX1ekCBAkn1Lddmtl4KHB1U7I4xkw0KtAenvIy6Q/uFp0S2Q8tF
XyntJyjxNG/eMURP5pTIa2y3K71ENiix9L9h+1OF9/Xbol9pyFDBPmtZn2mY
zKkgFU2VjS+QDSqEmi50DVStwV+1Sj5Q
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz11I03EUxvF/bmS5XHPNberSuZrZitW2zFbWns3mRgxJYRS9grRyuJDW
TVjhQAohLVcEgQgVLIK0NJgVTZfUhfQCwWpFSFgLCSO2aPMN1Iqd30U7cDh8
+F6d0obmelcWx3H6v/vvspE6g08HmlRIK2E6c33weF4OM4eZcWFL8GYpeRna
XkYmW53MIhwbX3zhnleSJThRN5S818Msx4qx+uw9dmYFGr99ypJ+LCErcb4t
ec4hY1ZhHb/h7UVvMXkt1ht6b8jDq8llcOePuqUS5nJED78u15xUkDW4q1C7
XB+KyBsRT9Ump5TMWgSadWvKbIXkzXjukBx13i4g67BE0v57YV5O1iNkjMPr
ZzbAaHuHhw9k5C0IjH2JvJ+RkiuwNLEy6m9k3opwSbe8ZzlzJapSI587juST
t2G//Yroa1hCNkIskIUmQqvI23GpM6Du4zHvwEFbOGeuX0yuwvAh9UixgHkn
BLy+lslreeRdyPWIf7SfEpFNGQaK5LHv/qtkH7DXo3mVKmDdjMFE16bCN0Lq
ZngsXUPCW2TOgtrey1ZXMJe6BU2jj4cjTwTUq9EdFczeqSD7quGPnT5rmc6m
vht1HboN/At86hnmrBndCkdl66OYlke9BvsO6O97VYumdK+h/3+lzdn+t8+G
uHFuwaKdom6HofPntPnZLHU79QnTH6LvxNQ=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU3EYx/HjNi9pmKWb95yaXVRWmrWm2X5uOnVe0ihKyRqWEWUlRll2
O5hSiJJNS5Fu+kKpqdEq00wIEV8Ii1hhGWTYLLMCFUxqSjf2/F+4A4fDh+/z
fw4cOMH5x7YVCDiOU/+7/z/ZJdnxuOfB4RDYNKUs0n0fOeLGzEHpFPraqTOY
7IIZ+bzYlMPsgfOuHuYrs1KyFwrrj2pONTD7YGx/iyJUxRyAXIMwrPdpEFmK
4S7HgY9BzCGQJpTv8927nLwC5jrjjfHngeSVCL9bwVXPBZBXY/JFf6c4mzkc
o6LKepPRnxyJyR+ZM7NSZhmcD3QPDp/0I6/DQ2fzgNWFOQrqSe2qsou+5Ggo
SrZbnKw+5PU42OwddknMHIPYbxb+/nVv8ga8vabLbXspIW+ESb3L99NPMVkO
QcPtuRSeeRPiDhU36B55kRUoPR0xPhTGHIs9lzUT8f2e5DjUj1Y5jEwvI2+G
SqarK9axHo8oTWO31sT6FsxWdnjnzSwlK1Fws0Vw5g4z0BKqfRfT52EzD5xY
U1erN5K5BAQa5od2y2meT4CbsL30ay07r0LZWH71WBvrKpiVepH3e9bV8Pex
fLmqZ/vVyGlsbxJHsv2JWOzZV1I0sYR6Ijqnatb6mdypJ6FQVdPr3kTmk+y6
BjXlwq4Pea7UNfgVqT/bWriIejKCUjIUknuO1JNx7tarZ5JRIfUUpMsvPLHI
yHyKXU9FdlVUhKhCRD3VrmvtuhatPW8kgwH0Pi5t4TyfBtv/JqCeDoE03Opm
mFfaejp25kZ3FIf8sZnLWDjPZ9D3d6DzmThuiFMamznqmZhUWH+rZLN0fivN
T9N+O3NZtIcu2JnPon2flX8B9eQHQA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HlQTAEcB/Atf0irA62iQ9ZV0VJkHaVvtRXbWnul0qHQDGIoG8nRiyEM
Q7bRuIYla4hG7iayzLiPxtWEGVeONWOGHM1aTBi/3x/tm3nz5jPf932/dw+c
tUiX7yoSiab/Xf9teembeqaxvkCK//oce3LUiap6T7YIjSPv/7hqHkh2gyLd
0uoWw/ZGs1zmduFtMNkHORmlawdsYfuhurB19YMwdgCMH4pcVlUOIAcjKc/e
pPwURJZiUvWDeZ2Z7MF43kMcGX46kDwUhbridW+6s0PQkn0nJGxhADkMzTcf
Hbpr9SePwDBBOm+6gi2D+dNML1tlf/IoVJa8n2nux47AkXeyVlt6P3IkXjrO
i46X+ZFH415yjvh7AHsMRpsC61fv9CVH4djEmmtKW1/yWET67svLWs+WI2HE
4+Zu6yTkcViVGRt92sAeD++KwjkvDviQJ2DN9bRsh4o9EfGy3Kqi3D7kaNhT
3rqVq3qTY9CUNeRykJg9Cfl7La4r9vcixzrlQG+b9UqtjnIBsAxSPh1zxZvy
OKTNiKwrknpRHofiRk30OLsn5fGYcqTu6JA9nMcjPEZmuPTOg/IELIjfdtHT
TPsLCejwaCj/FdWTcgVaPDbM/aGm/QUFXIPDHOJazhNRcON808MGMeWJqLl5
cKnYyPOT0CnSduYaeX4S/P3abJXb+fyTURxaZdp+kiwkI7xXSPuu+5xPRmDt
r5YsOV//ZLgftOckXeX7NQUKoeR3RAXnThYpnXIlQtWDfBIXcp7S1UKKU1+F
3MLsn7dsnKvQduG3MFzOz2cqPvbJyO/YSBam4vXusVHPTJyrYa65Idnawrka
yyS7RVst/H5MQ0F6d+3sarIwDXuFx6VedZxrcGrxkq8zSsjQoPrVZpfn7Xw8
Tdf3y6rBfKP9rEsaz9eiY1Odb/Y3On9oYcr/bMo6zH0t/v9fuK+FSl52rk3G
83Vd50GHzORL7o4T3NchMebNymYH93U4t9iSIZNwX4+L1yte2Mu4r8f70C/L
IzR8vXoENSw5W3GbbNXjXl56+9cn3Ddgl7rc0eZO3xcM+LCjKO54LPcNXb83
q8Hp/qVCM3K/1OjH/VTo91T5l0ZI8Af8mFl0
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1I02EUx/F/01Raa5vpnDnnXFlhNqbTdC39/6abbtELy8RlXsTECgZW
Jiyi8J9gF5mJBq6L0hZdhNMLg+VLpQUt7CLBhCHrBUoQKaJiZCRLK3aei3rg
cPjwPZdPtuvUoUYRx3GFf+bvZk9RE3g47NYipq98WWffTbuMmUOTr39SGM0m
J6Gy9orU5WKWIUPGe05sYE7Bp+mOZ6HHGrISzT63v7WJWYUbFe+ctWnMGtwf
bXPabmWRtZBygcO+CTV5CxL0S8ELi5nkrUhW79Sb5MzbYTj4IkHvUZFz0dnA
K399yCDnYdvtwbkHZcw6mGYmz1qObyLrsVKjyOyYSyfnI0d18ugdB3MBzgly
r2dGSTZgyBZeaF7DXIjerqbTA+1p5CJElp8H34QV5F34PtI+thROJRfj8ktv
ujOPuQSq107IulPIRlRzJdPDcubdcDsTHQ3ejWQTXFPacYPAvAe+u1OpXaFk
cikm6nOeqsXMZXjF98SnvZWTeWT6o6H6YmYgsjJ+pC1RFrMAZCjnF7t7yJwZ
q5xj9ViLlLoZkuYC02ybhHo5DgxeszYGyEI5liRjl6JF66lXYPPe3lDdvXXU
KxCMSKvrzrBuwVSw1NMynkTdgot9s48U7+OoW+G4mr8jvj2euhVZtv1GxcBa
6pXYV9w6Mq+je+E/c1WI/W8R9SqINLnLYn+Uj3UbDJ2ff5if/IxZsEEcN3T+
4/Vv1O3/WrDji3F5pVy3wP8Gvv7I5g==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2Ecx/GTVlorsjJ1buouJWPZ8FItnbbf5tx07kZahuQLI/GFSpL6
RqUGRSToUoJeyCpSCEyTNvKWBbousnUBg4XvjAqlIErKXCJ2Yf+H2DlwOHz4
nuc8/3M40tNnj9VEcRxn+Hv+u7Ij4fjIpKdOhrC+aVubE1+3i5g51Mpn3q89
kpJj4Te5VjLKmeNQEEifPRWSkOOhkGd2+d3MSQic0XiH8pnFmC47oJF70sgS
vKzo6LkSyyzD/Mpot743lbwXkw0For7ZFHI6Nj38KDRZmBXIv7HcXnZTTFZi
ruKdf2ZRRM7AkvvxlvN2ZhUqFy2mlIvJ5Ey4+5NPBp4LyVnwB40N02rmbMQo
RzsTHiSRcyC3tpxwVjEfxG2ZW9zoTSQfgq/z6s5+GfNhDNxauL+/KoGsRlBR
X31nbA/5CJonfJInZuZc2Jri2q4/iyfnwRNyfUoCswYxqRvLn77ZTc5HlrF3
wvxqF7kAjW+/+6qlzEch1dV2tKzHkbVw1CtfLAuZgZKB4bv73DvCdgK2IVdR
zch26jpESZSrgsFt1HWYHQ/+mAsJqOvRfSl6fL5qK3U9LvfU5bWlxVAvxNfc
1XW9ajP1QljUF8Y+qKKpGxD+/6KoG9A0qNF6+zjqRcjp+rKim/qlDXeeOSME
0fdaP19bom6kdewwRdppiryfK6b3W6P1xbz9S1BRmT18Tvabegmvm3nzmXnP
L6X3/0m9lDe/hbe/JXI/zsrrVt56W+Q8Thvtt0DdzpvPTvNtoPkdkfPCwfte
jsjnTf3vfwBTeA+m
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQNioVt3b8xWcoDwPtivzUv+yigC4zM42LMpX2Hb
pgjlczgsiy5NeuAD4ws4cEoEvv/wSQHKF3F4bH5/AvNsGF/CQfLRtP44Gxhf
xqHrUE7/ruvyUL6Cw61SeZNZcjC+koO8T+b3qRVyUL6KQ3y2oKHQJFkoX82B
4+QetStMML6Gwz2f+Zv6HWSgfC2HX7ssov9XS0P5Og4/X/797fJACsrXc3j1
+MIPeTkY38DB1srTUClBEso3dLATU13z64gElG/k8OCnXGiTAYxv7NCz6/2t
uG5xKN/EQWfr4tA/u8WgfFOHlQVnL2b0iUL5Zg4WWfZGveIwvrmD0NqrmR/q
RKB8C4cnWZpWf9uFoXxLh2j3/Vy/NghB+VYOCYWxv0+9EITyrR2e6SsZ52nC
+DYOJ6+pfPnNA+PbOig6pneW/hOA8u0cImetXSiqA+PbO5TuDrCx+MEH5Ts4
XOPtyPjpxwvhNzg4KHtNuxa1ggsq7+jwU2dSzfIcTqi8I5q8E5q8k0PbxGyr
anl2qLyzQ2CPoTZLKwtU3tnBx7x++2M9Zqi8C5q8i0Pxamv7TYsYoPKuDu8t
f/1z0vtmD5FH4zO4QfnP7AG5K7DO
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0X1IU1EYx/GLvcycM51rvpcbZqE5a6bTdPnTuenUhY5VpiNn4D8VaL4U
aeAyoiTSSIvIhWRJmLQULVNXhpkZZJGSGJSSiqlFWkaIWVZ0nj/qwuHy4ftw
7z3nSvbl6LPtOI5T/l5/7nSJd97paDogxV/NRps4y71HrmQONaLc1IZGCbM9
Go++3CU2kJ0RHNzV6fndl1kEN2OQU/9VsjuMG+TninVkb3QHR1cvdK9j9oW+
tTyixZ8sRUVGdVlF4VpmP7Tz9p68OOzD7I9ii7TWYCJvxDe7UVlUnzdzAMZq
enuXlpM3QaUd9v6k9WKWQXV3+nzoGU/mzWjm9fcs2JO3oH5CNjSZ5sEsx7Ee
67DDF3fmEDRZc6pkGeStEHy1TCVZ3JhD8azV4ODnQQ5D3Zt3A6/mxcwKHJ+S
dI5qyeHIDFOufNu3hjkCdRfyXdpA3garz4A04L2IORKR+/MumVrIUXDPtPWX
a8hKCPlutgmbK/N2qJXjx14sCJmjkawoaR2TUQes8TP6I47MZuD+k1Mj8yU0
H4Mx2w9zoILZHAP+sltF05UurMdCp+l5PK50Zj0WS1zqkqlgNesqqAyLYSs0
TqyrsDtdbs2TUo/71+Y4XH967TC/gM1zagjy5JEDpQLW1bDzDVjgNziyrkFh
R0pU+Dw9X4MgpczQOcHmuXi4fBSJZ8XU46Gtt95cb6H3J2DuZ/ueUh59fwIE
B4UfTh9i5rTo8Ky60jZDXQsjr/ayl5r2nwifhsVBo4LZnAjh5MOuBj31JOQ3
3S5LKaKehNzBua4sCZ1vMiqzZyuNN+h8k//7XzoYT4SkD01S1+Fs86rAByPU
d+B5Vtrnudeu+AVLsfGh
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQNioVt3b8xWcoDwPtjvuFF8YqoojM/gYL7g/IYH
mxShfA6HoKqz65/EwvgCDi8iFwdUsMP4Ig53v0ziXLNcAcqXcNiYZVH53QvG
l3GYftOpov2TPJSv4HAgOa4wogzGV3Locaq6qbhNDspXcdhW+PlSrTiMr+ag
cX3GMuZeWShfw+HP3K0u7w/IQPlaDqtW/V6U9l4aytdx+C/UNEfDB8bXcxBe
fGDmxiNSUL6BA2tuQ96/l5JQvqHD/ifr9z80hfGNHA6eXmST0CYB5Rs7WLpf
cdi0XhzKN3H43OYa4WoE45s6rA9hYfn4TgzKN3P4uD0oWNkOxjd3UGS5++Dz
HxEo38KhheXkKY7pML6lg+5z6QYuFhjfyiGuw+2l7RFhKN/aIfhaZ88lWRjf
xqHg2udDiYpCUL6tg9CLA4dWBwlC+XYOkbPWLhTVEYDy7R0+/9sV2cQO4zs4
8BYZWV9u4oXwGxwcVjgePnpMEspncHTYe9zqncZjHqg8Gp/ByeGs1IdXUwS4
oPJODieO2paX7OKAyjs7GPe+/e54gBMq74wm7+Lw3vLXPyc9Nqi8iwMkPTJB
5V0dmBS0fnGv/mMPkXeFqv8G4TO4ofIbYPxnUHl3qDkMDADMVcLb
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQNioVt3b8xWcoDwPthvMtgwZSMfjM/gcKplWt3n
TYpQPocDz3f9WYdDYXwBh50aKqGSfxWgfBGH3t2+x1lWwfgSDrdD/xn6uML4
Mg49kxd6LXgmD+UrOHQXpgm3G8H4Sg5Mdq/DpJvkoHwVh43z55StYYTx1Ry2
XJ3E4GwtC+VrOCyT/cdfky0D5Ws52N6bcXjVcmkoX8fh/MtH77exwPh6DmHG
mzSrkqWgfAMH5/de6k3NklC+oYPWtbVCHDMkoHwjB+/lXRHcfDC+sUPAly0n
d7iIQ/kmDlnmeXwNoWJQvqnDv6LvqpxHRaF8M4d8xt9tq6xhfHOHCI9+gUf7
RaB8C4dziREfP98UhvItHU5WutikqMH4Vg6utk9qzv8SgvKtHWbuX14eqgPj
2zgI6BhKn/svCOXbOjQ9Sep9sgbGt3OQXf3nWow5jG/v4Lly3SrVOfxQvoOD
rq1eyP5nvBB+g4PD7GvcP5eZckPlHR3aJmZbVcuzQ+UdHarqfx3MXsUGlXdy
MO59+93xACdU3skhSnuix7kKmH5nVH6DM6p5DC4OkPTHBJV3cShebW2/aRED
VN4Vav5Pe4i8q8N7y1//nPS+QfgMbmjyaHwGdwdu5rVVryZ/tAcAO328NQ==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlHtMU2cYh48OKw6QIrdyUbBOg9gULRORi/1RuV97oZTWZQMSNjOcTKki
ovFgiBoJRBjZ5gXF6QIK1DjWKTL1jAZhGkzEeNkysz9wTpdtNN4hCpvx/f44
p8lJ8+Q53/s75zvv+y0sqzSWz+Q47tP/rzf/7BdkdvafrVDiLbm1x11L2qb9
GHO46pyj2HFuIbEn6tTqJ/KPGcvhmxznGHsVSRwAeFRd8TvJWIG5SfU6mY1x
OHpPnYjq92Mcif31H96yb4wgViLP8tXjxO8XEL+Hvfm/T12WMV6CXwZKa9vz
5hNHYWJT1vpUZzhxNLTrPjENucKIVZiv+7pkSxpjNdpaDrfX7wslXo4zyxbE
p7pDiFfAq2FVTc8lBbEG4e2f/Vl4MZg4FqpeD1lcE+P3oQk+VvrBniDilTi6
pfPX5UrGcahsrAnx/yKQeBXi/n5wr3s243goPvpxtCk9gHg1JkqrXtc5/YkT
IDPP6HW75hEnQq5aEXZ92o84CQ9ilLEblzJOhrf/QPXnj3yJ12CaM0yX2Blr
8YP7QEzoyFxioCtJuT7KRZ6H5P4U1CwdmigvkJNPwbyHwkCXkeXpYD3UczxQ
xbwOFpvGsVnJ1q9FZ4pr8EqID/m18NmsSby5m5hLlfhUREyNXIt3v0s+DROq
lh0dG+aQT4O798brnYHEXLrEp2NR9pe3bZ1sfYa4Hp+BkVD3X61y5jNx1lHZ
ql7nST4Te5orEmojZpPPwvBgcrX9AvNZkvxsjK+enNKpZeSz0TxWVat7wdbn
iOvxOejovxN0NXwW+VzqJ+ZzsX3X5E8Vp6kelyfJz5Pk5+PG+VtP7770Ip+P
2MZ/XqQIzBdI8gsk768XM/SSPL14fwW95PsYxPkw4OJQwr9RY9603oCK4fOX
bvaRFwzI725KK3ey72/EyZ9PbPWyUz/CKO4f3ijuD8Eors+ZMDMyetKrixgm
cX/xJgw+8TXZNpEXJJ4rFPc7CnEmrPvcaA7LL0TWKcfpxUeIBYnnzOgPbW3r
G6f+hxlVXYna775h82AW1xfM0G+IvvYshDxXJJ4vFIn3gy/Cc5++ulcr2fMX
ifeTs4j3ExbYljVnXt/G+sEieX+LZL6L0aAp/+1wCcsvxu77ZY33u2m++WLx
vAvFGNW2eATfY/NvxcHLHdVmFZ1PsOJlzh+edbnEvBUNjd8u7nmHzjPBCkfG
uLHam51vNpQNKy/E8sSwQR/TrrQrAvAfnPW0ww==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQNioVt3b8xWcoDwPtj3+J+yiheD8Rkctqg92KJ6
SBHK53CwMfJp50uA8QUcdsVkHNfmgfFFHLqCw6OO7lGA8iUcSpozMypiYXwZ
h1LjpxX7mWB8BYfW/9wXSn3loXwlh/vft01wmiUH5as43PvBWrvqnCyUr+bw
1V5gx05WGF/DQakn/f42dRkoX8thjlre53Pd0lC+jsNqq413Hr+QgvL1HDaz
Xzr2iwPGN3B4/uyowBclSSjf0EHr2lohjhkSUL6RQ4nxMdvSs+JQvrGDWs31
i4fdYXwTh2V/V8irzRGD8k0dTl5paS09KQrlmzm0nZ0uGaED45s7VFVqP7+m
KgLlWzj0bubU3ndfCMq3dFjn/j6onEcYyrdy0JYVk0xPhMlbOzQ9Sep9skYQ
yrdxiGFfNEvaFca3dfB1O3b0ia0AlG/noCuo8XHWRRjf3mG99Jrtl7z5oXwH
B94iI+vLTbwQfoODA5OC1i/u1TxQeUeH2de4fy4z5YbKOzqcOGpbXrKLAyrv
5KDsNe1a1AouqLyTg7yHr6XYKlaovLMDN/PaqleTGaHyzg7Fq63tNy1igMq7
oPIbXBzeW/7656T3zB4i7wrlf4PwG1yh5n2EyrtB3fsHKu/mEB5ltK5I6T9U
3h1Nvzuafg+4fQBUoMNC
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtI01EYx/F/OWw6Y063NXV5T9SW6cp5a+3n1q6ui4qMjZQIhJiKFuFA
jPYm37iMNKILRhJkKBnSDbsYDmeXYUHhgjQiisiFZIShBnZhz3mxHTgcPnw5
zzkZh1trGtdzHFf+b/8/2ZLW3X042pSJkBY1sb9KDF0SZg4DTmmuaDyDzIdR
M/6uu545Hk7dYFDCZxbjqrZx9se1dLIMM7Z6p9LALEf18OSCaCqNnI7ugbrX
eduZM2F6YZ6TdqWSszG88dalvc83k3OABq9uwcKci1YJTxZ4LCfno3nYdD8n
mVmB2cnfvhZ7CrkAwTNjhoqnyeRCeCSF2W0FzEWYq22Xvr+YRFZi/9tth2KW
ZeQduGDNruGfZt6Jl8YGwZKcuRjf7vR/KBzaRFZhyuN1tT+Rkksw5rffs9mZ
S6HqmzxiTpCQyzC63DMvg5hcHuEK9LtnOoQjieRd0Ks/d75aTSCrMX5wy0Sq
gHk38vZlifUtIrIGKbJPX8/2xpOBA835/qUkshuIS/S62uaF1CtxOSBYuV4s
oF6JFUVv52BzDHUtsiznA44bsdS1SFub9pcukjlduN06+H4Kax1H46jvCZ/n
jjCnxzOf2nX8AZ+6Ht/LVte0BdHUDeg4uTrRNER2GyK6EYrbvGhVzwbqRkwn
LwbPxbP/mSK6Kfw9zhzxvjlivgUnrrx5JP0YRd2Cak/RVt4pHvUqCKJudgT7
1lGvgs2hHDmW+UcT6laa9yVkt5XucdxfMHzgrQ==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzV1I02EUx/G/L03FVtPWf3NOnW8Rc4x0NVta+21u6iyMAlFEgoJJa4Wk
USSUuyki2gorQrAob7SpA5O1lbE0ukihogwLIUujm5w010icIRU7T5AHDg8f
vgee3CMtB63xHMdp/+zflw1f5x0ZsuchppBeW952d4Bn5mB73OnL9+eSkzF1
omnCaWUW4YpCN3NLyCzGXPHgoaUhBVmKVm9zqLCBWY7T1/q5nOUcsgIaoym6
aGDOQ7JAJnNeziYXwP7wwszNSBZ5C1wHPgd7lcxbEXfjRyDrqJysRIt0/HxP
CrMKrmMZ+yWHM8lqTDdkN3c9lZG3YXr15fzXVxnkYoRvqyv9QuYSfEgLZ9hO
SckaPBefOasIS8jb8Wxvn/JNE/MONL4W2rpmebIWc/fe1YlkzKVIGsvvVgU3
k3eiJW7loruMWYfRIuPCQKuYvAvn7kw+4Wc3kcugCrk8vqvM5XAOpxQFPqWT
d+OtvjNR8jGNvAfjUwWRlfXMeujrI021mcyA8Hj6/KWTopgdgOW+x13YvZG6
AfWNJZ7WPLLDgLSgmA/xG6gbUTvgMlu9QupG2F/4A5OPUqlXQONcWDKMplCv
gGo4UaB1JVE3oXfkPT8hX0fdhPaO6JjdLaBuXtPN2Ffa4fuiTqBeidSEwfZv
1+OoV6Ktv0z/oIejXkX/L+tjvYruF2PmqumOxlG9plv+t8OC77roqlH9k3oN
4hXKaGr/L+o1//pvovXV8A==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/Gjls3mvMw1L1m51WLTCk0zL7P9vOzodLNpSShJXsgEDVlq
F+nF0Rc5ol6USUEjQSvUlZEV2CJRvGG+6AKFlCRlkt1NDUwrK/w/L/SBw8OH
L4fzPH84ioKyzIPOHMdp/z3/d7bkWfce3C5RYlGTut7d9wt83Jg53BpXnOls
UpBF0BYqSvN5Zi+87Wx0L/8QRJZBFS6pf1PL7IdwT61LkYY5ENcVwxmRFzeQ
gxConh33nVhPVuLVfNkBTT7zJhTyJd+7R9eRN0NdNNIQFcqsxjmrW+u36kBy
MJ5EpFh5J+YtWJDW2NTGteRtWBHSHCYaDSCHYqbssSnHwhyGrbWmlpYhf/J2
nOxve716yo8cjrGRTEu1K3MEzDN3BzuSfMk7cKWy+WWoUk6OxNDcxOlT19aQ
d2Le45CuW88chYhnZ4+pHDJyNGqreo/P2phj0BWS8OXGEeZY1Azsy50zMmux
XxQgXIpmjkO96nc21+BD3oX3mqkTYWZmHVyznO5M9kjJQK+567LgIAuA2OVm
1cc6b+rxmP7jyK5Z5UU9HpWaC3Xn28lcAhL3/opcyXtQT8DVwaaj4goyl4gF
LmMhr8KTeiIMLW2tKhuZS4L3Z5l8Us7eX2ZOj6cdz2eGZ8XU9eib9tyTY3Gn
zuPhQMxX9RhZ4OEcFDwntrOevNRCMl5IrMU/0yXUU5ZaSFn2fQPsWmWxuoed
37D0PlwqJKXST1YLm08qzKXBQz/82XzSYOL7+97FsZ62rBtRbo/VtTeyboQm
faNMf5jN34Q8S+78owmyYMLi/yrFX+p55vA=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mlIVFEYBuBLmVppM41L1pjpYKJSWpqa67xuM+qMOptki5WG0SLlUkQZ
eq0fKWQ4RUIuVGaGZZlBiak1aaVRBglZKEE44zIIURilpZXh+X44Fw6Xh/d8
Z7n388g6qslexHGcem78f9PjnPawveWwBPP6Ki23PSc4IiBz6K58wnU3ejDb
wu1RdWFlGlmI8aaMgKBpd2ZHfBrv2a2vJ7tg8mPb64lQsiuar+hGmvrWMbvj
VyG318uKLEFCX521Md2N2RN2O4tznzWuZfaCv7iqN9+a7I1hgcB8/5grsy/8
ft/PkA2JmTfgW03n0qJUsh/yBmeE8j1rmDdh8E/fxMjb1cyb0ZBuPhAiJQfg
rJN78ZVSF+ZA6OsWV3yJIm/B30P7SnvHVjEHwSllf8hoKzkYQ3/F7TuPkUPg
dfrDu245eSt2cVpnld6ZORRvjDdm4UsOw3vvnMyGVifmcNy8XLCyDeQIiO6+
P/i1yJE5Eq5D6RDqyVFombpgdgFZio1jYn6ZFRmwcbPSPe93mDcPZPVKHgfy
zFw0fDxtTD/llEdDO1B2vn8t5TEwV+ZH35VSHgNlSHGr0Y/yWIv1YyFavqpj
tIPyOJgO+YTNnqM8DsPVwUFDl0Qsj8d8fzLz8dhlU1cljl/JchlG/SWBR3yY
eRnELsZx/UUhy+UouBMufVDHzMvxasDz+287qk+wqE+wWD8R9jmiidI8qk9E
s7iptV8hYHkSjrerIrZOrWB5EhIb791eX0O5Att2BNzLlzDzCmyM9NM9HbVn
udKiXmmxfvLC+XwykmUvX5gi6X4pC82n4KRPz3R2KuWpsHPoOpFrpv1TkRNT
0bniOtuPU+GHfVvJTJDdvKHCi0mBdkceM69CZ0/YF28js0GFAfvSA9MpdH71
wvNBjVjdTPASGd1HjdC37ddefmbnMahR0NJcpjpF31eD7NqGRYXXmKGBaNzQ
dUdD/0OzcL5BgzOmrHJTE9VrMaUYsS1Rsv6AFrkDk12ZHtQvc3m9TZEpmtmg
xc2wwN5btdRfOlxeP7udu+qAfwxDQ0g=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XlIk3Ecx/HHWWrNYx5Nq9l0ZojYqHnNcx+nM51uiWUnggoLUUlESfDA
R5KgSHEWCRp2DQuXxgrNTs0ISiLLwKD+iJJiRJZJeNPFvr9gzw8eHl68fxfP
E1pSmW8ScRyn/fv8e7MhLRi8ZytXwKFZTYO6wPOGjJnDN1uyymUslOyB1s7G
aVsxswTPJ9znOhZDyAEIV//2n+5iDoKxKPT8wVRmGV76PDSbXsjJIWgqKeqc
kDArMG76Ku86voW8Fb7hF/a9mgwmb4Pq9kC/Ip45Ah8nnoxYymTkSCTWRvRM
Dm0mRyEwadjydGYTWQlFrd3yRsW8A/pZqa3FtJG8EzXFdtHdI0FkFczT1fXa
hUByNNQIE2FOSo5BWfxRb76AORYrVRebDKUbyHGQvTsAiTmAHI/Gntf3pR/8
yWrsmTp5ejKYOQFlNYtDLvv9yImYPzUQWPjTl5wEx/9iPRmLOZ88mnOZU1BU
VbgybmfzU+FnHx2z5jNr0BumfxszJiED1mRFacRjH4d5oELb/sD7kjf1NFie
XTkmriHzaTBeb9OZBr2oa7E9Rbl35DOZ12Le607zaqwn9XR0T4mXemPF1NMR
3TqzkDa6jnoGom6tcYtrc6eegRPm8sR6OZnT4XvC8i+t0o26TtAzYRuoPKs8
7EE9E2H6c1OHrq2nvgvtLa7D7wvJvMBclqBnoa5p+VF5H53HZWMpqqPhagXd
l892Po/TC+6vhzzLkCDtW0s9B9XWJM3Nyxz1HIhd++u+nPmhcfRc+h5LDvO5
gm5wNm+gfdkwOps3CtbvhigkcllsXaX1AnN5zvOR93+/P/y//F4=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtI01EYx/G/uXS2bGY6Z+rmlkWmmDrzbvvN26bOF2ZiqLSIehFFY7Ws
hOEgukiapMMwQiwrQm06RxRmaopQ0F0YJIkN08IIFS1LLSt8TpAHDocP38PD
gSPbr991cBXHcYl/9t+TLVHBvYe2w3Isa0oZm3y8sVXEzKEv+8We2gcyMh+S
XpX4Wx6zF/zq+KPlX4PJPtDp26dna5jF6DBNLCzFMweirX73WOtzKTkYb2d1
qisCZjmspd9P39onIYdA2NZ0x/ksiLwF1eXVY9po5q0YmBHmFxkCydvwxtpY
eL85gByOlkTbu9FPG8kRuHzqo+66P3MkRMPKTmOdPzkKPZEu0hYhczQqFgcd
tjQxWYHKzsmhvRf9yDEoeul5qN4pIu+AvIN/dSCXORb9mpkGWZcvOQ751ywB
ZVHM8dC7LJxrTmJOgIw3/H5m0YeciFetjyrOOJiT4HXecGDkBnMy3Apc7FP9
3uQUVNk9wrpHmHciNMT9w5x6A1mJYnXPmvl21oHuks2PJQKyGQhqWXSUxK2n
rsL4drniaCjZrMLtTdlDMX1e1FNxItRSW9NBNqfC84j35wsG1tNw82lTqcC4
jnoa/dda6ulQVH2ZU/V6UE9HuJ3nFnvJnXoGpuyvf5p8Wc/Ak4GUk8ZOPvVM
2Kx6S0Qx2ZwJqSY3QdS8mroaeZVRYbyzPOpqmBoGu0ROV+oaFBZFW4/Jl5TL
XUPv+bFsLgsC17tlE7XT1LMwmTD/KzVinHo2zaFlXmEuZ0XP+X8ep10xX/vv
/m/ha9/O
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQNioVt3b8xWcoDwPtjvi1E9KMcN4zM4/GNnfb99
viKUz+Hwe7lWjbohjC/gsPGZ5e0flxSgfBGHzXutTlrXwvgSDkLLrG4FysP4
Mg6fg4z6l/fKQ/kKDjqZ4V9PHpaD8pUc9CVXVRV8loXyVRwa/5789DcAxldz
eBnJN8XhsAyUr+Hw/vP6JQafpaF8LQf1BqXMMBcYX8eBK/9pU/0JKShfz+HJ
1CPNL/RhfAOH833fep3mSkL5hg6MIh2f//2VgPKNHGSN26/KJ8H4xg7ChxV1
xeeLQ/kmDq6pjzf3zBCD8k0dtp8WZ/2TAOObOawsOHsxo08Uyjd32FWg8z2Y
Cca3cHiXe+Sr8TdhKN/SITL+kEdUBIxv5RB8rbPnkiyMb+0Q7b6f69cGISjf
xuHxnr8N2uYwvq3DzP3Ly0N1YHw7NL69wyX7SSzidwWhfAeHH0vY6544QuUb
0PgMjg7P9JWM8zSh6hvQ+AxODq/vqLfoNwlA5Z0c1kuv2X7Jmx8q7+ygK6jx
cdZFmLyzg+AbEbEPYnxQeRcHJgWtX9yreaDyaHwGV4co7Yke5yq4ofKuDhNa
mHfcj+WCyrs5BPYYarO0skDl3RyKV1vbb1rEAJV3dwiPMlpXpPTfHiLv7mDc
+/a744GfED6DhwM389qqV5M/QuU9oPpgwNPhveWvf056z+wBsqTGTg==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0llIVFEcx/FBJ7fR1BzHJZdxXMpRNNc0l/m5jeM2TjtKlkRCWZq49mJc
xRDConLywcREw0prQkU0pZJISMRKJZfKfKg0UWEql8nKFvyfB7twuXz4wrn3
nPt3OX52X5Yej8eL/nv/e7JLdLCzt+20BBvSyk5k2d//YszMQ1HViuBkmwvZ
CA05Hu76CmYLdKkv6vfOi8lCnPqcnXtMzWyL4MmaRmUoswPO36yvN3nsTBaj
sqk6UCVmlmD9g3Jh/2Enshvepsoma+sdyR6QHxp0VC86kHdiOfKJlUbOLIX1
g4KXxQXbyd6IkQ5lTGnsyT4w+R2QvfDejrwL1xqm16azmf0wI2lazqqzJfuj
QK0pNe6zIQdg4npm+r1XInIgasWd5jOz1uQgaBxHJdJZITkYa7qYxhJv5t3w
dDP8uBpvRQ6BLumTUVnyNnIoTJp0R+X9luQ9kD+ay8YwcxhmfCUBuZ7M4Sho
DZO1N1qQI2C5IBRpRVvJkSjqVYWH6JhlWDF7WPYzyJQMmOX7h42Wm22YA9K9
ripenBNQj4Lz+tBgiNaEehS0HcO/Sq2NqUfjeX9ESWGPEfVoBFxaXI3qYz1m
s7kYOCtSQkUtW6jHYm+Vnxf/Ap96LLw7+AbBlw2px21+HxeHKxX63dMZ9D08
+WZzcuiJpWuCVra/+M3m4jHc/XppQsf2p/hvfQVujAm+NwexngDXxJqx9Dts
/QTcGmgqFhSy80zEt/WetHJDOn8uEaZWT0vy5sypJ0F1Rjq4bMd6EhLualrc
61hPxvy7HRW+5awnY2DMbemHKfu/KfBUugrjcshcCkZk1/g2U6wrUZ2lrT5y
m+aHU6IrrznNx5rNVyqifTLV+ZlkLhWGTvwDz0ZYV0GRWPWmPY3mEyqMG1SO
O34V4g9Y7gUg
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzF1I02EUx/GnrXI5wyzbdFl7KYeTWLWpc7aX339quthAhDASYwUDmxdr
uAi8qAllFJgrVxd2UUJKtkpnaOW6GDghAoNIiyLqwhERhUoXyaKo2HkId+Dw
8OF7eNTH/c1eEWOs4u/+e/nIDk3EYx0aZLRkD8cjr0xybobU/BX3iadqsgTv
knkt8x7uTXBWxfcIUu5ClHqj6daYilyEyoH4nN/KXYKNOcNKw5CSrIIuslY7
yLg1CBwVeoKWHeRdyF+61Pfw6nayFsFFhVGXKCGX4YPr5ngfuMuR2zM9rOjf
Rt6N4g6nKPxVQdZjzOMyTdZz74V4bvCN7XwxeR9sstJ76WQR2YCF982B7vXc
Rpwyab0TXjm5Aupb3YXCrIxcCc24ZGDGzV2FkZOzL9svbyWbMHSts+AJuKtR
7bMbeuXcZrw4dnj5+9st5BqkfLqaXxe49yPZlLgRmtpMtmDlds6ZlMBthS+4
MrmmhdsGT6Dt5/PPBWQ7OmOjF5u6uIGoRdNeNp2fcQgQqcrT0mgedQHhc+LH
H9tyqQvYefD66yN3yMwBY++3H0JiA3XH6ntWi9gDf0TfKqFeC2Wj2yy7u456
HZ7NWE8Hp3ivW33P6uEynX20oBdTzzI7AKn4fteX/mV7pmeZNWT1Biya078d
+k/UG+kfmlCWmTOr//cfMGW7Ig==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtMU3cUB/Ab52MqQqvQoVVmi2BRhPEQYeL65VEKBWpb+sLBQgzNzCaZ
ysOpS7yTLYSouLk5FMcmOFHDK2KUOSJcAWcwcT6y1WUx0bhlQjQO1BHDVLbF
c/64t0nTfPK95/7O+aW/n279Bw7fFEEQfP99///lj8Z1pufU+3q81KixaSCy
cVLNFuBNOnjf3akjvwpdcdipi/lsFZISA49XjC8mB6Nrb0nPyAF2KHrnFVv+
SGcvxGCs8fDE4Ovkxdi5vqT+qoqtR8yj8KB3vGHkJTjYbS7OlxaRI3Ez5cHl
OzcXkg1Qb5x+7msDexlCOsuvVpVrydH4KGCay9G7gBwDq3dH3Jh/PvkNPGqM
yfp+DjsOGQ9PHigrDSXHo3JiaefQ5dfICRgLdA1ExbIT0S3NMn97X0NeifqW
phP6MHYSTm66cn1DXQh5FbzZ+1R3+4LJybDviVs+9VN2CnZd8hRP5LHfRKP4
y/agjnnk1cg9PWaxr2KnKrwG5y/V3H66cy75LRTNaG7QmtRkI1rCLb8l9qvI
QKe2rftGbtBLi8CkYJ8sqSALaShsaG8KiabnxTRU9thSk58GUp6ODOezpGlZ
ZDEd3w0drZpdwXmG3GIGrG11Jt+ZOZRnKvJMrFgT4+z7k3MTPOviO7bouT+T
Yv0snB39LHbBFa5XWDBD/SBYM6rh3CzvV8hWzJ+N1lT9BsMAz5+Dxy9+KNw1
g+fPQcpPPUd+vMP7Z4Eu7d3ayhecWxT7nYsVasNYw3XOc6EN/X348/1cnyef
R8yTzyvky/sR8+X9CFZURn35xf4ufr9Vvp6wFkP+JU/+CaB+RIUFm3we2LA7
3nfrcAm/zwaj50mRVUvPSzZEWcODTWVcb5fPD7ui3o5M8cPncTVcr7DgkPcD
h2I/HShvXW3saiZLilwokM+LAvn/W1TkkiIXnPA1tkzZcYTXd+Jn3/hMwzne
LyfmDkv9rQ7u34neoogLYbP5fLlwqO/4Vlc0GS50mP9ybA2g8yi6sHvvsYj2
V8iSC0PbMlNLI/m8ulFUnbDu12Gud6PAX7vnxiKud2Pkqy1p7UaudyvuAw8e
lg3+nTBOhgfbty2/54+g+0P04NnRqbp718iSB6qazaW3m/l+8eJa2/naaj8Z
Xix7O/li71q6r0QvDtV9815/FVnyovqTgVv1Et9nhfh4RNd3N0eDfwExA5cQ

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtIU1EcwPHrIx/zgY911XzNR2YqlrO0+dpv87E55+Y2l69IE8TIIshg
IJRXK6woggTDopSKrJk9RqKp4c0YRWlBhRHVH2lIhKZi+RhmD/Y7wb0Xxvjw
Peeend8fi6g+qK9xpCiq7O/n3zd5aGPv4P26SLBrTnqh3VMONDEFI6qXpa39
EWg30JSsLisriH3gtGjj+eO/RGghVA6ZFvpvEwfC5ehbXX4a4hA46t5Z4+5A
LIIA8fuACn04OhI+ttx4GNYRho6G3JkDFu2TUHQMaNt6p0aFxLEw8co6fH1f
CDoOLpmUHa+HgtEJYKmlY8wC4kSw9rpO91RtQG+F7FnVpuZjQegkqO6/Jxn5
EIgWQ1P9gy2jKuJkkCjeguVuAHobRHQ2CWVjNHo7zPfpDVFZxClQmZLp8mls
PToVSpXnfCaGhegdcFHTZJsUEEtgc7TrlyWFPzoNpv3LahZP+aHTIT6UDqrd
Q5wB7cNdJmMCcSYIri3vzrP6orMgQ6xu8a4iloLfV3akW08MIC35sUsTjGYA
ivbHvfgZ5INdBgtrA2XNrmhGBo+epn2PnfTELgffaSE9R3tjl4OjKM7m0U16
Nox7ndy7ovHCns3bnwNRqrbx8psC7DmQfHZmSca6Y8/lmsmFZ9ZM0+EBN+x5
0NBoe1xndsGeB+HKQgltXoddAbozSfHOJ5yxK3hdCV2D7+jnIWhGyX0flQ8l
5eI7hyJ/S+09H2YltjV54qLdlIprRgUeTj0N31rnsRfg71/BXsB9H6XGea1i
V+N+Bzy/kGumENSpjX2TiU7YNXg+ub+GNx8tbz5a7nqqiDsP4JkpgiNX3gzR
n/E8ltcpHdj/Pxxxvw7qu9OllqsU7tdx78vyTOm560HPmyfPrJ47L8rA7WDg
zp8xcOfP8tZTxXgPfKAY+xTu55nlraeM3A5Gbmd4Znmmdv7f/webH2Gs
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQNioVt3b8xWcoDwPti77jYXvCUE4zM4TFHtmD1n
syKUz+Fgm/c/6mYUjC/gUJZa/M3vrwKUL+KwwSQ5VHsajC/hsKjN6+8xBxhf
xuH75laDyXvkoXwFh/21nM+F+GF8JYdSj9rUr7lyUL6Kg/3E3XLxq2ShfDWH
x9sEmt/xwPgaDnPWNjw85yoD5Ws5vP+8fonBZ2koX8fh1P5/E8/Kw/h6Do65
qlaZoVJQvoEDZ6GvwNODklC+ocMsd6MyiXAY38jhuOMGrkeHJKB8Y4ciydzr
b+vFoXwTh76y+iabe2JQvqlDV12c+JovolC+mUNttL3NlhAY39xhnexlJa3n
IlC+hcNU1b+RDPOFoXxLh8j4Qx5RETC+lcPCJSdE+68JQfnWDgmFsb9PvRCE
8m0cijeu7wyogvFtHQJytE5/lRSA8u0cwqOM1hUp8UP59g6luwNsLH7wQfkO
Dspe065FreCC8BscHN5b/vrnpMcGlXd0WL77utgpGVaovKND7bzLe8QeMkPl
nRx8zOu3P9aD8hucHIx73353PPDTHiLvDDXvG4Tf4OzAzby26tXkj1B5Fzgf
AINGo7U=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtI01EYx/G/c4Va2DSd5mU5sxIVyS6u1NxP55ybo0IYZq1wk3rRgkQF
xS78E8IgJPASRK0QFY2pKOZKXV6alSCFZa3LsCiFTIYXFBJxdKHzvGgHDocP
3zcPz5EaL+SdEXAcl/Ln/n3piHW9A92maPzTovy6RGqq8idz8MayIb1fyuwD
kyjAtVtPFmGHJW5wXkAOwkTto5dDD6OYQ6HsSNYm6skRkCVvGKgTkKNgED1u
r5FtZ46GUD12UdMmYY5B0aeZ0asjkcy7UDv2OcnsQ47Fa+6Xwn0pgjkO80bh
VNePcOYELN194nvlKDkRzsni2PP2MOY9EE/J+8tubWNOgtLHe32lO5R5LyrT
GtN1MeR9aLW8/fDTFcK8HyP2FoGjgHwA7anNzzWzYuZktDntDWZHMLMMRU6b
rdUVxHwQTTPXjIqz5EN4ZTi+tPxxK3MKxq29D0qKyakYPTZ8h+8PZE5DY/NY
8E0H+TA26rx6Fu3kdNweai3XJZDl2OTdUTlXF8AMvJHXCkOmmHkgi69wJ1VT
z/DoGYi0rDv0MuqZCJwdfmrJo+5hTgG/ptXT2c+oKzAQVm/uWxCxngV5/or+
SDj1LEzb3Hy8jOZV4lzZqtUrn5lX4qRqyG+ti3r2/+azUdPjGz/4hbrKo6vQ
qVrIK99M+8xBZmJhfUkhM5+Dhp3uAu4+dTUu35u0ib9SV0PSV2qtHqeuQU9x
6fKJCuoamPl3lVs6qedCb/w2nTBLPRdVL/JPrWnpv7XImXs/6H+DmddivUko
/T4RhN/7Xu1Z
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtI01EYBvCllJcodHNrOldOS9NUmtq85zMvU6fbB22VKIGVmZlNpUEh
1L/Ict0gNYtgoIkKiWZlF1uhLGdmZGE6sQ+VWmgUqUgRrexC5/1gBw6HHw/v
OZz3HNlOfVaBA4/Hi/8z/640RLrb5hvFvvin2QTdluFhZwGZh7DRkNOVHTJm
Z2TbZyyP8shuaKzYXxboRPbA2FyfIqTFh1kM0YD1xIM0sjcklVHd26xrmH0Q
obs83mtfzeyLxBcHBsq15LWIayx6PGeQMvtDcbWmofOpN/N6mL/d+SIKIQfB
aTjAsLtcwhwMV/3740f7vZhDcX6irFMqJG/Ejj0Nx5ZxnsxyvN46frh3OTkM
npLivZdKxMzh+LVvV1X/1CrmCMR8nOSu15E3oWdl5EMLn6xAcaj9zdATEXMk
XBZqXWIV5CgkBY88d6wUMkdDv8R+8losOQbt0pe+QVMezLEYzN8+Nz8mYI7D
mXNN69ocyfHIthnPDknJm/FJkFPw1chnTkBTTHh/i4kMlNrmLfkyZg4oMDU7
VNS7s1wJQ2BtTfVNN5Yr0eynfhVhYeYlQiKenL5QTXkizF61pq4ZypOgUfVZ
38VTngSZstBoWKA8ebG5ZEhbf9jyIun8FCRzh37KTzFzKYgeNNf3vaV61eLz
ONV/eSr40z2W1iyqT0Wg1s8jpYT2T4P8viRgwkD3T8MGqcizMJ/6k467pc05
oULWTy4duandrt87KFdDrrrSpX5G9Wp8qCtXtiVQ/zMWvxeXgcKLDgdXhNN7
ZoLfNlI0e4SZy4TpXlxuTTvlGrSYR0UD3uw/cBroxpYaqyrof2jR6v5Z7H9L
iN+P+fQD
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tMU1ccB/CrA8FWNhxQqLjxUPeQjgjIUxnf8rLysi0tfcHcZtymLMEh
DOIjO3MvZ9SsiEuIf7ogQYJjDQ/RydXNxQUwU+IrJi6ZSDLjYhUDSLBuC7/z
xzlNmuaT7z33nt/p9ya8X2fdulBRlMb/vv//8o/O3numpzYR8/LnHY3Z//z1
CG4FIz2+84GfE8ihqDOE7hnfxh2O4bP2ugMa7kgY9QMhJ8/Fk2Pw+Nqqth8b
uJdjvDdly/1Y7nhYu/54fMcbR07ERyuSjgSPv0peib5PJq/ujeZ+Dbdv7VLK
K14hv4GWHO/IF23Lyaux5l5YOxuLJRvw16h2C5teRk5G2dDivnYX9xponqdt
f3BHT05BR+fgfk0CdyrOZj9EvTeGnIaoig8yJ/qjyWsx0m/TrNRzp6N/ODp4
7l0dOQOjBU79vZkocibi70YdPe7izsLmG73vjDVHkrNx+T3no8lbEeQcuDZf
MLmd3Ovg27Fz0t3MvR6lvkcllkzuXPxqVo+xwZfJb6Nt6EST3cCdJxnY3jDT
t8BBZsB8H3huxNSB7uiaJ0spN6KQNT9L+Yas5Itm+UgwfvhtYyCc8gI0vtl6
pOUnMivAqdiu/qulL1FeCIc7tbs+kcwK0XjGvD5r5kXKi7Ak4kLTjr95XoQO
4y8Xf9OHUV6MKwPXntyc0VJejNpLA+fGTpOVDXAneU2Xm3m+AStKvr/u7tBQ
boLfd+XZ3qjFlJtg8AUtyjgcQvlG9HTXtSZ7QinfiNFl/vut4Xx9iXT/EoTV
p64b28f3V4qpsNOfz6UvobxUen4Znhpa9pz4mD+/TLxeKZfmK8d3X74w8GcN
X1+BOFN5tq4zmHLJyiZ87a3N2R1H87BNsBxMSQr6KohyM3Z9Nnu+tnPRvCGZ
mcX5VbM0v0XcDyyIC4wOZ/nJzCLOo1rEeRUr0g79M21UyZDMrOL5qlYcu659
2p7O/99K8bxRiaUPInV+HfWHVYp9Uivxw+/HP9U28H7ZRMMm9pPZpPWSFbvY
T9gxGRh07QvhfbeL/VbtKLDNZQQX8/VV4n5RJe6HSVarpH45UNF1uGhrL5/f
gbdyk21DE2TmEPujOrAwfvWs9iTvl1M8XzjF82VOeO/u3J0/Tf1RnWKfFJfU
H5fUNylXXbh0MbepYZD6pLjF9w9u6X2TrLql/njEfsEjvU8e8f6qR9p/tXh/
VONh9mwgP5n3v1q8XuX5VN78+hryRN6/RjjohA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU2EYx/HTxJxOSU2Xl+XmipqmIzU1L3M/593USaSjTChLRA2EVKKs
tu4YUxISRCK7UaSmaOXMlSGRRYRRQ7pIaK5WhKEFWYm5Cp+X2HnhcPjwfZ/3
vH+c4JKqzaUCjuM0f59/b7bEBbfNPZVyLGpG3VioQ5kvM4eL0i/+Qd3BZCGO
CRtu9W1l9sR30fBgvzOzD2Qfyj4PtcvIfpg/fbTYnsoswZXCify2CSlZhgfy
ZfWrEpnlODHS2xxwMIi8GlFtITukPSvJa5AQxt0rcGVWoOWc8ZV1l4QcigGP
xiSLKZAcBn24fSpLyKyEpfPjU/fyAPJ6uLx+tntMwByBN2Ln6yNaf3IkjAVu
mS+6/chR+NYiWjBOryBvwJg90FxUwxyNk02V8XVS5hg0G1SXvTRicixGFXt2
XjX5kjciZsr2ttOFOQ7eN0bLZw77kOOxvWTSGvZpOTkB7ytC4n+fYk5Ew03X
dYPj3mQVKmp+9i3RMSchYiBw7WQtsxrByWX1tQueZCDcS/G19TnZAMSNmC8M
T7CejP0hj36VallPRrhKueW+zYO6BrMed47MR7tT1+DMcaf+8WI36ino6ao6
qywSUk/BAf3cUGX7UuqpePxQta9mgPVUNFmr6zQ/XKin8XoacmL1JqvSiXo6
Fv9fAfV06LZFdu2V29WLPQPVHQnq3ksc9QzH/Vwmr2dCIAudE3XM03wWDp23
3BW/o+8ZsnDN/FL8ROJM89mONmTz7reJdz7PXA5vPoc3n8ubz8V03NyCRjlL
98tztCGP5tjSOtqgpf02ms937PjvP0dn/tc=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQNioVt3b8xWcoDwPti/tlz/p0gQxmdweDJbIWPq
KkUon8Nh6d3DDh9iYHwBh3MJZfxp/xWgfBEHnubm9YZLYHwJh9qoPtut3jC+
jIPCspAmy6vyUL6CwyvzBe+0FGF8JYdUM4HiX/1yUL6KwyeXxW3hD2ShfDWH
wxdq5z55JgPlazjM0XO4cjECxtdymOdwPDLspjSUr+Pw6Cx3csN3KShfz+Fw
xbS6+WIwvoHDAstWrse9klC+oUOdrPjST08loHwjh/C0FT9+McP4xg6HvFdo
XYwRh/JNHN7b53k+ZIXxTR0EJ/gxOBqJQflmDjZfD97riROF8s0dWlhOnuKY
LgLlWzic3rZ1ZVGBMJRv6XCy0sUmRQ3Gt3KAxI8QlG/t4NJQ8dewXRDKt3HQ
FdT4OOuiAJRv6/D5367IJnYY387hP0Pg/4QSfijf3sFz5bpVqnNgfAeHHKcJ
e/kW8kH4DQ4O4VFG64qUYPKODktOLi7jLoHJOzpc3HH1y40f3FB5J4ezUh9e
TRHggso7OWxclz9FL5oDKu/soLOZhc2sjx0q7+wg7+FrKbaKFSrv4hDYY6jN
0soClXdxKF5tbb9pEQNU3hWV3+DqwKSg9Yt79R97iLybw3vLX/+c9L5B+A1u
UH0w4I4m7+5g3Pv2u+OBn1D9HlD5Z/YAG8TBeQ==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ltI02EYx/F/WuyPM3Om87ClO1RMyWXr4Dys/TZ16laRlmUzMjpdtAsj
sYuKGB1UsKLSEr2rqKw5zUlZDWt4pshIKYkkIU0soZxIxhCt2PNe1AsvLx++
PO/VIz9Qkn84gOM47Z/792VHXPDI3WJTwK8pfdF8r1EexMyhq9gj4B1yMo+w
CU+HI585FEK+XTTilZHDUX8m/NhCHXMUCtr2Tr4zMEsx/iBxRtUbR5ahz7Sw
+JmSWYHOQU18TUUseSVuSipHtn1YQV6N/lefIxuUzCpc4Pk5Z4mUnICkSa1s
YlZCXoOOcol1ZyGzGieCiz8esceQk9AqGOjx8czrMH17jydOE03WQFGFXUPX
o8jrMXnIdXa6MZK8AbGVR+/PRDBvhPuLSzpyV0zehHPnO4drPRHkZHwqvFxx
cTacrIWruTw2apg5BTs4bX+LiDkV+ypNX3Vdy8lpsBUK8g7WMqfD0uo15yUz
61B16c4qZyDzZhRlvwjyPQwj65GlGzv9xscMpGu2VITsF/ltBxJFKm/921Dq
BpTF11Rfc5HtBjRLGtsGLMuoG7HV1NM9pmPdiDL39nTtrxDqGXg8dWVtzGuy
PQMNhs7unuil1DPR3pv6XTUaTD0Ttr4nzwefCqln4epo6SnjrIB6FpTmG++t
DUHUTWhpKqlRF/HUTbjnHhK/lC6hno1SR5redYujng3/vgdQz4Ew0HnyW/Ui
6jkIkCX4hI45vb/nYrdV03RcseC3Pfff/zgzzXupm/EjxTdvVP+kect/3UJ9
XP8bhhTkIA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBwBGIQDQNioVt3b8xWcoDwPti3rFg86bQYjM/gUHZAKcRs
hyKUz+Ggq3/y/AtPGF/AYdvJq/wHXylA+SIO/bXpE7z7YHwJh8hZaxeK6sD4
Mg5/AoXf52yXh/IVHHw/n6359VEOyldyePai6bi3N4yv4qBxfcYy5l5ZKF/N
QWtlK0PvbxkoX8PhX3nGMYsAGF/Lofnb/meRTdJQvo5Dve7/N54cML6eg/a5
F5x+flJQvoHD71WvLrTXSEL5hg779siFML+RgPKNHGSN26/KJ8H4xg7ChxV1
xeeLQ/kmDrt7Jiyv3igG5Zs6dNXFia/5Igrlmzn85ku3P+gK45s7tFcdqfgx
RwTKt3CoqtR+fk0Vxrd0KBedzdC/TBjKt3IIvtbZc0kWxrd2KLj2+VCiohCU
b+MQw75olrSrIJRv6/D6jnqLfpMAlG/nEB5ltK5IiR/Kt3c4K/Xh1RQBLijf
wUFnMwubWR87hN/g4BDYY6jN0soClXd08DGv3/5Yjxkq7wg17789RN7Jwbj3
7XfHAz8h/AYnNHlnB27mtVWvJjNC9aPxGVwcaudd3iP2EGa+iwMkPTJB5V1R
3dPgiuoeBjc0/W5o9rs7FK+2tt+0iAEqj8Zn8EBV3+DhwKSg9Yt79R+ofk+H
95a//jnpfYPKe6K5zwuV3+CF5j5vh+W7r4udkmGFynujha8Pqn0NPqjhyeAL
Da+PUHlfNPf5oen3Q9Pvj+Z+GP8ZVD4AzgcAPJkJAw==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tIU2Ecx/GTi7Sm27JNndqcYpEXlrdym6v9NqdOjZJSTIMg0xcqZZsF
aYSHXkgRStYkGihmRIpTmzUTjRqkLaICu5AUvVISrKFlmIjZhf2fF+2Bw8Pn
fJ/LObEVdQerAjiOU/99/s1shJW4xpy1cfBpQb+YMNbwPJSZw+PewNb+0Vhy
EFrcV47vrGSWwFOZr7FsYJbi8Okvdt2IkhyB0aXhqyk1zNFY+1jd+TmEWYnm
DweOhdfEkOOQEdUzaBhXkOMh+NTe0Ktg3o7oeI+n9OhW8g6sdrhM8+5ociLu
eu6beW8UORmirCnljW3MKrxxzL4Iro4kpyC9xfvT4JaTUyEX27RdGuY0PHqo
KBZ8jSCnY4jr5i9LmDNglZ94720KJ+/CqYv2bxYL8250Bl8flr4NI2eiJvOk
iC9hVkM5LWu/VSYja+BOMnodVilZi0DF+uLx11vIWZhN+N6QWsSsw21t+rM7
HaHkPbgwU9Ey49hM3ot65+ClokZmPcrs/TdlyRIycGasSKdeFvnMA6XlaQPW
ODF1A/Y7WnOqXCHUDegxPJl4KidzRpQntZlfnRVSN2JiUXyo3BJMPRuTI+9+
TC2znu2334QAZeKKsI/W86b/13M5eBm5MGeTbKKeg4V7k7/OyzZSz4VzoM6m
OhJEPRfNbbXaczGB1POwL7PpwbRKQD2P/u+33tfNmNesrBlVSz7zZr+eT9+3
Sj3frxegvi9LP9TN0fkFEAr6G+euraP7C/3OL6T3HPcHNCndzw==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2EABuB5w9k0p605zaZOU1MTtbxne51Tp07d1CiWEgX+EAvLAodd
OJZQSFhq6o8gLEElZyg0mpo3Yt5Cw4bWn+hiCIroumBTzC7s+4izA4fDw3ve
73ZOwNmKglJ7Doej/Hv/e9JLeFw/2FcugVVmqXHASVHiSc1B7+m6Lf2zAGIu
lNsX7OpU1HwcTLjzJNjiTyzA0Pm65vRmahFmbia31IRR+6LplC5O3e5H7I/n
vdWrRQtiYgnk8a+HK7jUQZjv/q21K9xPHIz1L85R+jFf4lBUiKauP3ahDoOr
LkQXXrGPOAK318oMJpMPcSSiZ4MMbhZv4ihkm4V9taXU0dAyHq1VcyLiGJhD
JsROZdSHMSrodj6z4kV8BAkItMc3IXEsWjsedUnE1HGI83Fp/9q2lzgeJxV3
+Z9HBMQJqHWcmua2Uieiz1K/LAJ1Eq49NL0QftpDnIzllsrUHin1UTSVmpuK
Oz2JUzBcfGBMzKM+hjfSRkev9x7EUsgZ7a/oW9RA4uxg2/hHvtUMcEIT87RS
4k7yVBxKiSwaWXIjeSrs/cO2eN2uJJehfNIwbOrnkVwG43f3Qs1Fmqex32fS
kKerTy/Vk/E4cpu+HPdqHQwfSnaRPN0mT8eMj3nlPp/mGdiMaLzaec6F5BmY
NKZUXR7gkjyTPR6Tia7Ul8Zxbzq/Ahtu/TXbsXR9Cps8iz0fk8VeDycbQxNJ
a6GLtJ9t08+BW2VMsukGPb8czBnmf7yz0L4SgdktC5ouOr4SmvAGxayW5rns
/TC57P1y8uC3M/MqwUz7eXiwwNvsiKX9fPb3YPLZ++Wo2DlUNuetgseqQGgW
7rZ6VGXTV6Nh8dIV2U9n0lejc/CtcNrXifTV4Dn0VK802ZG+mvwP21JrvwDr
iVs7ssgNq0G9ZDVj49H//gMvrD1c
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2EYB/DTULCat7zsZpsODZ0hecmc1/+mbl6npiFaEQiDUUKyHEn2
4QgRFZS5tEwwjUC7iKamYptWihVIEDOkLxWkQRfzkimWdsXn/bAdOBx+/A/P
8/C+T0jF8f1GAcdxmn/v/y97Ag8M2HqPKbGpxbRrHVsWyoXMHCbk0XHqrhCy
ByR9d5W3NMw++LJiGT46G0z2R7D14VyCmVkMz1edqmIxcxDq1lOj6i0KcjBO
V7+e1tnlZCXmP+QOhi7tJIdCXJMY1hPLvAsSfVttUUsQORwys/HtWYeMrIKi
om69KYV5N5amkh6/vy4lR+HzzMs1hZx5D3wf2CQNKgk5Gu6CP/awM2JyDNaG
tpcGPReRY9FT4ua2NB9IjkOz2nb16xjzXrR7C6QbmczxGM9avhFiDyDvw2LR
VH1TPHMCxEfsjks6f7Ia/VUnlstr/MiJOKh/tO3n/R3kJDjSrG6iN77kZBhb
OwS17cwpsEkbW4cXfMipkIlnPjZYmdOQr3s6MZvCDFhshckJa16b5oHS8phu
s9Kbcg16ZF1Djlwyr0Gl9vKI1036n9NC6Dd2suoTy7UorFRNrkhY/XTnfnw6
7iUrTeHjrH4G0ks24t11rH+G8zxcpvM8fKZLf52zeRdzeow8S5wPnxFSrse0
5znTD4Mn5Vku9bNczicblojGK9Y+Nn+2y3nnYPVCt+jwdzKfgzm/MuPqeXZf
ubjYvzVy9B2ZdzGXh2pT52hBIMvzEK1rGc55wfJ89H6Ttp0y0T7w+ZgcHLhj
rmL7YUBT2K8yro3lBmifFMsjFWyfCnDIQ8o3q8l8gcu+FaLCEHH7tzAAfwHg
u/tv
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2EYB/DTnJfU1LxM87a5Ik2HeSmv5Z5N021uuos6koRIDWlhlkTh
LA/SRSuLYeWHqMhuoplomKkRMwpRITAr/WSXoZQSppTWiG7seYPzDg7jx//8
33Pe55wTseeAvpzHMEzJ3+PfP/kJCnsHu01icOiLtMnttHelNzED5tqMd7eH
ItBu4LqUMttTRuwDb5TDI1PuxP7gNVb9PKxbhA4CpX9v7biKOBTKpuceWmaE
aBFUmneZpzXEYrh1xXd9fWs4egOUZpsWh96GoTdCpGfFYmcJcRQEdRqOS0ZD
0dGQkj6hebaZWAL8xgv72htC0LHwzahijPPB6DgoSuzZVFNKHA/WuMa9VWfW
oROgrX2gwT2COBGaRTMftbIg9BZIm7exXZcD0VuhbyzQ+eduAToJWu7caBOH
EyeDyBZw6ebOAHQKDFRJVgw84lQ4wR8ZdWvxR6dB/bCxxK4mTgfF3OQTr7PE
20A+ZAiPERJvh+6l4Os1FX7oDIgfCIn8cNgXLYVX5curo/rXogEGgy9e7V/w
cZgFWLPfd77hIJqRQVfIvb6Xud6Yy6hcDp5+T49UfSK5HMYfvf469d0D80zg
iaLtHh2emGdCcYxF8eIoybNA8oDvknTeFfMsWEi1/5LHumC+A45dm3gseO+E
OWUmGzycOmvmmldhng3VHenSnlYG8xyu2Ryqr6DWV4BQoUkVtDtjroRTFlOa
WUjuT0n1VaA7Fx/DP8nHXAXq5Lo+WyzJc6n1c+Hu4KRgNJSsrwbH98fDXE31
NVSuofI8av95VJ7PNZsPNXX2IVM7ma+WO2+gzGrBYqs2y1dw/1Yt1ddx9w86
6nlStuqo+eq58wA9d31Wz70fq57qG7jzAcqsgfv8rQbuvJgCSGz6vCKz/pA6
+gXU+0LZSp3PFFJ9ymwhGIsT7h8S/3bYWojXX8R+Ee5vFvuUWeJl7FNmjP/P
/wM8HX4I
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdy11Ik3EUx/Gl+UIxm1PWlrp0RWxDtE0zbbP99uJ0Fm2TLBASiaxgUqlF
7gnyCYwtvEkaQUkXLgJRXDiLykHZ1LoIIyq7EGGEsMyEVlKZVFbs/Il24HD4
8OUUHD5Z15wkEAjK/uzfy0ZSfzc07FIgrpiBO61T3sliFqCSl7udIwXkdJjc
L9S9TmYRkv1ue8ePfHI2Hk1skYd9zFK8zlvsaixlzkXn9Izy/LXN5HzM3gs3
LMzIyQoUywa4U0t55K3wcT2XTCrmbZBah/YEfLlkJTxJ9rOhpzlkNW6nTNnm
U5gLEVFY5kbtm8hFWHp7se/AtIy8HY1H+y6k8swa3ApO3vS+kpK1CAr8fLeI
uQTuYeeykttILsXDUXF6zCch78AxV9Q8JmQug8jTeiTizybvRJp87f6Jl1nk
ctzgp7kNAeYKvFN9dmsczLvw/mqbccjArENq/ZqR2LiYrIfGev1B7RRzJUSF
mpznq5nk3RDPj4UH65gNiBYrSk6omAEL3/FT4yHzgF6715PRxLoRwhbxB2+r
iLoRjhb1sy8yssCEbm3zbG8T6ya0D+oMQT/r5oR/M86EHPry5QzqFvQbxyef
yITULchczJbEJKxX4Y3Qe/z7PtarcLkr+X7k0DrqVvTMtZ8zfUujbgXXufLY
NZBKvTqhV+NggzbQplg1xHsN1icPcQtXPsXN1+BjxcovU9FX6raEbqMepV77
v/l//g1HdNdB
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtI01EcxvE/m5FsNczL3JzpNlq0maOl29zm2jPd3IWCGexNzJJACAok
Whm9aUV0E33RAkuLQFtZtheNImo1ylC6mVmQLwuKNMlchNnW7MZ+J2gHDocP
33MOHDiK7e2b23gcxxn+zL8rG2L/zfj1nUpklbSlhpU94wJmDuaeWu3nGwpy
PqLJHVvfNDMXQHEvgbspObkYA+r4guEMswRBjWvxpIu5HK8mj2oH5yvJcoy9
/ygRVTMr8VWpnui9UEFeBV9kNngqs5K8Gkc8z9q3VDGvQVmff19kWzlZA6N/
PPp4WEZei77XwtQlPbMWHedVv5onysjr0G05rT4kYNbBavbolK1S8noETebj
RREJuQbas7G5lkwpuRYlpfqqscPMelyzXBz1TovJBgTTV5Q6M7MRn7qfx2wv
S8h1cJx7W3j7BLMJmYE8xdSLYrIZ7pnJhKiT2YLqKVlIkMdcj86uiCrKLyJb
EW5LhgOXC8kbkAioHlQImW1o3d3y48n0CjLgCO1f1B0jhwAhP3pgJsy6HYGl
/b0yJ+t2+HZpns5LC6g3YG/cV1/3XUQ9x1wjBu0PR0aly6k3gifXpIVDy6g7
8GjE2hG8k0/dgUr3JpP46hLqTmw0Hrz1Tsun7kT2v/KoN9F9GVu2N2HOlP7Z
oP2WNefCniGLLdbP0XkXarpmF+z3U9TdOefd9P4v1D103wfqnpzu/d8h77/9
vwH+WNjb
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtMk1cYB/ADFEURBHRVKwoYdUwIKrqWq/0DWgqCUqClF0Azt8QMnSFs
mRENrx8UEy8JiPuwbEbYDEa8MjdEkL1qEFHZlwVI5gdiMC7RqGiyMVDRLX3O
kvO8SdP8+j+X5+R9TuM+2VX8WaAQovbfz3/f8jE6f+66XLUEfo1Zj4bUz/5i
trRAZ+cvTkt7HDkECVFxz10O6Qisi/RYhydiyXNheRb5oLpZej7Gcz/Mu5wi
HY2Ab96OnGyPIcdix8qkJtNfi8lLcO5CR8/9ZOmlcL370X14/yLycmzt6TOc
+ieaHA/zoCfasEx6BYLDFg1naAvJibh+sf/0QLOJnIQe19Cj5a8XkFchLzzn
anGD9Gr0D9p23rBIJ+NW65XvLN/OJ6/B3cqLr3os0mvx7vNth+78OY/8MfpP
nHM8jZc240HflT+Ga4xkC2LshanGsx+QU2A2zfjh5SnpVLR2DRvvRkunIaK+
+tORlrnkdESFzut+3D2HnAHPlpt2r1s6E77cX2dOXooir0NGckF9+NZIshVd
pqbvO19EkIGvPmo63thO1oBC2+3eR5kyz0JO6RtzsC2c8iwMhR3aPrEpjPJs
nMm61Xt7AVnLRmDsisnQtlmU5+B6X9rz+FGylgNvQoP9t92hlK9Xx2vr1fFi
A2KmBu6ljM2kfAPWHH02nqXPoNyGhtGa2uzx6ZTbcKc38+svr4VQnstyZmFX
19PsSPzJMM18TOZ52Hfy927jwyDK8xAadH7Pk+MBlOfjRerkVHbSY6s/z6ff
5bNRtbZRHS8K2HxmUUj7vaS8kPK/Kd+kWmMWm1m+WV1PFNH5J/xGERvPrBex
+hzq+eBg52HWHep+opje/xvan1lj1ovZ/BK1PpSgpi3d2t4i6H2VoMBS1zGa
RO9PL4HjyOoEwwED1V0K//9foN8opfsXTPNL1X7QmYUTe+omb1SdnUbznWqu
OdX1dGbhwsGGqrTaGBoPl9q/movtz3JRpvYzytTzamXqefUy+v+R+7vVHG61
Hs3N9mcWHrUeeDCR2Li3dYe8Tx4MmMaeNEXQ/dXZeOFV64GX3Tcvq9/L7p+P
vX8f6z8fjaNH97H+L2f9V876v5z1L7OoUNdDBZtfweYzi0rVYNYq/6//PQM5
BWo=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0m1IU1Ecx/GbktM0XeWWaz5sKytKVk5zrrn22+azM1AR4Splzy+KxBKC
amQqTsJeWGnvsoJwQTNUInWWRjiiIJDIJKNa4gNZNE3SCbqK/c+be+By+PA9
53A4XOXRquITQRzH6f99/2c2pKVPXF2nVQjIa3xekfgiPpyZw9l77YO1vUpy
KBq8bstgJbMY04WtokMi5miM6qa6mx4ryDGw6eo/1vDMsfA1ZT1yipgVKFE6
wvr0CWQVQtylCRJ7PHkbns22VtV54sjb0ThzWK/xx5J3Qqn4kdqczLwLsuns
kaJqOTkJk/M96UPdW8hq6Ps5p2FVRt6LvEhLb3ELczL8bX3HvnliyBqUnXQs
LQczp2DcL3eV12wmpyLiobZooF1K3oc3yzPXGh9IyGkQ26uPf7kfTdaCnx9P
S1zZRE7HbU/zms9zG8k6VNSn8GMzzPuxO04qO3WEWS9wBpYKJkOvWpkNyNBY
7ZGVG8gHoHvruuv+KiYbYSxbqDgoZx2Y/bSjYU8d9VqgjNd0nlNFUTfBYXo5
7Jatp27C8O+oEr46groZI73vF8aWwqmb4Uu6cbnjTBh1C1omzl8yL4qoW9Dh
+iB9HbuWeias2itPJ9TB1DMR+B+DqGfhl2551awOoZ4Fb8/Iik3Czs9GV2fV
LXV5KPVsbM1vG+Ud66jn4NWw4UJNP+s5gvvlCs7Phe3OuwGph+7D5dF7+I2B
nkfr/wTM5SPl+s9F05CPer6gFyA82Hnx+8056gWCbhXsF5grpPVTxr/NFfhM

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtI01EYx/F/02pkc1Y6NzdzDslrm9u0Oaft57R5mYuohmRFF7pAwlJj
bwbpP/NNlhUmFQMT60WRbVIRtiY0oRAHUU2iCKIi0JCiRLBaZhf2HMIdOBw+
fHnOeXMy9x/delDAcVzZ3/3vZEviuBe43aRCVF/NPyfHXovFzBxKz45aDtzN
JAvhW+6yZ25mToI/J8sh+6UkJ6Oz0Kt9epFZiocKbUhYy6xA0sT66ZlPGWQl
Tg84wrkaZhVmVbnPPf1ryVnYrind+3EqnbwOwZlHzTulzDmQWr02X6+CnIdX
De/Gx6bk5AKM9Gq6ThYxq2EwOUbz+9PIhTA94LzlCzKyFsHCU4eau5h1uNFm
d9bImfXIuNbdkW2XkovgimQPjYdSycUQtp2Th/Ywb8ARgzORd0jIBpxJfdYz
15JCLkFn/HhIeCmZbMQuYRp/2chcij7+hVvsW0M2QWv1+OuerCaXIT9dIju8
j7kcYXNPfOqbVeSNmNSo9M5cZjN2eLwDKQVJZGBIfms4bBNHzQOuwJayku+J
1CsgatWZJjpE1GPMWfB4VrytsWUldQvmRP4T88VkrhLnO+Puv929gnol3O2R
0aaby6hXIfr/BNSrkBDndU9fWEJ902LzMeasMfNWHBs0me9c5ahX43rgpSSk
WEq9GvWG9uEP6jjqNRAo8yIJg/PmaK9BQ6PO16r6HTVXu9h8LY5fmRiRvGfz
dTHv18Xcb4O++/O3iuAPmo8xV48vxsiCRT1HnXmSun2x+f/+A0bn7H4=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n8s1HEcx/HL1khaxPntQlJkSifpiBeHO+dnbtaRKBN1WWej/Kg/vrHC
XG6yW4txKTF1qavJqChrptm0sWkq/5RZP24j9MPPVevz/uP6bN999thz738+
37dHtirlhBmPx4v48/296dindj0xnPbEP82G96+sDc/xyTxorxmWrJ56MFtg
24i+LDKPbI3QlwvNyZvJdvAtfB2l73FndoSX0dIhLofsCnV9i+zG9FZmd9S0
pI767CZ7QttZYV9UJ2D2gu6d0N7msxuzN6rLj3S830HeiUkuR3lX7srsi7bA
lPFljQuzHy4uP2v7sujM7I+MjX2KRlvyHiz6Xb3Qnu/EHADLXRVHN8w6Mu/F
YFFdiUpKFkLdO/M2s8aBORDdzy0luq/2zPtgrB15GD7KZw6Cat3y5Tsh5P0I
Mk5P6s3JwZDzgkcMNnbMB2CYc9aVnbRlFkG7fTWNpyOHQNBT+LhymByKKaWP
aLWSfBBpWQPSdAU57D+H41VpVGiONxmm8xzQXdCW5s+nHoGW1iG+ZnwL6xG4
LRIOtTcx8yKRPeTZK+RoPhLy8Wr1qBvNi03NidEpmUkptqIeBR8v86mfEupR
eFRQOJ9eQj3a1Fw0Ro4rvs1PUI9BntasaJOQvR8Xg1tTl7LFufSeEiz9Et8s
9qMuQdabrsyxEupSKKQa6w/91KWYPTSm0QbR/4nF9dpm5cA5Zi4WqRPrq6vO
U5dBdaXUybaeugx1bqeMDR+px4E7G74g8mb7wcWhK6Ps2OF82pd4U3PxaOh4
If5+j3oCklN+uNwvp56AYZ8zD1xXqCdCHmDBm5CzfeQS0STQ9jWG0X4mQR/S
Oij7RPNJEFQpOxb41JOhFq3liosd8BtYRwSh
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwB2IQDQNioVt3b8xWcoDwPthPurtMcAEXjM/gMOvUZnev
xYpQPofDrBMstxPcYXwBB6bkqBd5txWgfBGH+oaYia/qYXwJh3rJK1L8SjC+
jMOsYNepGUXyUL6CQ+KBX9E7j8hB+UoOUayVLv4KML6KQ2XwPS/XNFkoX81B
0n1+deAsGShfw6Gp7txUpS/SUL6Ww9LVXX2f9GF8HYfGBLft0/OkoHw9h/0b
vXu4TklC+QYOz58dFfiiBOMbOtwQ/CSZWSIB5Rs5TOvPK1jVKg7lGzusD2Fh
+fhODMo3cWiceyFesgDGN3WYV7riloESjG/m8Kbv3Cb7S6JQvrnD78IF9b4Z
ML6FwzrZy0paz0WgfEuH6quVvAwJML6Vw+ltW1cWFQhD+dYO0e77uX5tEILy
bRzc9r7McrgoCOXbOpRqTpk8aZMAlG/n8PqOeot+E4xv7/CfIfB/Qgk/lO/g
sF56zfZL3lB+g4PD3uNW7zQe80DlHR2YFLR+ca+G8hscHT5svvi3VpQTKu/k
sHz3dbFTMqxQeSeH95a//jnpsUHlnR2q6n8dzF4F5Tc4o6pncIGa/8ceIu/i
YNz79rvjgZ8QPoOrAzfz2qpXkxmh+l0dIOmVCarfzaF4tbX9pkUMUHk3NHl3
VH6DO6p9DB5o8h4OtfMu7xF7yAzV7+kQHmW0rkjpP9R9nmj6vVDd2+CF6h4G
b2h4fLMHAOyr3z0=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tIU2EYx/GTRLfNZZrOe7q0cpXmbXaz/Uzzvjm3TFpaIrggw+xiWlKd
opv6h9Siq0I2nFokFISKF0zR7kGKrlIzUMIytETN0rSi5/1jHhiHD9+zw/Nu
7+ueekCdZsFxnOrv59+dXXYJj2ofpEvwX9/kou2Fu74KmDkcmYy9aVfhTl4A
mbakI1vDbAXfvCpj83c38lLMl9vmt59ntoex++IrhQezMxwMYzrt9WVkN+hO
6j6V9biSJcgYsiseFDJ7wK+q8r4kyIW8AqeU+4Lf5TiTV+H2TOGN/BInshS7
jusCB1Yyr8FR4Z4uHe9I9oaxqb5131MH8jqccpnxz8hg9kWcaW3Kwgl7sh+K
TzjrSvXM/tgtHRtNX8YcAFGOdMcHvZgciHTvyd62Z3ZkGa4ZS8olrsxB6B0s
y0ossiWvh2neBZPLyFLyBkR+MTWICpg3QjvSJfP8bUPeBI/sOXrZMPNmVGUa
d3rbMgejIcnzsavAmrwF+rRv+qQyZjnG8yvFyaNLyECb/PJccQ+ZB2odrxTX
DFtRD4F7yN68rGkyHwKhTVN25ufF1LdCtV/6YsyB9a0o8EvrvpXCvh+KrFrV
5vUTIuqhKA9pbml1sKQeBu3qS5GvcwTUw5D+tLqhvYbMbZvVt+FNdcfo2wnW
w3GrU/DTGMh6uPnzXIT583wExi1rTk8FCqlHYnn01U5t+SLqkah/snFoVR/r
Uebmo8zXw0UjUetXeUhCvwcfDSf7voFLl9n6Y8zNx2Cwe+VZnzOsx+LwvU3y
h3dYj4UivLWlP5h1BaIqKu96FrH3K2Z1pfn/wStnzRc3a/4483k5lfk8UMG4
PPp9QBObRwWXe1OdSUG0PxpVSCs2WuTeZvsnHikHkyefD5ARDy+P+f0/Img/
8vGwFojrPtWRG+OR23HMkkth+1sNQ/+51FAdGWooD1vlXm0h82qkKr3Kp4V0
XhrVCCv6aF2Tx86PBi9+DeSfLyVDg5d9ht+Q0nnjNaj/qlHGGciNGnwXJTR7
+YjxBy0tSOY=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XtIU1EcwPHrnPOxfGRr8/2YJWoycpo6H+23zTlf29xMJVGIUghmSGbl
I3GEJYXVtCgQCkvNcBSIWIYaC1Mz0kyJERZlQn8Ypc5qTDIr9jvB3YXL5cP3
nMO554QfrtJWMCiKUv99/33Jwy0cHO7X8cGuVXGZxY3X6ktMQcd1z9MbA+Fo
N5CtsDJr1cQ+UGtdGBRaw9AcWPSYql/rJPaD3SOz5ogs4iAwOL3s/rIeig4D
VrLRUhZPzAf3wa5PrTUh6F0wXW1hVPUEoyOh5YKxaHQzCB0FF7dCe9bKiGPA
cGVWyfkRiI4F+RGZnFVILACLv8nlZH8Aei+4vn1VvsAgjoOZ8HSJotAfLYSH
5vUE30k/dDw0b73TstyJE+DQwSLbDR0PvQ/aFDxBvZmLToQ6A+dNthNxEphZ
LeZgCwedDK4hzAPP5nagRTBVl5FWHkmcAnPidibv/XZ0KoiLv5eqAonTIFoV
wZEfI06Hipt3GQ2dxPuh1PVOR6CcWAyimeHOiY8+aIC66ElbhRqtBzCm8Y9G
jXljl0BxifBBNR+tl8A9ydj4hL8ndimMTqZ8i1rahl0K3VNdp9g1XthlDvNl
4FktTJ0/S+ZnQKXUMOp1G8frMxy6HOIvfbVKTO7YHUxlgi22/UxvJemZoHs+
9GT+MRu7AsbXvQtKjpP9KRx6FjDCYjbYRtKz6OOpbFgdeL3ZuJOsnw2GZueh
D2Ue2HOgvmnjqa6PhT0H2pZONEitrthz4XybLqUhFK3PpY+n8qB32Mx9EeSC
PQ8ab82PcBedsSvp1ishL6np0ZKAdJVDV4GmNW4P8xwTu9phfTV9P1Q+hGYp
Rdw+7JBP378+H2IHmKzEy2hTPv08KA39/EED0wGry9d88Hz0Gvp9mTQO/6eF
FdHGb6ngp9g+n/iz3XotsJ3v1y9fXbPbpMX1bHZTBfQOBXifv3B+wf/1/gDl
MkG2
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQNioVt3b8xWcoDwPtg/9TkuuUcMxmdwyFz/d6HM
bkUon8PhwuMV030yYXwBh49apzcoCsL4Ig41sSeSWrYrQPkSDpZX1Q7MiYfx
ZRxm6SRdnfRHHspXcOheGHpJUx/GV3I4OO3g7lZbOShfxaFH7BP3njmyUL6a
w0e/jWqHz8lA+RoOZlcjZVhUYXwth55r4R+e9kpD+ToOiipGFz3PSEH5eg6O
uapWmaEwvoHD9CNnl4bsloTyDR0K4uoOqvjA+EYOD37KhTYZSED5xg7vDax8
N30Rh/JNHErN1VK3psL4pg7Heg6Vl+0Xg/LNHDj/TeG0NoPxzR0EJ/gxOBrB
+BYOCo9Fpy6OFIXyLR2S/DRX/OOB8a0cTC71lqvuEoHyrR3iOtxe2h4RhvJt
HHzM67c/1oPxbR0WLjkh2n9NCMq3c3g028z09mQY397h8Z6/DdrmML6DwzN9
JeM8TUEIv8HBoVLz+M9UfwGovKODr9uxo09sofwGR4e9x63eaTzmgco7Oeja
6oXsf8YLlXdy+Ma7s/GPKUze2eGs1IdXUwS4oPLODu8tf/1z0mODyrtA3c8M
lXdxMO59+93xwE97iLyrQ/Fqa/tNixig8q6o6hncHOQ9fC3FVrFC5dH4DO4O
3Mxrq15NZoTKu6OZ7wF1zzN7AHKCwGc=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQNioVt3b8xWcoDwPtiv6NZ6zcoO4zM4bM3dumXB
akUon8PhhlGGvLsnjC/gMP3ge0PnDwpQvojDhtS9cxZOgPElHHrY03+vt4Lx
ZRx6705xm3pLHspXcNg47aa3ogeMr+TAWV4zQ7JFDspXcfBocLXb+lcWyldz
2L9cVTzBBMbXcHgZyTfF4bAMlK/l8P7z+iUGn6WhfB2HXw3nFliFw/h6Dp8T
jtrvXSoF5Rs4zBB7eyJxuSSUb+hgWR7ymO2XBJRv5LDH8r1D0UQY39jh7xH5
7i23xKF8E4eJ7uJ6VdfFoHxThwX8TFJ/XGF8M4eVBWcvZvSJQvnmDtr9buec
TotA+RYO8de3xl2ugPEtHcpFZzP0LxOG8q0cfMzrtz/Wg/GtHY4EHJjdsEsI
yrdx2BejelCOG8a3dbAx8mnnSxCE8u0chF4cOLQ6CMa3d1hycnEZdwkflO/g
EKU90eNcBTeE3+Dg8I13Z+MfUx6ovKPDh80X/9aKckLl0fgMTg7yHr6WYqtY
ofJofAZnh6r6XwezV7FB5Z0dlu++LnZKBibv4lA77/IesYfMUHkXh8AeQ22W
VhaovKtD8Wpr+02LGKDyrg7vLX/9c9L7Zg+Rd3PgZl5b9WryRwi/AcEHAIU5
trA=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzl1Ik2EUB/BXRTK2cuqaM1fpiMgVq5y2pq33v632kSIli4H2DRGYuT5Z
VNKgm11koFORhPBqVLTFliWRQoULQlpW4GUghbphbEVWk3AVO0/Qc+Dw8OP/
nMOpPO5uPpErCILhT/99WSkOPHoaPqVGVikx6um7PlrILOBW/wrP4sNKcgHu
zy0Fhp3MMixX7k+mvlaQ5Wjvit14MsCsxJtPwXFfHbMKUb94L3dwHbkC0Ts9
3a7JtWQ1XjtfpefKmddjNvLt0Fn3GvIGWIaPxF4+UJE3YrLG7rPmMGvw/GDm
w7GmcvJm1EsziatDq8laLCxLBE6Gy8hb0Xm3T99qZN4GzVSwuGBASa6Gauj0
rHOslKxDUuxwTOcz12BkojT/11EFuRbzN2MR8d0q8nY0nZdd6Y/KyXoc9lnj
xvES8g6EbMlmj5TZgLYLPx/nuIrJdbCOxdvwtohcj5ktal1HFfNOXKzq9fdE
ZGQj9rVrJhbKmHdxFiEteeE5Ey8kA0XzckVKsTJrL9CyqdseuySh3ITBKUk6
UEv2mhAOuXu1rQWUm9F5+/2oYjqPcjMa9ddGPmrJggWulurQOXVGzOYW6Lo+
/zA9S2ct7EbSsLhk1s5QzlnYQ3uovJwFK5dzFmyQ5AUvJ/xfaL+N228nf6fc
/v9/wcHNO7j793LznIUGbr6Bu6/xn38DNnne9w==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAmIQDQNioVt3b8xWcoDwPtjf0f41uYkTxmdwsHyy62fm
CkUon8NhTZ7K+q3eML6Ag3Du5sIdzxSgfBGHsgu1qUzlML6Eg5fufZt0GRhf
xsFloptRfoE8lK/gsLt4Y6rDSjkoX8nhX2GdkdBtWShfxeHHnqZXAqYwvprD
26K/03m2yUD5Gg7+v2dVRn6QhvK1HJw978m884TxdRyctc7G3l0nBeXrORy5
4TXL+akklG/g4H9dN4HzhwSUb+iQsUhctV0UxjdyeJ2yqenTGnEo39jh869j
R+/cEoPyTRw+bg8KVraD8U0desQvTPpWKArlmznI3I5wEJgoAuWbO2wvWBap
JyoM5Vs4uO19meVwURDKt3SwMfJp50uA8a0c7MO/xPhJw/jWDrw5Qq87CgWg
fBsHz5XrVqnO4YfybR2cQ/6YsbrxQfl2Drq2eiH7n/FC+fYOxr1vvzse4ITy
HRwmPi6udvrODuE3ODjIe/haiq1ihco7OoRHGa0rUvpvD5F3dOBmXlv1avJH
CJ/BCWreT6g8Gp/B2eG95a9/TnrfoPLOaPpdHJgUtH5xr/4DlXdB0++Kqr7B
FdU8Bjc0+91Q3cvgjma/O5q8h0Pxamv7TYsYoP73gNrHCPW/p0PtvMt7xB4y
Q+U9HdomZltVy0PDi8ELaj4bVN7Loar+18HsVVA+g7eDzmYWNrM+WPh6o9nv
g+Y/H6h5z+wB4rDxIw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd01tIk2Ecx/E3aZ5qpunW8jQdZWlDM9s8bLafU+fmqRAWeFFIZkSTJLSk
LHwzkImgbkYXyWBWZm4qmNhBsYMhGSLTi4yIiJIOdNMgWE7NDuz/XMwXXl4+
fJ/3d/cknqirqAngOE717/3/ZY/YODYxYpLBJ7dGXdefZBMzc+iVdJ37OJZI
DkZjd+1s3FHmcLR/ta86PAnkKBjuDR9bsDNLkJZaYzHnMcciKeKPa3BSSk7A
ak9K63IwswyR0g/z7tp48i4I2q03tK44chIGqsuvV21i3ospZ9ieF6Wx5BRk
Gl1Dr6ZiyHKon/VVndrGnIoWx+fw7opo8n6ka+/u7rPvJKfjzOtCgS2C+QBc
J/Wl1QMScgYujMRbje93kA9C0BC3r/mRmKzAU2mPxBbCrITxraDN3CQiZ2J+
cLLt2mIUOQv672+ehLUzZ0Pu7hh+2BlJzsGnHqXiXfd2sgq9d2ZEnYvMaoTe
Xj6um44g5+JLmizjbDLzIcRIlr5ZrOFkDSpvDvWK5MzAz/XxypYgMg9cTH7p
rTnMep7/eT4P5yeOqLOWw6hr8cDdlRY9R+a1WBSaT3vLhdTz4RE+vrqm2Eo9
H9L1udksdyj1An/zBXCPLvy+IgqhXgiv3Hq5v5bMF0I+ujlQ2RFEXQepvixb
7BBQ12FmOrexYTyYehEsS/VN2l90ni9Cq8WU0yRl/+txqXnluckRSF2/Yd/g
v8cb/Pe4Yv89vhi++xRAvQT1TpXm/i2OegkCElJWtjjXNL5eih/ZK+vaVI/P
/AZzZbTDcX8BBAfnew==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H1ME2ccB/CTxHSuggiCQJWXDgQEUWBUxCLfFnlTC30njWYjRiKLsqFS
dftjuzm3SRQzwI0IMwExOhHM1LAhBKwiMLNMgosEB3tRu6JzczQaBHGwLf5+
f/QuuVw++T7fe+6e3HMRW98xFnsJgvDGf+f/Vz4CLW2dF3Yo8VLjGVHtEZHV
PmwBb1V9cq3yQgT5Fahbx/MmCtm+ODzWMN08EU5eBPPY7zc6athBKB3o/zE3
nb0EJc6fvAKHw8jh6FEuqHhNzVaiba5/U+3HoeRI5IpZ69r+WUpehpE77wm6
fHYMBqK7m+6eWUJeDpf7+INbLgU5HiPXp3tLbewEqGb/+MZZGUJehar9Y282
BrMTUT6e2OWnCSYnIfPx2c9LtwWRk1Fks07V7lhMfh1py74ebqkMJKfgo4M9
o7WOALIK07saPtCVsFdjsGXgSWQpOxWqP10/t8jYa3CiXb255vwichqOltmb
N5vYa/Hwi92a1gx/shqVl+bFdf/qR07H5CnZ+04Nex26t0RdDZWzM+Abn6i4
ObuQDKy52dnQ95vvS4uAa6Uy+e1YzjWw1bU2BsRzrkGm+YVqbrYP5VrMCobZ
ovIFlGuxU/tZl08j55nwCl/+XH5uPuWZ6OpPexxznyysx2D77afDk3LK16N+
SD51OoUsZCFs5ofvU8dfpTxLkmdjwvvyhy9S+P7ZOHWjaa+8nOfPgb1Tr06d
JIs5+ErT09sX7E15rqSfiyHvQyVT+ZzneY4X8yT5Bsn7SSxsxIr0BPMVF/cl
FjZBl93X60zn9ZVY0CHv7PnmqC95fXV4MtNhOyDjPB+Hk4pH64u4nw/vnX6P
Du3ivADvxvZPFRdwXiDJ9Z459FAE3X9QVc3j9Z7jHXrP+QSDZw4D9pxbm3Hx
JPcNiNBsr7DPcN+AFQtj3HWD3DeiM+TYict/c9/omYtGPBqNPrjyAPeN2CI7
WafI4u/T5Pm8MEnmN3mul8OE+f7X9pU9pPUUzLDHHqupvsh9M9RJmz71KaL7
i2Ycv3JmnyWe9o/DjHv1qpSRGt5PFtTePTLnFzcZFiR2KKLv2cmiBd+WnbYl
BNB+dVhgGqo4cmsp718rYiNlzmc5ZFix8ZJ7g2E1WbRi63fKjmSR+1Zor5pC
48L4f1AIR5z2r5bdZBRCFTKvyd0QgH8BbISArA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2EYwPGT15XOzNyaa6VbF6cNL7PUZeazeZ1zdzWzLxVZygzBtGg1
OgZKgkaiFV3MxLTSJgwpKa3Wh26EH8TyQ9KHioIicZnkBbMLe97gvAcO48f/
fd5zzguT7q+ylPkwDGP5e//7JZew6O6QyyYDrzwZM/KiQesqYgaeNMn7KpxS
NA86U9+eCrASh8Kww3bnvCcKHQ6vDFkzN5qJRRBcXCy4IieWQHTn5A9eYyQ6
CioXnykD/YllYH+ka+pKWY/eCEkdMXsjXevQm6G04WRuD59YDqrplwkmjQQd
C4Gvo2sPVK9FK8A10fxutF6MjoNL08E2URhxAti67eKjigh0IrQ7JAe7W0Vo
JVSEzBUevrkGnQQPv1kNxi4heivUfZE+/qAl3gZv5JX7egYF6GRoGLkYUaIg
TgHJRAmEtoSjU8EUf11WIyJWgWta3GEvX43eDnO6T7y6gjB0GgyJ29rvT4Wi
d4BUfaixdok4HY7HPJ8vMxLvpJwBuy87OwUKYgDt7f7eTVdXes0C8KuVaWOn
+djVcM9zLl48EoJdDeP8M+XzBtI1sCH/wnjprRXYKTOZ4Oqvaovbw8OeCZ6B
0V8OwXLsWVyzWfDiafqxmge4nskGxYBfQPLZQOzZVM+ByDy9Stjrjz0HWj4e
OaGZxfVMLpibErf41fthp8zkQZCv0/61dRl2yoyWmteC9//igz2f6vnguDY2
LHzvi13HXc/qIKl5clbtns/w9gKu2QKYUi0saeJ+YtejP2PX477kMnDNGrjr
GSN+z3ecN1L7m7jPBxO3sybuvJvqjJmaN1PzZvCJil0I6lvEeTN1fhbYVars
r5b9xnnKrIW7v9vCfR/Gyn0eWKnzpLrbSp1PIddQ+P88/wBD6k+H
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd019Ik1EYx/G3kWkuddq25qZuamautenMlZnup9vUqZn9kUoKLBgttITs
IsPkJaT0okzxoiwjQTQwE8OFYhijwJUKQbRuuhCMjAxdSdFrlhV7TuAeOBw+
fM+5fOJP1hxwiDiOy/57/t1s5OWu0cGqBPjlMyc9VTtzxMwcXGdcQ/f64skh
WDSk9mQeYZZg4oTlUhbHLMXcfaPqa5eGrAA/fLCJz2GOQXDx5NnO52qyBvr4
7HlNMnMCHCZJ7VJLHHkz5gVFiGIilrwFjfbJmoptzFshUi9mFPExZC0SO9bc
bHulIuswPuR5URfLrEfKcr1ZqFGSUzGT6E6/OxZNTkOlMCtc28hshG1g+krr
EwU5HfpbjxaOL28i78CX8PJnKQbmDKzzRXhbnXKyCdY701EjzTLyTvwMP2V2
25h3Iar/zWlfg5Scie2zKj50LfNudHV7ZC3eKHIWfnQHN7zPZd6DsWNJ7jgx
czas/IVfaVcjyTmoHRxoLrvIbMaosr1zZEFCBubeJTcaLpN5oKxaO/EtmvXc
gJ4LlWLmY2sb63moSxkXHPtYDzBnwdGO/i6ZjnULVrj9K5XnI6hbYTm0bArK
D6duxeEK48NzCazb8Nh3w6CcYt2GyM9SuU9O5vIh0miXxH0bqAeYK0Dpg+s2
hyuMegGmlL5P7ZJQ6oWo8gyPvR4RUy+EN6zJKZTSe86O216x0JPBuh2Crq2+
t3o99SL0jr6Vv4wJol4E/z6JqBdjIXPpd57+u9nfmT/4zZWsNl9C/9jsXW0+
wFzpf/8BWnzjYg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0W1IU1EYwPEzXasxa8PcWmZuTjOdw1Jruqnbs/k20420ViBEEI1A7dXs
zagVrb7YbCWjCIMylGZKJva2EltEJJTrQy8fiiCtSGabFOxOKDP2nA+7Fy6X
H/9znsPhpu3YW2+LI4To5t//X/pIrMPewSYFRBXSj2R3ryJCagK7jv7JeHcr
Db0IAqVnwje3UIsgu6jdk8nI0UmQfsJwXdlFLQXt6Qhj1FOnQEgVcA98l6Hl
4JgT+FvN1Ao4eKdbu7MxFZ0BH9UJ/E+PVqIzwTZ5ardYSJ0Fkz2c59a2FLQS
Cq3j/S99K9Aq2DbV/CWYSJ0LY5xx7eq6ZPRa4O83i74+XY7Og5HHqZvjA1J0
Pvh/MaP+7dQF4O7Ys8/jWIZeB5c1Xve0T4JeDzP36zel66jVcMV5rdF3SIwu
hF7ve8lYCnURDDLOH1JIQmvgsPgq6ehZitYCz8oZCj1LRBfDkxfnPjMnqUvA
m9zZ9TAoQpfC1ob8gQMKIVrHsn5+v/Zn1kQCGsBy21lhG14ctR1Y3QCt3o0l
RcwS7Aa4F7qwJvkVmhghTq6cFfThersR3jx4+/sDI8BeFmt7GTTkuEyvj9Be
DhHVxeO9zXzs5aAa4vLUzoXYK2JtZ5lUgmuipc0Ypr2S1atY+6ug4Px02DCK
5xETnHU1adtktJti55FqkJnMGolnAfZqCGpm/xpzedg3sOazTGpYvQbq2vNy
uA4u9lpo6SvW371BsNfi/5rTR7sZBPH9x6YuzURtN+P537Bb8D4R7BacS8g/
K6TwUQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQNioVt3b8xWcoDwPtjLSrxNYmOD8Rkc3p2adnb6
YkUon8Oh0bq/NtEVxhdw2Bhhd3rGGwUoX8Rh+SXx84u7YHwJh+/a+0wbdGF8
GYeZV9YFnN4uD+UrODzk+eKb808OyldyeLj5/YFzYTC+isNWd7v5y3bKQvlq
Dv7Ttj47IwLjazj8mfbRtqVABsrXcmgPdH2y/YQ0lK/jIP/v7GmLD1JQvp5D
Y+XbckVpGN/A4eflfHaXckko39DhZcTZincVElC+kYPF0frqebvEoXxjh76y
+iabe2JQvonDztOR28IjYXxTh6saOYnLtotC+WYO2sclvi55KALlmztYZxXN
SNgC41s4nEuM+Pj5pjCUb+mwcMkJ0f5rQlC+lcOj2WamtyfD+NYOS62MTyyf
C+PbOPxYwl73xBHGt3U4eU3ly28eQSjfziFy1tqFojoCUL69g9+aPtfUrbxQ
voPDxR1Xv9z4wQ3hNzg4XOPtyPjpB5N3dJh9jfvnMlOYvKPDWakPr6YIcEHl
nRx0NrOwmfWxQ+WdHN5b/vrnpMcGlXd2kPfwtRRbxQqVd3bYuC5/il40B1Te
xaGq/tfB7FVQ9Q0uDst3Xxc7JQNVz+Dq0DYx26paHma+K6p5DG4O3Mxrq15N
ZoTKw/gf7SHy7qj8BneoPhjwQOU3IPgAUGLEdA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQA2IQDQNioVt3b8xWcoDwPtib2RQvWCMG4zM4ZJUFv3q2
TRHK53CYG73aaFE0jC/gwJ69zu8pI4wv4vCyytB63moFKF/CwajpyO1JATC+
jIPSmsO+KY/koXwFh2uPsy3WaML4Sg55Om9ZPWfKQfkqDp9cFreFP5CF8tUc
ZFSOHw+Pg/E1HCTWBtfpnJKB8rUchFNTA4ONYXwdB+t1kTd0p0pD+XoOorKx
WsFMML6Bg56d670V6VJQvqHDdCHb/eseS0L5Rg7zHC92+XnB+MYORv9TJPcv
kIDyTRz0Zm56H/tHHMo3dTg5dU3gaw0Y38zBIWnb9UnlYlC+ucNhj8/zFPeI
QvkWDgLthSn3F4lA+ZYOPxOL/zZuFYbyrRwmp36YHLNcCMq3duBa/CPO7agg
lG/joCuo8XHWRQEo39aheLW1/aZFML6dg66tXsj+Z7xQvr3DxR1Xv9z4wQ3l
OzicOGpbXrKLA8JvcHCQ9/C1FFvFCpV3dAiPMlpXpPTfHiLv6PDe8tc/J71v
ED6DkwM389qqV5M/QuWdoPLP7AGMfpWI
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU3EYx/GTTpuudKmt2bwOKdOxmuW850/nZW46N1Mq64UYvggzKV8l
lTNSaGiRCb6wgiKbaGoqsVKJFQqRXdAwxXpTYo3KsgumY3TD5x/sHDgcPnzP
OZzngRNZXl1U4cFxnO7v+e/KDknJneH+SjlWtZhuCW2Ofydm5nB0ukTTORBJ
FqIqWVAyY2AWI8ble7pnIYIchCbzdFVaA7MUzfoLl1VxzCHQPC8rE3eFkyNQ
ODgvrfgcRpZDFy3zGdMxR+Hhtke3E22h5C0I/Db+3hjKHI1GiXxKVR5CjoH6
8Ohs+w0ZWYErwrITkzObyUrEPnP4GAzMO9A2+rSjeDiYrELq0MuGCYuUHAe9
1bJP5Me8E09sxb5RwZvIu3B/KEC42Cohx6Pt5rVOeRizGuNOh6WxYyM5AYde
jYxYPwWRE6HVNc0O7GdOwsHyt3MKRyA5GfrBrzpTAnMKRo32dvNQADkVy/p5
YX0+cxpEnj21Hy5tIO9GTXdK+sB1MTkdNf1954y1rAMy6ZzjYgt1M/Dx9daz
28+w+zPcbc5An+yWbVLvTz0TmmKX2ivHj3omJu5O/ZhZFlHXYGn9vXpX/Drq
Gl7Pwth3/z2lx1jPQn9vdavygJB6NhSDAm/1+bXUs7GiaDlpPeJDPQfh2oIk
SZcX9Rx8SXL+ylR6U8/l9VzkJ9TZ5pSe1LW0rzXUtVj9Hzyo5+HU1Rcjkjd0
vzkPpiZVrKBBQF2HvaVxvcflv9NXO8+cnvbP0fN6Xs+HR0SMU9Ttoud55gpo
niXqBdjZvPAzw75C3eA+j9ng/r1cofs85kLefozuhpG3LyNq65wPKruo242w
Dk9LHodQ50zu74eJt0+T+/x2E2++Ivf5UPR/vj/Kayz1
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU1EAx/HbzDSf87GlzkxHhZSJZWq+2s+3a3NqmuKjkkFlSTTTnBmy
WxkVRFlq5KtSw1IzX+WztMyZEgkp9qJSGRFamDCtKaEZnfNPFy6XD99zLodz
jpP82O4DHIZhApbfv1/68Pc86mpKE+KfZkQ5i6L8b+bUDPxZh5PRLU7EhhhN
T+fekVNzkfV+UMszpbaGqnV0i3ObI7ENDmevDM7eT22PuB7bc8r5dcSOaBDc
bxuWUAvRK3FbUZznQLwe3YHlq1p61hJvhPBTlaZxzp7YGZrErOBYG+pNuMtR
DObeEhC74NLLCbPxp3bErnhlNzNVyKV2w76vKZmrC2yJt8LWUR2n0afehrM8
R1XxBRtid8QfvKdb0KPejgphmb2ieQ2xBxz6PuuGI6g9oV3oV3/8wCf2QknN
s6C5euodgLz17TUltTeKWP8qi0BqH3gW9KWKLXnEvpBlcE9dV1sT++FQESfT
1J3aH9NH++bcf1oR74SSV8pcqaYWISmsx2ih0ZIY0Em+GJ6WErOAKH42WSaw
ID0Axnr1OVMFxGwAkg0qSwQhtAcio85X1FzJJT0QXXaF5R0/iJkgJJTUV/Bc
aA+CuOZB7YYyc9KDERT721M/1Iz0YJhY9SoVk7SHQLvYmXDGgM4PgcV3a/4M
n4xnQlHnJ0x1fk7Gs6FYYqKXUjLp/DA8eeEz7awxIT0MiZuvhg9lG5MejtI3
xvPVHsRsOPLz9NrH9hqRLkbaQHv3SAftYrxuH519p6Pzd0GtNY9JTKf//8+M
hNxvuj4JvIe6bveP0/2RIqOp4WJUDt1f6fJ6z4/pVPR8IiD1UrVpXMn5sRGQ
Dwg73Vl6njLk3hx5zJ+gXYYm3eVJG9D7EInLihO1STHEbCR8jxy/kfKQ9ih0
Klx+xXB4+APZeQS6
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n8s1HEcx/Ev40pHh+NwxJFkuvw4kUJeuEN+HqZCNRF/YFIkXaXL/Fcs
S1l+rLFUS//E/Nr5dRqrxDJLtal/2mz9PkOkH1et9+ePu+/23XePPb/ffb57
fz7uuSfS8k05jpP/vf892SXK6NE8LPLAf+kiMr4tyZ4JmDm0Nb7uax9yJ28E
VzzeeDqb2Rq5quofKhNmO1Q4mU2ktknIjvAtds0eUTC74LlguD5/2o0swWhL
EM/TntkDsoKu5fY0V7InDuhvH7p8aQvZCwu1khXVmAvZG3l5sZpCB2YfLLYM
WVSlOJOl6FJ1tIZfE5N9MZ9eIXpz04nsjxF/E7dOAXMAhKUJ2pILjmQZavTz
aTwL5kBoH3WYzmU6kHfhyxFt37EJETkIfZMO5j9zmINRJVU1l+jsybsRtqJ9
e+Uocwh6IgrWzhfbkffAlu8wuDAoJO/F9W2/MrlbzKFGDsOTs/Kw417M4Sgs
X+s1OWhL3gdraYDztN6GHGFkGFoNaMQNrQNfralHYqeN92LTDFkdCUvh2JnS
9wLqUejVXfUTT22mHgU9l6rPKWc9Gjaf7EQ6EevRaJ7jf78TxKcuR9aO+rjp
SrJaDlOJzzq/05K6AlanZKGz1VbUFSh63D88O8C+j8HW+BtzWfc2UY+B2++p
yRAdmYvFlFj3ocGa9VgE1n5ejRy1oB5n1OOguriuLbrPo74fdzUvRU9dzKkb
mYs3fF8dj/p3ZeeiVjdQT4C024wXXEdWJxitn2hodaLhPLgko/9LwviSID3r
JJtPMmb6Xyy/WmPzS0bygzpFfg/Ni0sx3C91Cj7Ob6/xq2b7qzTcXyhxeEN7
k7OCnQel4fkYVaK7tGwpq1KIPy9eDmE=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIU2EYwPFTampe5m3TzJxKirW1dKa5ubVnZzo3dc6lEprSFAaCgorT
ykuMICktL2UfwkItMS+0vBBmFpZmkVEQFIL5ISwkTXFkTVc2K3zeD/PA4fDj
/77P+8IJzi8+rttJUZTs3/v/Sx5W5oPRgcIQ2JJJwq0ffHyCSUyBUKOOXjcG
o51gqGEDEmliD8hvC7uf8j0I7QMzzj/9uq8T+0GM1E1bGUEcAMKo5UVVOxsd
BKqp7hzlbCA6BMaqCzKtK/vQ++FwKId1SkIcBnMMxkK/PgAdDnOWTjvNjb3o
gzAt3lWRvuGP5sJSXlf782hiHvSUz0haG/egIyD/Yb9g/KMfOhKmP9RM1YmI
+WAy68596vBFR0Ftc6Gwik18BPi+bXk5tSx0NHg2pVJSPnEM6EfGgyaSmOij
QD9LD+SwfdCxwDU1GIcbvdECGC7pyuIxiYWw5J2lM1/yQseBuc7om/vDEy0C
bWnu76mvxGJ4rzM7h48QH9tmCYz6t9waWfFAA9TzdbOtWrQB4OyBlxadmnQp
9IlCCsInGNiloOwx9obeRFM0FNFNT9w73LHTsGp9lHXekeyX2c4zyMCtyOvb
xVLS40ElfzH5RUx6PGxSmk2tnsxPAFfv8dMlC+T8BJBlbMQ4yPE8Sg6HxLyM
sXk37HIoH00Txa6Tngidr+5UuOjJ/RJhcpWRnl3qil0B2ZxmxdszLtgVwLa+
eR1r2o1daWuDEv+/I/YkMA29+1PDdMaeBAPG4hbeSSfsydD8uayKXsP1hmTb
9VQKWLhXq+8Wkf0p27oKNJcjOfYX7LGrgK1QCVi9DthTwcXuXuXitR3YU6Gs
L04yeJvCroaoK8tr0qcWyVZXw4rgl5XmzW+ZSrM1bLMhDedQ1F+lrAs1
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtMU1ccB/Cbgelc5Sk4oOKgFGdBQUCojiLf8ihasPRFS4Elhgia0T1A
u4wmZndsGZhli7FsCWUYpwYwOhbdGK/JbnwwiNHMGSqZMZhhYJlbgMkydDy2
xfP7494mTfPJ935Pcnp+58ZXv2mpeY7juEP/ff//pc+Gst6hi3VKPNNcripw
4IYqjMwh+uFspn0knvl5fNhbf+/9g+RQrEnyh3dy5AjIDZWNt07GMUehoXS7
+l4xeSNiXdqZ0fsvMcchMbBtNVlBVqIyoTRhfcsmZhVCZjXau1OxzJvxesDR
E+Yc8hbE153y1n6wkTkJe8bbl1+dUDBvRXD2RFxbIjkFCYbP/BXdMczb0a3X
fXppKZo5DW0+T+bCSXI6mlx/fNR1N4o5A47a7sWnAeQdONzac3St8CJzJiKN
tZrpPnIWzr3WEbW1l6zBfHDZVXUqeSeqhx/8ufLNBuZdmO+zWBN2k1/B5KMu
t+PzSOZsZP0+ff+CjKxFaHP9gcnTEcw5kG0KtF37aT3zbow1FmgPbCbnSgyk
DSpe/sUd/sw8cPmH5snFd5k5HQr4d5bTmsNYrkP4r8KV8xZmLg9udav3xKVQ
ludhlTOv7j8SwvJ8uIdM2p2LwSzPx1BMa8fALHueKxCbL0CuY6HKqKD1CyV5
IbaFbZn33aa+XmxejyrZaZ+ikPpF4vX4IsTrDh5zr1B/D4Jc4Y9a6qkvMbcX
JlfSjb+iKd8ryQ34du54asxN2p8Bjor0ngYl7b8Y3bqr10eig1hejHa//Eln
ppzlJQhqSM++00R5CfxBLYeeGJm5fagb7R++M8Ce5/fhdv/4wsQi9Y2SvsRc
Ka4/DrFW1K9jeSmMFz4prOml3IRtOSm276eZYRLnvAn5tqWsNXq2P8GEs2Nn
3pYfYebMcOUdvxz8BTPM4v3zZvE8CGY8Xhl0Nsno/7OIzw8WjPlVC/+so/Oy
4PDFr46ZPMyCBdr0kubg/XS+VsgDvvT85mWGVTIvVvH6glXSt4nnFzbJPNjE
8yTYEHt+yV+loX4Zdt0aOjXygPpl4vniJblQhulUZcYbaurb0Zlg+HnHFerb
MfXdMp+softoxzWT0M4PMgt2fPz12uThSbqfDvH9hUOc8w70vdXpTIlk911w
wFsz563qon450vS+AcNN6pdDrZI9/LuIPc+Xo3pUOZjBU78cHfy4J6SH3h9O
+IzvPZ16gb1/4ISnMXnGn8jMO9HRr6309jALTiydCYyf+TEC/wKQPp+P
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlH9M1GUcxx84IAsCyfPEIA8vbabXrdPkN/HmEDxREO4Hx93B3dWWW16b
lW4kRHxb6Zi/Furc+uWoDWEaTnSly5RvKf3A6WYOcesPaWw6XCmlS0CDavd5
1p7Pd7vdXns/n8/n/TzP+/td+PIm1yvxQojt//7++5ePyfvl6b6oBTEaL7kQ
f6DamCpZIHx7497JrxYSz4Lj0s1Wh0/ybCzYF1d17G42sRHn2o0H73RJzoBl
LK9lW6XkLKTM+a7p9TEzcTaOt1vbqgslWzDy3siGl/oWEC/CR73dZ44tkvwM
HpyceTcu/BTxEmyNG0lJOp9FvBQpr2Z9lpYp2YrB/umOi+ZMYhvOFv2SeyX6
JPHzsDsOLe7qnE9sx8ah8sRP0yUvx/BQ6+COogziFfBt6JmYMkh+AX5LXue1
unnEKxG1Pbj+808m4hzseCc074t7c4lz4f5kf2azXXIenLeGz6buNBLno29i
z1gGJBcg1F4xVnx+DnEhbj7751Z7jeQi7NzdtbjXILkYH/Z3N3mtTxC/iGRD
b/OtfenEJdh8pLDk+OeziUH3kRZjjbEoxYyonYlskXopyjwPcxIrUkl34Lli
m6f/xuOkOxBY1uG89FYy6WUYuJvmDryRQnoZzvxQcHvJKLFYxfRVTC9nejl6
Ss8NfD+f5okKPF154Gqg5zHSK9T1YjXTV+PyqaF71yakP6fqV3Nie0e0oMX8
COlrYD2RkJSzh1hbg9pd9mUJ2xJIr0T36WHTYFYi6YzFWrQevPKN6VcD6Wvp
/AXp6+ALLD/6pmWmJKYzFlV0f3FUX8XmV6O5berb6OEk0qvVeWI987ced/Kn
ph02Wi9q1H6oYX5rsC637eSojVhnLGoR+37EU30tq2e6znThUvcHF+Kzl04l
H3lI5+FSz0N3kf+/6HzcWLH79/ul+mSM4Vb9aW6YnVX5psO0f93N9u9Bx+jm
Fsd9ul94MGnd+3b3a49SvQcfX02ePLSS8qF7yJ/MlxfpvxlN4yZ6H+BV86l5
1TzqXjWPog7jJy7/3TqX5oGxVqeu15kufMy/T82v5sOPA8VNW76eRfU+tv96
lVHP8lSv9tPr0Xd0035bkPoJPz5433DqeiP5g5/598M8ffFC3rj072f1ATY/
oOZRC6j99IC6HxFU/SGo3rcWVPvpQfZ+Nqh5RAPLTwPLXwN7fxtZ/hrVfGqN
lO8/qJ6tFyG1P0Is/yFWH2L5D6s6wmx+WJ2nM11EiG/EODui6oio/SNsvRah
c6Cn83/+Bz8nNV0=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlH9M1HUYx7+hBnic/CY4tOAqA7ywQAwR9H0giCjHccfdccdxsRrFAicY
glG4rxepWyU/JGcxNIaCC3+MiOJHxHe6A5rTqazLP9xqQUZacctKKIhqPZ8/
Pt/bvru99n6e5/P8+Dyf6Bf2GEq9BEF4/d/vv3/2CzP1D/eWq/E/eba2jNU4
6/wYC/hkqrHD+XE0sQ9Kd8O0wcw4ALWoXzO5gnEIDu0v/DrgTBRxONbubnop
Wcd4NbacvPjRyOxjxFFwT5Unn4tlrIZvf+d371Q/SvwEFh96ddbuXkO8FlWG
fW9NezOOwWGTOjzSspo4DobAkoWak5HEGowOHWtsDWAcj74DK1z161TEz+DK
zU1Lgy9GED+LzIvfHmr+PJw4AU/6XiuM//4R4kR8+J6Pz/hNxhsg+j9ocCQx
TsLB9uvPR1SGEW/Ey+V3MiQl4+fgdeLUX9liKHEyFjqXR/9wPYR4E2pD24TG
rmDiFPT+qjpVV8Z4M+xvJtpuzQQRp+L90e5ak4ZxGoZVre2DswHEW+AXfKm2
8kd/4q14O6H0dlsJ04F7t59qWO8kFgF9RdyV3yOYrsX9v4esTm+ma5GbNeaa
TmN6Oiy2hAt71RRfTEdPqros5jI7LwP7hvWpyXOrSM/g7YVteDotvmD0jpL0
bTirvewaiyAWMvl4Yia8ouL+VPT4kZ4Ft/JI2byO+WfhxsBXv92aU5C+HeUT
A19MDhKL26Hcm7B50sniZ2NJyF8qqWbxs/l+CDtk9e/g7YUcWf05CPwpJMwT
RvUKO/nzxJ1IfPfnB1rJl/RdeDznuNt2diXpu2R6Lq6qPHdbA5ieC0/fjcX6
UKbrMOFKq60e8iFdh3lNyxvdFUzPk9Wfhz+UgwcXklj/9Hz/oOfzF/X8fCQ9
H0/IR5tbMd+VRIx8Wb756L2wpzW+iPKTZCwY0NSwbOCbYrKHQdYPAzR9yx/e
eNSb/A0yfyPPMPL1i0a+XskI131/o62K1V8gq78AunNHM0v72bwK+PsmFWBk
POWXmCnmb+LjQ8aiic9HMsn6Z+YZZtjWNWdf28/mZebvg2SW5W/hGRbZ+RZ+
HpKFn5dQKKu/kK9PlOlSId8fwcrbwyrrn4wlKyrSm0ZWdbD9sOFTT9N61VVi
2HD6y84aRTW7fzZ+vySb7D0rgvWD8x2hGtpPFEFZEXTvSBXb1yJ+fyWZvWDn
3zPY8Vrs+HxpHvO38/EkOyLDp2aaW5h/MYJmpEs9hkDyL8bKzjlHlotYLIZi
2fm6u8eIpWLMnfY+MK1l77UDZ1ISJ7rbieHAZ5Vd1vhQeu9FB6ZfiU1ZPByM
fwDpYv0l
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU1EAx/FpYfmYWunSnI8tSTdt6HzN6fI3p3NzTzNdiYFpotgiFAWR
oiUFlaSB0D/9kyhYWFqMuVS0P3TOlDINLURS0DQKZOEDM9EKzwnchcvlw/cc
Dvecwym+drbUlcFgyP6+/770YeVZ+l5d4WJPjrSlmuAZC5OagRt2UdsjC4f4
MBSC/JfT56l90T0V+uO2O7UfWgMWK9mWMOIA7D5t9ODlULMxIa4tjJ8LJQ4D
d2U+PERKzcVXpY4nLw0hDodbzIbt+rdg4lOYbNDe50VQR0Kz+UuYa2QT8zE6
IO4dGgoijoZdZk6sc6cWYNRlXByRc4I4Bl1RIaIMRyBxLCRiZSy3iFqI8csK
dcmzAOI47FaU3B1ZPk4cD+9afv6XZuoErG4N22ZnWMSJsBTWFRmM1ElYt97p
2ZjxJxahve8Ta5RNnYzt1oOc5Q9+xGLU2w0Xt9TUKYh2NHZam44Rp+KB2T1q
YO4osQRRwazAskvUZ8DTnvTLvHqEOA2eB17UfW+mBpLf9z0Znvfdswl4Ox2+
9tuLdikahKWzj4tol0IjH7YtSogZ6ehI5ZZHDvqQno7Vnd4L9Ydol8FQIOys
4tIuQ79dvBK54EV6BiZeT6193vQkPQMbzJ5b2wm0Z+4fb8rEaYng3JslJuly
GNMf9nu3eJMuB7NKmPKxnvYs2FZ9cgsq6fwsp/UVcA3jb3l20K5A6M67MZHD
g3Sl0/rK/eMZ2U7dyQwVuoKeWydV9P9V+/eLoYbeyB9bD6T7qwZHWnavZofu
nwbV5e0DOhY5T5MGFdWb3S4Ger5atLSN+DdN066FyvwzOyeJ3g+dU9fBLc/F
7Bik8/UoHuH2xpnIeOihTrppXRAQm/T/79sfGI0Mrw==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XtIU2EYx/GDCF5C0k1tM003tZyK6dTKdPpz6bzPUUkZecEYFFmWElb+
s0Rw01RqiuQQLFGzlU3LIB3JCsMyuhiElKXUEKQiRZKkyyp8nz88Bw6HD1/e
97zPOZKyir1aJ47jlP/u/0+6fAuGRwePS7GmxZQ2kd6xTUjm8NxRs/+CTcLs
igVrs0xyjOwJ+cqrl3ovsjd8zQl1emsQswgz02qLrZjsj4YbsfZSd3IQQiYS
qufqA5mlaHW7m9M1vYU5BK72CZcjieStsFk8lkfaA5jDYI0w9H9Y8GcOR4Mj
sGepiByJqJ+WItW7zcxRCHU0XloVk6PxLBnX401+zDFoFyjGBj6JmeX4+mKp
XBFNjkXP0Hi3/rWIOQ4lNp3YXUiOR0f+6mypw5d5B9p0im4vJXknKprOiYVG
H+ZdkDi/n1v+5c2cgIOZLZ4fx8i7Uef85KlrOzkRohLrVLOKnIRqHxPX0itk
VkCwYZN13kpOxuS94f7KU+QU7HtjuDgVQAaa7rhFPJgVrFkHXBnrqy6IZOZS
oe3sdarp8mI9FbX2sib7TWZOCffuH8WqcepKXt+DqsHbBs156jxzaTgjazVe
HvJkPQ29wdlv4x4yc+nIUz0etyuop8OjXPBZf5q6ClXmxJSha9RV68/LZUCm
DvZOP0Hvz8CoX2vn/W+0PhONcu2MqZTW88xl8XoWzEnSo2GPNrKeDU15+OR3
MfVs3vlzsPxnpLDWhXoOb/9cFHbcuuoTST0XBw7JByqltH/eeut45tTr59Gp
Mb9dGntSRvPnI0139ndMPc2fz/s+GnwRFmpXDOx/QwOjdtF4uE+Av9TqBh8=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIk1Ecx/EHby2nOc3Ny0z3LK1h20htlvOy3+Zt804YoRJFEBUKQmJB
pj1KFEUXTK3QJClUSh14CboYFVFkYaSB+aoXaRlmpZSXmW0V+58X7sDD4cOX
wzmH53n4/eU7D7hxHId/z/+ZDdmuuw97S5VwatawbiiK7xEzc3h16krNzz6e
LEL3F3vHQCGzBLysLXhySUEOhMp/8ExBO3MwVs7V7XGkMYdhKPDd+r3vI8gK
2D9s1F/jmZVIuTp62FESTo6El1D4dbxpA3kTpnwePfUMZ1aBD6gJd78URo5G
yzHzjdFBOVmNkxrHjEXErIWteMA44xlK3ooQv0Z9W0IIOQYy40RZ99Fgciyk
Qbotw3VB5DgUVX9PPz8vI2/DeNO+4u63zDr8SFi2m7TM8VBMSJtuFUnJ29F6
L6mkwRpI3gHNlFzw9mBOQLs+7mVnawBZj5gH8s0fK5kTIVHHyN84/MlJWMr+
JKrNYT0ZYvee49MNrKeANx48W2mXkA0YGov89duHdUDjr5prHqEuuJgzIjfj
xfPJZNaNKCiLfj0fwrpptQUTupKUh1TP/KinuvRUl54Gy23rnajrZCENmmRt
4ePPvtTTV1tIh5sielnc5UM9Awu+92tXdGQhA73W8kZtiYh6Jmb7R/5US9dS
z8Tp+lJ9VcQa6mbEXfi2aHzCuhk29eUTnWVkzuKy3oLh0NnpRok39SyX9Vlo
GRPbOnRi6tlQ93t4xV+k/YRs1E9UVJkW2f45cP5/btRzsLs41npE6TA4ey4q
uhINfTc56rl0/xXqefS+55wW8lx6Pp3PRj2fvs8Fw1+M8vzG
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0GtIk1Ecx/HHiddZXraenC6nliJrrDIvm5b7OXXOqaukYaX5ohAMA2O9
ULNoJQQDC6wRZNQbBc0bKNpFMcpaL6qFlZcyehELYTJoyDBbphX7nyAPHB4+
fHn+h3OSTjRU1Ao4jsv9s/9+2eJNo+ND9cnwy6MxHZ6eDhUxc+DfdN0VDyaR
QzFjPNITc4g5CtsjO9why4lkMarv9z29c4s5Fic/aU3ubGYpRj7X9TSNyMiJ
CK5vWp0TMSfj8tKyPGhXAnkHXHGLYcrmbeRUDNeZJ9YdUnIaSmeXOiWZzHJ4
E97b5tviyQpcSK0Z/yhkVkIQ1qqypsWRd+Pno6nI4GYJeQ9e533VVThiyekY
0M8vmAOY9+LUbIpS2L6VnIEvO2snhQrmTGTdqzhuaOHJWbD6pnolv7aQsyGv
UtkfH2BWYap/wto6KyarkfHuamPKGHMO9Ia2+eGjzLnoMF7yOcOZ98F105w/
oBGR9+P5wSe3LWMx5DyEd67U6OzRZA00ld5qYzwzECGabDzjivTbAlQeSx80
J5O5/A19gzktjP3XimpHN1HXQpAo9wn7IqgXINot5j38ZuoFG+YXoif/mf2F
hP1fiLcPZ7wfVoTUiyBbc7xSecKpF2FosMGmrAqlroMjzrNoi2Jdhyvt9Tkt
shDqxegen+NfSoOoF0OmL1fzvWROj29q35pWGUxdjx+K6+e7T4dRL/n/PEsJ
2p1nW7Tf2XwDyrIvPnAqA6kb6H7rGn8vhTBw4NzijQDqpfQ+q9TL6PwFvy1l
NJet8n/+DaJ74SE=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdy2tIk3EUx/Ghi4xgbUvndJe2xxaia+Y0bdV6fs+c25MlWMsE6VUSBZHD
ULTAJkQw0xfOSrqsCKEUgsikFa40LOkCClugUoSW0JVo0QXMchU7/17swOHw
4csx7vXu3JcikUisf/ffZaOqvhUeOMghoRjfU5I6rVcyS3Da5L8QHDSS01Bl
Mh6v8DDL4XG76rzfDOR0NPiFj++DzGrM/Br6WlDJrMXY99DE8OtVZAO4yEnl
LM/MoWnkRl1Ll568GuFDdk1vREdeg9CRXoBjzsXCfN4x+SktOQ/TNbNPHr3V
kM0wxTsC81nMFrj38AZ/MJu8DvdubtOL41nkQvh08aL6emYrqgYMW3ffUZOL
sOK+50qKmrkYRxtzvNeETPJ6nLWFez6NqsglcJpk5hkFcyn6Xzw4c3Eyg7wB
Cw2XfZUHmG0QP0wNyzrSyRuxVC/d9TC6krwJnsn2zqiOeTPOjfQ1V5uVZDui
fLc086WCvAVGYX9706KczEOjnnsX6GYGruZUPC8eJbcBaxW5X85HWBeSuoBQ
rKsge1xG3YHa/IA40bKcugOxwcjv1oxl1MvweMze3DiURr0MfeEp1VPtEupO
bC/13Z6zpFJ3JvVytF56dlf1ivVy7OgszJeekFJ3Jf27UFNrvX6Yi/OJ7sZn
289Fh+VHwm1u+mMjUn9DXfzf/wCXMr9b
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0FtIk2Ecx/G3zenKDit16qY5l0S5mr1a2rS136Zzzgl2pFAjKYTKi8W0
KEG2wuqiPEAWaDBMEkVLceKhLCsj6cAusqKbImKgYFlrF4VrdmL/52J74eHl
w/f/PA88qUese6oEHMfl/lv//+yT7h8eH6xWIiivbtbibBwWMnNYXjMq3NyR
ShYDMesWPpuYJYjnpt86fQpyLJz8UMXdZuYETC2MTF/XMidBfOurh7uXQlYg
7WXz/EQysxIKfcPRxMNryWlw23wCa1cyeT0y5O3PbJHMG/BLpJK1pSSR0zF5
UV6276CcvAkPBp53uW/KyGr0FOqvuQKJ5C3Q5pp5ZSUzD5Ox9rgwkEDOxHnP
Q9u5UuYsaExv4BqIJ2+FqDZZZR+TkrehY5VAFjAyZ6OtyXli8nQcOQfZX2Y+
3I5i3o6mk6d6y/fGkjWY3eg7y++KIeei9lj3RKl0DTkPBY4zi/yl1eQdqIjq
bJcbmbW4nFn1/kalhLwTI96WDJl7JVmHHv2Tp1OJK8hAS4Nw7OOhZUE7gG8a
/2+DOpK6HnV2/+PqXrJDD7fMO9cqoXnOgMF+a6u6XEzdAO/Qq8X6uKXU80Pt
yA+d5wrQPf5O+iJJRL0Au6/wqogLEdSNiBbeqZu7uoS6ETV9eTpXJ0e9MNSO
wtB5zkT+rgv2MHNFyGqc/6l/tEC9CAJFuj+6L0DdHGqHOez+YpTk2Ec9aiHd
X4wDZZn9NuUf2m9BvfP1fekn1i1h55fQe/+g85lndH8B6qvm/g==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/GDeSndvGy6vF8jTaemS9OW+XPq1M3bZkEJlhmipGJSYYjR
XAoWKSrdEYIMDDVllRYJtckmUeiLIn0TiGZpOHERZEZkhf/nxc7gMD58n4fD
ec7/hFXUaysdOI5T/7v+/7Of5MjouKEmHFuypStUVqu7GzMH8XRybP1AGHk7
hKPS1UQlsyeedqkM6s+hZG9cbmobK7/K7Iv1nMg8QwpzIL6ZlsoEj0LIoago
nB81zgeTw9Ec3P2ySci8C+hLSjVcDCLvRnboiLnvdSA5CmvT5jEfDXM0bO3V
CyZLAFmKTZG+NyqfOQ7iPuMdg9mfvBed8ut7WlyZE3D6t37U3OJHTsSJOsO9
2x98yTI41bvJ6iw7yfswJH8wqVqWkJNwt2hjrnyTORmoGJvtaWTeDxdTRK/U
6kNOwXDQ+/DoJW9yKhSmkuCYEOYDqLrhcE4oY5aj5qiL5tQtMfkghnPWtI0C
5jRYxccqf1wRkQ8hJkjiV3WSOR2ufT+PKy1eZEC0bJwY1JJ1QIFy0rKY5kk9
AysfI1vj9WRdBq8rIBBPNJ756kFdgdi0uMOvvgipZ6I0pjt3+oIb9UxsSHua
+2t3UM+CrGN1PcNI1mUhQnVzpvShK/VshPyZeptiI+uy7ddzSjRd+mWqGXCm
rkT/+KzkTaAT9RxInzg6J3e6UM+B5lpCjGObI/VcnB2Upz++z1HPxdb34EA9
z369Ls/+fpyK13nm1Lz7q3n78+2fV5fPe74C3vkU8M6vEF2t257PlbH9hbzz
K+LtL4Llu0dJaYOAerH9+0IxvKzeEpvEndYXY0bYXr1RSN3IM6fBmK0r3n+K
1kODkYChZ+/UbB40ENaKVtobaF6MGgT4flru7mHzo7WfL2ihX6zoWBxi86hF
wouAyIXzIvwFb5wmlg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQNioVt3b8xWcoDwPthH/zvupMgF4zM4OGtsOVC7
RRHK53B4s3PBLN1EGF/A4fSrdbIfhWB8EYejEwPyd+9XgPIlHA4nC53flwjj
yzjcd1l0u+mJPJSv4PDkrWPKVhEYX8khatWhebMb5aB8FYfVvOtn+Z6UhfLV
HKx1GPaGcsL4Gg4BFjzP061koHwth128fXaXt0tD+ToOtWet3crEYHw9h9uX
CzRyDktB+QYOCc4frBq+SUL5hg6XTtwwWq0B4xs5ND3eX9ToLwHlGzuU3Fp8
QvCGOJRv4hCpZLHgRhiMb+pgtjIo1qtaDMo3c5D38LUUWyUK5Zs7mL15dncN
O4xv4SC09mrmhzoRKN/SIYZDqmGGJYxv5SC3s3hb+2lhKN/a4Y1wZOq3TiEo
38bBpaHir2G7IJRv61Cpefxnqr8AlG/n8J8h8H9CCT+Ub+8g/+/saYsPXFC+
g8OHzRf/1opyQvgNDg4b1+VP0YvmgMo7ovIbHB2q6n8dzF7FBpV3cgjsMdRm
aWWByjs5THxcXO30nR0q7+ywfPd1sVMyrFB5Z4faeZf3iD1khsq7OBj3vv3u
eOCnPUTexeG95a9/TnrPIHwGV1R+gytUHwy4wfkAXr+v+g==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0VtIk2Ecx/FhhtaSlodNmy1nqzxWaofZtP023TzbyjwQZpJJkkH4ll1Y
1IsISygljxdRF92U4IoNpuUpJUFiYGgiSqk3ViwTEjPD6Ij//4U+8PLw4Qvv
+3/eR33u8slSD4lEEv/v+b/zkuc6u+3loVjVV33uqbExbz+2BOHFLqHZoSZ7
Y2H47ERcDluGJkW+f81yCNkfjrvF3e5mdiAmFnRztVp2MDR184ubHu4kh6Bg
V3Cvfk5FDoXWI7B7yMDWwDk9OesQdpD3YDBbJY5/CSaHYdK5aLsuZUdgRF4x
3VGrJEfhZVdjfZOMvQ95cY7wqpLt5AOItma1tbmCyDFomC8Lu6ljx8JiD0nL
ex5IjsM1u6ohd0pBPohfgjqrUss+hEJJjtxyT04+jCfvXjU/GA8gH0HC0sD0
nSK2FtVD+WdWMv3J8Yj+pBQ3e7KPQvXiSofV5UfWobzA60RJKzsBpsTZG29W
fMmJcLcIBpue+zEMWvrvi13c9bha9rjvuJwNyKJilMN/tq1aBEb1DZ6KKbLE
AOkGW9XnRu4GqA0Xait/y6gbMfd+b83+arJoxDNle+doxlbqScg/HftUCCWL
SfARYnVvq32oJyO7vc5U6iSLyeu6ae37RBMslyJcS0H8fTNej2u+/dzC85nX
zZcCc6/7Ika4p6CvcPeASsrnT0XvkHXmxy2ymIpwjdfscgr/vzQU3Ta7EwfJ
Yhp8pYqejz3c09fej5iO/kjjfLvA95cBmbXi/MwjspiByHrzsNHFPRMfNrZ8
72wNwF/8O+Bm
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQNioVt3b8xWcoDwPtjnmy3/u1gcxmdwmP5tq+z5
nYpQPofD919xma8TYHwBh9yCECO9rwpQvohDmSTLscCFML6Ew0WehNrVXjC+
jINj5p97jHfkoXwFh3KP/vPTWGB8JQeOJyfYk63loHwVh61PWOKlpstC+WoO
hy/Uzn3yTAbK13BQVHhj0mMI42s59P34v0KuThrK13FIPbQ9YP42KShfz2GF
m+PUTX8koXwDB7G79rtKpsH4hg6u6x+0TdwjAeUbOcQfbJDkEobxjR3kjtz7
cclXHMo3cXBR5dO5LygG5Zs62Hw9eK8nThTKN3NoOztdMkIHxjd3aGE5eYpj
ugiUb+HwJEvT6m+7MJRv6bBwyQnR/mtCUL6VQ7T7fq5fG2B8a4dL9pNYxO8K
Qvk2DqWaUyZP2iQA5ds6LDm5uIy7hA/Kt3MIjzJaV6TED+XbO2Sf2LHv8k5u
KN/BQf7f2dMWH7gg/AYHh4mPi6udvrND5R0d2iZmW1XLQ/kNjg7Ld18XOyXD
CpV3cvAxr9/+WI8ZKu/kwM28turV5I/2EHlnqDooaEDjM7jA+QCo5ZfP
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBWIQDQNioVt3b8xWcoDwPth/0QjdHiwI4zM4lIQueWW4
RxHK53CYIrP/XWckjC/g4Ld28UlXRhhfxMHXdPrBt8sUoHwJB7XcCWkWfjC+
jENAKs8E5uvyUL6Cg4im5dcWLRhfycEobdOXRUFyUL6Kg7nh3WjeZbJQvpqD
TIrK0S9fZKB8DYf85qaGQ8IwvpaDeoNSZpiLNJSv43DGzmGF6WwpKF/PYcNP
oT6lt5JQvoFDS4r+8V9tML6hw+356YWdqyWgfCOH/1nJHSeei0P5xg5ztr/r
luWE8U0cpjbYLhZ0EoPyTR0Oe3yep7hHFMo3c5C5HeEgMFEEyjd3kIjfc6nP
Dca3cPiZWPy3caswlG/pENNsHHXjhRCUb+WQUBj7+9QLQSjf2sGloeKvYTuM
b4PGt3XgzRF63VEoAOXbOfxnCPyfUMIP5ds78AgfKi94CeM7OAi+ERH7IMYH
4Tc4OBz9zB8cVcgDlXd0mH2N++cyU26ovKODzmYWNrM+dqi8k8OJo7blJbs4
oPJODhvX5U/Ri4byGZwdVjgePnpMkhcqj8ZncEGTd3GI0p7oca4Cah+Dq8NZ
qQ+vpghwQeVdHSa0MO+4HwvlM7ihuqfBzcHHvH77Yz1mqLy7Azfz2qpXkxmh
8u4OTApav7hX/7GHyHug8hs8HCD5gQmq39Ohdt7lPWIPoeY1eELN+wjV7wXn
AwBzYMyd
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd031MzHEcB/Af/+RZd5ROdbqr1OnEKVKpe1/pQZJ75GaHK4/zUOm0kqaf
htxII89JqGlmZkVYxGVMWCmjIWZTUusPF7ZuWp7m+/nj7rbb7bX37/39fn6/
+/4kGVnaDaM5jjP+/f77pY+noeFu3VYp/suuTD6x235vPJnDrqN2qf6uhHkM
ht49XeGTSXbH16wHBdEC8lR0tQedP33Hj9kLwv6WOvEKsg8WtvrFxo/MYPbD
RkFcb3UkWYqaCqF/8SUxcwCqusI8Bf2+zDMxxn4o8LCEHIznZbmiIrMP8yxY
jU2myjZvZjmSrLUp0xTkUNR1lX7o2D+deS7ElsXSV4MiZgXe2C9UN1nI8yDx
Sh9p/eDFHIYjQ+bk7a+nMYdj/WfLTWs0eT72VravFWV7Mi/AWb+Gyb1fPJgj
0Oy/L5iTkheiQbnRUbhtKnMkTBmfuuV9U5ijkNEibQzjydHYanTTrDtFXoSE
mJ7CFz+FzDFoelLy0VFEjkX5Bnu5qZasxJadjlujVpIBR43bnh4VMw/0zpGG
ZcoELFdh4jbhwMEd7ixXYeB90L45xcxcnEvuYi4el/1T3oU/pDweTzsDfgxP
oPUXw3I1Wll/iXIXcwmQqDZZc39RngDlyh+mNG/qJ2LRvNSSSWZmPhGzBcGD
Zzuon+QyXxJyZcfLj9VTnuy8Hp8MYZ/t4VUtrb8E5h2rh5/1Ub4EZx7U5hnk
9PxScN8U2CweT88vxfl6bim6743wIRGUL3X5f1IR4usp2pROeapLf5nzPPwy
jKt2rEl8THka3OUK77bflKe5rL8cdd+mVxVsZueFXw5ZgFvPUBKdH7XzeYAa
ikbvoE+5NI/a+XqbGv0nc1TXlNTX4Pmthis52czQIDWi6HZ3KO2ncd7fpkFc
qPl4jpn6WrSlGwe/v6W+FnkeFVzZZepr8UX2bZdCTX0tSm+MDbn/ke5Ph0dq
WwXfSPPrcLGmxaOsk+bX4Ua25fuqfOrrnOfh9M7zQg9dp/XwS1/aX4+eLbKo
kRLq613eTwNKCh7lO86x9xcG1F8/IPZ6z8wbEP6yNC+wkdlmwIHWUyKj3AN/
ACTHZvs=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tIFFEUBvAxQ7fs4Tsfm481xMq2fJab5rerrrrqqqsiKqZYiqihlZng
g8GiIki01iCjEDI1IkM2w0eZKK4b5IYFEqFYGEWBtWChBtoDz/1jZmAYfnyc
e8+dOeNbVKkr3sRxnPbf/f/JLtes/uG+chk2ZIk2dK19POfEzGGAX1nsfepL
liAlO8/Hs4DZHl7vTdKBnczOmLt8skL/yIfsBu407zuZwizF1xzF9Kt33mQf
ZARIrevVzDLMFLzOHDN4kfcg/0Fh3nFrZn/MFlb9mivbTQ5AzJMCs/GxlLwP
TY3mNtlPT3IgnukPXr0QyiyHcda/+EubB/kQyvtqq04suZODYOV8ZWl9zY0c
jDsN0pL7N5hD0NEmkUy+2UUORXvq6nzhH1dyGBxatJwymDkct5rvlo3VuJAP
oz+6ZKW+wpl8BEUm2VAI70SOQJC6fVAz5UhWYKXTtvGTkvko9mr9nONOOZAj
sbQ+lNNka0+OQnZucO8Z2U7yMfQoxyeM7tvJ0Xg+qfgesLCNDOTub00w19pt
mAemPCzf9PZbKVfCYphea3DZQrkSIdcWl5WjZE4lNK9Cy0Xrgfl8Vh+DctPA
yNtBtn4MTBNR56uHJJTHoq+3Ui/PI/OxCDRstglvtqU8Tmg+TrS+WtS/Wrgf
Fy/qLx4/In6vq+Q2lCcIzScIz8slis6fKOpfg9XA6/XdFSzX4FJruaLOm/Wf
JDpfEvw0N2dye1j/yaL6ZFGeItyPT0Hrwtk61TJbXyvcj9eK6lNF9anCfrg0
YY400fsQ5aMic+nCeYHIfLqwn9F03J6xW+0KY99HhwNR8swXn2k+oUPny3s1
dtU7qF6Hh5Gy0oBxmudRHSLMwx3GD2zeM1Bd2j2S6kr/BzJgk2VlsIw74i8N
lkHb
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdk3tIlFkYxk9lZU2mtTVlTXnpgppJ6WqjOfloqZM5OldnnJluxkBkEUnu
Zm32wdYSW0oXKbpAQZCSZrTh5ia2X1tWVgZRTUZCgVGbUDvRdlHSLvieP875
4OPjx3Oe8z7nfc8XVbLR6hvKGNv87f3+5Y/W0dRyvjQagxTIqD96eF37GM4M
/piV+5rORREHo7Wi9UiXiXMYGuM9a9ibSOIJyEvTo6SK82QMX9sd3pnCWYfj
bU0hZbURxJE4e2v1s98fTyeOxqUhntDAXM4zUZLc4+yrnEY8G/mGHeUNdTri
GNTpZvl8j6YSx2F7x8Kcn7Sc4+H756L5xJ9TiBNwdcuhyhNazvMwypie/Dor
nHg+JnR0tQ+8mkyciIYHroonLs5J0J3c8NLeOon4R/SXRZnK9ZyToQQnVb57
riVOwduLVtuMRZwX4E73qX7Ecdaj/cHOXeXtE4lToV+XkVg1iXMaVuzOeWW4
9gPxQsTOHPn8Yy7ndHh/TXJ3/jue2IDL3llXpms4L8K0+s9+74JxxBnYk+jr
OrYqjBioiL3R6yskVgDz+rjb78O5nony2JqDB/7g+jduMafrP40lPQv+kN1r
ewtCSM/CXEOC/e8XxGwx9u0c1vx0+WjSFyNw4V7/9omjSF+Ce80P/+/8pCF9
Ceoyr7ZdD+f+bJTebL58/y+uZ6P1RtqbmO4xpOdI/hxJz5X0XEQMdNzWBygP
M6JjSqCnJoznMyKp6vXHTJXnW4rzjRtrEjzBpC9Fb/yBX2rXcz1P0vPE/dgy
tL0Ltbk3UR5lGdxz9hvvbqE8LF/Mo+SL65kJTndiY1l0KOkmFDRUZ/uaeH8K
pP0LMDQyrk9Tz/2Fkl4o1TdjRt4hv7uO6sMsnl8xi+dVzVL/LOJ6WKR5W/Db
/tK0bREjyW+R+mMV5wMrjvk1vaeT+bysYj7VKvltYj7YpPtiE++DapPul12s
B7u4n2LHf6l9A1kJI8hvR/yFoBEp1XQe5hB1OMTzKg6xH6pDmm+R1P8iqf9F
4v+iFon3jTlFhhNbd/RdKT1DeRQnalseaW/phpPfCcve+XOCdgWR3yXmhUus
p7ik+Us6K8bNNsPPmy/x+sVS/WKpfjEijKZU7Rli5hbzwE39fJEx6HdDM+zs
1p6DbwdZlZh5aP2HQYaH/pcv5Jd01SP5vZJfYkVi1Uu5GfsKxQ7zAg==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd01lIVGEUB/Cbmi2jTrmVuc+kuUyjM+ak4/Z3XHLXWbSyhxYQA4vMbFEh
L9JCpKW5PKQ9SAumNmKbUEiWqYnYQ+I8iAgxtGmLoWVpaYXnC2YuXC4//txz
7ne/83kfOKLJs+A4Tvv3/vdkl3P2g8edBSIsazpm4e3AmFDIzOG+8XJzxV1v
8mrIs50nUnKY16G9eO+V+hXMjvATB1cNNnmRN+KN/n2oSsbshto97Qr1dU+y
F9zqTtvvsmYW4aFIBrXSg7wZC99bVjbku5N90T2g/OxndCP7QeGamW8TxRyA
WY+RurFKV7IE/eO+ee/qN5GlCKn6NBfb40IOxkTO65LnAmYZ1qheTGYUbCTL
oZwy8h0NG8ghuDn+emT0hzN5G752abTiaOZQrHoqbpJ8dCIr8KhQMqe1YN6O
0pLAdwYfR3IYrvGjpUK9AzkcadvLu4xSZiWW98eeHAGB5Z3Sydr15Ej4Z4gd
Ew4zR8E7Nv/C8cV15GhkHQoY+ubCHAMbh2cnCz8IyUCHa3vXq1QyD7RFig76
9bI8Fg+nq4M2DdtRbmZOhTjdL8XKRJarsDVKqnvy1pbyOLM8Djtz5foiEasf
j+Tb+lafJtY/HjcGr58QFLP6CbAtkkeMVFA93sxcIiy8AuYFbTaUJ6JvRqjN
PUrmdpia34HcwJqkl6cElCfBc3F4KGx6LeVJkNyzslZcWkV5Mu2HJeXJtB8W
lKeYmk/Bl/D5RZXUmvJUdOqP1En3rKbczFwaztUUKMs8qR+fBnWlLNDqrBXl
6Sgtn39a0Er1+HTUGI+VqebY92WYms8wq58JcUqDIbeFrS8TjQbBz1uhbP1Z
pkYWWmJ7+/pd2P/OMt3vHjNzauy+eqfZSULzBTWmxrecCaog82oMGjbPLtjQ
fPaoUeI/8DMvk82jxnTeoDGdD16DQ6rqbrtm1l9jOk+cFkucemlfMXtfi4vy
vPHGfay/FvH8qd+y86y/mTkdCg0zz/Z70/mCDoHuzi75+8m87v95/ANXK0Lp

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAGIQDQNioVt3b8xWcoDwPtjXaIfMqRCA8RkchM+Z6eav
UoTyORwqVk+v3OQD4ws4NJ5KeCz6SQHKF3EIOxszU3YKjC/hcOOj9etOCxhf
xoGXfZm80VJ5KF/BYdrbSdns5+SgfCWHoEtsG2tNYXwVB/3E+am25bJQvprD
ZJMl8aePyED5Gg5Tqxr73rLC+FoOCZfkt82PlobydRymrm2POHxSCsrXc5B0
/y2lYgXjGzjcmHbDXvOoJJRv6PCO/cjk+W4wvpHDDcFPkpklElC+sUPZRrlJ
oXfFoXwTh6V3Hl6++kMMyjd1CAj6Jr2+CcY3c1gt+E5CbbMolG/ukHx7z57l
b0SgfAuHjT/6Xko4wPiWDt6bP3oFmgtD+VYOV1K/cWrsFITyrR00/ZRFXHNh
fBuHpidJvU/WwPi2Dq/vqLfoNwlA+XYOkbPWLhTVgfHtHcKjjNYVKfFD+Q4O
OU4T9vIt5IPwGxwc9h63eqfxmAcq7+gw+xr3z2Wm3FB5R4cJLcw77sdyQeWd
HIx73353PMAJlXdymPi4uNrpOztU3tmhdt7lPWIPmaHyzg4+5vXbH+tB+Qwu
DtzMa6teTWaEyrs4FK+2tt+0iAEq7+rw3vLXPye9b/YQeRj/GYTP4AbV/xEq
74aqnsEd6r6fUHk0PoOHA5OC1i/u1X+g8h7Q8PkPlfdE5Td4otrH4IVmvxea
+7yh/oCCBgQfAIL94Yg=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1XtQVFUcB/AbiGCAIo8FgeIhFNqKBYGAIF9AEXkuj+WxwLJjWppMgKA4
GHRVTIyBxMzCByIIWApEDoGAsokoxqASA9NMNOTQSILZEiCQBNXwO3/cuzM7
O5/53t/v7Dn33HPttqdF7dTiOO7j/77//7KPRN7Y2rDHHovS+Ba+m1g6ocfM
IU8pz4qotiPrQa+9ojIhhNkIDx4aBj8dsSWbYvcX79xtzGe2QExpRcdjR2Zr
6F16Nsy12JBt0Wa8I1dlxGyPq9yU5+fKV8kO6C4Y6RupeYX8Gs43jpe2/2VN
dsKRnEOZvrHMa/G99c2yvhYrshTr0qrzepyZndHwc9EvvUctyW9iSne0+r2G
VeS3YHXcq37QgdkFOloLbY75FmRXmHTYrTO/YE5+G91rPvjGek5CdsN4U1T0
6k3M7jjzg3FLeZ0ZeQMCpP0PtI8ye6AlXTodrcXsifBMo4OnO03JXpirXGI3
8pB5I4xr+3dr8pi9IVtfbp9lwewDY33ztsdtJuRNkGqK65o+ZfZF93eNX+1N
ZwaqvFy7as4bL5oHMhvqj8tyVlLuB8/7reV3fjWi3A9jg6/nrz9M5vwhS13b
PbWK5f6YmG9JOKzL8gCh+QDUW11t+jFkBeWbcele5X79rOWUb0ZAzJy7TiCZ
24KVT00lGgnLt2DAsGDXbLgh5YG4cdfrmdOwAeWB6JxYEa3IIHNbhf34rcLr
uSBRHoQ9Xc03+67rU75N1H+baPxgoflg4Xy4EOF8+RAYmNzKTn/C5h+KK972
u5w6WB6KsMA7nb/5sPULwwIXuaDKYnmYqH+4qH844hQudXvtWf8I7GuVeXvM
sPlFiMaXCXPI8Nzw+qE5NzZfGXosNaOnjF5etFomWr9I4fwRKbyej4TijZKg
+wdoPdWRWB18ekBxmXIuCmcH9Ger3ShHlHD9+Sj0NvdP/jTD6qOE/bhoYT9E
C3M+WlQvup6Lgc18T7eHhtXHQHOt959cs2VUH4OS4cyD/tO6VB+DPz3/nvd3
Xkr1ctgEhXlKvtahejkWz1Mtqpcj88pG328rOKqXw7Xoj2k/9azvYn0s3a+F
RUNkPlbYTx0Lfe3anNHPXqLx45Bb1tcmeaRN48chdMNHTcPOZF6Uq+OE/bh4
oREP6bUlS92Lab58vHC+6nj6/7Q+XAK6On2ys1r0qD4Bs9KTH9aksvVLEPZT
i3JOgYa6tFPOiaxegRP52s1DyWz/iKxWiPZfonD/IxGp/iduLL/I9nui8HlR
JwqfJy5JaCQh4UztRTMpO69EVifBMNV4rCCDPZ/JsLIY/r3kJBnJKHTZOXhW
xeqT6f6z+mTcG3CYfGHAzlclnn9SZ548SYYSpe012XIpO4+VKCyqcqzVpvNa
rYSyIPCJz212fqcIz3+k4FjO7QMz58h8CoyOZewYqiCrU7A9fM3leQP2vlFB
68sLL4J4sq0K7pbLKsfLyVChtLjs/Vv7ySoVhsZq9sWdI/Mq2h/0vitXoWrw
UV//jAT/AlevONg=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0k1IE2Acx/GxViu25evmVnNOM7E5rE1nLrX9Nt2LylBbZRsKZu4gCaHU
0E4zKIo06dDFTlENMmvkGhaCZBhjFL049RAj8mAdMhpZli/Liv2fg/7h4eHD
lz/P5cluPXPEzeVwOKX/zv+bjeRYcOzR6RwkFDMEfPG5c2nMHOgU/rfHR7PJ
22FPGRm3OJmT0fZxfbI9riSn4809tyzkZ5ZC5pamPnYzy2HxNAejYmYl1Jff
2QPdWeQcLJTnf1icVpBzUcqVjoWMzHnojYe/x+szyfmofuLhneqXk1WoWx3s
ccZ2k9UoymjNG/YwF0Kc2axycJkPIDL8+ZWwfRdZgx2d9uT5CRlZi/3rmsCX
LcxF4Mvb5isGpORi6K3TGPFnkHVYvGQ+YdYyl+BudC4y81tCPohg0/mWxg7m
Uszkd5z0jYrJesQaIgM3SpgPga/gHZ2cSiOXwTF7pW8qk7kc4017JxSCVHIF
wrO5P1aFKeTD8O2peV/8PJlsgHPwwS2xmhno2RdadteRvUCjS/uwKyeJuhH1
HaqXP2WsG3FV647ebGH7JtwJ3/YIzu6kbkLKQrokJiFzKvFiMcnh6hRSr4So
S1sWuSCiXgWuUrUiuM96FZZET3vXdGSOGa6C67bX3QLqZqgDvG0l1/jULciy
2fWSoa3ULWjo0xTwLvKoW5H431zqVnpvzZDoNhT1f/1lfLacsNe2qVdvtLca
3/Qrf0yFS9RrNu3X0LtsajfaW0v7nwx/AYWb0r0=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQNioVt3b8xWcoDwPtgXG1SGLOKE8Rkc5r7Qfbxw
qSKUz+Ew1yB//RlvGF/AQbbizv701wpQvohDzLbVB+fOhPElHPbdmR7QaATj
yzgwSsT+XbNGHspXcGg6Ea0X+UoOyldyuPrDqVnfAcZXccje/4PHuUEWyldz
cAhImhH4TgbK13C40Sd47YEMjK/lwNV2eJnUZGkoX8ch58FEf7VDUlC+nsNZ
qQ+vpgjA+AYO3KJXS/ZPkYTyDR0enHgtmCsO4xs5nIpb/2mfuQSUb+ywUyYy
94SqOJRv4rD76SaZ+8vEoHxTh39F31U5j4pC+WYOJTsPKRz2gvHNHdbJXlbS
ei4C5Vs49BWUrooOhvEtHaaq/o1kmC8M5Vs5BF/r7LkkC+NbO8zcv7w8VEcI
yrdxsDHyaedLEITybR1KNadMnrRJAMq3cyjdHWBj8YMPyrd32Hvc6p3GYx4o
38Fh47r8KXrRHBB+g4PDe8tf/5z02KDyjg5tE7OtquXZofKODrXzLu8Re8gM
lXdy4GZeW/VqMiNU3snBx7x++2M9mLyzQ3iU0boipf/2EHlnqPnPIHwGF6g6
KGhwQZN3hfK/QfWj8Rnc0OTdHJgUtH5xr/4DlXdHk3dHk/dAta/BA9U9DJ5o
7kPwAU/EymQ=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l9Ik1EYx/HXKVE6m6nZcjbnSg0XM13p1Gw/deqca6KyxFk3VlSKWGRo
RfoiCl44tNSCsroIxbIsC5c6iRIMbyxKEqkoqGFolKMknaX9Yc+52A68HD58
n3M4F29EaWXBEQHHcan/vv87WyGmAVt/uRwuOTTOUfnlF77MHNYE2mPO90SQ
16Ii2cc0bWQOgOnwq/vRDhk5GDdtwXnl15jF6C9Tn1nUM4dBGDRafWI2nCxD
UFdv0/d4ZjkKhy6uXq2Vkrehu1ElnX22hRwFYWTbw6485u349l4yUtsURo6B
5ZBGvPJRQt6BaF5+fL+WWYnEFNNTxY1Q8k7cU0jVWsdmchxqKlrUpwuZ4zFy
qvhXglVMVqG/r7JdWcK8C+qxunPXhzeRd+PtH4mtpIo5Ad0rPeFRnSHkRFyR
DYhmPm8kq+HIn2zpSGBOgk7f/OZBcTA5GUc7BFX+KuYUlI7Lh1V8EHkP+rLn
C6qFzKkoq1qyehUFkvei3l5qsd/ZQNZAU7RwwChhBr68i26IrQ9wmQdybvXd
juwUUU+D1dEaGzqxnrqHuXSM/RAVmk8KqaejtcF78MNBX+oZKB8ffDw55Ec9
A1P+TcecRn/qWrwcfL0wvcS6FmbFBd3zGjKXia36S1PmHrqPz8REqGOuPYDd
nwWV5eti2pN11LOQ3xyn8Gn0oZ4NP++7Z+favKhnw/W/C6jr3Od5HQyJdY8+
Kb2p57jP8zkeXQ+BLGbZr/e3xtX1Hj3X3XwuvdfpmucMHucN7u/l9mE+aXk1
XTlDnfknnTfSHMf9Bctr7wo=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd039MjHEcB/CHOp2Kiuskdf0SojWXfijUu0tXrnO/G6uzkZkfrZWwVMNj
QxtKbbEsP2dUqNUaonBHDC1zrDQzMb+mMYmpnSOsz/eP557t2bPX3s/n+zzf
7/fzDcktMGyYyHHcqn/3/ye7pFlXOlrzQjGuoeTBcxPGvvowc/j2vGH95eYQ
shjD+rs1z7TM3hBp5U/H7MFkCfIHGgZra5n90LplccmIijkAyqoK+7WXQeRg
DAcfc2j9mUNhy+1/Ii2RkWejTq5WtPcHkudgY6r5tDWWeR7cRUmKns0B5Plw
uPxp626dRY7E0aby1Xcf+pOjUGI8GPlgbCZ5ISqP95YVZzDLgYHdOT5KP3I0
mjJefCiawLwImse6rvpNM8gxSJzT0n+5QkqOxdxX+rM7RMxxaCzssW2q9CXH
49fUjcnWNObFyNVENPzxZE6AwmqULQiSkBPhJnM1dT2dTl6CiNlu70bSmZei
sO/7nXUh08jLoLz5aQtsPuQkRGjCJGn5zMkIvOToM8czA4eiN7ysW+s9bh5Y
lR3dXBTqRXkKfD5LpEPSqZSn4OeU63sdsZ6UK2Br7/3RP+pBuZO5VOH7fCom
Bs+3e1xi9cud8uUIUx3ry25wpzwNB6rzEsuC3ChPQ/XbbWWKETKnRGtzQU1U
jphyJSLbXCfFVbI8HT3+Q4M13jQen46hNtvvXb6TKc9wyjPw4N6y4u03aDxu
hfB/+BXQH5YvcN3vSrlKaF7l9P1MlO6xW/MuTqI8E+r4PdfeRrlQrkZ9x3Pp
owAR5Wrh+9xKp/qVwvXgNNh16lmn9A2Nx2uE43Fa4XrxWqf56bCo4stIioXW
AzpU7XNpH1jD5qsTzt+iw73vXsbsrWz/9ML9hB6pJkecSMn6RS/sJ4seCY87
ztx/Tf3GGYSGARfCVC9i7rB+NOCWOdwq86D+thgwmvlevFfN+t2InPTb7vYW
Mow4VHE+vMmFzgdvxDSPGZ0fOskWo9N5MuFjxHCJXEeGCd1XrzQWFbJ6E4p9
67gjF1i9CbLr266Wd7P6LJzke0u9mll9Fsxif742gc4vn4Xy0q6doyck+AuU
1GC/
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzk9I02Ecx/EnJZPmf+dc23RzlYjWsKXNbdo+zunKVQfRzJWHgg4xQSkx
s4O/KCWIwlWbhwIxrYyVmlFmaQc9RKUXoXWSslGmB5tESqL2h32fwN8DDw8v
3jzP8007UVt2MowxZv67/518ySqevnzs0iKkoEUfW9ZkUnAzyKNbheZXaeRI
tMwoP1fWcMdBl/7WcVfKLUVtf0dW5AMNWQ6vN+lKw1FuFWqq+lJnYrg1aJ/M
sfe61GQtjk9/WnJ6U8nbIB2LsEuGUsjpGO/3HLp2ijsDP9ukVzOmVORMBJwN
tnI59w68GA4GdjYryTqUXx4dr8/nzsbClOOZ95yCvAs/pls6D7/fQtZjKcEo
06i5d2P2yETjfKOcnINO7W1V3UAyORdue7Ku6YOMvAceoaAr3sptwJeN3sXB
9iRyHrKrL94f6ZGSjfBsX61iHYlkEyIqNjwJjiWQzQgMrwpZBu58pPhW/McM
8eQCKOWBb+7rceS9iEocPVs3G0u2oE/5cHDSwQ10v+lqkNTHhCwAi9FDF1Zy
o6gXYuS1aT4jQBYKccsv+XUvV0LdiglFcO5m3GbqVmwt9fqdPWRWBPXaxLu8
IO9FaLsU/vxjNe82tLpdpvPqTdRtOOMzWwbuMOrFqHTqe09rf1tCvRhhmsxl
iW8lZFaC78blNatukXoJJOGPmuZuLFC3U/9KXWS2j/6hJYjM9ovui8xK188j
lIrmd4i6Y/287IDofZHZwf/+Azcs7ng=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H1M1HUcB/BfaiAa8ng8HCAClognxtMBCd2bE/B4fjjujnsAXItFgaNE
NAztV2NKCQQIMiQqXSoTZSOX8rDYj4CyMdqwJJcPrLDNLPXEDoUJq8bn+8fv
d9vt9trnPt/v7/v5fT+fgNfKc4tXcBxX9d/3/1/28dB9PdhbGohlWVXVdZcb
Ku2ZObj9qNxafi6AvBr7rO2nBlKYnfG6Q9Vm+b0NZHdc/eHXgY2tzF44X3Dc
Y28Usy8qpj1t+kZ/8gYY6u+8vSCsJweien3T0AFH5o1oC1Wc/UPjR34JxyK/
LBof9SUHo8emObTFiTkEvkPtdw6bfMgKdDZ3fFFTKyeHYknn4Xf0ujf5ZVz6
5XGk6/de5DAUDfPea9yYw7HLqJ9vK/UkR8B48EFSnc2DHAn74aBPFX/LyFE4
3Vrh0g9mJVwvXHvTesidHA3T7A3li4tu5BgU1ib/GT/KHIv06Pcvz4Qyv4Kw
AZ9Nv1e6krdjc2aQe9JuF3Icfi6ecwjuZ45HQMIbH1UuOZNfhV/3sylLNIur
4OM1c7epmcWBv25uqtn2IZkHjCcunJQpWDwB3XGBJcEjThRPQOVgdlzM03UU
V+OStXGbfILMqzHlWFsyn+lI8R3oShgZ+86bzO/AnGP/B8+iXqB4Iib7rv1z
/elaiifCf2liPMa6huJJmFc0V58tc6B4EqwXJxcPyshcMnp7yltCzaspnowr
Y/H79w6QuZ3w12TEepx7nuI7obi4yk7ZYE9xjdi8Bo01K/umC9j+KQhKPT5l
6iLzKeLn4VIl+6diQm691+LM8tMkz5+G0it9Qz/103m5dMn66Yiov/8kQWDr
Z4jNZ0jOlymuB58pWT8LHVNr589EsfpmSc6XLTayJftJLGSL1+NyxOdDDppm
Kt5TP2H1zMHD2IUldagd5eeI68XliuPIpfu/kvJzaf951XJ+Liq6t6u+OsVR
vhbL82sF5Wsl71srfh5BK6lvntjIE9ePzxOfV8iT3E+d+P/Qie83rxP3g6CT
1F8vvv/QS/pFj7HHTlrTO7SeoEeZuvGbdSdZ/xlgMIX37Amk/oQB2WUh4zZv
1s8GDMpbOvsfkgUDtroEPzoxyfo7XzwPkC/pd4mFfHG/c0YcDS++2bGL5Rvp
/bD9jeJ5JRiRyL+7GHaEzSMTrqqaV3neIsNE75PmHW9C2291z91+RBZM2C/r
4D45w+ajGb2z8s8PlJBhxoPdo7aIOTJvhrBFff/8Hpq/ghkh5pixoSw2ny2I
sw3friskw4Ly+ipvt2Nk3oIiZbzdrQmyYIFy1hScNs3yCzC+cPfjw6dZvsR8
AdobPnvr230sv0CSX4iuGyOtnVMy/AuMNAIX
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVyWtIU3EYx/GjhmVGuKnL0jU3ypYsza08blrnt4uXqIYWIpRkBScyV4ky
GLZwBCUY2WVQUBIzBQmrZbV6sazohUWWI8LVKMGUFKLLvEAuyi7s+b/wgR8P
H77K/Ud3iLEcx+X92//PTlbp8/fWqRBVWLAPD43apMwchkOcgnusJC9CrrvT
OlrDnIRDse/X3I5hTsFWThpI9GaS0zBZFvn0ZTtzBi6FTI6WKQU5E57mtva0
bGYVThzefVBSsZK8Cq1WqejulJOzYL5XM9jvzSCrkSyKFTt1zNmIKZ9O4C+m
kzVQzL0aKAivIOdgotfpmGliXo+X+ROLK4eXk/PwLuzp7Gtk1qLWf67WF0oj
6/Bij3fqEc+8ATfeyke6u5aRN8LOZ4k+kTkfp87XGY4pmHm0B1ZviW+VkQtg
1gwF4k6mkvXwCQdmnbYUsgED933XG+qTyYXo6HqeejYoJRehPjj9dJ+SeRMs
LsfvvBYJeTPGc1W6I2uZBch7fgWreWbM7y5AqJqptqazboR+0O/pH0mibsQ6
iXry8msyZ8Jprfjhyl7WTbD7y4sKZpdSN6PvmeGbemwJdTMimgvOblsCdQs0
dxfE57ctpG7BNr75wVhOHPViHL/65qHsI9lVjMaeQuHONY56yXy7SlC1S3ur
QfVHiPZS6M58/WF8EonaVYrv+p9zppxx6mVIjLvZ9Nk9KfwFb3zC1w==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtIU3EYx/GjlkbTNC/zMm06zURq5qbmpmu/OTedNvOWhd0k9IUYqIUg
prZ6IUFlqEGEERQabVFhGQYaFakhIpWixaBgaAaGeZupS6TC5/9i58Dh8OF7
nv//iThTmV/mynGc9t/7/8se4ZEXvV0VEmxqXt2aWilyFTFzmAuY/VzUF0He
Bmu/59HxEmYfDPU0xEvcmf1xtXn5RFVnODkIXaKSGzl5zKE4fsoqf2oTk8OR
39Os6I5mlqB+8OOkvHAXOQpr7SvmSHMYORpJ99vudQ+HkmPgV1aWVyBnjkVS
eb+1vUNE3ouWH1Wll2whZCniihIiF+3B5P1oDAvsXPweRI6H9PazuZPrgWQZ
lpp0x3QyZjlMNWq7MlpITkB56XJt3J4AciKCTveNNuv9yUl4XnV+qbjWj3wA
OtVU/QeHLzkZt2zXXL4tMCuw2uHROKVhVvKcglF165bArzvJqTyrMDQRZf/j
yXwQRv3gwJTKh6yG11nfn1eqmQGD+Yll9x3vTZuAmt7c1OTVHdQ1eKh5NzAY
7EVdg30qaeHraTKX5mxTGl69V/6KmfSkruXNazGw5F1QXM16OsQbI8PJ89up
p+PTy3H7l1UBdR1cw2Mdgkf0v0kHr3OylLHL7H69s0163nwGbz4D7ROCtQeJ
rGdiJGR+5qYPu59nzoA5hWMjTepO3YC6i463FRYyl4WmlgrlBbEH9SyIM40K
oWUr9Ww03B3rE9rcqGdD4Pa4bqbNhfohyK/PrmjerKk3O8+ckfZfp26kfX5T
z6HzFqjn8Pph3jzPXK7zPsh1njcxT6v/AmgfFuY=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQNioVt3b8xWcoDwPtj3yD208uOG8RkcMnZo+h/b
qAjlczg42S8t6guD8QUceBo+Tbr6SQHKF3GQW3g0tGEKjC/h8ORUxaO1JjC+
jAP3xC1RaZPloXwFhy1y30Mm3pOD8pUcqvZ59yw2h/FVHBbGrK9ljZaF8tUc
mmTqBSdskIHyNRyMMieWnGCH8bUcPsX84HdNlobydRw2VS2daztZCsrXc/CL
qDb8eE0SyjdwsLXyNFRKgPENHYQLvA/m1UpA+UYOJbcWnxC8IQ7lGzu4pj7e
3DNDDMo3cVhZcPZiRp8olG/qIHM7wkFgogiUb+bQwnLyFMd0GN/c4UmWptXf
dmEo38JhcuqHyTHLhaB8S4eT11S+/OYRhPKtHHZLTZm7870AlG/tILv6z7UY
c5i8jUNAjtbpr5IweVuHvcet3mk85oHy7Ry+8e5s/GMK49s7TGhh3nE/lgvK
d3A4+pk/OKoQKt/g4DD7GvfPZabcUHlHh7NSH15NEYCqb3B0MO59+93xACdU
3smhbWK2VbU8O1TeyUHew9dSbBUrVN7ZIbDHUJullQUqj8ZncHGonXd5j9hD
Zqi8C5q8q8Py3dfFTslAzWtA4zO4oel3c+BmXlv1ajIjVN4dTd7doXi1tf2m
RQxQeQ+o+o/2EHkPh/eWv/456T2D8Bk8oeoYGAAs3cQ9
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HlIk3Ecx/FlkeZKnc45nfOYmdN05pV3frx1zrnNwjLD1C7STtM/yuwp
OyzIUKxAEzpQK2NgBx4zsySDDkLDER0QXolFLfIPDZOKvr8/5mCMF+/n9zw8
e76/x7Nwn267BY/Hy/r7/ffLPqINDwztxTL8lyluyNp+f6iAmYfyirvdNR2e
ZCskhm49V7qJ2Q6La68pVi9iFuL87y1dL1o9yGKg2Uk1pmJ2RfGIemnllDvZ
A3cGbkVopcwyGBrzP03sdiOvhOOp8WHJEyl5Feaqui83BjHLYeH+M0zJuZL9
8LzN9mXvgITsD6NVZVGWK7MCuZ9VqdIqF/IadBosXpdaMgehITW4XJzjTA7G
ocioaodmMTkEGa3nNvJtmEOxbbz0/tloJ3IY+G+mD8xXishrMSwvKWjpcCSH
o/liqaALzBEoet/T0/pVSI6EJvCq7JCYOQpN3PBhW70DORp5VSG5byftyTFY
LRU57yxgjsVQXN0Sp48C8jpMBMpC9voyx8EzfufZsnk7MiBtmzPmhVPngPRb
+tveV2ypx6PMoImJmLGhHo+c3GD9QRnrCRB8FYpMItYT8PBZ1Df56HLqiebm
EnEzvv/pgPMK6kkwrqjeNasmc0mw8PD7xW9j65PNzSXjlYtpqt7OmnoKZv3r
KlpLllFPgZfykjH3JuupaDTyZ1vC+NRTMdg5PP12hsxLMz8fl4Z2/b56xWYr
6ukw3Rv8fdSRnT99QVfidG1x1BF3S+pK8+N5GQvuPwMBsYr1jybY/avQFiPb
Je+n/5NT4csHn5OBJ9jzyYREPDpZW0fmMhEgkP9oGGRdDYNLfVPXd9bVaPFS
vgt9wnqW+fPnspBneb1BkszmQYOYYNUZm61kaBbMg8b8en0a+Kq9hMl72Hrt
gvVazGSMWx1X0TxyWgR1S3xGysh9WvTmeT9247N51eH/+4cMnfk8czqowo91
jCpo/vt08DfV6DsusP2Qbb4/kA1xfs9QTQrtHy4bN8ZOFSbuEOIPRWgvYA==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtI01EYx/E/G6Y1zVnb2rzMaRZmuUrTXHPtt3mbt6WtlilYWIPQF5Gb
WUYwIqSMhCgKLFKUtHIhCpqmJhEbVswgI7q9yIgxRWhlmBloxZ7Tix04HD58
Oc95ceKqju+18DiOU//d/062JPv7h3tr4uGXT9sUcznNI2TmUH3SNOMZiCOH
INkbu0JRxSzEoQpx+3keswgbHM9StnYqyFLMdZgbToM5GhWV71N7pmLJCizU
mluDZMzxUH5fH15ZJicnYNDUzh+7FEPeiHneZ2WmO5qciKX6Y66MEuYkPL81
3dVSF0XeggNPvLrQrkiyEsHvXh79wGPehre+to5Rq4y8HSPWg7/TB6TkFKjM
ua0XBcypsKW6NHXudeQdkF+ovvdDzJyG0VmTcU+HhJyOF4vepsY7YvJO9PU0
yqUfReQMGK3CM9edzCr0LjRPS8G8CzVlwaVHbqwlq7EpIfjLzzzmTPj/bw1Z
g9eW+ZWJQxHk3VBNDLe5PgnJWixzpcuHbeFkoCfK8fBVIdmOgK5D3XBJZsbC
auoB5vQwOppzLP1h1PVwzoWbyk+EUs/CXd1Tp0vGehYiZkUSn4Tdz0ZYbYp6
8hzr2agZH3w8OSSgnoNkjXLfmIf1nID7ueApkhYF3fSePcBcHso3XzFMnKJ5
9jzcfCP41ZnG5hvgjvTNXBOuom7AuFNTb3sUQj0fsYZileR+EPV8nL09OSKZ
4lMvgLVbre1r56gXQMB/0DBz9ZvW3wvxVbW4pFd6/LYzz1MvCuhFNJet4v/+
A3ey4sw=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n8s1HEcx/Hr9IP4w+mOq5zccaXSya9TUl5+3XF3zo9o9IcdpS3CDcNY
Oa2mwj8kpR02P1tTU5mRMpr1R2OFsWbMiTaaFZeyyfqxPu8/+G7ffffYc5/3
Z/t8P+KUrNhULofDCfr7/vvSYx/f+bIjXYL/+haYV5aim+GROeC7jk596RIz
W6KAbyk/H0e2RYY+zku26szMx2uxeelZJVkI0WPznWR/siO82t51ZAwcYHbG
4ozDXKcFWQLTDq/cEbUTsyu4LxIT1o0i5oMw65qMchuyG1Zqzynn1Y7MRxDL
0/3Kq9vP7I5jWS3XhmRkGcbGI99nq/cxH0ex6Ld3ZuZeZk9cv7JU1johZPaC
1Go4QTbvwOwNp1tpj74LyD4oWRD3zUbYM/uibfJNtXFcwCzHxM7SCdEKn9kP
2hzbonuD5BNonLuZEnKJfBLDyQnL5o97mP3RpW9JlAnIp7Cmnrcs0dgxB2B3
41qSYpDHfBrWFu2Fi1XkMxhL/WHl1k0ORE7H09vRhWRgJLByu8MUswHQj5sH
ksU0PwgP+lrz492ZDUFb9g9GqrGFW9RA64MRaijY8Cyl+SFQvFpIwwfqITis
deGHZVAP3bJ/KGYfyn0nq2h+GDwVtd2qIdo/DDWm8m3Ty9QVSE/YFXOhhp2P
QYEnyq+x+TZ0Xkqony+rYvyoKzfP44SjrKJZ2m5BPRzBMt3dbB2tj4CdtUPv
517qEdD4FXd9klFXbbZBhWrpRiKnnroaV+tGe+1N1NWI9miQ5Arpf2vgM1KR
L+1hNmhw9K1wtclEPRIBq/3T5UnsPhki0e9yw40jofulRXN1Dq8b1LW4fHG1
wOMQ9Sj06N1/nuVSj9oyPxrc+/Xr4QYB/gAcN/4g
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU1EcB/Bbaa/5mK/ZfOS2Ip2ZOpevNes7p7Om7lUmGUFJoqHQgxlI
EZeosEKTHkZWkKRpaIKIoomyXMsijB5kCIFgI8Rek4iaVlb0O39sFy6XD1/O
+Z3fuT9p6UFL2WKO4/R/339f9oiKege7K2X4L9cW6dUNm+cDmTnsTrXETnRL
ycvhkzgxcMnALIRv4351pVtCDsXb6ckrQc3Mq/BcWBrcqmWOguNb37PhqRiy
BOdCR4Z4I7MMye9Pn/81upq8FknOGwd0YczrMDGy79itwmhyHKxfIpRyWxQ5
Hsb5pppdrkhyAi74z1yT7GRORPGDaY1fWwQ5GTGOM6/fvBeTFZhXKrvCDzCn
wJqpqg1pXUVWYjagyC5PCidvhHXurkyhEpFTMfmhrbr4Rhg5DXcPjb2oqGdO
R6lB3v7bjzkDN/vVuy91hZIzsWy1z46HL0PIKiwtWtTjsgeTN0FxPzJ2qppZ
DWGCIvLZQhA5C4W6Rw5nlpC8GTXyUXeZkXkL+lwNSRFjAWQg6GOoyCUi88AC
Z17Yaw2kXAPtjp9pvjqWa+D4Gri95LAf5dkY96+tcBv8Kc/G0Kjqc9w7lmvR
oZZVxNlpP16L6kGTOuMHq5/juR+f43keLhfFJSldR2RsfS5antw+KrCyXOdV
X4fr4wL3nVQB5XlQ1n36rrGtoDwP7oSLx9uqyNxWr3wrxiJcM5eFKynfhoZT
S/on95B5L3N6rNE3jpe0s1zvtT4flY/7h18N0Hn4fK/+Cjz/B1/g2S9X6Nkv
X4h2jd3xSEz9cgbP++a9zBm97teIxZL4OUEHy00wdNbnlvXSfjBhV9O95rAE
mhfehKrshqGAZqpvM8FUFf/0m5jNkxlSTfnZ6t9kmBE8bRvpsNA88macdJbW
OTvJNjN+tCw74dSw+bVgfbRIXL6PDAvye2b15vQQ/AGtqyRA
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCwBGIQDQNioVt3b8xWcoDwPtgHmm08c1kUxmdw2KL2YIvq
IUUon8OhUS6S1ycJxhdwmG3S1NfNBuOLOHwrmXHeeYMClC/hkFnB4lIRD+PL
OGQ/8mOreyUP5Ss4qLLM/K8tDeMrOcy+3nxPWUsOyldxOLNhql9fpiyUr+Zw
ySTq0/PpMlC+hsOME24BUg+koXwth8cPdDZbG8H4Og7e1jWeIklSUL6ew5S3
VZPkL0lC+QYOTrv/dLnXwfiGDq7rH7RN3CMB5Rs5fJrB/a/nvTiUb+xwqKdf
cLESjG/i0Dj3QrxkgRiUb+oQb2bLdvesKJRv5vC7cEG9bwaMb+5QfbWSlyFB
BMq3cPiZWPy3caswlG/p4KSXMKUoAca3cjB0m7XT66wQlG/tkDp3GVP1AkEo
38aheLW1/aZFAlC+rcNqG6UMjcP8UL6dg66tXsj+Z7xQvr2D35o+19StML6D
Q/aJHfsu7+SG8BscHM5KfXg1RYALKu/o8GHzxb+1opxQeUcHeQ9fS7FVrFB5
J4faeZf3iD1khso7OUDSExNU3tmhqv7XwexVbFB5ZzT9LqjqG1xQzWNwdXhv
+eufkx5Mv6tDYI+hNksrC1TezYGbeW3Vq8mMUHk3aHgwQOXdHcKjjNYVKf23
h8i7OzApaP3iXv0HwmfwcDDuffvd8cBPqLwH1LyPUHlPqP3PoPJofAYvNHk0
PoM3qnkN3lB3wYAPnA8Al8TfTw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tIk1Ecx/GHXZo0sJXucW7TXagxbNhla+2i7bdpa85ZkFbvDGqlzGBC
0AsjWVBhmIOaJQYZiSFzCK0LWApGaVhQvfBF2AWSJEiQtOwmKyr2Py/2HDgc
PnwP52I4FN17RMRxnOvf/L+ywe+7N5puMSKrRc8bk2fP0QJmDvHZD3XFDwzk
PMjTVyHbz6xA0+XuZPibnlyIg9FbS8uXmFWwz1zp3+1k1kJz1jF+YFJH1uN0
vtkUFjEbYeHPNERspeT1uNFzQTXeWkI2IbHpaZIf1JLNUDXO5fUomcuwcey8
9FqThmxBkXtkYGpBTS6HZrI+Kgkyb8bIkxmDrbWYvAUvw4HQ4aSKvBW/J3Sd
d18Xka2wJkrS7b3MNpR2RJLLSuZtmD729v5UmCfboQvUOfkhJXk7euN9kUcn
mB0wSN69/5opJDtRzzlepNcyu9DY4f9UOVFAdiP9RX29rZm5Ap1dNzcMi5kr
8XNA1j7nXUfegeMpt+d2v4LsQarC2Gx+vIYMVDVk7FJ/ftYx4Ll6cb5bsZq6
F5Y7klX2uIy6F+cutrhO6sicL9cxH/1XSr0Kg6Ov+Gdackxgrjp3f6wap/qm
x/hZMfWdEOnLVuSpjCfbBeb8sHYt/PA+/EXdj8/OlT++8o/Ud5G/UxeYCwjO
Dwh6DeTi4bb5xBL1GsH9QcH9wdz9XG3ue2K1gh4S9BD9m+P+AveW45w=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzF1I01EYx/F/i2ptLTaby9R0mknZGpZZW2vt595XsMAcpo3e0FFpZSui
960LmxEFdRFWS7ICo2lTUXJUiuvCLPQiy+iqmhmERYIycgyp2HMu9MDh8OF7
nifrwLHiSh7HcYX/7v+XHZmj83lbVTYSGteNqYNxt4SZw9GPDsPj9iwyH74F
te8O7WEW45X7zdUdPGYpmhqCwpy7cnIKQhGZuc/GnI7g7ZLR5oFMshwV+cKn
kWgGORuXk1y35hxnzsG90lZLf8dyci60xRVh12g6eRWqA9ZnuanMeagxG8/4
XGlkBSxOnbzOn0pW4r66VjBybRk5Hx9+efljIynkdfgS6+JaPMzrIZr0/9ju
X0ougJdfcHHim4y8AZHG9w5xKnMhHJ/mXak7l0zeCM1hd/2+Dil5E3ZyqsE2
CbMKZXvD1vJdS8hq7Lb0CGKtSeTNeNnn+/zHw6xBzfBEeH8W8xZ0O1f2ZgiZ
tVhtXyE1HZGQt0JXOum0pzHrUHanpTFZISYDkp9S2bhsccJeYFhUd3DKLqJe
hKrXXd1DISH1ImROD7xVjQuo62faq8darbKk5zubN+BR/8NTwpNsvwFRUehS
vHARdeOs/UbYm6+bKjvZvAnla25YB0+zbsKU4ub5puqF1M0z7TXjrCfWW/Vk
PnULfqtj03ol2WvBhYahF7Kvc6lbcSKg0bU/4KjPMmcDT54XEwbiukS30b5o
wtw2+sdxfwElzs+1
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0m9IE3Ecx/FjM/9tmjM7p06dUibOpM3UqeU+m1ubU+dmCBI9qEDoz4PI
FkSBXUkUpVLpo/48MeifhpRZ0bBGfwyEfFCYD4uEoKW2hCxlacW+P+J+B8fx
4n3f3++4u7w9B5vbFIIguP+e/67sEFtGAvcO5COqsEU7vtfYF88s4Ll7orX3
cR45HsljwWvrW5hToJbmL03O68lpOHTW+vXLVWYt0o+H2rPrmXXwtqkvKKdy
yXro+jpSW2OZ83EmY8Fc484hr8Okv9PU+TKbXICPZs8z7YyOXIjAr4c/xI3M
RdhhuOiaOJpFLkaOdfmBeyGTXIIhQ47ZHs4gb4ItEDnn7GA2wunw71NGtGQT
uloSXW+HmEtxX+iXzqcwb0bxcExseU86uQyjM9s9TddFcjn8S7fzjVXMFRjQ
zGkLhteSzTDvt5i605krETTYZgfb08hVWNx9+PfJkTXkanQPJxiefkglb4Hx
SdaGT0eYt2JnXP/lLIeGXIMVwbeyy7+abEFSu6n63akkMuAZ7HG0jZAlQDOT
JobFZOpW3LK+eDWWwboVo6+r5gqn1dRtuPJetXijTEXdhtLu2Z/WYAL1WrzJ
DIf6UhKp19L7iqNul1uy42ZgShzXraLuQK6rsVK8Q5Yc8HUZDTGnY6hvQ/T/
VVDnLDjRUHHi0XSJkrqT6y75fpJLvp9Qx61fB4W+aEk1ELFEuxvfKpeWbSUL
UUtuqJR3j4V6v1Ovp/6Zej2ty44Gbr5Bfr/QKL9fauS6h5v3cL2Jvsci9Sbu
+bzyeXi55/XK9w96uXkfN+/j9uMc9HHvr1m+Pv77DwJOHoo=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GlIVFEUB/DXZplpNo77kk4qbmhpueXy18nJ3ZkxUSNEy63UVs0MlEd9
sEXToijTRNtk3KIkxSWZjIwQDZQUAyvRNOnDjErRqhXe82HmwePx48+599zD
e8/u4DF5xmqO42L/3f+fdJkkPO1+nCPCitTBbdtleR82kjlc9V6ICWmyY96A
+exyD0Uq2RA/BxxddDiyEA3ubZnZNbbMZkgyGk8cCiJbwWnUXNTfu5XZFj2C
9OJUQ7II6XlLT6IzbZjtIVV9C57lrZkd0VR1xnRuworZCY2Nv+5mqiyZXVC3
XFF1qZ7shlqVm0L41YLZHSXTiggTe/J2nG/uM0pIMWfegTfp4dGHFGbMnpBU
6843uJK9UNalepdy2ZR5J+KrlqekVuRdCMuYaiu7ZcLsjaycGbFSn+yDQXGS
+afvxsy+UMtGKm54k/0wplM6Zr0gZPZHce1Ij8mkEfNuuKmvtHZUkANwc7Js
1ft5AXMgpnr+8K4+5CAcH13sS7MjB6P3gMNzGz0y4DfUXdf/0XDFPBAj6X85
HcjMhWBxqSv53HrKQ6CfK/hy4QTloZDmugx8Nac8FI8smzuGozazXIz7r++d
1ss3YLlYK9+DdnWlh8Ug5Xuwyaiv8Pgc5WEQfFb2Ncm3sDwMMx4ir6POzJwE
diFZFwuWaH8Jkm+31Bu7UX97Nc/D70W3xfU7nSrKwzXX48O1zheh2Q8fgcT9
nq0nRdRfJHJDK58Z1FP/kVr7RyFC0droUEP1UVjmZMup+VQfrZVHa80/Rmu+
MSjolgb4fmf7cbGa/fCxmutxcRDv++29TkL9xaEpQJTt9IJyKYqcX/3IiGPr
Q6o1TymcY7cJw/LYfJRSDAdfW2s6QfOXYeX/wd4nyFDepuva+4GZ17JShsvl
Dxxa1tD7K8f0EWf/P6XMkGMoLWl+cZyZl+NskevsqAP7HpRyFBpXcxUPqT4e
Np2n2ksHqD4egpa3h9UlQvwFFHA4dw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0HtoUlEcwPHbLoWPHlrLzeW2q0aIiVRuTreVP3W6+ShCWYzFQApB0BD6
I8LZdhfRX8F6jPXfCIK0Pf6QCDQtmFGLjRltsYigVWaDiPVkLRGp8HeC24HD
4cP3PODIT4Q9/iqKogx/5t+VDEn33XQiqICKvphev+Q/PyogpmAhMDoZnZKj
eeA/Bd1Nx4hFMCAQLQyvMehqWKFDq+4YcS3oaJ/96RFiGTybUduEPxvRDHjl
cX6qjVgBt5bCivxIA3o3MDE3s6FQj94Dubl3NXElsQpmA3XK7HkZWg0lunxn
LrELrQHp4bA/KybWwkoievZHpA69DxxbrUnPFSl6P5TH61uOS4kPgMScD02e
qUXrwPBosH/sXg26CbKXhsU3FcTNwPJ0A9/fS9B60N/29Dn7iVtg3tojLazv
RBtA/61X5VomNsLF+evSHg1xK5x8lcnEPlWj28Ay7W3Y20jcDl7KkEuIiQ+C
ResbOe3bgT4E664Cb8i9HW0CIT0V+XhNjAYw5tI3Hr8RVcwCTLQrAqqH27Cb
4f5M66oqvxm7Gda2pIZKzWjKApcv0MnlPgF2CwSfJB8spoTYraB0ji71xkm3
wi/N1WgsxMfeAZHB4nRwfBP2DvhsLJYtWjRl45q1QSz9QjIr24jdzjVrh3Nj
ixnJWxp7J9dsJ1Qx6qJwomSq9C6u2S78n6/YHfj+B+wOvJcMJ9esk7ufcv13
3vVv/28cj9fD
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0GtIU2Ecx/HjRlFeppnNbS4vw4VZjNyqudT8bfO2i5qGKBaxhEiyjMxC
pHBZ2gsTBK0XYYJdyGZqaWFlSksczBFSVq9CkSBICl1Gl7HWBf9P4HngcPjw
Pf/neTgJFceLDwk4jsPf59+bLXHJw5H7VQosazHzScuP4EQRM4e3bQf1ZQ8S
yGsw/6lSe3IPcwQwqio+sBRPjsKl7tuzde3MEnhmTI+sacxyGKdstghHHDke
p597j/V8jSUr4LziHGnKYE7EZKSzuqd5I3kTgqRXS6deyslJCD/v9tvFzMlI
PNJYoqqIIW9FvTk6IKuVkVXovCErm3RJydtwxtU/E/xFQk7Bm31zuo+BaLIa
ns3V9+R+MVmD6+dCB28WMW+H+/WFplPuDeQdGBxojpW8iyLvxOHLgtowDbMW
BpWto8a2npwKq7Zh+L2KWQfLkNdcpGXehZbWW8o+IXMaWofWbhmbjSSnY2y/
0hkbwpyBLHvdr5SL68i7MSLruPZ4IYKcidJydX+NIpwMmO70O5SdZDvQm66o
TBpnXY+BmLvDryys63HU0DYq6hZRN6BHPz7hkoZRNyCsRp023UjmjJhYCt9b
fiKUuhFxgRee1MVg6lmob/A5qxyrqWdhQecLGFRkLhtnu6afiueE1LN5PYc3
n4O4vHyd2LGKei5ChH318+1B1HMhiE/2hfT6M5d7Hv2P38u25/G6ic77Rt0E
Tevn7/pnP6mbqX+gbqbzvNQtvHnLyu85K92Tlt3K6/kr97PzzBXw9i/gzRfy
7lf4f/4Pg2oJlw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/GDlTVXNnOu6czLCLMalpe8135uzs3mdFZampBZo0LC8pLp
kNaLrF4UGRIhFKbSRa2lJl00b2llkGKaGEihe1ORNEJ0rcyK/Z8XeuBw+PB9
zoHz/M/xz8nbZXDiOE797/x/ZYcorbWtKVcKh6xygTY9UO3OzCFMP7Ve0+tP
XgHF+J4XeQeZBegcHSudWsYsxEaDoLHvnh9ZjKwNIVeMOmZv8M9VH3/EY/ZD
w/3u0WNaX7IUsnpLbInZh7weu6sffvg5v44cgLOHaut+xDAHIndAxsuv8CZv
gvysi+f1QQlZBo+MoZLgaOYgTOcN6jJPepG3YtRUNdN6wZMcjI/pEyW9fOYQ
XPw9PNqkFJNDUWTfYO5/s5YcBp/ej7Z3OuZtKD1j786tF5HDMXlrJE3gxRyB
X65H5N0qD3Ikms3lPuJxITkKyQUC47U+5mjYbcqaYhlzDLJyJi2yz+7kWGQc
6NFk7mPejkstvM0dn9aQd+D5q/OfbGeY5bC0z5k2RzADI4YZXuBTN4dNgEAW
LBmYJ3Nx2K/udLE/pPWmuIXrOQUMN247GavZ/QpkLa+pkqhYV6KgIUbeXCOg
rkRRmz420uZKPR7JjZdVhtZV1BeZU6Guv/YUv5DWm1QYevJ+eszGp56A0EtT
s3FdPOoJsLYMzZV5kDk1KiwFRsXscupqmo8zdQ1kLUudwy+zrsH3KPsfRRDr
ifDV6KJE9cuoJ8LxvzhR34m9mSEP8qXzckffibKbw+2iiSXUtYuer0V5RW60
0ZfMJeGtl/VrpcCFetKi99PhbtyLvpeebH90cPsmFFlFbP+SYZY0Pn6nXU09
GSvde4pPfCFzKZCILZ8rrrL9T0G86fRc8Hk2Hz0Kj97pSBHRfKFfNG/9wu+p
S4/+kvjYwwHse0uFIii7Mj+bjFTkvJY+CzWRTanQb6mWFoqF+AsWnh3L
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd031IU1EYx/E7xZcw32rNmfNtiamVr5m5Sn9OnTrn3LSQjP7IEsRJltQf
muYSqagQUyFSkQrKqJSmiS6dtUSysEgGGiFIGZIVajgkzbRizwm2A5fLh++5
zz1cuIEFpTmFdhzHZfy9/t3ZEhzq6ddpxLBoIfG936nAV0JmDqO6buOaIZDs
jOxc/nj1cWYPNPscq1lbDSDz0Vqe/+luC7MQ+ob7/WUKZhH68nbdKfjiTw6A
uqPDfEPOLMaLzEjezVo/chDMlcpn5i5fcjDWVy4Ejc6LyCGI5z0ufZvAHAaj
aLDN9NSHvBNFCQcHA3jM4ehOcnJvqN9KjkT3eYfhqh3MUfilf+fuWO5NjsZQ
+5PWuGYhOQY93jNT5ikv8m4EV06MDaUxx6K1d+6q7wbmPTCVTOpHTgjIcRhK
X2wLHNhC3ov2/gnBaxFzPIzbakM4MbME6fJrH7oO88n7oPtZNysE836oIm6J
zwiZD+Bzcajk96XN5AREyZr18jebyImQGWaLMeZJBmYixDEnQ8la2PQkLF3p
9DpqZj3Jej8nxdnQpsaGLg/qUnyb3F4bUUPmklEirTe43Xajngzlo7rUwh5X
6ikYd71ctKwka1MwvOiem396I/VUGF5K5kKmydpU63mcDJ7f+YIFAZsvg2ak
b9Ckd6GehpZxl+V7sWRtGiqqV4yaB47U0+n7O1C3MZcBRVx173S4PfUMVLWZ
BgQfyZzc5nk5XOw7Kr428qhnwi4gbMXl4WqipWciLz+6s0y8bjGnsLZWYf0+
LstmfpbN+ZW4eF0jOefvRF2J+fiVNWk469nQdZY2hR9xpp5tcz4VLP+/ncVQ
WXetyvr8z1U0f4nOr6b9PyyGmubS0qpp/ww9b2Mu5//+P2/aJzY=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzWtIU2Ecx/FDQngtTTPvl6nRdCwvmVrafk6nc/OWJJFWhCBEGVreuhjN
iN4YpqYVZhZZWSkbvvAyGxWlmJgmKateRNkqC6wWmrE1XcX+D7E9cDh8+D7n
d4KLSvOKV3AcJ/77/Huz45nfe7/nIA8W6UWDGvWlTldmDnsfBRnnuoLJ9ohE
U/OhTGZXmA87xlR9DSJ7wFQ585Ffx+yFZ9OTQ8IQZj/EvJqf098IJAfh1OWu
soWJADIPxxciXxf6Modi/w5uUl7pT16Pc8M9+R2zfuQNmOU90F7PYg5HnoeG
P6LyJQsw9ebhor0LsxB8U43IUOpDjkRAeSpv+oc3OQoHTKd7h2qZoyFRvTvb
qPEix6BRV35C/GsdeRPa+r/V+TswxwJFfS+bqj3Jm/FEOt8erFlLjsOtlnI3
NZjjcXUgsfCC0oOcgN1F73WCz+7kLWjNrjXqHFnfipawpV3cNdYTIdDXK/vP
MychKq1VLRtfQ94GSdKHmudGZhF0miVFRBwzMKoNXfjt7GaxAjBz2837KlZT
T8bN0Y4qp4pV1JOh8u3ufyFnXYyMu8p7YW1khRjH+COG4hxX6ilwdn9cXfaF
9RT06Rs2+ozTHpdqvadItf4fJ7HZlyC3JHzspzfbT0N2d72kuNeFuo25dCy6
qGtNsc7U03FF62S4HetEXYrA5fGxeL0jdSl6lKXNwkJ76hloOGM38HYP6xko
iGiUThxl38sQIruoLbjDusz6PieHQdBU01niQF1us5+Jp8NJ1RWDZEUmvicY
l8XCldSzcLJ9SuM5Y0c9CzsLopVHeGaRpWfT/U8WK2zM5dAOHYWNuVxr47//
AGQPCYI=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H1MzHEcB/BfDxvp6fSsO6pL7XKnB4lw9K5cTrnrHtZUK9J2tCFFhA3H
/NGk3NkM1+bhTFhisdLV1EllY9lqlCVlGOVhQlJ/VJjP13b323777bX3d999
Pt99vr+Q/F0anSPHcco/798ve/wy6pvrtgvxT6MJLRFBY86zmTn4cvkfRNUh
5NngFdy88lHOzAP/lWlm69dgsg/E0VkTFReYA9C+oDLzcTSzAJXKc44WQxA5
GKG/pv3DPy8gC5F7qvZ6v4R5IerfOW8OPDufHI6wwiZxb42ALMJ1QZhO18cn
L8Lj1mljVxCzBJ0D4boPZwLJkTBLtD4aB+Zo3Hgf+WI4cx45Bg6GnumRowHk
JbjDmfXlPOZYjI7rDr++7E9eiqndIYq98cxxqNx35Jh00I+8DJYnWQ0bs5iX
Q/rzweDJTb7keAheZoJn9CGvgPxjX4tHOfNK5OS/eSsZ9iavwpOG+hu7i5il
qLjrIm4Z8iKvRkyKyZLaxbwG7Sprlb6JOQHjJ275547NJQMRylAf2U6yHvAa
trbVaFieiPdRwtjCCJYnQpHS2fFuNY/yJNzm37zXk+ZJeRJ2JBnue1z2oDwZ
HT88tdnFbpQno7vx+diLCVfK18Jw3KlxKHcO5WtR1es6WR3HchmyxUb50/1k
vQyjd7unDvm6UJ6C2IovvxKtZH2K7X7cOvS6lxVMKt0pX4eGUUNUYBerT44a
qbBA9JDVL8cMp57JKyFz6+Hm3VZaNMLy9bb9cql2/adiT82qhDtmdj5pyJll
NvFl7PzSsHiu6Jupm+Ub4L7D61NZMVm/AeVLdANVeSxX4EDEo0ldOssVqA5N
7V/axnKlXX1K7G1WSeMnWH/pdvvbmVPZ1gMV+AFvh42n2XqV7Xqrym4+1Lb9
QY1nunEXkYX1q8b51mulGRKaP6sa4vl+87ZtYfOowb//Dxka23nVa1BecTWs
1onm3apB3ffAiwcL2PxroYq6JCwJoPsC7f/79BvvMjZB
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU2EYx/GTla7mJW/zMk0dFaYryuUsL+2nc7bcplt5aasoCmPlyrLA
IP84CmVkStpFmEgq2IKZpRGl3USzDCnQLlhREBEUdFlqMs3WBZ/3D33h8PLh
C+e878OJ2lW0qcCN4zj1v+f/zpYo98bt9kIJpuVQ2K11+x57MnOokY/oUu1R
ZAFs9a11sRrmRXh17KDszq9IcgCKNx0Ir2lkDobgm9qVr2QOQ+iFva7mwQhy
JP6MfD1R6ccsgVDA7enMWUxeAtnF5Tsj2sPJyzBcVi20vQkjRyM/77DV/EdM
joFqt1LlnsssxfKpUsVEUSh5JUbfH2/KexFCXoX7q+ZE2H2YVyNEXGiu2x9M
jkPjeYHg0VAQWYbFD945h3TMa9DtnXC3x485HonLrg23VonIcnypftqhGAok
J2CHPMX97RPmtVBnnn7dYQwgr8MNxR5nqYU5EZNOZXOJlDkJu/olXTLen5yM
yqqWpVfmMqfgbIHj7DabH3k9jpht97JFzAocticpOpoXkYF8U1xbscRn2jyg
zJmSz8/wpp6Kq+LWm0Ma1lNhSTtz17uJ9TR4FcclPSv3op6G/r6UkiNdAupK
tLcVnVu5lcwrMSGtLbVZFlBPh/T6PHd5tQf1dES4ngysdSykrkLfqM9m0yFP
6ioM3noxNuwUUs9A/UvhxKV4Mp8BU2yN+ulR1jfM6rPMqWd+j1fjcmpv38MQ
ug+3cab5jXCLjJkU2uk8XCZeep00T2SxngnfLwEih4jNRzNrPhqMurqM5R5s
/lrYkyXm6F42Xy30lpiBnyGs62C0XmkKlJJ5HW6Hnmvo/M561kzzWRAHf/hU
U8t6Njz9e0oOfmbvz8YK3+gf1kHW9Ujnj/5eXeE7bejxvGB8QXQnmdcjOU5b
4b2T3K3H+Km2oO1jZM4Ap+ajoExL/xcMaEmU9dsayLwB7rlzrjt6yd0GGHf0
qE1b/PEXDrIcKA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0m1IU1EYB/DbVIy2D6vp0jQ3TUpNltNqTqv9N9/n27ZITRFGsF4QMh0G
ucRL0IsYkRQmGBlFlFmCK43Sah+KRDF6AY3oS1gRIahfyqm5ij2HuOfA5fLj
f55znnPujT9Q73DJBEEo//v8e7Oh3jc4PFCXgKDmTIrj80nLcmYB5yq2qYa9
8eTVcNw82nawilkJ5aSq/dSslhwB7y1t15arzFF4pqq1frEwx8LmUlwMmdKQ
tXi6fGTiQxpzAuwnTaOe+jhyIpIz7nVFPd9I3ozKCx+bZwKx5CQkhssqFmKY
U+B8pxnqqYkhp2I0s6ld+WYDWQd/9UPzTBhzGuYevP3dEhlN1mOgv/6yriaK
nA7n/gr/lbr15Awoeg32kR41eTsmcqqivy5EkndgqeF6a+lh5p0ocys9nS8j
yAbEPXYPnR1XkTMxPjTY23iM2YgXNl+3+GQdOQvKVH3M68BacjacDbVLY9+Z
dyHefKitaUVJ3o0Tya/8rnLmPZxNaE93fep2MgMybcqivE8RtAhssnZOVt9Z
Q7kZHdNuj+VXOOVmnOmoy/JoyIIF9vP6raGnQym3oMTQ+mhaF0J5DuQh95t/
XFpFeQ6C/5uM8lypxVzpekIet34eV5/PrZ/P5QWorE7vb0wImIJ5AddfITSF
pUb13TCqL8Tt4Sn1WCxZKELLtfcj6s80Xyzi6q1c/1bMGhdXLLqfwf2EYqnF
Yup3nvISyr9RXsLlpVw9Z6GMvt8y5WVw92WbvDcE6q+cux/Ogk16Hti4+7ZJ
z++zcfvbpf3DTuvSELncZ+fO5+DqOYsO6Xyfg9t/r3Q/cBb/+w/qzzhx
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2EYB/CjW+pSyakza+ZlmS0v85Yzb+2Z0znvOiea2k2MIj8I6TAm
5ayshPI6ispPmkWOAo2K8nY0rfwQYaIJCRED0azMMG9NqdjzEue8cDj8+L//
9zycw/EpLlOfsKYoKv/v9e9Ollvuk56uUhFY9EP2YlEQfINLTEGtQPi09YEP
2g5qYhrOHU8kdgKn0f5azpw32hXCpkuWF+uJ3WHY3K09Iyb2gOBfH1zWbnqh
veG9o5ej9ytPtAgU7+S6Yj6xL1S1ito0x3ah/aDpKq9zocYDLYa2WCvbW/NC
tD8cbrx7vrCEOBDehPRUXHu7Ey2BjrLQ3X5JxCFgL5ioGDDsQIdCf6+nhvPV
HR0GdebxyS4FcTiMDLZP0cXb0fvhclNpdJUXcQR0TH8en1h1Q0uBt2ngxUiJ
I4HfmEHJw4gPwKf5+9q8VgE6Cq7ohs+utrqio8G30qpFuuCCjoFKwR2q4R5x
LBT8/Cjds0EcB4eODqkK8okPQtHF8IKpWWe0DEy9G/qASGIAe85D3ZcWvsV6
gK3tq0eUI2hKDj7yk3XaTSfM5aDsmzsNYySPZ/XjIYgvXrw9hvspBQjdTbNN
zaSvgNFJ36XfDqSfALK8paIMIekngPMsPWRUkzwRtPsMLc3dpJ8I89N7LwVf
IOcrwRgrOiV+uQ1zJfS9jv4uNjlgnsS0PgmC4iSagRlHzFWw7Pi8xhxBchWE
X/+2Iqd5mCdD4GOujbTeFvNk/N5oKoW5X58Cuur1wdJOG8xToetRmUFSaId5
Knip0qPcOrdgnsa0Pg0s/6M15umQfS00gFvLxTydOQ+VAU2m8qr4FTIfy1Qm
6/xMWIha34yXkPmy8PtZWQxZrOdlMeehWTmVDWmR1c9MEg72s5nn6Vmms6Hc
GCPrbqOwr8b3tyaz9NWsvpp5Ps3KqRzmfJDD6rNymmVKA9be/uv2RjM+X4Pv
Z9liPfGMxbQGe2TlMg0s61mm//sPI6tMmA==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAGIQDQNioVt3b8xWcoDwPtg/trY/JM0D4zM4KP5qb52z
TBHK53DYW7l35h1fGF/AwUNbppv9rQKUL+IQLcfjEz8BxpdwOCLXF3HKAMaX
cdh1gXla4DZ5KF/Bodyj//w0FhhfycFWgD98u6cclK/ioPdMdWfBRFkoX82B
WUm23lIMxtdwaBNTumqYJAPlazl4XJ39N/aGNJSv4/D002aLA5ukoHw9h/Xa
chYuHyShfAOHM3vjHrEsgfENHZJ2bLA8dFsCyjdyeG9g5bvpiziUb+zQNjHb
qloexjdxcE19vLlnhhiUb+rQUGr/xUoNxjdz6BG/MOlboSiUb+5QfbWSlyFB
BMq3cNhqn/ajJgfGt3Q4Welik6ImDOVbObwRjkz91ikE5Vs7XEn9xqmxUxDK
t3Fwaaj4a9gO49s6xLAvmiXtCuPbOUTOWrtQVEcAyrd38FvT55q6lRfKd3Bw
DvljxurGB+E3ODhc3HH1y40f3FB5R4co7Yke5yqg/AY0PoMTmryTQ/aJHfsu
74TJOzucOGpbXrKLAyrvDA0/dqi8i0Pxamv7TYsYoPIuDkwKWr+4V/+xh8i7
ovIbXFHVM7g5BPYYarO0skD1uzmERxmtK1L6D9XvjqbfHU2/B6r6Bg8H4963
3x0P/ITq90RzHxqfwQtVfYMXmvu9HbiZ11a9mvwRKu8N1cfAAADwBtV7
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIk1EYx/FXLRxS1rzMu6mUZoxympeu++l0m5ub07JSS0ybiBIaKmZS
bVKI1ySpmYKVSYJI6UQlMxUJMiH8I8wsUDPFMqEyGFMJKjxP4F54efnw5cBz
3nN8M/IStdYcx4n/vv++9AiSep535fphQz/Ej8/elxzYQeYQ/mC8c9boy8yD
1bqnfiSNvBOLqju2abZkJ5gKG8YlnT7MrvC/WJcVoSZ7gmdE1dT0LmYfvC/P
MNQEkP2Q0j7S3KT3Zt6NSrWDtv6RF7M/ektaAD/yXkwtrfbdrvZk3oeGUanG
fdaDWQg3VZ52hE/ej1MhxsArme7MQRgOqsjKr3RjFmFwwPukzbIrczAwcy2V
LyWH4NsFY9lKhwvzQXRMes22tZJDkV06ndViTQ6DJtHk8bRMwBwOfp2aiwwm
RyB6j71whk8+hIWtd019Bmfmw5AIJ8ZtbpKPQL40OWhf5cR8FF3m2q+uIB9D
bX5Re+oJ8nHIFdUfjMlkMUonSrZz6WRg9XzBb32P44Z1QHd+wa+Uy8xcJJTd
PxUJ4dQj8UT2PbF4G/UoLAaulIg01KOw7JisNVU4sC7BS81wk66fWSeBSNr4
TPGGejRyCs29VqepR0PU7xEwV0Q9BveG2oqThNRjMNcUFvqxnroU6ZfOrY99
4bMuRdl8Rs18BzMnQ2F222C8gNbL8OJV+Yz5Oq2Xw6xc4OnjqMs3z8PFIlU2
ZLfWST3WYn6Fxf4VFvMrN8+rU+Jh66jzrXfU45B7xjYh00Dr43C1+e2A4BP9
XxUa1fq1z3bsvHQqi/NW48aW12M8A3U1InLEwTUudF/i/9+fP/uc+MQ=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0m1IU1EYB/DrRFv4nu/v29JYZpZmNufMv5uv29TpHKISmTUKFTR1UERw
LSwsppWhZoglZaAZqExTC0uLoDCMAmHhJzGlzExxbmla0Tkf5oXL5cf/3HMe
zvPwi8tztByGYaR/339f+nhpDCO9pQL811KCVL6w4OxAzcBfUd/hbuATc6EK
5V+Wq6ld0eyX82DNltoDc7Zli8pHPGIflMq6zdMq6gCIuemNkd+CiXn48fSV
QhdMLUBD4d26Bl0QcQiyv7Zbzl8LJN6DNsPPO6PLAcRCzD0baj+poQ6Dq8tG
cceEP3E4Pk6PmrhO1BHo/ayf/lDrR3wQGonxVIjRlzgSRZY5i96dOgqTK+YX
k8d9iA/BS8yrdLzoTRyNltiRpu9jXsSHIejjtr7OoI7B6mDtkMnoSXwEwxXh
a2oOtQj1FbquQrUHcSykL9VB+4KpxeivqFopOOdOHAd7jU3/0vguYgmKzh5b
fzvvRhwPs2KWW6Ok+VFo2zo5F+7RPAG6vbcbb/W5EgP8xNN1uk1iFujcLTdG
j9E8ESubw/mXdtA8EfvjI3JHvziRXAoOL+yXQ7cjyaXIfFyfrDXQXIa8gqgn
lQIXksvw/I14UThD1jNJyG/tue8ZTvdPgqos7N2qLz0/2bpeNhkDSzcO+E04
kzwFuhGVRGQmZlO21ZcKWe5GjF0KzVPRLRGcEY6Tepg06/PYNOv9mHRsMdlb
RdW0/nTr+2Dk8PeZmb95i/4vxyetaadwiN63AiXV5gGbPNIPVrGtX0rrfrFK
6/VMBq7rH4b22JL+sxmwnKj6XWOg85AJNSN63+tG5oXNxJT91anAZTo/WRCV
JETpvcm8sVkot1m/0hVH508FTkv7ehpLDBVm7ZpMg82e+AM0AgZl
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQNioVt3b8xWcoDwPtjfVrP3TxOG8RkctjzuX9i0
SRHK53BwXZXy5HcAjC/gIHRg9WL1zwpQvojD/NnS83+2wPgSDiXmK9pvq8H4
Mg7au+58v1ItD+UrOFyLPx9yaLMclK/ksFzt9uq7v2ShfBWHLcF21vpuML6a
w5EsrS9bZ8hA+RoOCzdcN6i6Ig3lazkwvp/85388jK/j4HKv+p/wVSkoX8/h
jNlzrtC7klC+gcNX9lfL0jfC+IYO96RZ7nN9k4DyjRz6jF8z3gqE8Y0d1nrc
elbECOObOJSaq6VuTRWH8k0dos7zZs58KAblmzmcdY6QfPpDFMo3d7jO1n5d
9pMIlG/hsPhJa5JzGoxv6XB629aVRQXCUL6VA1so4+YPh4WgfGuHkozl+/zF
YHwbh91SU+bufC8A5ds6BORonf4qCePbOUhLPH4xcRKMb+/AI3yovOAlP5Tv
gKq+wcGhdHeAjcUPPqi8owNvkZH15SZeqLyjA5OC1i/u1TxQeScH49633x0P
cELlnRx0NrOwmfWxQ+WdHQJ7DLVZWlmg8s4O8h6+lmKrWKHyLg7czGurXk1m
hMq7OLy3/PXPSe+ZPUTeFSr/EcJvcHUoXm1tv2kRA1S/m8Py3dfFTslAzWtw
c/Axr9/+WI8ZKu8Odd9PqH53NPM9oPxvUHkPqP/+QOU9UfkNnnD9AOvN1Jg=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02lIVFEUB/CHEJh7buOeTiaTSqiT5pb+1Rx3nRnTaLAsYSrRFtfMRF4W
kRiWRVlKmShkKGOKy5hLg2IukLhlfpAI/aCtSIlYFmV47oeZB4/Hj/99l3Pf
Oc8l44JcqcdxXMLW/f/JLuuUzt62LCG2tRpq/LlQ88qAmcNcpm2VrMuFrI/B
1vGO1RRmM3h2NEzJPjmTLSErMZBNVTDboCJGpdjjweyA44Lu6vqa3WRnWM2t
+j5fdCILcWVv0Z68c8yuuClSpZeNOJLd8PiDudl1M2YRJpcHFE1eDmR3vAhR
B6rT7MmeGJT0tU9M2JH3Y6joQWmdNbMXNsVilSDTluyNsuyvFc/e2ZB9EJAq
qSs3ZBbDpMg99f09AfkAkh/9XZI6MPviiVF1l+WsNdkPfEHoWqAb80HUjJu/
fKqyIvujvfWGk82CJTkAafp2/MMA5kDYpPdNV0qYg7C87/tlb6kFORj1jaNW
t+fMyYcwq1zfKerZRQ7RcSjG5lzXNo2YgQof5ULtSbNt84CRxeClix9NKQ9D
c7DwrGiIzIch4shvvx0SE8rDoefs/suw2YjycAz/ME1W5JC5CG3zESjolQb7
b7D3D6PVvqV7Oo7tr2MuUns9r2NOguzwO/0m9SzXMRelXS8fhcSWykhlpzHl
0TDO9QmaKSPz0egfCfwmWmL1x2BK/XZtfsOQ8hhkjaoHZnrIXKxOHguFR1X0
RBHL47TX83Ha34uLx1GFjypXyM4fj6awoeHXtqy+BDSONRQa5rP6E7T7wSXq
nF/HXJJ2P/kkmK9oBpvlrP9S5LW1lkuLyZBqzwsvhUHDxgnJMFkjxReLY8r1
cjZvMnhLanpi35AhQ9o1sWJ+hczL8PNU3p+rnTSvmq08Y3HJc4XNrxxn7uvl
G4tpviFHZ+jpjZJsMi+HynFG6L5M1shxSzB5dz2H/T/JKPUsrj2/aoV/QSw1
VA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQA2IQDQNioVt3b8xWcoDwPtgnMMzZcVgYxmdwEKgJlRLc
oQjlcziEm7y5tjICxhdwmOcSu/DMBwUoX8Rh01KFGepzYHwJB6umnz+c7GF8
GQd27zN5c4/IQ/kKDue9RObKCMH4Sg7blAwdAq3koHwVh8tNt6NrZstC+WoO
SncXP97wVQbK13DoMP8m4KsN42s5iK4vPl9WLA3l6zicE14g8POxFJSv58Aw
ub1rphKMb+Dgyee8I2iiJJRv6GBZHvKY7ZcElG/k8EH9uBxrJoxv7LDmuuyD
5UvEoXwTh2BDDoabwTC+qYND0rbrk8rFoHwzB/aDynN03ohC+eYO1llFMxK2
iED5Fg5OeglTihKEoXxLBx/z+u2P9WB8K4fHe/42aJsLQfnWDldSv3Fq7BSE
8m0clil73TI5JADl2zqsl16z/ZI3P5Rv55B9Yse+yzu5oXx7h7NSH15NEeCC
8h0c2iZmW1XLs0P4DQ4OtfMu7xF7yAyVd3QI7DHUZmllgco7Qt0Hk3dyYFLQ
+sW9+o89RN4JKs7AAAAi5Iqq
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2EYB/CTUZlmOVtqzvJeTk3zlte1v7rNeZubIl4zLwnRxTQTtlEw
k8goC5oSKCIYGqKWF6y85C3tBin2YYQUhE3LxFTygwnRhd7nwzxwOPz4n+d9
nvc9x6XgQkqRGcdxCX/vf0+6bNN6B7rOuuK/VsRDVekOLVZkDoWFDn69zS7M
5lgb5U6pJWRrDN4ZGzUsOjPzkZuprXSqJtvD+EY92xFEdkSee2WMZsCJ2Rnu
5Uv3NMaDzK4oTFrCqzCyO8Q7sq5sSz/AfAgexf3ehjZHZk+8v80zfHIke0Ht
xS/rVQmYfdA4tWu3/p0Dsy9aJz7mizLIR/Gk51p4/uP9zP6QhCwHZ/mSA7CQ
8Vb9XW3PHAi989xXZRQ5CHtGUpvN7MnBKKmqWy0ttWM+hte17apFT3IIWhvn
O71P2DKHYtip3r5hJzkMzbVlvD7sYw5Hw9PIbP1DPnME5PG3ZrozyZHQary/
GDzIItQpKjY+W5CPI/PkmDwrYy+zGP79gsOz5TbMwKXTD4aSbZl1gESn/uV/
ncfyKLS4xc8EjVmzPApHeJ6rddPMXDTK2iLE3U2UR6NcWKO/2015DJJkLyaM
IspjoBG+/FmUTLkEVudsFqtKKZfgZkDRh/o8yqWm/XRS5OxoqhNIaT7Zpvlk
GHCoaehbpvpYzPu5BhYL2fu6WFw1FlQb26leDsutHdpvesrlm/I4rCfMmVck
0vnEYVw5Uq/rp/OLx/a0LT0rzymPR3bssMVGJ+UJKDH8GMt3oXyTuUSUdT26
odRS/0TT/XBJm+ZPglDhxpeep/kUpt9LpzBdj0s2PQ9dMsTpazkKAeVK0/1D
CYv767myCVpPaTrviBKyZwtnME31KtP+UMHax18w+ZvqVZCKjJenNqhehWjf
vJqLefQ/piC3SrYgGmdGCmws7QbnB5l1KUjlQie7eHz8AaFDJh0=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzF1I01EcxvHlEKvpnLn+udQ2p4XTYb7ka257pk6nW1M0E2RF+ULSKkHJ
IsOMoNmFF2pikWCUNSclFJWJRCOoyAvLLmYYWDSLsiIVs2YtK/Y7XezA4fDh
y3OiqupLa/14PF7m3/vvZYcrvzN60yKHV3OanvYS/oSQmYcmh3xn2r0o8mr0
8dXaHjOzCE21jUsmj4wsRkfGx7G2XuYwNBQnKl4ZmCNQNzPlx72UkmWwrpTX
xJcxy2GuGJzwXN5EjkFAwPR897tI8haYjA9nJ2XMsbhSLxX3t0SQ43D39uHz
KgmzEgvmH8G66nByAsZDL4ncro3kRDwpGXjRomZOwhTnbx8vlpCT8axGb6y2
h5FTIHDINFubmbdhT9y3RYuUORXXJyPf2Po3kNMgPBa3a7qLOR3DjrUFfZ84
cgbmh0vLotXMmTi7/HxQ4llPzkLaQmWs4TXzdlztbgwZAXM2Eneftt0fEJNV
MFe9dSk/hJLVmDmgyPJYmTWIj+Qk+/etIwMiZVL4+EqI162ApmLRbAon87R4
6oxZ/BnIuhZHFOe6Om+JqOfgwgPb0XIl/deaA4UpWqw7xPa5yE42WoV72T4X
O/IfP5pRsX0eCu1Dg5t7g6nnIeSzmJvjhNR1cAa11blNQdR1WAoaOfUrNZB6
Pi46Be5rqQLq+XArO0/YDq6hXoAzHZasZmkA9QLYRie5sQh/6noY008OuxL4
1PUQ8G8cn+1aRb3Qpxf69CKfXoSKyuShBvmKxtsNSGn/8l3rcHvdasDXzOXf
OQnvqRv/+w/9vN4K
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIk2EUB/CXyEua19zUZmpaZhdNl+mmq/2dunRe2s1SsxCpsDJMU/sg
wTKwIA21EJx9ULuXLe2ey1hGiQ4jizSioFo3KXKR0orueJ4P22CMH//znvfs
PO87v7hMvWUGx3G5/77/f9mHn3vV2LMjDNOySnl9X6dWzmTmUPumuOFN13yy
Kzb2m1XvweyN6rbN7+pfhZL9UJbXfbunjjkAnZbWkw+jmIPgVh5TaWgPIYdi
vPnA/jMuzGHwj9vofk0UTF6ANK/B7zU755EjkBdvnfCcCCJHouPui4ClEuYl
2BRzhNdxUkBehnVjJud5fszRWNzV9Lq3Yi45BoeTji7e58Yci/ZWccSBwkCy
EHfMnZKiugDyClgXDQQ7bWOOAy9na8K76/7klVBOXhm8kcocj8SI7qddDXxy
AvRDvr3tBh5ZBNF2qbDBn1mMdEX9s0v5fuREjLdUJF+QziEnIVauv6kY9iVL
ENsrWPS6inkVbJlvXfdlMa/G9PkyS+F23LZJfs+HDET5RH7Rj3hPWwfk6y90
8JaRuWTMntO/Z9e4F+XJODF4vNq90pNymX29Tob1BUJDRRjVcylI0f6Md5JT
vS4FpbLGPs8Odn0q+gYSP0daZlOeinBFy2jBGTfK09Bk2V0j++ZCeRpC0rPF
/HNOlMtx2jjGHwoi6+SYEP/4LYt2pnyNQ74GdU07EmtCqB+Xjh5D2dHoDa6U
p8N6eeTXXt4syjMQ8nvYLLLSPLoM3PvqpSkop3k5BUZuPJl8anOnXAGPCmHS
41oPyjPh88mPb+Wz/5/psL8sh/05mMvGRUHX9UeZbP/ZUJYuMU8FsjwHu88n
SS91sutzIH5gbL//kuVrHc5vLc5Lwkoi77LzUeKQcMvztiKqhxKnwhXP4vpZ
PyUyzhrOLTxG9SYlBAGWD03NrL/Kvh9UDvdT2e/DpMKox8GS7zlsP2p7Q40q
o1IisrF9qe2fF5Ma16yNy+cOs/1p7A0NPEp9Px4sZ/NrHObX2PfntPjDqf4U
VbL5HazT2vczaVHo0qkXpLH3JxeWW790SxN88Rddlk/G
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQNioVt3b8xWcoDwPth3que7K4rB+AwOtg1ylYGb
FaF8Dgenc89rncJhfAEHRcf0ztJ/ClC+iMMt93WP7s2E8SUc1MwdCq67w/gy
DtmP/NjqXslD+QoOedUx1fd8YXwlB5eFH0MnXZaD8lUcjgvLaf21gfHVHDSu
z1jG3CsL5Ws4MErOCj9/UQbK13J4HFXmEiIB4+s49PO+mqkQJg3l6zmY/X+1
7UmvFJRv4DA9U5xhoQyMb+hw+pLl/53JklC+kQO71rYesS0SUL6xg6X7FYdN
68WhfBOHz7+OHb1zSwzKN3VQvxe4sJQVxjdzOKjcosGgJArlmzv8+uG8qFxH
BMq3cDi9bevKogJhKN/S4dFsM9Pbk4WgfCsHrsU/4tyOCkL51g5CLw4cWh0E
49s42Bj5tPMlwPi2Dp//7YpsYheA8u0cAnK0Tn+VhPHtHXKcJuzlW8gH5Ts4
LDm5uIy7BMpvcHDIPrFj3+Wd3FB5R4cPmy/+rRXlhMo7Ory3/PXPSY8NKu/k
ULza2n7TIgaovJNDeJTRuiKl//YQeWcHbua1Va8mM0LlndHkXRyMe99+dzzw
E8JvcHFgUtD6xb36D1TeFU3eFWr/M6i8G9QdDAwARkSwkA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtIU2EYB/CTOjNnOk3nJcs5LUxtpcvLdLbHeZlTp9tcBVsfQgyKSbpM
LM08QdgHSdCsDxWBdrFcLs1baqRShmSWUlgfog+OVhniQMs2vFTseT/sHDgc
fvyf533ec3g54cVl6uMuFEUV/rv/P8nFPdQ33K3ng0NWSQ3btdzqTUzByaHm
gYin4WgP6Do3c5irIeaA+hEnon+Dh/YHsfyLyHSbOAiWPg1O/hQRh4LK+HLB
91UYmged0yVfE2KJ+TB416xvUO5ER0Jfw9yP/tYd6N3gUTJ37V4gcRTIj/Z+
uKwNRUfDJTdV6/Tz7ehYeMyakn9nEQtgueydQmsIQe+HLptfI38hGB0HceI7
PLuCOB7GJtvEx+qD0EIwf1YbLroTH4A3AxrPyOBAdAKw3y8b1i9w0Ylwg9fn
Y/kWgE6CWp1E3KshTobG8soOXZE/WgTFE/whIb0NnQIm2aK6yos4FXSyEU97
lx9aDOZna3RMEnEaWPbxhaf2+KIPgrI0evJXMActAflDU8euWz5ogApjquRJ
G+Y0MPJ0MIr5J6JeoOl0qBxWipP/eGMuhQzNaiIrG01LYW+aQDNi2Yp5Bowv
+RRpDV6YZ4ALL9rONqKpTGfTmaCNacp5e5aNeRbcnGXb7ieg6SwQXllYSR/d
gnk2TIynVZ0Z8sA8G6w9M2u1ASSXOdfTMug2lbUIdFhP5UBE7vVZ7QNPzHNg
KsQ638JBU3LnelruXE/lMubnQpO5oka6shnzPKhv0qfUhKHpPMb8fOf90vkQ
2+PmnthI+hXO69EKsMU2n28vJe9XwNhfAbQPf+S+DmVhXsiYXwjVdfYxfYc7
5krIT6obMAtcHQalcz/NyEeV+D1tEke/Cs8Phf0M0ypw/F9csJ9hSg1HtPGm
0/wNx3qgds5pNbBdO6vnr27CfjWel1WcXwSLIvu6VPAb+xmmiS2Sv4yzQWU=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQNioVt3b8xWcoDwPthbPVwb4yIJ4zM4NOUyv8w7
oAjlczhUXV538lw0jC/gkFRq6cXzWQHKF3EIef705K7JML6EQ+XLB0v2G8P4
Mg4PAks/ysyUh/IVHCYfzQq/+lQOyldyCLrEtrHWFMZXcXi+6UtsYb4slK/m
MMlq4pnmmTJQvobD4/knTvxngfG1HLasa+4Qd5KG8nUcyvo2L6gqlYLy9RzK
2pmSOHZIQvkGDitW7ergUoTxDR0kpbMzpudKQPlGDk+ZtpdNeiQO5Rs7HOs5
VF62XwzKN3FonHshXrIAxjd1OHmlpbX0pCiUb+aQmfK1Ql8dxjd3EGgvTLm/
SATKt3AI0F+gVCIB41s6nKx0sUlRE4byrRzWub8PKueB8a0dfixhr3viKATl
2zgIvThwaHWQIJRv67DaRilD4zA/lG/nEKU90eNcBTeUb+9wVurDqykCXFC+
g4Nx79vvjgc4IfwGB4efOpNqludA+QyODlX1vw5mr2KDyjs6QNILE1TeCZXf
4ORQvNraftMiBqi8s0N4lNG6IqX/9hB5Z6h9PyF8BhcHJgWtX9yr/0Dl0fgM
rqjqG1wd3lv++uek9w0q74am3w3VPgZ3VPc0uKPp94Dyn9kDAFB/ykA=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0nlIFGEcxvFBhU2N1PJaNY/UvNbUMlfL4/HYw3u2kIzUSjCsDPMIbYla
tbIgCAyyNkPN0BQPLMXKNA1FpMsVyw7FQjEyOwTzDit6f3+0A8Pw4fu+M+/M
vA6pmbvSdDiOk/w5/17pME9obW8+ugn/9COk51rWIgzIHPpvaMrNqh2Y14BX
rs38GEw2hlSYXS7+Zs9sihT3u/qpRWRLvNEMdyS4kG2QbNFWWqm2Y7ZHnvzy
y6t65E3Izuh/HZxgy+yEQud9KSPqjcybYT8wLH47ZMPsCjuFzHPMj+yO/PeK
DxdyrZlF2G+s+cR9t2Legtre0YNBiWRvLNdNDRSfEjL7QCbJPay7Ysm8FQU5
LV7Posjb0CqcHJsds2D2BT/b0n8/grwdFUY6VisSc2Y/CLody0TTZsxiLGdV
nIlNJ/vj4XHR/G4dcoCWd6BY2ZO/UGbKvBNdHmFf67PJgVDHFSyNG5CD4OYk
mJiXbWAOxvXHNXkJovXMITAW+Vi/WDVhBgZDSvQsRplVwPijXyoPMY0PhaFu
g3LqCvVQ5KbXdMabUw/DUNqcvusD6mHIaW66yCvp/uFYuC04PRHKxqvCtdYT
ofX8CEg7Ph+BhuZLYFC1kCLtpa5lTgpPE9cZtcaYdSlOuvUtpsUzczLsVTdU
momoyxBZ21jnXGbEuhx8hvvTn0LqcjRZ17cNRlOPxIl2PtB/YR3rkVjlFKsH
cqlH4cuIy1mvQpqvZS4a1Y5R73yfUI+GW5yjqeQYrT8GSYJbamsJvV+MVo9F
Z5Jzt60hfb9YRN+biVKI6f/G4abqldKokVkVh8K+PclLMbQf4lE1cS41/BCz
Kh7eyUU1HXeo8/CbnhytF7D9Bv7//aficf55qTBRxNzF45LFQMlcFu1PBezk
sQHmdWb4DSlMDYI=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQNioVt3b8xWcoDwPthXczMXfOCD8RkcSn77zBJb
qQjlcziIRvhKBETA+AIOX9tczvR8VIDyRRy0kzZtLG6C8SUcLFk2FNtqwvgy
DvcDUpb1rZaH8hUcog5cinZlhvGVHCq+Wlh8i5KD8lUc9LP9nl5ZIwvlqznI
Zik7N4vC+BoOZtL+6Ty2MlC+lsM3sSbmjGZpKF/H4fiWEycrZWF8PYfGBLft
0/OkoHwDB/ab51NuM8H4hg6/d17gZ6uUhPKNHPpmXq0u94DxjR2uX6091WUj
AeWbOLxO2dT0aY04lG/qsD6EheXjOzEo38xhaoPtYkEnGN/cwWXOA6GdnaJQ
voVDZsrXCn11GN/SoYXl5CmO6SJQvpXDLL/GX4+5YHxrh7gOt5e2R4ShfBuH
7QXLIvVEYXxbh+BrnT2XZGF8O4fJqR8mxywXgvLtHbRlxSTTE2F8B4eCa58P
JSpC+Q0ODiUZy/f5i8HkHVH1Nzg6GLrN2ul1Fibv5LD3ePv9H/UweSeHrJIf
2xjDYfLODkutjE8snwuTd0Zzjwuq+gYXh4VLToj2X4PJuzo46SVMKUqA+qfB
1WFzQfHnqAqY/9wcejdzau+7D9Pvhibv7hCT9OixzguYfneHdbKXlbSeizgA
AJL+uUc=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtIU2EYBvCTIEluWWnqsouVZS4vqS3TLnu8bFbq3OZWWqZDGF0UMlPM
JDhaRFFRphlZkhY2SysUtTI08xKJGJnMIqSLFTEStFKxEs3we//YGYzx4/me
7z3n4+wsTzmkNdpwHBc//f3/Sx9nff2TmtQVmNGwvP63NHWnLZnDa4OsWlex
nNkOshvFA2YFeR6K6gYvHP7ozuyE3H12zf3nyK44UFnj+tCLvBiZloxZxwuW
Mbvj7k9Pl6EPS5lXoHXvSp93IWQPcOuPiz5nL2FeDRt36R/7qsXMa2Apbs9R
vXNjliJPdmZUJiV7o+lBZ0V3+SJmXxR8fB8uGZAwr4PEoSikLJjsjzZT3fWg
ElfmAJj3fAq2TLowB+LXKUW8IoC8Hnmlr5Il6c7MMpw42dZ/pWUh8wakqLwq
J0XkICS/qU/qPerEvBH7LttkigPJwSjlzccc7jsyh+Cb188cfzV5E+bcGk9S
dsxn3owlVRN9iUHkLYJ8K7K8igov1c5jlmOK00wZMh2YgYbhi36LuufOmAc7
XxHLQzEmfpw3IWPmQwV5GFJfPGrufWzP8jD0iU/v/60SszwcPY/MI2/HKQ+3
Xs9FCPaPwO61BdteHqVcIegrUBna1vFcQvsrEa6b2GCrpOtXCq4vUnB/kVCn
SbtGJXQe26zPgxeY2460sItNc8upvx0ix9bsdAvlOwR9gbko+Mxf86Okh83j
o3A2wNh/zUDzo/FrsjEhfzbl0ThStUlee5PyGHzv9zzpl095DBJK7pUv9KZc
Zb2eV1mv52Ktnw8+FsbS2za5ZfR8qHH1qSlb771gxlCjOXHVs6X2zLwayibL
QfSw9S1qdPZ5jPwVUV8D+a6RRJUbMzTI/5Jy/ks1zdMI+hpUhAS+MJWy/Tmt
taHFoGOCcewMzdei0DhcmGhibhHkXBwy95uaY52pH4fxqK92edHUj8PM+436
cfBvdPMcyKK+Dvcjh7TZIvb/gg5hvoaiDAMzr5t+v2SE3pMzt+is9+P01vOg
R1dD/Z2MdOrrkXRaadnSTn09cs05Ys7ghH/P72mv
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0GtIU2EYwPFTzlsrnJeWl+nUTCrnyPtl6Z7N25zTbZYlXiAKKTrF0iVe
y4NgnyyxTbqIgUFaWpJF6DJzKpYYCkPU6JtZkIa4QLJpaMWelzg7cDj8+J/3
vM97Qs7q8st2UxSl+Hv/e5KLX/BqqJ8OBbus0jFleYvQg5iCuYHn9w2jIWg3
4H7OUOkvEPOgslYTcM+N2AfiOhlF8WAw2hdkByVfTuYTCyDS0lRS40wcDF6d
W9elOiE6FM6PpHEqTEHoMBj+3qZrXAxEhwPdFJZaHkl8GBoLTnUVqwXoo7Ae
NGv81ByAFoFwe/pDotUfLQZaoIu9KyE+BtWXWxIrT/iho2ByIqXq6mtfdDQc
cp8pFH89gI6B8PoFy3gWcSzEP8kvVdbx0XEwImz37XAnjodHbXpPE+xHJ4A5
Qr76tMIHnQh0oav23B1vdBIYyqyGkm4vdDKcKS/dmvrmiZZA5vDyRbAQHwee
KCpgZoc4BQJ7f8+XJBCnwpC/scO0xkNLoebIe1uZmhhgr/dY1ZVlD7sZgMey
8Yl3fvuwy8AyOLf+8RcXuwzoycG3syY0JYeiiFbFTDXpcmhd0tfJN1yxp7HN
OJhKh2l/64qRtwd7OrTPc21dceT7GdDfpzOKi92wZ8CNVjq5TkjWZ0L30AJ/
SuCMPRNELzku8bdIz4Lahs1RuscFexZcezD7hr/ohF0BQkVuEr+HrFfAWtLm
tlyM71PZDvNng010u777kjt2pcP8Sofz5bDnZXLY+1Eq9jyMClQJDQNLYjJf
LnCdntWuGHZhz2Wfl8pjv8/kgb5XIn3xkMKuhtNF0X0VoTtSe1eDtjkqgtPE
wa5h7w8OZjQQc3N1Q2a22debNfh/ftpNaXG+H3aDlt0ZLe6Dl/m//wDPCR0h

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02lIFGEcx/FZ3VxzzWO91qM8CrM0tUxLbfPnsbpq6u66BVpCRBK1kARF
ZYeDlSKJqVmRYlSEhmUpYt6yVpYFlgdpbypMkzUCtSJqTTvw/7xwBobhw3dm
njmex3tfjjbbjOM43b/9/5FtzjubOxr1PljUTNStJ77Vf+yZOXw3iuaOtXuT
LbG2qsehcD+zHRqUxarSBS+yI/K/KWxc6pnlsKteU9uTxeyB29zHTslyZi88
dL/fMpTsSfaBxbOdnk6Fq8hrYBH8o/e0cSXZFwG/Iy0btjP7YSrDpgJPPMjr
4byVNy8IZw7Ahf6IhupCd3IgrHI+5ef1uZGDcf2rtV4uY96I36KvB1ozXcmb
oG70StzVKieHoOhKwjLPARfyZjRX1kSX2DKHosg0UOc670QOQ45orqAuknkL
ZPVvDs6cdSRvxXGnKu5SjQM5HC9Oxm3b78scga7nhR9+5snIkRiKKhe7vLMn
b4PMaHh8T8usQEr8s94JhR15O74ttGfkS5ij6HvbkoHU+yXK7OYVi+YBM6/1
Juk9a+rRqBqR/qoJlVKPxuqkqyOZd62ox0Df19o93MZ6DDL9y1SvTpC5WJSe
N2/9kEXn87FofJBTEbjbknoccvNMPfo6C+pxqO0YdX7psYy6Eovz04y6Emdu
DHc6j5lTj196Ph+PgjJ9xClPCfWEpePxAnMqaIo3+osviKmrBPdPxHS4aSEm
kD1foqAnQWpen/v5soh6EnZsyWsZD2Q9WdCTBdfvEIwvMJciGF9gLlXwfqkI
aBJbhJWw909DX6/i+NF21tMw0zQ4f8ZpOXX10v8FtWA+qPFopjTIrd9m0QaB
OQ022PvNVg7S/IIGHW4V1W3TZF4Dd/m4saycbNBgMsgn5PA6Nl+1iO+aOoRB
MrTYeyRr7qWRzAu6QYsvDhnZP4rYekjHzzuSsxPRZKTj2lix6P0smU/HnnMh
mW+NZEM6lIqJ069N7HodZFKXzslOWm/QQbJKrHs6ROZ1UAfd9Dkqp/Vq0EH1
ebTb5qIj/gIRFFE6
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIU2Ecx/GjL8qsqXNralPT4Wyz5WWmls78eZluTsFEM22VKAvFoWUX
STSORpRCEU2IJC0VWabOpLLsZiqFCUJml1cRhmmR1bAaRYEVPv8XduBw+PA9
fx6e5wksqsg2OXMcp/n7/vvSI8m9ebe/TIYl2RN6y4u/O4nJHNzV5l9PhgKZ
XVChcqmZKSV7YOPAjqeuIrIYrSr54PGxAGZvVBtLfTrKyb64EmYM2yckB6C3
7MbJ4pz1zDJ8lSknmy/5MwfhdbhSnvLZjzkY50NV1nc6sgLNEmXpiTZf5hA0
PU7ozePIKkR6FQX3HJEyh2Jaf8zxaXEdcziuFWbEDGjJEShMtsfyDh9mNX6q
ztVYzeRI2ITjsx/avZk349WL2vFGDTkKw6Odzi/zvZijEXi5Tpw4IWGOQfRC
gcLwZi3zFnTtn5gsOUPeCpvflCxkTswci5bbml0WGzkOta1T9yTTImYN8veO
6Ap2kuMxp1w4GpFF3gaLyW4xWj2ZE/DAKB/2X00GXDt+7El9JFwyD6zIdbpu
H6WeCEejzWv3N+qJ8Hz/cKQ7m5lLgnFle7NUSz0J3RpZiWLUnfVk9El7bj0z
MPPJEM6LJXaJG+spcAgG635HrWE9BXkFaluljOa1EFSq46bqBaxrYU46e9+t
jeZTsSk+NGdolnoq9F22q/KLNJ+GRW77YuEhWj8NArPnx1MHPFjXLd8Pr8Nz
k2OVYpD2p8fB/r6GrGrqetTPFJ2e6aGejog70g1vD7Pz4tMxL8o3ORro/Azo
jI0cs7ZQN+DCkLUqV0U9Y/n//H/mMpffJ5+JoConS/QXEf4AJc7oXA==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQNioVt3b8xWcoDwPthf+pg95ygzjM/gsLreyVxv
tSKUz+FwaP2pLR9CYXwBhxeRiwMq2GF8EQejOynfPvYpQPkSDqx3MzbONoXx
ZRxEl+kcsjkgD+UrOJxw+8+ySxnGV3JwUA19IdApB+WrOJjwmLadfSUL5as5
KK6LsZtsBeNrOBxqdei9nicD5Ws5GDzlXdZwWRrK13GoOVCnek4CxtdzWPg+
nv/FRCko38BhYsXz+IWSML6hw++dF/jZKiWhfCOHM3ZP3ILOSkD5xg7Nogr1
MztgfBOHIyLllQqfxKF8U4eEyLCf07NhfDOHYz2Hysv2i0H55g5TG2wXCzrB
+BYOqwXfSahtFoXyLR1c5jwQ2tkJ41s5OOtcPc/cCuNbO2xa3yYncUcEyrdx
MIhtXr53BYxv61B9tZKXIQHGt3OQ21m8rf20MJRv77C9YFmkniiM7+BwetvW
lUUFUH6DgwMkPQhB5R0dJqd+mByzHMpvcHR4NNvM9PZkmLyTQ0Jh7O9TLwSh
8k4OM/cvLw/Vgck7O/xYwl73xBGm39khq+THNsZwmLwLmvkuDk56CVOKEmDu
c3WIjD/kERUBc58rmrybQ9Sn22aqf2HyaHwGd3j4AABwgLfv
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GlMU1kcBfAnbgXEgtCCFpEtglobRBQZWU6rFCi0dKEQEHGJL4FgYkcm
Lugwj8lMxjEzOoAwEUMCGqmKoIQgKlErWNwiGlQkftGIcSHq1JDgQHCN//uh
r8lL88u5597kvntf2OZtZt6D47iir8+3f/aTWzu720vD8V2uFN688uzP3swc
NuyIu7n3TBhZgrD1Ie1OPbMvok6mJUlehZIDYB8IvHtsP3MQrs2ukEXFMwfD
eW//ud97F5BDcWmy5M5QDHM43kQtleZnhZAjYf3132lVHfPJCyHZ8qz2eCBz
NIL9TJG1fDB5MYpiamRNxxVkJfa9Kzl///48sgp/yWIibSrmGAzVDaUscs4l
L0P12+LoitXMsfDU3BgxlAaRl6OxViK5PhBIjkNDSO3lI8nMK/C+y2yJSJaT
V6I+tFP64qWMHI8lB7X9mtsB5FWwcKv62/2YE/C6bru6NcWf/AMyO97rTPHM
qzHDOqXD1TuHnIg3/vn82J/MSeAbmj32NPqRk5HQ393Y99SXnIL8+tYmmZIZ
OKM43TWQKf1uAXCOSi0FP86iXA2P0MUT3i1kQS3KNTih7nX2zfWhXIMxnwuV
kytYvgb//Db1/JP1XpSvQYSubrDgBJlbK8rXovyXiaulp2ZQnooF6foE+anp
lKfiv4SJTxoVy7Xu4wUt7sxzjRzyZfOnYVxZvde+1ZPyNNi7H8lvBdN8XLqo
n46q4bI9mg8zKc9Ae9u2Q6p1Esoz3OfjdKK+Dsv/fvtB7WB5pruFTPf94rIw
6LOveNzA9i/Lfb85PQynD6TynSzXi/oG0fsxiPY/G3kFsW3bw9n7zUZLYnhx
dC+ZM0Kv7XM+T6LzACN2L7o+zmeTBSNm+ffstL2m8Q4jmiN0j+N62Pkxifom
0Xqi3GES9c1QBA2/qqpmfTPmt0wOFsbT+RXMeMCPeUZfIDvMOHzFvtOqZOfd
ghreVVNoJ8OCn4rtl7PlZMHifh8cFiTGZv0xeyO7HznuRg4KZx6tV6Sy9XPg
dez/Iq2T9XNgGxzt2RTG1rfCe2pr+UgN61vhq1ym6P/M+lZcMzqOCBdpvMOK
LltzvkrG7nOu+31HLjpsZaMFu8hCLsY3lX2s7CQ7ctEgPCyXtrF+HuoNlRPD
XvT9QB7mtD4scVUE4AvZPHeZ
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlHlsVFUUxq/tULClCBSHlrZ0OrjQUkYoCLYwzDczdLrQZbZ22ukgxqSR
ODUodGNLXwgquBS6REiDRJZIO6VjwFSKg/KAtKBGE6ixsRrE1NSlaiGK2KZS
NXPuH/e+5OXll+9+53znvJeX+uwWZ1UEY6zmv/v/J7+0pT2hM349wnTbFDta
p16M5sxw4m/d1fe7UolnwDoWZWso4Twbm7/+/deRP3TE8/DB63GOzg7O8fA3
tt6MtnJOwvZdyZE3TqYQ67DumzYtG1pIrEfe58ejhss5PwJTc2jhpkAy8WPQ
HH41M1fDeTGOGPDl9fIk4nRo9h94PrAvkTgDg8aoOtfkAmIDGjKv3Kr3cV6G
wl7kpB1OIF6OhET/5kMvxBNnQput2zpz93ziFWiqa9yz9qaWeCXaOy9Z73Zz
fhJHazuGluk5r0IweUCf/uM84tXYNNjz9EAD56eQcbspeO5AHHEWhi/8oyxZ
PZc4G3+9Fpy/8c85xGvw7qKCoZWXZxOvRWz13NF9L3E2IrSg7e3zY5zXoTat
rbXlLGcTsr4IvdN/izPwXuLpczc2PBRmBaho7z72cAbXzSIrZkwxx9QzNXSe
WbDUaHBfHIkl3QJ7dfpndxO434pU83P7a+9zvxWj3z6+94k9XF+PpXMW32m/
zvX10nw54jxKDranXR2vKuG6DYnxwz81t3DdhiJbf98PRq7ninmUXMmfJ+l5
mBl3uf7Fn/l8+ai2HPxo1rFZpOcjvzMYePQI1wtQfLopp6qHz1+ADvOVvv4E
YrYB/mu9Hw+cjyFdYlaIk5+cqIup4fULYXVPrppmI2ZF4jxKkZS/WHwfSrHk
L8Gigre+8nZEk16CFW/+ds+sPki6HeMZLbtOVRPDjmt9xvqaD2fQeTuah7ft
tNybHmbVjlea/dk7U4iZQzwPB84Et7QZKrnfIdZXHZLfibGsifsWQxT5nTgV
GtR+mjSN/E4xr+rEwb2Rvd9tpHmYS9Thwo7GiUv+ANVTXGI/1SXWZ27sPjpw
Qft9JPndUn9JV91wvLF8ieZlDflLRUYpwv/TCPKXSn7pPCuj/OOmsL8MHm9m
cKt+KsxKGSJ06RMxXZNhVsuwrWuN6exxRn4PYiK7d/zS+gD190j9PeL7UT3i
fli5uB+UIyWvKEsb4PNLrJaL+ViFmA8VYj6lQsynSsy80v69Yj3FK9ZTveS/
Q/0rpf6V0v4qxf2qEjOftH8ffY8j5PeJ/VQf5WbsX/cj3k0=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU2EYx/ExArWbc85Nc15mIeINczmnOfdz0+2oc5AiKaYjL1lJuTJh
GNZRCQOtlDK7aEZaiyjLcEVEXtAIpCgwE/IPC0tJSgxTqRAqep8/tgOHw4fv
eV7ew3sUxZXZZUKBQJD89/73pEua63jaVxGC/1rUlmWrHtRuIAtgG1rxNPQo
mN1xq6C6+IOJLIJtdcoRuxrMLEFn7gKMrWRfWEp9BseTyHL4quJqx8aDmIPx
6n6LoiaKHAKOmx9wbw5k3oa51yc/L70LYA5F+ZJV16Amh4EzeI/198iZw9Fy
7k2WZNmfORINK4Oz+fXkaLTOWUvrPm5hjoHlsDhxNZK8HdcvJ4Q27vFjjsWI
vb8j/oovsxJ9vZUXogvIO2C46vHdHkGOg8NvdvrHtIxZBe8RRZSsixyPjscL
TQEeZDWubWx/JHkrZU5AG6/p9tKRE+E2vLUj8qsP807M1InDrCXkJNxsq/J6
ArIGqvOj+9PF5GSI700cWDwhYdaCy2h+/zCfDNS/2F34y8TMA0WnDV80o96s
p6Aiz21XSTszn+LSdejkJ2o8e6nr8HNv1Vqdg7oeUXP+/Pp1tL7eZT4VC4dG
l5UrNJ/qvB9BGs5aq+8U5NB8mks3OH8Pb4B8Kg+iVupGxBQ22J/dpm7EUITu
292j1DnohnMCI4KocyhvEx7bpKSe7vw+nw7LpKNo3EY9A92fThXr91HPADc/
ObC5iXqm8374TJirRMcvPqduclnfBFHjkdLpG9SzoD6ojT0jY+fJZ0F4qes3
x9P5mp3/D96MlzPdawiX4g/2RfLN
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l9Ik1EcxvHXGWpbi83UWXO5mYSKjtLmm665Z879uYguIqMoV04Macio
oIuFNi9SsVpEQdAuohIJZpD/ajJaEkFdJUvcG11E1ggmFc6JuVhSsd8J6sDh
8OHLc3c0TvfBThHHcbW/75+XnaLWqdCYqwwZLRktIV7+Lp+Zw8mnzizXpIac
B779W2f7YWYZhgx+z9FVNbkArWZZ4lo/czFet4UE7w7mEmgid+4+8JSS1Ziz
+CrFM9vJZXh8JvmmR8FcDq1SqQ6cUJF3YsqdbPviLyFXoKPDFjqtYK5CkzDm
GLcpydVwn43Ndg9vI2vh09+s7BMz78L5AZEzL7iVvBsjR+JdvJG5Fi9Nj8Qf
nxeT6zB/bKEhvq4g70H1xIaceh+zDs7wh+X1ySJyPYZ6HYrRlUIyj8jobLK8
m3kvhJwBQbVcQG6AfVEIb77M3Ij7sUtO8ylmPRyD1rjhxRbyPtxauJL1PpFP
NmBtOLc3ZmJugiqQjh7n5WQjauQVidsRGRmoMWgPPfsszdgLRILzK2/XJNRN
WJVO96V1m6ib4HoVDM9Ns96MqHSwK3WA7Zvhj0pSIzrWzf/tzViaiPzsKdxI
veVfe1vQf93VeKE0l7oF+/mLTz5ps6lbkPmvIupWiNRVPySBtDHTrai7+vW7
aSaVMWfDuYDeOH6Po72NduzYIcl+6Fm8kaC9/W//BYwZxcg=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtIk1Ecx/HHudSYpplNdykvWNgSS1db87bfs83pnEKKYlgEib2aESW1
UsSHsIzQ0iQiCBEJHFkLK9NQWhoNrVjpEBpBF4ReVKJmYo3SCv/nhTtwOHz4
nlti1fHSoyKO47L/zf8rG9Ly/qE+WxJWNaevspW5XkmYOSwoyg+2ORLJYegJ
SjznLWCOQt+24V11cwnkGGRb3uucncxxaKi8nNNvZVaCN7l7c7/FkxOgNpj8
8zxzEsJC5PLWS1vJyTgr5ZrMy1vI28FVvClc3MGcgoe+Rzeby5RkFSyTUt+p
JgU5FbFZg7fGZuTkNDzgQyOvtjHvRqjvdfU7EXM6xqfMx0a0MnIGMlaqZa6u
OLIanvzDkkUl8x6MWh2qiUOx5L1wt4zaT7ukZA003ytTrB82k7WYK/FeuaZh
3ocm8fiLsOsxZB08Rw7ML/g2kTORbA/q0MwyZ8GZP1tqD2fOxg1Xj708NZqc
A5Nw5k9680ZyLnSeoS73xyiyHhE10V8vnmAG9teoXi7KyAJwT3FnYNIaSZ2H
sey3Zp15A3UeDv7Zc7csgroBogSVX9IbTt0A29jgE+9jCXXjWgtGTAxO/Xj7
k3VTQDdB3TqzxD9dTz0PdY3+EdvtEOp5aJ+urTcshVI340K7LbM+niyYIQm+
W/elI4h6PioqM5wnk1b0qz3AXAG994t6AWp7s/T3uzk6b0FDp3dY+imY7reg
SNs4MJ1G5gpR0pK+U3xeTD3AnHXtfsEacH9RwP+KMKvzLxvSPtP/itdaKKZz
HPcXm97uSQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIk1EYx/HXbcJC57ZaU2vmlKxYMtLN5pa13y5uc5qYkTG7WSCFSUYR
glC95QWjSXSDIivYGJaWoRVdZiBE0A0yQ4PIIgylQWxdtDTTCp8T6IGXw4cv
5znnjzdlR1VxuYDjOOPf79/OlnLD7WDH7lRMK2IWXj3WWihl5rC9obbuSmsK
WYz1W/dUbNvCLIO85N3Ohl9qsgLOrEOeyGXmBFw46fP26ZlV+Br8OOS8kUxW
o/Jad7M/jjkVz83vxcO2ReTFeFu2d2SgIom8BKUCt+9IUEVeBk9PojQQWkjW
4IQkdF5dwpyOmtiH/tFHC8halNkiJn40kbwCtrB76dFa5gxEKRq/Tf5OIGci
WjDVlVbHrEMn5+OPy5j1KPp+68ldezw5C7nlgze955TklQgbxyetWmYDbOl9
L4T188nZCJzdL78HZiP0vU3VafcVZBMm/KKU4R7mVXC5vW86Pcw5aHeGi6tj
55FXI2DSPW65OJe8Bo4HnyrwUk42o9d8ShQ/wAwktU30bzaQ+VnmLCiq1Dwb
SZRRt2BjaWb7vlQpdSsOBItysn/GUbeiX9K4a6xQQt0207wNuqbPPyzdc6jb
0dFedUa7SUzdjpbga+VTVTT1XCS71hqVrWQ+F+u8GctF9SLqDnrPlHm6O1Bg
OHxnUCuk7kSM8HpN6HQUnXfi4KVXXcoPrLtm3se7Zs7j8iBQa8Zj2iZofh69
f4y6m+Z/oT7LXD7dQ4vPp/9hiHrBf/8B/FXiXg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzntIU2EYx/Gj5aWWl9Q0tdSWiUmIubSms/2mU+dsc1NCvFFUhrTCylWo
SUeQqKDSMuuP7I8uFAlC2WVLEs1WUzGS1G5YhJoZZYt0pl2s8HmJ7cDh8OH7
POd9l20pzix05DhO/ff992WP78bbzTd0QszKIm3JX9EWJGDmcL7n082RpmVk
Vxz1EKUaCpg9kaGYaO50YPbBwKmoKWV9CHkxIi4Uft0nZl4Cs8q8b+1wMDkE
ftEv/fIymYW4E+veOnAmiByKq2GvGwaml5LDYKixFgyKmcNx68m7tqcVS8gR
GK17WKp+FUheBZOXrkqQzhyJk5Wb2rUHA8hRCCqRC3u/+pNXI8vwM8phDXM0
nvdVdB6TLCaLMLNj6xHziB95Dcr0y4sbZMwxKCp/s/2iI3MsjF05d7JzfMlr
UVrt05fmwLwOw0511rtnF5HFqDdI8k43+pDjkO8awJ8TM8djbNfDCZHVmyxB
R6lcsi2MOQErQ12GJlOZ1+NKnMh8td6LLMXmPQU/Oj8sJAO9hdZ54UYyDzQH
1NYbv3hSl0GaPZ6vDmRdBlXKI9NQAuuJ0OyM6JrwJ/OJmOG0M5v1HtSTsMD7
wYHdo2Q+CZc7Lu0X6N2py3H/cdxY+OAC6nJY3YyVP2PIXDKuydpNj/zdqCfD
9M0jK3cP6ynoMfSNv/guoJ4CndnQ8sxI5lJt5/lUVFfNMbwtmE9dYTvPK9Dv
dqRoSk3ncWnoDrB8rPWked7OnBLLlXX9uddYVyL4d3fXOgvr6Xb76TCbEg7o
77lS34AbjcW1kXlkfgPKDk236a47U1fB0tTzq2LRPOoqrGqa6xx7woW62ta8
GodrdHHlwaxn2P0/w+58je08NLad16BmsKQ8cZJ6q8buflrb86FFsEIl9r3u
RPtalDTES29e5Ghfi+zc6Ma9whnp7H4mRMc/T8pap2YNO/N2bs3EF/H078TI
97SfRfegB//9B0VHQHk=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQNioVt3b8xWcoDwPthb83ct3skD4zM4fHnB+Lt0
lyKUz+Egt2129bRQGF/A4Sv3IqX/PxSgfBEHDWWD3pNzYHwJB+YZtbWbXGB8
GQc3gTltc07IQ/kKDsZt84rLeGB8JYd1ZT8qlybIQfkqDvwfuvo3T5KF8tUc
4uqurV35UAbK13BoT9xs2M8F42s5HIz5fy/RTxrK13Eon6v6P/CiFJSv55By
eJthDy+Mb+BwS4x15Tl/SSjf0EEoO+QW2zsJKN/I4ar3oaiHijC+sQPvlzkv
veeIQ/kmDtsPcLnPfy0G5Zs6nHm8+K+DFoxv5uCiyqdzXxDGN3c4qNyiwaAk
CuVbOAT2GGqztIpA+ZYOSSeUdhk3CEP5Vg4bP0nNr8qA8a0dot33c/3aIATl
2zgI6BhKn/svCOXbOgi9OHBodRCMb+dQqXn8Z6q/AJRv78BbZGR9uYkXyndw
uMbbkfHTD8pvcHD4sPni31pRTqi8owMkfTBB5R0dmBS0fnGv/mMPkXdyeG/5
65+T3jMIvwHG/waVd0ZV34DGZ3BxCI8yWlek9B8q74Im74om74pqH4MbnA8A
GvGy+Q==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCwBGIQDQNioVt3b8xWcoDwPtirsOw8rSII4zM4/BefIiG8
RhHK53DYfrA48lwAjC/g0OD9OHb+XwUoX8QhtDW1PX8djC/h8G+BbvuTQBhf
xuG0hfzsjQwwvoJD2J4LF2I85aF8JYfEhw++R02Tg/JVHBQ1eIRZfshC+WoO
P/Y0vRIwhfE1HFo5OP6szZeB8rUcsk/s2Hd5pzSUr+Pgw27MevquFJSv59BY
+bZcURrGN3A4szfuEcsSSSjf0EFwy27JiVowvpGDsm9pWEOsBJRv7HD9au2p
LhsY38QhnO3LnTBTGN/U4SnT9rJJj8ShfDMHtZrrFw+7w/jmDhPdxfWqrotB
+RYOJ6+0tJaeFIXyLR3+LGZRfH5BBMq3cghmsDi3URDGt3bYXrAsUk9UGMq3
cfixhL3uiaMQlG/roOmnLOKaKwjl2zlISzx+MXGSAJRv7/D5367IJnYY3wGV
3+Dg4Ot27OgTW5i8o8O2DxP0pc7yQeUdHXRt9UL2P+OFyjs5GPe+/e54gBMq
7+Qg/+/saYsPXFB5Z4cTR23LS3ZxQOWdHXQ2s7CZ9bFD5V0cIOmPCSrv4sDN
vLbq1WRGqLyrQ/Fqa/tNixig8q6o6hnc0OTdHMKjjNYVKf23h8i7Q933E8Jv
cIea/xEq7+Hw3vLXPye9b1B5DzT9nmju80ST90LT74VmvjdU/hlU3hvqbhjw
gfMBa7Xfcw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1FtMVEcYB/ARkKpctbgKRReJt6IuIrLKrfsHCqzI4p69gCxgjIRIxMao
D1Us8fSBSojVorQhpZekD4WArlGDoqAcq7ZagwkhoqYPlXgh3g+tQaCI2uw3
DzObnGx++fY/3zdzJrtgyw5HhR9jbO/75/9v/jG4O7pOVsXCJ91ytOVW92gw
N8Pw7dbyY94F5Gmon353SZqNOxw3W7sXFjLuCPQURA61nIghz8WwdezhMxt3
NMwBW/LujhvJMag9sFW5nsgdi8nyHyeb1fnkhWhOyM/svDOPvBif+dccUdK5
lyIw3r268no0OQ5GJXfF32bu5YgK2Pr9peMfkU2wpR463TEaRV6JgzcGQ+9p
3AnYnKWnqCOR5FXoeXCiZzCJOxFp5wdq++rnklfj7bbyumtDc8hJGA51X/44
ntuMpuSu757/ZiCvQaAeNtBQyb0Wfk0//2dVZ5OToSv9h781c6fAO68/Nm4o
gpyKA9VX9oz+wJ0Gzz9/mRe9+ZCcDm/uS8fnwdyf4Ipda1bPzyJbkHPh8Tb0
zSQDu9tTLad+CfdZBUK2z3pat5PMMlDkWeXdFRtG9Qxc+CPlxdL7wVTPFK1K
ZlkoOHYou6IjhOpZaM24fPX3SDL7FCvSTa6eR7wumWWj6lrnxf5zQVTPRl/n
rVd3RsksR+qfA+Nk7421+gyq52LmswiDbgilei7O6N/ER/WSmVXan1Xqv06a
f53UPw9Zrgnz1By+fh78YuLGg9r5/teL/dT1uPpvmNOzk9fzMRJy7suJJD5/
PpoHgsZ+TeLr26Cf7ntTM3s61W3ojdKfNIbz/RVgbPmRL1q283qBeF5sg3R+
kpkdnmUN1pt7yLCL/VW72E+z46uGqpR9xg8or6Dmp/5uw6A/5RW0dN02/Bk9
lfIKTnp3NJpKplFeEfsxhzg/JKsOqb9DXI85kfj189cZGs87YbTakg1tvL+T
7jejvBNB/sernxwdtvjyLtFw4WXy+GSmacRnVbLmovvylvJu0XCL/VQ3fP+v
ftTfjfw1+8/eN9F5sULp/ApRvX/8UlVbIOWlulZI81CdFUE5mLAsoDaA8kVi
XS0S34cmmW2U8pLVjXQ+UygvmRWL+0Mx3f8JOr9icT1NMvOI80Cy6pH6e6R8
idRfsipZK5HmLxWNUilfKr4vTfo9KxP3C8lqGd3PMbo/ZdL920Tv65HlHX7G
AGw=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd031ME3cYB/CbGysBQcBSEXBAdYqCReu0yOr4Vt5frH2hVKEQ7HQzVPGN
QDaT7ULU+ZpoUFxwxi0wEVGUmEkDmtx0sDkDW83Wbc7MZCCiJBOiJviyoYvP
88fdJZfLJ997nnvud/dLcG+yrZskCEL5y/P/Kx8axzfdHR4tXmk0vaQ3c8Nx
NVtA2JvXazyXE8iBuLQm4Lalkh2G0N7tX68NZKtxwffdzYzT8eQoTCv95fEe
BzsW8307XR8FsOOR9OmEK+aDOLIWlQ119gU33iLPgjf3SJZbw56No7rklju5
M8iJqE+51qppiSXPg+7Z+bLsP2PIyXgq9n+Z5mTrMDO/wV9yKpq8AN7uST9t
U7EXojFHXxPlnE7Ww9jl3+nbG0VehPr4O8MWE/sd7O96cLN83zTyYmxsdqt2
VbGXoFMKyjkxoiEb0Hpi6HxSGTsVlYaqUNHBXooPPUMZUgg7DcbH3/61vzyS
/C6eN72RcPdnNdkIV2C0+PlS9jLMqn2tfsmDqeT3UHBhLN9qYKdj4NK/YpIh
ggwENY2XZ/eEv7IIRAxLV9psZMGEGW3P/S4D5yYMpWgXVc3lfDnajNr1iVen
UL4cF0cPpkT3hVKeQesdRHkGfuhZVlvdFUh5Jg7ueN17u4zzTOw65EnbHqei
PAst3b9pfowNoFxhIRsd7ZsO60qpn5iNvujR+4fDqJ+Qo+ifg7j/+q6njnKe
C5/310e/jwdTnovma001wdU8f578fjEPPQ+n2Eu2TKY8H/6Q3eufmEMoz1fU
F8jXQyzA5e/T/kkc4PpCnDJd7emdzvWFOOYPfnJyMc0jrFDkK+As0bdv1dJ6
C2a5RTP26dfdOlYRRvlKhGyIGNm9hSyuVHwfi/z7wYIJwTpRUc39LDgXc6bz
RgFZsiCvtf3021/w863y94dVMY9V3k+yYuTWnB0pdTyfDZOnXqndfI+fb1Os
l01Rb8PqxrNfRSZzvV0+D+zyXLRjfnjiWKOPLNkV/3cRtnWc22P5mIwipDsf
ucwx/L8Xye+XijDXPFOdtZHrHTDqCz8LreB6B+oG3QcGz3C9A+PNqk8GTbTf
JAc6N59crYvk/ViMew1bTWfTySiGZ5XK+v5RsliM/jWrxh7+QZaKYRdS+zvC
eb874XL/PZA8zPVOHPcaS+vb1XgB82V55g==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0llIVFEcBvAZDbWc3PerOZq5k7mkptl8bjPq6Dgo4oJUaoMwVrYopgQz
SBnWg1oWlL5YJLlkqLnhQk6IRmSbSaXgQwlKQZNKjGZR0fk/zL1wufz47nfu
+XOPV3F5lspEIBAk/r3/PelyyhkY7S3zxn/pJaYWdZrL5mQBZh4UmyruejFb
4FTMjpz3CrINgu47Rys3xcwOaOYisyduk11Qa63x1cWS3THX1mC7PuDJLMar
C9yvDsMeZm+s3Vqa/JpP9sGU9HRjk96D2RdXzVYdyz3J/ggNUAk9W9yZA1FS
IhtVO5OD0at1XVlQc8z7sbzWH/2kz435AOrMJWIrP3IotoVrpcMFrsxh6J7L
q17Ic2EOxzH5GMZ0zswROLF8/nF9LPkgajRbk2WdTsyReOd/sqh9yJE5Ctmt
zVxNKDkaQQ3S2YTnDsyHUHrTpGJ3ODkGs0V539c/2DPHokf2LatKRD4Msxxh
v/6pHXMcxqevLBk05COYU/3Y6T9iyyzBrnuGo9IpMiAdX1XjNbMWvDwektyN
QgVHeTw4l08rTddtWJ4Akb2u6syqNcsT8GzeZ+OniPqJ8Iovra/8zd7XJqIy
oPnG9T7qJyG3IKznnDf1k/CI6x56I2cWJCO1o6dzXyvlyci/87DNMZj6Ul5f
ikF9Y4jbCyuWy3h9GaoDpjdVmdRPMd6PNgXte9M+RugoTzWeV5vK+34aroWp
FluOU57Gm1+OL4t+l0JqKZfz5kvn7T8dZTPDE29HLFmegal16+yCsyKWZ8BE
HLhl2cUsUBivp1Xw5suER9f2fGEU/b9MqCsMg8JcOh9KY0NpfJ60SiTHfb74
cssOfwDtaAfz
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtIU3EYx/HTvOa0ZupyZk7NQs28ZN4tf1u5LN01SpYFIYjGpAtuSUW4
oiShUmtRdDOpTFwl3roohRfMwoRMMsJCyorurcJMw1nh83+xHTgcPnzP8/zP
qxOUu12Tx+M4TvHv/v9kl3B9S1uDLhjTsqRpDM1uoR7MHJ48Gr1ZXh9EdkX9
L9F3o5xZgOOpU1EvvwaSvSEyZ+cUVDL7IsypaGBrGrM/RrM9umuGxORAfGnZ
3/pwMXMwchYoF3gdDiCHoFu2raLSMp+8COUl5W+zljKHQi+Ri0sN/uRwXECP
dsPzeeQI+AvuuJhkzJEYeDx+IeWUHzka4u7Sp8/eicgxEM02JV9MYl6Koar8
nWVmX3IsnmZ2bnwVxLwMn5rPD0fXzSXHoaPrCm9QyxyPmsla8aJzQnICTtVU
1wYHMCeCd7rqT4bRh5yEXEVYrdWdOdnOKWisLw3wfeFNTkVI8YwT8d+8yMtx
cuGklqtiXoFNua9HIt4zp6Hhh1/VngJmwHn9jCZL15xpGwF9wdV7SiGZkyBI
kl9msAqoS7DEM/T7mX4yJ4UhzHTieCPrUmjPXK/2iWB9JQxtqtTE37Oor4Ti
2rH0vBYP6qvg+dlbaBGyvgo3LRVRfn1kLh2qwvDeURHbn47LDy/t4utZl2F3
WM94npJ1Gdy9Oot3fJhNfTV+Wlu1B1xYXw257H73m+Xs+zJQKK24O6uanZ9h
+73cGphTgwtCu2ifcQ2mOPXUFj3bvxa8wPAJvtmd+lqIrX29iRY36pm2Nmai
4qDD7eHNrGdB9+D2vYE7fOpZODvIH6+JI3Ny9PlZPpoEbN7OnMJuvwKWpv7J
fT4zqStROVK0VzrmQl0JcYY8SVjnRF1la6js3rdzuwoNN7abInNcaV6N0kpd
8l4xdaihPhKz2PGQI82rbfe3q/EtacIqjXSmeQ32lEx06OrI0CCiydE5/hg7
X2O7r12DrISSWyORDjS/DtP/Lx7Nr0Ps0S9jkvbxtL8majaX
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0nsslXEcx/EnHZc/TsXhuFeOaBKWS0fk8nE5Lsft0BS2dDCLsKjsUE2n
ZWFdbGnUsRqL1Kq1w9gOKkOby2gk5dZa+YNFcy1jus3v+wfP9uzZa+/n+2zP
7/cTJZ+NSdXiOE7y7/7/pMs4trFFnWGNDc35LnitNOhYkjkkXxE88NSImPUw
o6lSOSaR9ZEubEh8qE02wvMcmXZ+oxWzKbYvTRe9TiBbQsxLlo6s7mW2Qqv9
U5WvhGwNXmjXJemTPcw2ENnxDXkru5n3g29b1lAbRbZD9IXyqqEmS2Z7fLpt
MPzFkuwAcXrnaGWNBbMTfD6qE+uDyYewYNamnas2Z3bG1fxZhciC7ALpnLG6
MNWM2RW19W8fFb83ZXaDmUVGWkUW+TB25tkf/1xmwizG4nVJnMSF7I57Hi3l
s+3GzEeg6Y1vOhFP9sDX6qFYfXOyJ06JvXUm+oTMR3GtsGO8oo3sBXFZZ1qo
gOyNlLHW1roZI2YfFPK6e/QqyL4QvPiQPldABn5kdS67/jTcsBJIWBgT264z
c37wd5LfPSen7gfnIJVG2idg3R/VNV3C0mFm5RZzAdCJ3dYw10E9APff1Cli
HagHYtD3Ds9kwoD1QJxXvyyRXWTmJJDnnFzrmaIuwUqNbsGkH80HIVCZt+5c
RD0IOzIF34tz9FkPRvewzdIan/oWcyHgG7Yrsqd3sR6CGy6p45Vymg+FYKqt
/VkMzYfiQOQ+I0kWzUsh8jtdkvubva+UwtHAbl41QPNhkGXa9y6bUQ/b8n/h
m7+nDEfQq+kzGKAegW+t68qD7rR+EdB3cLbo/0M9cvN6KCMh8Z68/G6V1icK
CmElV/qY9i8KGXG60SkVtL8y9CfFzS+OMEOGEOnN0fp4dj6UW3qbDG6DtxS2
zXR+otGc7fDrmJYQfwHbDRKY
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzWtI01EYx/E/6mprTcx0mbqmI6LLEp1tbebabzddaaZBiEJYg8qSCGIj
KYqpUUJOaSuL6kUQM5K0dOb1zaKCQTBS2ajwTaAZo3BFzK2yG3vOizxwOHz4
nvOcfOvpA0eTOI5T/N3/TrbEB59ODDTJkFBEJx1otrkEzBz8gqm9oZ58Mh9D
U1dH95iY0wCj0+AJ55EzYH1ysjK5nTkLw92tHXe3Meci8rhG4ndLyXl4HV28
Vzi/gSxDW6/ME8hm3ogF2Snt7QoJeRPehuMjro5c8mY0NOBQ9/0c8lZIDLcO
283Mcsx99ap9g9nkAsTrh/SfeMyFeCfmPQzsX08ugu3Ix6TxY1lkBaoC1S8e
NK4jF8Mz8346GBOTd2DsVd1wbR2zEm2Xns/c9GWSVfiRelz3zMy8E5Ga6a4b
KmY10vuCJyIXM8gabJ/PcaxKYS6BPNLZP9K1lrwLsYo5fktlOrkUrbNW5+yj
NWQtTI7mpaIrzLth33Ld7RpMI+tgn6guVcdSyUBUNNbyU7k6YQcwORr89iYm
pK5HSNTeGK8SUdej2Pl5Ue8TUDfA/1J71jbOp25Y1o2Qe1NWqDpXUjf+f58z
4U5IGO9R0n8OEyLeyaULmey9edl8My5fayo5L6V5XBmkln0acS+Pehlq6xX9
Z2S/dYlejgXN91+GgmjCjnIIk/vOhd1fqFuof6Buobkc9wcex81s
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03lIk3EYB/DXQZnOs9w8WrZ51DCbZh7lKr/mfc+p2ExJo5Vpdtkd0goq
xAJNs7ALNKxQM/NKWsuDDksREQy6LKQVMmJkytSSip7fH/rCy8uH7/s+v+t5
Jdv3KdU8juMS/t7/nuwSprU+bsp3w38ZQ5SHWyyl1swcFDbSe+8aJORFELpZ
8nxjmO3QN2D+45JJTHaAjfxGYXEZsxOqFhjK1OHMIkQE5Z9N/bqcLIZe1lbp
7crshvzzhrUNOa5kD0z09TYdr1xGXgEz56r0gUERWYqK5yEN6RyzF+5/Smgs
PbeU7I2ifnnkESGzDKezI9uv7HUh++KCRN4zpXUmr4GxefB3kYDZDzW8W5We
wU7ktbgQPLsz7Kgj2R8dIlXBS0/mAOSe/LizmscciMB7yqzYk0JyEB5/eSga
qWVeB/Mu9+veBgF5PQbrB8Y9CpiDIc87eDW7xYEsR/TYG51NCfMGFN0c0go/
LyFvRHzQqfZRGfMmLEwzazb2LCaHYGvUU8vpB8zA/uHx7hwJWQPoMj27XPks
D0VhU2Ox4oQ95aHINK+uWhpB5jajd9jj54wVyzejxE/9/lq2HeVhUOzxej3h
TNaEoc1Y6uPSb0N5OOo2uOVKe2wpDwdP7DXNr7OiPAJ3Q3uePXe2pjwCz8Zt
UzIOsDwS14b5U7UBfMojMWndcfpXAMuj8ORF8HfpKFkTNfd9LprO24LyaPS7
GMcq7Cwpj0H+y0e6oQ5WP2be+LG43VtzhH+I1qOJhfVBP/nQGZovF4fVG2Wp
T/Vs/nGwNzgIjUK2/vi59TTx89afMLeeZp65xHn7m4ha99i3/t1s/5MgCd1V
fHiW5UnIPpA18+obOz8F8g6Z2szS6byhQLnaWJ55h/WDAhebLVbpRsidChiW
qNSTxaw/kv/u7/kR0yn2fTLa99eqZALqP00yVNu6ozO2kDuTsZjvqNVrWX8q
MW0Kqz7qTf0MJQIN+g/15tT/GiV275g45rOS3KmEeFRwuUbF/o8UVIlbbfVf
BfgDNbAxLg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2Ecx/GTl7znJbc2nU1XypghXlLTZvvNzW06L6wSw+UCKwj2wjJC
MqRRFBFqlOtVaEhImrYY6rxSwVxIF6UVBL2JnBCK0ZGMLlhW7P+8cA8cHj58
z8Nz+HPSGpsOngziOE757/m/syWsHZ1yWmXwi1dNm9JjLFHMHLq1KWOzI2nk
cLy8Gz03e4I5DnbRn+p0AXMi8nttBvN4KlkE3nAk5omJWYL5FW9FxlspORXi
XXOeMCmzDDdabg3UlO4k74bBNbOg70whZ6Dd46y990lCluP6hrRvtYFZgeIW
eY/XlUzeg/mlhS+uEOYsfJBpfZM1SeRsrNzxHZ8YEZNzEJl5uSGCF5FzYVF8
W7NKmfNw3mn6IW/dQd6Lx5MJ4bxdSM5Hz7n+99ky5gJIDVVFwgcCciH6bp+N
nwDzPnSPK81djkRyEUTHpr2dOuZiWK7plkpmtpP344VrdKD5NLMSW2u3DPPu
BHIJLi02diwOxZMPQFW3drQ6mVmFQaXslNwdSwYeJQ+NeY1kG6A5vF4QqttG
XY2gVMWvqMFo6mr0q92eZ+IY6qXwfI09VH+G9VK8SuKX7XGR1DXgh1//bhNE
UNfA6WiyZ5nDqWsDuham9pzMkCsh1Mvg/z+DqJehsvDimC8rmLoObT1vpoUf
ybYAc3qafyh1Pa7etBZfkIZRN+D+1DvhcwnrhoDz5QH3l6OuPtfRLNtQ+XsF
8jo+f1c//em3rYLmtU7duNk2I6KCH7Yud61Srww4H2CuavP7tir6Lo77C+ob
7jg=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlnlMVFcUxp8VRUUsKIzCgCxqBRxQQDaV8rEKqMMM+zLAm4XUCF0sIAVs
eRLbQl0KSGIqtkVttIJL3aiCy9OquAStWLCpmqISFWsrKlWgCLXpuX+8N8lk
8st3v3PunHvu4mJ4Pz7nDY7jdr/+/vfLPoqkIy0Hcl3xP/WGHL45cHaegjGH
eeVum39ocSEeh+nKD3P7sxlbYUdp3kp3c8Y24O68rBxqdCaeBt/RfNRVNWMH
uAw/udvU7kTsjLb9VS4lnoxd8fPxRWtjkqcTz4SdUlMxv9KR+C20hjVkOPc4
ELth1L1P7udGM/ZAvDU/tOobJbEKKStm7ZypZOyFfp+xrZER9sTz0B1RUfaX
3o7YGz4jJrtT9dOIfdCRcSeoZ3gqsS80fYcvHo1gPB8wNN2oKVIQ+6G4yqYj
ZhRjfyRsrVWWeNsSB2Cf43VXjwc2xIHwfKAUJpgxDkKRbR335c4pxAuwNKDs
x3tejBfiROvnv/eXTSZeBO9m5ey7hYyDcVI36/R0C8Zvo7zbsKF7jzVxCO7P
dfV9z50xEJLSp1MriQVgnU/OrTreivRQTJxypuiDnjdJD0XM7n0Ns7YSc2EY
4bQjfAHTw9DUWzXXvm0S6eHQ5Hlc/tuO4gnhyG9cGHJwO4sfgUL32k01B5ke
gT9uzV47t5zpkXg+3JxWbs70SFn8KOl8hChpPm4x1Hs2RuYcsSR9Ma4d7ej7
td+C9GgMqGpW78obT3o0nIbbLgf2TiA9BnWdFgM7/Wi8ECPTY/HdxR2rLApo
PkIs0udUR1/5iMVfIou/BL2Hrr362JaYW4rqe/mlYS/NSV+KNvveR7VWLP4y
KQsy5tTS+QhqhCcO+Y+JYvWJk7IQh7ywqhOTtjFdg+9Dfzp33o7qA41svEb6
f0SNLL9WWh9o8cLy2Johv4nk18Iz2Cvx1H2KL2ql/cLFS9cH8bJ6xkv/nxgP
3w1/vgwVWf0ScOFccFFB8zjyJ0jrK8hYlI3nEqFd7z3H7FMz8ieipGzwdG7D
WPIn4rPq3AWlTrQ+YiKeBA0Oh3mRziXJ/EnS8UKSNJ6YBNUhs7H+G0nnkrGr
5YbiksMY8ifDKXpZkKKBWEiWxhdlOpci7S+kyPolRbo+Yoqsf1Ol9UGqrJ9S
ZeufKu0XLg2dlhXLB9Rs/dJk+zFNut/FNLTY13597Anbn+lwbBzq1AXQ+QMZ
C+kIutJSf76L+dOhM9++RRnJzq8M8Csz/7n0kPkz8OKLfVMz+5g/A/kH9ldq
SojFDEx+KJ5pjGd+HdzVM2wi32V+nXR+gk66H0QdCls0iwL72f7JlPYrMmH9
2EbRq2D9K9PFTNn5l4Vi99aBnDhiZCFty95ttiqWP0t6HopZsvM3W8rIlp3X
2XAJfaeycJj5s2X14/FLzovxbseInWUMHu0hNWZTbxPzvLSeAi+NV8/D09rt
6ZZrLB8vrXcXD4vRe0sebWL59bL8elipvJVXRlh+vfR+4/X46tSuoiQVsSDj
ej1WFPQ3jUohFvVYcuhprDaA7s8uPQ48s/+2ZDm7Tw1I6Kxc3+5I7GzA3Tp/
v5ubyA8DBvT5r9YcIZ2XjRdker0Bhguuzb4CsWhAZHD36quDFK/LgNxUc61x
M8tvlN73zkZkVUT1BJ8lhhEP3J8Ve2tYftl4wSjLb8S07OPtG6PoPSEape+L
LiMG+8O3F6nYe8OE6Ec3Tk5aR+z8mmPX/3YwjRgmONxMhVU1MW9CaUexJccT
Cya4mN3uej5EXG+CR0bguZNx9N4RTTA/PWOr6jFxlwnWVWou1Ie9j3Jgcb1v
5fAnCvwL87LApQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz11I01EYx/F/bqUpSzNd8610swjN4bJZztZ+m9vcJIuWEYKr0KJgF5IW
ycLaRVFQSmJI5MroYqZDIUVaeJG6NqgoWi8SdTEombMITaS9UVTsOUEeOBw+
fJ+L5xQ0NpuOJ3AcJ/9z/77sCA+OjT+wiBHXgirieNjFX8PMQdE5qTk2WkBO
wsoGieluPXMaNFcTJYej+eQMRM/ymvb1MYtQq/d6ZpTMubB7xgQt/RvJ+Thy
4vmNutAGshj1B4LmAQNzIV7GGj/MdeaRN8P9qv32TCCXvAWLdxzF8gTmIiw2
hFN1TTnkrRC5POGp8WyyFO62nvN9QuZSGLPf+rzaLLIMN/cUmpI6RORtmC9V
1I4srSeXwXpa0uxUM2+HRRrzv34qJMvh/9p/5pA9k1yO4bw34qLZDPIOXLY+
aQvbmXeiZDbHlsxnrsBcT4t6SLWOrIBMf+tRzYt0ciU+9ZbLP3Yz78LRU+bY
s+BashLpwYkpp4l5N1qdlaqRe2lkFYwDw4Ob7KlkYFpw5WRkryBuG1CilNY9
DpA5Ne6r3R5vFutq+Fzvlt6HU6hr0DudEnHIyTbNsl6Fso5vIfXEaupVuH6R
5/Kbk6lrsTDq+9meyboWXZ9bz2lCidR1sF6ITloGV1HXYf81WTH/Ep+6/n/b
9PRfjno1UnhD1i/dK6hX0z4RVbwbMF8R/aWR/ojbZqD579SN1APUl5mr+eff
KVrgBQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzl9Ik1EYx/G3UbYxjGm2VjPdXtqwJUu3spmz/bY5nbtYoyzFJZQwCBSl
JBwptJiTEXShFkFYUKuUpNX6wwwzlQrqImOgrWBdlBFWRIWhblRW+JwLPfBw
+PA9HB5lffNej4DjuKJ/8/9mR7r//lCkgceivptO1d/l7gmZOVR5PVFRREkW
wqVS+h37mCVw3gw9t61gzkKntyYuuaYgy8B/MrQFHMzZkAcMI9VPc8kKpNq4
Q+qVzDz4kUQ02ZRD3ow074WJqp5NZDVsiltPQs+yyXlIBG9/lkqYNfDvee8e
bpWT82HVvKh7G95I1oJvnb4a1zEXYOZd4PKByQ3kQlwyx047Hcw6rBIsPFR1
yMh69GaY0mLJ9eTt6CyM5sRdzDtw/Xd/rrpXSi7COV9pKMPCvBP+jseJ86Pr
yAZcHDS6e8JZ5GIU1Pn7hvuZd2H8cM2PmTdrySWwlX5of5nKJBvx6KBqLEfM
XIoJz6wo70EGeTc+buP1TVuYTZDLpqa7uiVkIL0x80vwKNkHHB9yGQ3za6ib
8So9eCTpTKduRu3WLvu4V0zdgtjg5M/X82SfBcn87va+RhF1K7qmWtosc6up
W/GtOPXHok2jXoZIuPms1i2kXoYTJ1NjDTdYt0Gg0KTEA79Mi92GloES050r
HPXypfaVL33PVSzrFaiu1YWP8QvU7dCf+TpnHk3S/3bab5Z65bJeuaw7ltrn
oL047i9Uj9la
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtMU1ccB/ArCwsDykOhQ3lahgJ2wizFIbB+CxShQOm7yAojbAQ22YZY
bTWaFeLcI8MwTdTNZQFdAIt7mjKwDiuGl8tcgKwQt2wDH4EYM6JuPMbitvA7
f9zepLn55Ht/vb9z7jlnY/Wb2hofjuNq/vv9f2eX0OB0fb1bhFXNyyqktcJa
ATMH3an9a6YubyT7YSWp8mhfDXMI3lp4sMMZxByG8X7rq9OOOHIECl2BVVNG
5ii875DcrvJnjkNd8tl4JWLJIoTaGhdSq2PIz6DjbUnM3FA0eRP+lIX09vky
J2ImOHjuK0sUORmSUUVrvSeSLMb0SHjBHweZt8Ld4kwNvbmBnIrue/JaVRrz
c2jzdWuHD64nb4PNHnrKOhZBluBE3J1ZtZw5DQNFXclj5qfJUpzOcJ28PyAk
p2Pzr5r2fb7M23GraW1iw8vh5Ofx0qSzcsIWRs5A2niLNeES8w40D5sqlouZ
M3H404nLwul15Cx83+M839jAnI2LDXsfltuYX4DO894H49HMMnx0pdNqEK8l
A1V7Kv6+Phu6ajuQpIoPU7xO5uS498vmIynNIZTLcSBpeKmmlMzloPD8F46E
T4Ipz0F3lqgu8RqZy8Wujz9vDxez+lx8GXnh2/EiluchV7+S7psfRHkeBh8G
68r3BFKuQJf82uDQegHlCoz1/vRoajGA8nxIWu4vyN1PUZ6P2IKSDKHDl/Kd
WF3fPpTvxN7uTNk3ZznKC7zyAnS6JoXXo1h9IUYGs62WS36Ue5lTYv7i2D+H
w9n7lYhXnvSUd/lTXoQznoClDin1ay/C7pHe/ok+1n8x/3l7MVqPPNH7WwWr
L/HKS7AkPn6os57ex6n482X3MlcKj+DduiUVm79SCBq3ZU40kzk1Phs9tz/A
QvMPNZ7N3qq/cpc9r+bXu9X878Fp+N8DGvjEJS8HdLN+NPzxu73MaVG+5cOC
GzZWr+X/n13LH49bi78EfU0rUjY+HepzWr8Lamf969Az35qy4Qe2nnRQXTim
qHGy/nX89cbp+YYejznN4yoLW896BK4bsDbMkd16/n7gDLibIpK8kUT7BQZ0
xCtvpg2w9W6A/7nFyvxByt0GyEyPzKpItr+MiO5e8Zi3s3ojMm642oZ+Z/VG
9JsTrsYE0H51G7FYdMevqZjtXxNesyz2rDGRYcLMmXTpzyfIdhMU2bcP/bjM
6k0YPZCX9comdh6UwVw9c0s8S0YZcq7qYrbE0nljL4M6pU1kiSC7y3CsYZ/j
RR07j3Zh8sl3JqMfhOFfYbOb0Q==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQNioVt3b8xWcoDwPthnz3HQn8YG4zM4nJx9cb7o
MkUon8Nh/muZNdJuML6Ag2xcUFLiGwUoX8RBpG8Og81MGF/C4fH2Y/FL3WB8
GYcg0bMMT1/LQ/kKDt32NydJG8H4Sg4puf82+aTJQfkqDhOSXtx33CUL5as5
tL2Itzb6LwPlazg8V9p3bYEvjK/l4FGUtPfiVmkoX8ch99h5q1ZmGF/PYfVr
x3Q/Eyko38ChR9H68M89klC+ocOKOt88D2kY38hhssLTFwGOElC+scPV6IeW
L/+JQ/kmDqXmaqlbU2F8U4f1ISwsH9+JQflmDiW/VioZWsH45g5a0RZH9/mL
QvkWDu1VRyp+zBGB8i0daudd3iP2UBjKt3LYXFD8OaoCxrd2mP6wh/HeRyEo
38Yh2n0/168NML6tw48l7HVPHGF8OwdNP2UR11xBKN/eYZmy1y2TQwJQvoOD
ffiXGD9pqHyDg0Ol5vGfqf4weUcHy3O7Fxx7AOU3ODoUr7a237QIJu/kIPTi
wKHVQTD9Tg7czGurXk2G2efssNTK+MTyuVD3NDg7+JjXb3+sB/OPi8Pe4+33
f9TD5F0cCq59PpSoCHO/q8PCJSdE+6/B5F0dkk4o7TJugOl3c/iZWPy3cSuU
3+DmIBG/51KfGyw83R0WP2lNck6D8hsQfAAEf7/h
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02lIFGEYB/BJK9PVNNNV01xbK9YSMc1rO/a/m/e9u66VaRcI0Qpl2aEm
ThHVh8osoQ+mkUmGUlQWaYdumVdWENJaREgYIXa4YrWumVT4vB9mBobhx3+e
5515Zt4lO/fo8u04jsv9d/6/skNquPfwtlGOGVlUO41Z7S8kzBzuWuvqQm8s
Ic9DvruyPyST2Q19Hk6+1T8DyB4wq7ZaPC8weyNwcGDbtJLZD29qW5ufVcvI
ASjyiznyYsSfLMetLi+TcyDzUmg+XmzbUrOYvBzP0v1581c/sgLDScVWRTLz
CjTY7e0tu+xLDkaqQ/icvg+LyCGQHxquHwhjDoVX6Wj00QM+5FWoKFZfU/R6
k8PwPnB3Xfdy5nAU39ZOKEq8yKvRdfrpoYPtUnIE2mXV3jWOzJHQX6ryLVnl
SY7Cqx2bxsbfLSRHI2ipwydrAnMMrtT3eFaY3clKbC/M+/18eAF5DST2N0pG
LjCvxeKmKXNuFPM67G9ao7pT50Zej7T4rs5P65hVKA7qtuVnMAMuBe5fThWS
eaC+9+pBSdF8ytWQTb/si7Y4Ua5G5dD+Uo3VgXINgptnz408S+Y1OFFpVJbK
WL4BozGT05qQuZRvgCwxLUbaOIfyWGE/PlZUH4eGhwPS5350Px+H1Kjy+0Mh
9pTH0zxmUR6P8DPfrGqTTTWTJ9D6n2fMi8wlUv0Y5YmiPEnYj0/CzH6xo/WT
hc/DJwufl0sR5SmiPBUl5ZNPjI1sPqnCeXJpwnnxaaL6dJTV9j+SfmT904X9
uAzRfDNgaX79p8zTkfJMnDtu3zKYR98XmcKcF+WmTLxcZBmpciNzWtiCzx9p
KKD7oYXZ5dQuW7oL1WvxuuXNj7cTEqrX4pdL69GpCGeq1yFnZWXiq8OUQyfs
z+tg7Glp629l9TpUmyW2axFkTo/OcVd9TiH1g8i8HnYBKyYlTWSTHk1r5bsU
Ha5Un4UFXz2kFin978jC427ld8UQq8/CdXVHZ5cPvY9JlHMGYQ6D6P0NGJ9+
sPmYA+0vkwEbc8Ju7pOz9bOF+w/ZaMtd9sRfQvufz/633snBiXKyKRtbEtqd
Jm+54y+geoG+
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtMU2cYB/DKMFVQBIUCVhCwKiDohMmtYv8FKWoL9HZATGdQV0RgMkVi
vMydkSnjAzqpy7SbRtkcMSgGlXhBsCReiEtYZJvLZDNGqkYhBtGxzhhR4/N8
OG3SNL/8z/Pe+pw3em2V2e4jk8k+fvt998sfhdDe0VYRg/ca1viNpur2hLBl
2KofGfmrM5o8Ac/KGhacKGEH4ua4lQcb5exgCLvtdVWtUeQwCOdtg39o2TPQ
P3ekynB7JjkKg496ezRx7BhUZn3TGXAskqzCnQ7nnzvuRJDnoNS2P31JGTsW
VtXM6Zm2GeR4BNR98XNgo5KcgDz13rPtnunk+dinKvhBvY/9IQZmdScf6Qon
L8Rnq3d1qwzsJGQ/PfHtp5+EkZNRfaD184muUPJHKNtxt7TJh70I5akbA0RB
QU7B/ogNQ86BEHIq0so1SQ2h7DSs6798uXkomJyOxEdK0c+XnQF5pK/1at80
shpxKrn7v1z2YuRkunf++nIqORPHM5J7mg+zl2BehCJ8/Rq2BoeuNG8VEtjA
/e9TFvU7yCIQmLBQ2TsWRLkWv9tHJ8ZeJIta+H9wavsTB+dZiGh5dduWynkW
NEUvbPlKzrMRrV1fX/M6kPJsDP4996sFtWTZUtTEHXA0nuF8KcZkprGSLVMo
z0HRqqTWzTFkMQc1HcbFaZ4AynVeuQ6JmfOtVx5OpjwXnTcynsYOTKI8F9ee
T7Gs2kSWLYNPVPxL/xbOlyFoKFgxrODxl0vHE5fj+etLxbVyXv8KbIu78b+9
gNe/AjZ5k1OZw/vXo7pFrTnTxLkexc5Tx0ISuN5A/U7ziQZU9Fzo+u2iP+V5
XvPnee0/H6eVJ8/36Xn/+TBWxv/ybziPXyB9Xizwyo3S84YR2dZXKeN1/LxR
er4uIyZXTh38ehPXm5AYFPvMeYsME9J7O45ev8f7NUn/f5cJ1W2n643b+XzM
0HU+LsctMszSfhXN8OgfTPjSQHaZvfrTAs9P8l1uLeWwoMs2uzvSn+stGJpW
bB+t53oLHPZhh62Z+9/qNb8Vte61De6T3M9W9GkafUP/Ibu8cpkgfR8gSNcn
CtLxXQL8fvSs1l3j+kK8v395/YWoWCk3rfuO3m+xEO2aUs/OSroPXIVo8+x9
HAa+H4qgLt98sORcMN4AdSZrlA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQNioVt3b8xWcoDwPth7tf/akcUD4zM4RP+dvLB3
tSKUz+GgrmxrZBcD4ws4zEq/+m7pFwUoX8Th1esZ7dKtML6EwwTeu+feKcD4
Mg4uZSZTDPrloXwFh9+r937+91MOyldyWGR/5E9EBoyv4qC/3XF30wZZKF/N
IZLH+PwZfhhfw0HkRGVYnZ8MlK/lkH1ix77LO6WhfB0HOcd/W7y+SUH5eg5n
zJ5zhd6VhPINHAri6g6q+MD4hg6TFZ6+CHCUgPKNHCKVLBbcCBOH8o0dHi28
EiogJQblmzjM7JuXdahMFMo3dbDIsjfqFYfxzRx2Feh8D2aC8c0d0qcylfAa
i0D5Fg7sciwhRy4JQ/mWDtqyYpLpiUJQvpUDN/PaqleTBaF8awe3vS+zHC7C
+DYO/xkC/yeU8EP5tg66tnoh+5/xQvl2Dtd4OzJ++sH49g7feHc2/jHlgfId
HPYet3qn8RjKb3BwUPaadi1qBRdU3tHhxFHb8pJdHFB5R4efOpNqludwQuWd
HHQ2s7CZ9bFD5Z0cJj4urnb6DuUzODtU1f86mL2KDSrv7BDYY6jN0soClXdx
KF5tbb9pEQNU3sUhPMpoXZHSf3uIvCsqv8EVGh4fofJuqPwGN6i5MOAO5wMA
6q6voQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU1EcB/Djs+kyNLfra8ttSYjG0lnpZrXfdL5Nt7tNyx6kUIIaklaE
IS5pRdCiMIQoNEoS2hJMTHMVK3qHf8gICSEM7UFYLf+olLQH+90/zrlwuXz4
3vM75/e7V1nXzO8PJoTs/Hf/fwoXZxv2DDaqICC/fp/y44H5WMEE3JbLPU9H
lGgRqJq4mHN1gqMBdPnv5yMFSyDpk2hK71Kg46H5QoSnqVqwDMLSXvcap5PR
CqjZkXFyT7pgFVRUTT1q6FqDToGxFXsd3W/l6HXAj80Z16oFp8LsjaAntuMy
dBpIW4Z6fKNJ6PVQNekNl0sEq+Egf2lEEZ+IzoCrWkfkjDMBnQmDA80X1bvi
0RpwT8qn+/vi0Fmgieut3X2KQ2+ElEMTbxakgjdBToNe44yTojfD6bbHx35d
kaCzYaG2denEcCw6B9LlXEJ97Wq0Fjpn65yz7hi0DpSG+jNHlqPRuXDHf35D
4vgq9Bboe3H9qPiw4K0Q1aLJ9XVGobdBzJyE83NCrof7z3RfU2dWogGSl8df
5fgjA7YDND4ffeC7K8bcgPMQYW4A/9DEUrs0AvM8aO/x3ePehWDOmOSD+Wxm
eqgjFPN8KM/uGJlRC7kRAv9fMOZGqK7RDLSo/ugDeQG0unL1t68RzAsgWJG2
KHb9xryQtr2Qfp8UMeuLmPrFTF4M4pBbbZ+7gnB9CdNfCd0PKWXOX8rUL4Nv
2sXlPPUPPF8Z1v+OeTnmHzAvp98n25n1jEkFXc/OmFRClvPLT4N3AfNKZn4m
+vxgor+P3UTPx2ti6pvpesDYbqbn4TXT+xGe3g945n/hoa1j8WHjzXDcn8f+
0cQC/Z5J7qUsDNcztlvo+l4L07+VOb+VmaeVOb+Vmb+NNtiY72mj63kZkyrs
g5C/uetv2Q==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtIU1EcwPGTb12Cmi7fj/UStZla1jTdb5vT+d6dijSCQjCCqUkL0qll
ZolkwjL6w6Jif1TOB2WahJYzy380UST/kCJDMFJLK3W5Iiv2O8HOhcvlw/ec
c889f9ywolOqYjtCCPf3/vekF7+gt/+RRgBWrYhfmKbXeFupCThOTnYJjGFo
F5gdvtlUn0XtAWVTZ2p6lkLR3sDNlDW63aD2Bc8BtaA8jjoQSosqwxPHQtCh
kJz98HvWDmoBxJ7oXjWogtE7QbP6o23VEITeDYXNM7qlzUB0OFSo9eeWU6gj
4NNAXfnzjgB0FEy9G1x3cacWwrEyrwRzlD96H/w0Lkw0VPuhY0B0Nn/OyeKL
joUL2p7osQzqOGg2H1eUvtmO3g+3+r5cCXKlPgB9Jre0O4t8dDy0tg3J1jqp
D0L8N3V45nsf9CGIb3l5Mt2LWgQTHc8aL057oxNAVxn5cXoXdSIEP9U+aRjd
hj4MfeX3jgh9qJPAqWDL45VhL3QyHHU2tAbIPdFiWHy7pz66zgMNIBrvvzsy
i64FUJZEjK750S6BvUnC/MF5d+wSyOlolhf3ookUHkiGX4340S4FdaReMV7B
wy6DuKufzRKTK3YZ6Oe0VVKzM/YUW9emwEbUter7JTieyOG1/8rCdQ837HLQ
nbcMaYxO2FOZnsrMT4PLek1CVQhdP42Zr2Der4AQRbaIb3TEng7LIstvqRDH
16YzPYPpGVBze2qA/8EeeybYhUZYeO2/xNbOmGQBz75Tt9DyFTtjko3rr2Nn
THLwfDewMya5OH4eey7ui15KW4OSGa+03Y9JyeyfA217orjbQKzrAAfW/4kd
ngcHXFNMpMMlB6tNHBSqY7tOCzZxvsp2PVAx56Gy/V4TY5LHvD+POa88Zv+M
Sf7/7/8DVTNTEg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1Ik1Ecx/HT1Jwoa7b5bNZy26PoNtbMzOVrz29LNy8MQTC9CwUhptBV
RANj3fRyUWxzIBQGg/LCWNBMQlIWSEkXXmiUFxlii/AlcUIoszYq9j8X7sDh
8OF74JyLv7H/WteAjDFW82//P/kSuqfevBwUkVFCmkpaBi/ncTOMrZ+Oh58Z
yXJAVZ7ccnMr4avrWZlYNZDV8I/LPQv3uLV4pZ95uiJy61DlZVWrMT3ZgHTH
xP0bedwi5lVlllRzGbkCkem5arvnFLkS3+L1RjGqI5sQei9Fehi3BTrldH7I
dZJsRXjnyrH1wAmyDaPHW2Iv4qXkMwhuXzXdauKuwRH/UnrjtpZ8FruK7jlz
tYZci4BbY/MuC+RzEKPyR+8ucdchpn+sHSvgtuOTaahv/HUJ+TzuLIyW9lq5
66H70gtlQE1uwHePuTF1V0VuhGt2w4PFYnITlqRgruYrdzM+fK749buIuwXX
zaGRYFRJvoCb5vnkQCe3hCGnf1YRVpCB4p9qISGQfYDMYDkofF5E3YHaB9v7
jrcF1B2wTuYetT/Mp+5EYnIxNVzCe5bZRQw/+TgjrOVQzzJrRWb+ZNRb6f0/
Uqa3oTAn4t0c2c3Y14adhoO00/aDuuuwfa7D95mb+h51d1Zvp38w9hdPuL74

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1Ik1EYB/A3DTJ1tOac86PSYWZac82c5ed/c5s6naYg5Uc60kGlpKmg
YsLbB1RkmGVdpFaKrm4SvRANozLRFFEvjHVhoeaILDKzRmQGFT7nYh44HH78
Dxye5zkBJ0ozzU4cx8X92/9PtiRZvQM9xTKsazl+qW9qxi5k5rDY+TivrS+A
7ALDxXMr9wuYhXBur0mvXvMni8GPXe5WdDJLYTs94RWvZfaDu8fLqrLFXWR/
KN7sN0XGMctgVgkrVht2kgNRqC/+Nji7gxwE2zH3llENczDyMz91jOf7kUMQ
2zspsFh8yfswqhiorJ/wIcvRNVWTERXJrMBQqrggq92bfAArrXJ9v4BZiZ6u
0iZ5rpQcjsGhTidrthf5ILLrlnT1dgk5Au/bXmcJfZhVWDgvCi4r9CRH4lSR
vTpsD/MhLGdMN9xWMR9GWoWw9s6wmByFwKpNt1RfPcjR0MhNTeUm5hjkJj53
Xe0WkWOxPk/mOJhbLU61D7aT45G3pf2ur44ZEJSIPl85K1w3DxwpCRm3e5M5
NY7mKLvKZdsoV+ORemh4xFtAucbRvAY3Ljn3zx53pTwBzVa3X5YIN8oTqJ8u
lGsRfv3LT/WLrZRrkRPamDRZTfc5naN5HQTlyujpC+x9/Yb3N5hLdLzPJzrW
wyXhmtL8ttnE6k+CUT8ybItl9SfDV7rwsfEmy5MxZg388dud9c+AD2Gy8DN7
ybwBlScfPkuXsP6nOM6DT0Fbx6hng5XlqRir0cYUBdE8+VTU3Zt+Kpln8zUi
Z2VGtfsPy40IfSW1d8yz/5GGgM3v5r6vkfk0aFvmRE+ueuIvw4DzVA==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtMU1ccB/ALolY6fMJVkAl2aDqoRWGgQIFv8QUI2Cel9YVGJhGcU4xj
KPGaKJoNnUzji8yIGjUQSRRxIhqvQdhQweADH1n2SA06s2m3CVoWhy78zh/n
NmmaT77n/O7pued3Jq9YaynwFQSh6P33/1/2Ee2NzWeLNBiUJ/XW5aEZ21TM
AtDR5o5qmExWYdnnjxa3O5hHQ9fYPbbw73ByIJqeVGwvrWSeADFmsc0TwhyK
6N4H47wHwsjhSNw8kHHi6SSyBn0dB/cbpjBHoPPfFY9/3/0heSpSHn/6fPmz
ULIW8fZ61W0LcyR6/jr07E7PRLIO51aJU2v9mfUw+fvs+mVlCHk6BuLWlO9o
CSbPwDdfGk9q2yeQY1BmqEmxRzDHwnpowG0KHU/+BBHruh55g0RyHAy9136u
XBpEjsc2v/YbqgOB5Jl4seZ6b2zfOPIsZM3c8r1bz5ygcCKum+Rq6dJYchL6
vqofv+TVGLIBCZ3NR9t+HU1ORnPIvu+aXjKnwFQcebM3mDlVMR7oidbEfvYx
1ZOAkrqk1HPHWG7kx0tGnGg/vlG9YSTlaWj9Z5TVte4DyhUWZqM4bc+VkTU0
XpoNhyumfr1mFOVzeEtzcMGzJzqkg9Wfi2nJetvVngDK56Lr4v1XD9+oKZ8H
V1RVemcpWZqHjzL3d7tO+1M+H17dt5tPFY+gfD48DV1vy4PIQjo/XkrnxwsZ
0DX4DYvfPZzyDJytX7tPv0hFeaaifibC0rMTxNqhlC+AuXJGlN92P8oXoKKq
KHFTGNUTsvh6UpYiz8bLhP7/0vTDKM/m6wk5ONX8QLwRSs+TclDlLtmU9prN
X6hY/0LF+k18DhOdvyE0XmHZRO9rIHVwvpk3zIjd9edro+wdtGSGesiZsud7
fWi+ma8nWFB+5O5l8TcyLIr9svD/T7Zg8L7ypflWvh6s+LE1+YsNl9h+Kixb
Ubal/1pRLe2nYOPrw8bnko1fj2zj1yvY+f2GnX9/kh3V3WrvyTg6n7IdvuGR
/eo61h+5OG1saW0LpvONXIz5I1D0iKxfcvnzL+fiyg+JL7RuNt+B7oCdhd4c
Nl9hycH3o+yA8/CZmiAd6+88vt+Rh69jCn6qzmf9noc6g6ZQ20L9KStywcnf
H3DiXkHfCG0Tu0+c/P0lO+FdXvJ2ayO731yY1FRyYcdNMlw4nLO13+1P96Xk
QtLq9QfzzwfiHfV3tZ0=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzVtI03EYxvE/imlJy8rNQ3Nu00Ks5rG2tc09m8ekaGRSSlQGHWix0q0t
s2AJUReK2oXdmBUumAcUCQl0dKA2VjddCIugs2BRlGulm6KzYu+PaC+8vHz4
XrySo2f2HovhOK74z/69bAS1YxOjRiki8muviSTGVh4zB/WP9pJX9yXkBLga
4t4ZTjEn4WPnjfczKczJOOGXG00PxORUmL40Zg01Mgtxum5E9InHLIY5MNcm
sWWSpegUHQ68/C4iZ2PYGmq+e4R5E7iWXy+E7gxyDnKOv76lyGfOhfrm7MWa
XiF5C+YmvXuawxvIMtgCul01KuZ89Bv5YWd/OrkAPX3pB5570siFyFsuuPc1
lrkI1lHR9do3KeRidHeYzg5cYd6GIZXDU/1ZQN6OFf41vq6TzHKEm4IbV7r5
ZAXUs4/fth1iVuLqhafnQz3J5B0w5N2WWlKZVZhvMC9dHltPVuOOw8vv8K0j
azDlWrJvljOXIGNw0XdQvpasxc/weF1rfBIZODdhUCtCvIjtgONZnzXRQuZ0
2KqR7Xs4vZq6Dk7dE7cnjczpkVXd7at3rqKuh9etsVnGE6iXomvK3KIPxlMv
RWbVbqVgII56GS71TroEH2Kpl2F/feFwk3RZG+nliBHnLiQOLkZsL4/qFVG9
AkXt34K6R/PUKzGjXAjrZdPUK+kvm6r/bY8ytzOq//Nvrx7Feg==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd031MzHEcB/CfSqUjUV1FXF3NyO1GpCfcu4ej5+6hK2k2azPWUU0XW2l+
HrKZx5I2NjZpK1GmtKjk+qOEzSat5g+ZRWgitEoo7D7f2e/7226/vfb+fr+f
z/ez+/ln5xl22QmCkP339+/NHrmpue2OWQmbxjSDL+f16VyYBeQOmGJqG/3J
zki+MROVY2Z2g0Ld7LjPjdkD114pHzbV+5G98bFRM9SfyuyLgLcXLd1TCrIf
ZgX97E4LsxKl/dPjJc+WkwNRed5wOzeWeQXM41M3xquWkVfi51NlX1YgcxC8
C7/mVxzzJauw/0pwlWpwKVkNXUuQf2gM8xq8+9YUZm1cQl6LitGickWvDzkY
i+62+ZQFMa/DjnOqS4N53uT1mGqRZfj2eJFDcCuyujvhg5y8ATmhua6iiTkU
l/2aFw6/9ySH4afrbk2nljkcKQVuxZVdHuQIxI0MdLieYo7E2fzCuiwj80Ys
lnm1D7e7kzfhk3vmromTi8mbYdlT05EqZ9agV1Pu4PVqERlYlRLgod1HFoHv
M62ZR53cKI9C9ePrB2QWV8qj8OBRxOeVQ/Mpj8bEgvtHfoWQxWj8UJUfqtk7
j/IY3GnIq1BnOVMeg4CEyv7ttS6Ux2LdmdHJKCutF2Mx1vT8d4kn26/Fl/Dp
mWi1I+Va1LQNyJ/4zqV8C/Sn1652KHWgfAuKDk93mutovbBVanErVz8O54/b
33u9gyzGSfsV4qFqcnDccNaJ8nguT4AiLjlcXkf9iJyFRNi+LzvKE7n+k6QW
k6TrhWTufskoufqiXf7GnvIUlA0VFEdPsv5SuP5SufM5CzrpfKHj7qNDUujh
liE11bPquPP1OFFmjihWUH3ouXnrpfOz6qX1BIN0PQxcfS63GtDTtemgpZXV
N0rXw8jd1yidl9UonaeQJr0fOItp3H4uF0yw8wualt38pbHtNyFje3DDfuWs
zaKJm58JBTcjNY1VAu1Plxrp3P8lHTL7+qKRC3NofzrNb8J2vpBBHqb6GXQu
PSJnK2dhm9T47z+mi30H
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQNioVt3b8xWcoDwPtjn+YZ6rhaC8Rkc7nuw15xY
rwjlczgs42Q3YwyA8QUcblYXGO/5rQDlizgs19ucljEHxpdweLr4UrKwF4wv
47B17uJ19ifkoXwFh7JDH3NXfJGD8pUcJHluq5rJw/gqDssevDw8J1UWyldz
6JkfNXHnHBkoX8Ph5bQjlX63pKF8LYd63f9vPDlgfB2H5aHXt5jmSkH5eg4L
LFu5HvdKQvkGDgovN2+9cV8Cyjd02L1Ibk6NFIxv5PC2jXNVa4c4lG/s0FdW
32RzTwzKN3GwUttwY00vjG/qUDlB5KonI4xv5rDi9uGpc6+JQvnmDm1np0tG
6MD4Fg7tVUcqfswRgfItHWrnXd4j9lAYyrdy8N780SvQHMa3dijJWL7PX0wI
yrdxgMQfjG/r8HjP3wZtcxjfziF17jKm6gWCUL69w26pKXN3vheA8h0ctn2Y
oC91lg/Cb3BwWHJycRl3CZTP4OiwwvHw0WOSvFB5R4eLO65+ufGDGyrv5HDi
qG15yS4OqLyTg85mFjazPnaovLPD8t3XxU7JsELlnR3kPXwtxVZB+QwuqPwG
F6h/mKDyrg6BPYbaLK0sUHlXNHk3B27mtVWvJjNC5d0cjHvffnc88NMeIu8O
lf8I4Teg8Rk80OQ9oOYyMAAAetXFfA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQNioVt3b8xWcoDwPtinfvI5WMsP4zM4bLn274jm
SkUon8NhVq3RCV1HGF/AYcezfZnyLxWgfBGHBGt3d665ML6Ew85HYm7HPWF8
GYeuQzn9u67LQ/kKDv/uKVvNUITxlRyWnFxcxl0iB+WrOPSIfeLeM0cWyldz
mHTinuFcDhhfw6EpNGxZtL8MlK/lIDPvwM2ei9JQvo5Dhl3IPgVGGF/P4d6d
5+n9M6SgfAOH78kWZye8loTyDR28PohtbEmF8Y0cCmbm+Z84IAHlGzvE9uvM
vJcP45s4XI1+aPnynziUb+qQ8rR4S6c1jG/msP20OOufBDEo39yhueXwnekH
RKF8C4eDyi0aDEowvqVD7bzLe8QeCkP5Vg6TUz9MjlkuBOVbO7jtfZnlcFEQ
yrdxKN64vjOgCsa3ddAV1Pg466IAlG/nEJCjdfqrJIxv77D3uNU7jcc8UL6D
g/y/s6ctPnBB+A0ODh82X/xbK8oJlXd0qKr/dTB7FRtU3tFB3sPXUmwVK1Te
yYGbeW3Vq8kf7SHyTg7vLX/9c9J7BuEzOKPyG5yh+mDABZXf4IKm3xXOBwBe
tq05
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzl1I02EUx/G/DttkJKu2ZfOf28xenOLypXJrc79NnX9XRDiErJQKdrEU
wuj9jS3SuknUVTeRJYWj0iJjEU3CxGhFJpQgk27SECqk6YXl0FGx8xDuwOHh
wxcOj/bQkWpXMsdxJX/338tGWRMIPmnIQlwRC39CCSfPzCFiXL8gDmnJEuin
1U1SN7MMbsXT+s4UZjm8oZaM7vsacjrcc+/rbgjMPJpmR4ZSJ9RkDWKNfWF/
LXMWsg2nhZs9meRsND8YeTmoZt4A7+Lb2cXda8mbMBOua91zkCfrUC3vz3nz
OIOchwHd7Y9VCuZ8HI5OumJOFXkzRKNdY6XNa8gFcAfb3IFwOrkQvcL41NEk
5iI4CyRc2LmaXAztHa/cOqwkb8FE12iNTMW8FZpJxfW7tQryNtx6btrneyQn
l8D2ypmZq2Y2oP6K/Zt5aBXZCJ8r4tvvX0nejt/3xBe+WplNMBXuvJx2YAXZ
jB+fN17SX5SRS3E855qvo4/Zgu51jvHiQWbgWaRNrxpOi9sD7OpprXAFllO3
Ym9uu/DhlJS6FfN5Hef8janUbWhpbzCeVYup2+APjinf8SnUyxB6bT557IWE
ehl+GqIxW/4y6uU43/mpX/lFRL0cUlHvme++JOoVKLo6/cs6MG+J9wRzdiRr
dFHpwwXqdro/R72S7s1Qr0zowlJ7hIT7VQk9wZyDPEXdQf9ms2OpPf/9B+0F
3/g=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtIU3EUB/DrK621WmVL00zXgx4yX/nO9nW6Oc3NTeesBQWRECg91Kis
8KoVQUtL7QFR9KCyl6RmqUWsTJMiwUYFRYEYQkI1MqqJzYqd3x/3Dsb48P2d
e87Obyxi8/b8Ym+O4zb+e///ZC95YceD1hIFPHKqbGFDKQYJM4e7w/UXa9oi
yAEYi4q+mryOWQbXlUzVYVc4ORDX3eu/Dl5mDoL7w0bLl2zmUEQ31/5xDy4k
h6N0oi/W349ZgaH2b/YBSxh5MR7fkY51n15AXopn6hsbwj+HkpehtrK6XGVh
XoEfYY6md7YQciTeO3YsK+2ZT1ZiS8+9GJuUORpxx778SrcHk2Pw/ZxS2yll
joWf9+TDJQeDyHH4fV9SFNo/j7wKYU8//n6lZ46Hpni43XZGTk7A3uOBr7O9
mBPhNDnqTybMJSdBN/r20YyjgeRkGKMuKCqCmFOwftMTnXXdHHIqnhrtZ/nu
2eTVkEXGhAxMziKnYSRKEbdtOfMalN9MVbVdkpFV2LW8qbGhjRnQa/t6P6WR
eaB3bGaBded0ytPxRnpkq8sgpTwdJf2djxxdEsrVsK48oRvYQ+bVovoMNKf3
9PYFs/oMuCIb9l8rnUp5Jvp703ZXdAdQnolrD97Kn4f6Ua5Ba8v2JuUGlmvo
vli9Fs72wT8H5pJ5LSLbfack1PlTnoVFOafeWJunUZ6Fn9Ku6ol4Np9OOC+v
g7QsNtVRQ/Ny2ULz2TDcqtMUd7A8R7gPPgcL3S9fJDmpH7cWL+c7R5tkrP9a
UZ4rmi9XtF+9cF5eL/r+BtH+DMJ+XJ5of3k4MVy+T/2L7cco3BeMMNliVvoe
8qXzRkh8bleONnp5bDeK7seEyqrxxyU3plC9SXieN6HIGttSpphUeepN9Hvk
qD5faOTjwHnHQ/mQD9WLcns+chOr7g8rKecK8C153K1Wsv4Fwvn4AuF8dpE5
s/A8zMLn8WbR/GbR/IWi+UXmC+H5f/Wm/qKcs8A7fMW45OaE5/kQmbfQfbuo
v0W4X65IaBTR/COqv/gdilA=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n0sVXEcx/FbKWoVebi4nuWZbqSU5w/3uq5nWhatcWP84c7T3dSw6kiK
Jm1EyvWUWatEGrbExNS6zMOutPxljU13qaGlJqxav+8fnO3s7LX3Od+d8/sd
m5Ts02k7eTye5O/570oHP777VafcFv+1FDiwvjm6YkTmYbBrhzhrwIZZB35l
fa41SWQ9NAo7stdXrZkNoZxN+hhTSTZBtMxGmRhANodvW93U0rQVszWkkRYP
q4+SbQH7+M96ZZbMdkh2sHjqqEt2wP51Qc/XdAtmJ6yoA6ri35ozuyC7+Bo3
ZEB2g5X78+bcNDNmIfo7VK1jzQJmd+zO5LI2NabMHlism0t92UU+htYXb1pK
p0yYPTG2fOOKnYJ8HHlrjh2qEWPmEyj32UwXXSJ7oeDq2qD8CZ/5JIrqJ5NN
c8in8GBEv7ep3YjZG+XGk5WruWQftFtM2bosGDL7wvWOZDx4lOwH3wxFrayL
7I+4cg9XrRJyADp/VWhMQA7E5YapPv4nA2YgqVSi8R9m5oBvmcM/PFepB8HZ
Tnv+Zyj1IMgTtONS71EPxnyGs8/GTerBqOemC3TbqYu2zRch5Z1trydHXQxt
S60zw2rqYiQmD0nPJVAPgaZGEfQskHoIxi8kLH+foS7BkQUzbp8W+z5OsvV9
eKEY7el+rMih50O3dSmChbK7Chl1KartNxJ5jdTDtq4nFwaT5D51hYTWMxzn
dQRcrTf1cBRO5x/gyahHYLKtv6z4A/UI3K9oyBi6SPsbibkifaecVGYuctv+
R8FLsLdluYl6FLJv55saVFGPxuyXR3lnldSjET+zu6y0kHoMRG7TE7tKqMds
nceL3ToPsdAePKx0W6T7Y6F6f70kT8X8OhZi+4Nus4fo/42DcsI+bM8tZsRB
Lvw9q1bx8QdrGBbj
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ltIk2Ecx/GhhoZimrbNeZw5dSYeZrosaz8Pc9O5NVMxY4th7CZbucQo
u3mxoNQk2SaVEtaF2UlFLcjsJNiFdoCkutFutIMo6FKnUQwrev4X7YWXlw/f
9/+8Lw+PuPrEAbMXj8dT/Ln/PuniVzwcGaiJxT85FZ3LSuPhLWQexg2z2sk+
MbMfyltdGzsqyUFYHXvwaMkdwxwK38AAn7e3yELIGsembHpyBORZm0bsXuQY
tJVr+lfU0cyx4Hc9l7b1RjHHQZwYEOLzI5I5Ht7ur5pT8eREDFi/LNyvimBO
wo2Ny9eab4YzJ0McJ3tX9FrEnII3Iue8I4ichvEPhZZReRhzOvxfxChSzwqZ
Zaj/mdA/PiFgzkDtxY7vVit5JwLuyEufdPGZM3FUfjyQqyBnobu9LngY25jl
eFybvF7mRd6FNOO5nqe3Q5mzsWgZc2WshTDvhjTO9/O6irwH36TLZ9L15ByU
fWy6NBlJ3gu72Wk39Gxl3oeW1m5Jrzd1BSYVNh/Bp2BmwGQ1/pqYY+aAZwbJ
aJQ/zedCUblq0IVTz4W/d2/DvJ3m81A30N+kb6CehxxZyYVAE/V8j/XzPXoB
pLrtoUoL9QKsNfcJjKvUlf+/zykxInJcH14KYr0Q9VKH3TbIzHmYp4L+WNIr
Vxh1FVpk5ulOE3W1x7waC9MJ51MbqRd5fL8I781rmxOH6f+KMdOZlTllZ/vF
FSMvxeQ4aaL91qBd4q7idTFzGtQc9C09coV6CYZq61YOnaZeAkP1zGzyHHUt
DH4i7mo2Ox+c1uP86BCt1mbz7zJzOtwLXhTGD1Hfj9hBv46XWj5+A2A+7q4=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0nlIk3Ecx/HHIxx5b963pnlrzVo6r4/HNs85FTVlHgmDsmZTS9Mihike
kaYShf4RaFTLpVmplAgmmBiEiaRBRoTLNK0UxZZEVPj7/eEeeHh48X6+v+d0
Lz6bIdNnGEb4b/9/pJtN1uDIwGkP7Go92qxy/tN7c2oGnw0M73T3uxOz0BvV
XDqVQm2B34/npGUbbsRWMJlx5vTUU9vhbUPpFa03tROesiufdbe7Ervh/Igk
IlTrQuwBC5sGOauC2hOubfnZQxPOxAfReT/aTMWm9oFruijwI8+J2A+GTa0l
DxodiQMgfznNrzegDkKM3It/KsuB+BCetF8Out5lT3wY9m4T2Yv7qLkw3+rL
/Ma1Iw6BS2OJasvalvgI3t0oylO/sSE+Cp4qIz/pIjUPqttLj/zzqY9BpXg9
c7LFmjgUvLWlD2oj6jDUGU69Yt20IuYj9kWmi78rdTikLAflrTDqCBTODxbM
XqCORE21/5c5L+oo+HoaaX6KOMTRUMxtjp9wZxMDvuIDVgK55a6VAHt5bLw3
g5iJQbXv5C9ZmgXpMbjKlS10FREzsVgK9ggp9aXzsTA2eFjztYPOxyGCm9Jg
VkR7nE6Ph6Pd4nJbO10/Hiac8SrFijnpAoxO8r/7LJqQLoC+m9+OcS8xI4Rp
OTd8ttaUdCHE6haBbJCYESEnj9tX7kHWU4qw+ed5bq0Rvf8ErC541wXX0usn
7H0eJlGnJ8L0DHu1sYzOJyHQ0mejc4b2JETnbEnFjnQ+ee/7VCajVlN8TaOm
PQUVA/1NkhraU3Sunwrh6EoJZmhPxRonV7bdRL+fGNvNfbb5W7SLsb9HWyCc
oPNpKDmnHdLLIecrdcxI0CFb75DeI4YEuYXjCXnHyf+ilEAQqbk0vUP6mATD
iru5Qdb0f0pHwHpL33ArMdLhWaXXwfvBwV9pnwtJ
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQNioVt3b8xWcoDwPti/tlz/p0gQxmdwuHTm67b+
9YpQPoeDh17YhmsRML6Aw413zskJjDC+iMPtps/rDBcqQPkSDsbMCW7n/WB8
GYc3cxo6Pv+Vh/IVHN5ubdx1UhvGV3Io9ahN/ZorB+WrOLB2T5rmdF4Wyldz
cAs7LTvlrQyUr+Gw5sOBvqRoGF/LweAp77KGy9JQvo5D7KucR++FYHw9h5VH
7ybaRkhB+QYOh31E4kMXSUL5hg4r6nzzPKRhfCMH7m7zyrX7JKB8Y4eJi5gn
vLOD8U0cgg05GG4Gi0P5pg67eyYsr94oBuWbOaRnP3M+wAvjmzs8bhTSKEgW
hfItHEwu9Zar7hKB8i0d2OVYQo5cEobyrRyea36qNAyA8a0dfng/5Wj0EYLy
bRyKN67vDKgShPJtHZ7pKxnnacL4dmh8ewf78C8xftIwvoPD6zvqLfpNAhB+
g4ND6e4AG4sffFB5R4cVjoePHpPkhco7OkRpT/Q4V8ENlXdy+LD54t9aUU6o
vJPDhBbmHfdjuaDyzg4Xd1z9cuMHVH2DM5q8i0PbxGyranl2qLyLw3vLX/+c
9Nig8q4Oxaut7TctYoDKuzowKWj94l79xx4i7wZV/w3Cb0DjM7hD+c+g8u4O
xr1vvzse+AmV90DlN3igqmfwhLqDgQEAx2/Ocw==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2EYwPHTFrZa5Kx5dFNzzpRhOvKe1z3O6+bUadhqGahgaYZSmh+c
4gm6gFCpiaWpLBKzSQMJ6WLQSqL8EDoMo0/RxBhiNEnUrYsVe17inAOHw4//
+/C+HM4Jq24sq+FRFKX9e/97kosun5yaqJeDVy7VXNHSeoKEmIJb65Mhs0/D
0AIYz+xsmNERi4DZbpY4XTK0GGQlGT0rQ8SBUNk84lRqiIPhiyVmTfEmFC2D
YMXmUoBzP1oOlxUmtzWK+ABUdV9ICm8IQUcCTxblEY4HoxVgONo0ULsVhI4C
2mmkZHLiaFidT7M5+qVoJQybE49XxhIfgh+W5bmrbRJ0LNRNddVNfgxEx4Hh
1Nimh08cD5FtH+zT+QHoBBicjdD4dNLoRHDcfV8ukhInQf/14TOvWvzRyXCs
4IbI8UKMPgwVAilzO4U4Barfyp/FM/vQqXAwhJacrtqLToPNwiXBRR1xOtQM
jfJMZj90BqgMaxXFQcSZEOOnWB2wi9AqGE+X1yqmfdEAmgdWS8QgmgEYmbnX
Imzegz0L/FbEtItGM1nw+rvvEeO53djV0HWJ/+TTyV3Y1eB6ZP/V7r8TezZM
WBt7lScE2LPBHd3Tdv8s6TlsMzng/R552HPZZnJByH/YunxzG/Y8aB+ef05/
5mPPg28pnt9qpQ/2fOhebDKpN3Zgz2eflyrgnL+AvZ7SwDupa7lXRLoGwrV9
C8YxMq+FOwtC92iiELsWWjs8L+stZP9CuNJdn2oKJfsXcrqOc34d6JI7Hi8q
0VQRGIxx1vPyLZW3c0wV4//wE3sx5/2UcOZLIP7a140smxvn9bh+1WvQ4/tb
x/V69rxNz96PKmV3KOXMc2wrxXORq4xt+O8/yT4kTA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03ss1WEYB/BfFqmTUo5cEyeVsNNFTkL1dcj9do5zJlLJ0ixtLilLtx+q
ZSGky7r8UbqIlhlKWjkyJVabmZOm/imW6XaacktWzfP+8fud7ezss+/Z3ud9
nvdxSkpTJxtxHBf77/v/l30WaRse16bKMC3D5tyeq8V9UmYOry8bG4Ibncim
eFbTUW/QMptjKLJvonzYkSzFmeJfCem3mK2xc7dlc7cvsz1kFp2ay7olZEfU
ST/teD/lQJbBXzOpMA5kdsaLCplxdv5i8nJ8u+N28ZiE2QW1GQOf78XZk11R
qI81DBTZkd1hkxpiVPLFlixHXtWA+Tk182o014YVzumwIa+BXYF3zTtn5rVo
6bzhm3jKmuyBsYeSWPt2K/I6lAZZyXPeLCJ7orKv9fw1vSVZAYOq++x5BfN6
+OzNvJRYLyV74fWurT+G31qQN6DzQcPdzHRmbzxMvx0nt2T2wZomuxUfDiwk
+yKvP6mo/94C8kbYWX8cLC0zJ2/C53crTqzKY96Mal9ZikvrfDKo3/OmzQNm
mWt9uvPMKPfDiNmj3EnPuZT7YcnUq04vwxzKlVgaekEfX0nmlUhtb3za/UhC
ub/QvD9KP+4/rBydRXkA2ts2Zmc1mVIeAENd15+jlrMp34La+2nl8m0s34Jx
97Ijd/axPFBoPhCvbA1D5easviBhvXwQKv1a257bsPsFC80H4+bLioOSLOoH
F4Iresn4bU9Wf4jo/FDkHJ9oSa0yoTwU3zdMTCnlZC5MWA8fJuwXFy7qX7io
fxHoauz52TvGzo+A3ux0yngkqz8S+5QlT+ZdZ/OLFP6fi4KRo+uEpJrNT2Qu
Gh5FX0f9dHQfRAvnw0cL76eLhnvdTBNFMZufStgPqETzVgnfj04lOl8tfG9Q
o214fkx8BqtXlOvUovnFCN8zYnBo5Yvx5Ch677zIuhgkZmz/3THI9kWDpwnL
WhwktE/Q4ItFXPJIAZnXYCxswDQ3nKzTICHfI753kO2fFs7ZM84pvtN+Qouc
Q26f9Mtov3ktKvpPJvnvkeIvN6xwVQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tIk1Ecx/EnXV6ajGlz3puKiUwZLnNNTf05b/NWTPBFXtIi3zhBrEhT
zCepILyk6YtKECZlYBiaDVJTTJLKUgtlgr2IEkNk2bIbziUV+x9iHXh4+PA9
h/85ISer8sudOI5L+vP9/bMlLTCODelDYZcluTxfNdggZOawPRMyWToYQnaD
5vxrebeOWQzbA1Nx9ZdgsgSVrXMtIzeYfaEXNVV5qZgD4XZ7Y4UblZGDYa3n
ysIFzKGo/a5W/yjcRw5Dc9vYvHEqiByOmGW/jan9zBGoMDfWbOoCyXIYBpei
6xYDyFF4VTdzoteHWYFpo6t5oMyfHI3i+Sz38bd+ZCUqbE3GpxeZD+BCkM+d
zVVfcgwGtMsfT+9iPohTq2ceXk3wIcfig2GxQOwvJatws62nYuqcN/kQ5EXq
6YmjzGpo15cmRM0SchxKl4zHF2qZ41Hj3c1d69tLToAy49ZI9qwX+TA6yy2d
xXeZE1FWXbI9s+ZJTsILU9i3bQ/mZAT4rqx1XBeTga87o8eaXMk8UKlpHxcZ
RNRT4GmWSC1SMp+C8WfxGxErHtQ1kO3MvlRb9lDXoDCyQztXK6Seill/y3qX
mPVUtF9yfvSuhMylodsk3OqLpf18GmJaP/1MmXSnnu5oPh3PpxNrzo66Uc9A
XaP1ib7fhXoGooYFLqo2V+qZ/53PdJzHaR3fw2thGX7zq8Gbzc/C0P2qLkUR
zeOz8DnOuqNR0DwuGzJtXpy0fzf1bOhalJGCywLqObjSoY+vl9F9+BzH/Vwu
GnoWHkvfO1PPhVOw3Cq8Z0u29zy6/5bdfB6dY+uIo/l//g1GCfQ+
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQNioVt3b8xWcoDwPthHOHs1OfPB+AwODq6bSzK3
K0L5HA6ap0UvvQ+C8QUcRKUW7Dv4WAHKF3EIdRb42N8G40s48DR4diVZwPgy
Dn/Z15hvWiYP5Ss46Do4NU58LAflKznkvROb+5oHxldx+JCR1LEoWRbKV3O4
EikjX75SBsrXcDjzYMttez4YX8vhYMz/e4l+0lC+joPLvep/wleloHw9h/9c
rUnz5GF8AwfV/ituPwsloXxDh4OnF9kktElA+UYOrPncxrlHxaF8Ywe/cwFH
lmfA+CYOc+Wm7pttB+ObOiTte/Dp3xYxKN/MIT37mfMBXhjf3EEr2uLoPn9R
KN/Cwa9YoHraUREo39Khr6B0VXQwjG/l8DOx+G/jVmEo39ph4yep+VUZML6N
Q0yzcdSNF0JQvq3D4z1/G7TNYXw7h4Jrnw8lKsL49g7LlL1umRwSgPIdHJac
XFzGXcIH4Tc4OGSf2LHv8k5uqLyjg3Hv2++OBzih8o4O7y1//XPSY4PKOzlA
0g8TVN7JoXbe5T1iD5mh8s4OTApav7hX/7GHyDs7hEcZrStS+g/hM7hA1UFB
gwvU/GdQeVdUfgMan8ENrh8Aj/Kwqg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQNioVt3b8xWcoDwPtj3yD208uOG8Rkc9FYwFN/e
ogjlcziI70qt3h0G4ws48K96GSb1SAHKF3Fwn6zF+KcTxpdwmMB799w7BRhf
xsF3rpr5g0p5KF/BYfuGqjch1+SgfCWHpI2JW7+pw/gqDs83fYktzJeF8tUc
YnYpN83ZLgPlazgkJ7vvzhKH8bUclq7u6vukLw3l6zjMed0b19sjBeXrOXxl
f7UsfaMklG/g4Lk7X/wzI4xv6HB4+ZY55rMkoHwjhyMi5ZUKn8ShfGOHQz39
gouVYHwThxiGYLGAiWJQvqlDvJkt292zolC+mYPN14P3euJgfHOHXQU634OZ
YHwLh/SpTCW8xiJQvqVDXIfbS9sjwlC+FRrf2mHjJ6n5VRkwvo3DyUoXmxQ1
GN/WwdX2Sc35X0JQvp3DwiUnRPuvwfj2DlklP7YxhsP4Dg5XUr9xauwUhPAb
HBxKMpbv8xeDyTs6FFz7fChREcpvcHSYuX95eagOTN7JAZJ+YPJODnuPt9//
UQ+Td3bw3vzRK9Ac6r4GZ4eX04oc19rD3OviMLfhahX/Opg8Gp/B1cHpYLCc
tjw0fBpcHS6s2dvZfA0WXm4O9yL62nu+izgAAI3ssNM=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GlIVFEUB/CHlZqTNm7TlKU2RZSJpbllqf8xd01ncRy3UoqQmqLFaSEL
XxAZQYsmGS0mViYKokmopTVZY0YomFghYZRUpAUTSZmUVnTuh3cHHsOP8849
9513z1u8Zbdum50gCPl/r3//7Kcw3LnXbFLhv2zRpxKqx5zkzAJmtdQ0uN5e
THbEtRlR6so8ZjneZjufGLJn9oB5tHB7Tb0vWYmR1u78m/HMC4F2u9NTX3zI
vqguOXNF6cesQvDEYOz3c97kpeha0dMU3rqIvAzlPcOBVx2Zl6PUoFJ6GReS
/dDfNjj+asKL7I+TvbsUe5cyB2D49cfCsxcXkFdjaKp37H3ffHIgIiOSAlUF
zEHwSbJ6n69SktfgvV3rgfJ388jB8H48PPF8I3MIqvbXDa1WKcihGDnmtnzP
Vk9yGNKK5MUXrB7kcGhWVavMSua1MGU5aLdWupMj0Pmk9M1EiRt5HeI7P+1A
vyt5PfIcai55xTFHYlHDrxd5YcxRmBa00wXmueRofHduP/YrZA4ZMPW03R9o
l/23yFlQo079yNo935niauSsLEvsO8TiMdL1xBj0LrCNVsidKL4B547PaHuz
iSxugM9U77NwG4vHwtbS//uo52yKx+Knf/mRWzvJQhxOlJkiin0cKB4H/5aZ
9qFnyEI81pz+8kNtYfmchQTpemKCtJ6QyNVP5Oon4XDJ5ENTvT3Fk6T7EZK5
9ZNh/TZXn7OX9TcFl1/IftaGsP6mwM7Xb1LWwOKp0n6JqVz+Run9Imchjauf
xvU3nVs/nYtrpP2ChuuHBmUjRcUxP+h5LRr0WCMPmu86Ur6Wy9dK7xe10v1Z
tNz+dVJDx51HHZobd1cE5FI9i457v3ppf6GX9k/Uw/Wzh8KmcKF8PW48vX5A
ZiYLGdLziwwuP0N6/i0ZMOYENe5TsXkyYI5718E9n8gwINo4npfmRfMnGlC7
JHkouEtO+QasD0otdSlg85kpnWdkIjfhgdNkE827mInUsJLWkQD6HlgykdLy
NVkbxr4PRmTndyXmZJFhhJtsXseHDrJoRP7LO5sHDnngD5UjifU=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQNioVt3b8xWcoDwPti7Nj2PYmOF8RkclJ+ujpZf
ogjlczjsjX695pc3jC/gUPVFXd7hhQKUL+IgUPn/yc0mGF/CgXXLNlNPPRhf
xuHlg/DyjYvloXwFh/jLbvb1b+WgfCWHk7LmAeuCYXwVh+nLr7vbzJKF8tUc
tFa2MvT+loHyNRzWLY1VfCsI42s5BGzXUjR3lobydRzCD75w5FkuBeXrObzc
7zl71k9JKN/AwWn3ny73Ohjf0EHh5eatN+5LQPlGDtev1p7qsoHxjR1ExU21
zzaJQ/kmDtsPcLnPfy0G5Zs6bI2pSgjPgfHNHHYV6HwPZhKF8s0dAvQXKJVI
iED5Fg7dvUtV1zILQ/mWDk1PknqfrBGE8q0ceHOEXncUCkD51g7rpddsv+TN
D+XbOOQ4TdjLt5APyrd1WHJycRl3CYxv53Bxx9UvN35wQ/n2Dsa9b787HuCE
8h0cfupMqlmeA+U3ODi0Tcy2qpZnh8o7OgT2GGqztLJA5R0dfMzrtz/WY4bK
OzlwM6+tejWZESrv5FC82tp+0yIGqLwz1L6f9hB5Z4f3lr/+Oel9g/AZXKD6
P0LlXaD6YMAVzgcA9YyjgQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0F1Ik1EYwPE3NzKd1prmtjZ1HxrixthmrW1uvc8239rUxAYijd0kjKgF
SUMKU9hFXoyGZUJBQcQoHNkH2oTCIdUoBb8J6yb6wDDyIg3mtKGzYs+56D1w
OPz4P+dcHHnbebcvh6Io09/97ySrpGVkdMivgKxW6f6BhfhGATEFjqrYy+6Y
HL0LviTuhK80EvPB7D5VqkzJ0MXQcNVscEeIRTDHbxM8cBBLYb7wljA5VY6W
wVxq/Z72exlaAbQh4J2oJK6Aab9mk9NSij4AeR9j1yLXpegqiEorfb4PEnQ1
WBOTlvEzxGqQV+jnXVP70RpYLtui288Sa2FR+arm7pgYrYNPEu7n/JQIrYcV
rfn4cFKIrgH1M+5OQy/xQTjZ/ZMJr5WgD0EoPfdQvLUPbQCHemGW00N8GFTj
orX7X4vRRhDwhPGleBHaBIz1W9dsWoA2A1+tk8xs70XXgjc3clvCEFuAbk16
myTEVpDbToc6Mnz0EQgMPQ01d5JOszpAYLCWHo6ggwAFRa8vtv/Yg90GUVvi
zVtxIXYbdIw2W4wbu7HboelRL+MbId0O5ZnpSeNqPnYH+Ceej717wcPugN/q
G10D5/Kw14Gy/uZ7TxTng3XgUfU5Zy7hPMX8Px9koG8xcNm+nov9KJwI61Tc
Hi52lqljwOM87lzu34GdZcoJrR79kwuKbTrbnfgfFHYXzv/C7oIVUzpj16Sy
puohR1ad5g1uYmeZamDdZ5lqxPeW6D9E8uGo
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2EYB/DjjDKWpjZ16rzNtGX3eZ+X/Td1zm1eSqUyQ7oIUoGmFeqn
KRJ9kNCsBl4wNCMdCjYKbJqoqSipaGBQFpoFlWFeIjJCKnreDzsHDocff55z
nvd5TsDZwmP5Ao7j1H/vf092uWc/tnZflOK/VpTKiui4TCdmDvH9ulaVNYDs
gBczc2PWTGZn5J1ya6kSMItwvfTEK+c2f7IYHj82OmqUzBJIPCzK7ZN+ZH9M
6URNEldmKbKONluqT/uSd6NbWyivN/uQgzEfldYv/iohy9DYaVyYTGIOQcaj
UMWUxZu8H+P9m7UTfswHsfpW/+RumRf5MEzPJ9qyrJ7kI5g6rzWcaxeT5aht
sa9ZjmcORZ6+F72DHuQwRCFQgDV3cjiMV5XfFcHMEWi7U+LSAzdyJKq2jI07
mETkKIjzemduapijYSkqWc8p3UVWYGu2nWVlyJUcg2e5QQO+QuZYWL1uN/V8
cybH8RyP9c2nJyu3MSuxNLen6lAlM5CqGRn+EEc2At7ixU+1t1iugjlWWiAb
2km5Csdz5F3FUjKnhmOxPOZlpSPlajxUDQ2PeJK5BPSNKpZlizsoT4DAP+SX
0EzmEnF/rPWa8IoT5Ym89yfB8ZLr0o3LrL8kHHCRrdZPs/408DH/ns2NdKGc
Zy4Z0ZPWeyPzrD4ZDwJ1r8MGWb0WKe1dHUGN7Hxa2/NyKSjbO7qRn87qU2zn
xel489PZfo/T287bqOftxwChfWf5lzrWvwGavs8XMM36T0XR7PrgmQDatzEV
P/UfHSoMbP9peN8QEf6mjuU8c+kwLVTbvVtleTrv/8pA95pXc3kBGRlQD2T6
7vMT4Q/jWQYd
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIU3EYx/FTShMz03mZUzNnal6GNHPLprafzrnNeQlTbGhhwtK0SEtZ
EeQK0sjUcIaRhXabL7RoQ4vSjEwRIouMMiqJZEYmpZTQKoyK/s8LPXA4fPjy
POcmKt6fY1jOcVzS3/PflQ7fvN4+a3kI/mtOsW42qjHajcxB3hoX86VHxOwC
YVNmh2or2QPaMk3v9/lgZm+0D0w8GDxD9kOW/pDmczQ5EBdqCmSqhrXMwTDU
WsoPTAcxh0BmaRw+504OxZGS2BXuWMMcDmvl1Ey3PpA5Au+dT7WO2gKYo/Cs
ZEgj5JHF6Mwb75Hu82eOgSTFEnatQ8i8Ac9HAp1e88gSvPL8KtxT5ccci9Py
37uVRgHzRjy+nesaKiTHwVStmJeH+zJLoRS/eOp0wodZhtrRVuF2MXkTNJ/G
B9zrvZnjwQtyzh0a82LeDP5KQf+HfrIcRp82rslCTsC9kbp3jho+cyIkdwPW
T1aTk+B6xbEzbdiTeQsU+fOFWQFkBVbt5c+crPRgBupjDW/biphNwOHIkR+G
bOrJcPMaNFZMr2Y9Gfrz1y/5iKmnoM+/5eKdWZpPwcGuBIXtMnUluhJDSiMe
0rxy8T4udcn+VFRHtpibbTSvWvz8JhWO24sb7N30PmmoKu0cyPZl729Kw5ii
2VkwQV0Nx1XeUXsydTXMhjlzYSd9Lw0K1Pddf96krlnStah4+W1wl4i6FkWV
O349+kj705fcPx0O3ZTLsQya16GsynFrWT513eJ9XAYm22TSN2bqGbihns0x
utH/zsTZsAU9185syoS9LFK+UEc9C9u4+CdWT2/8AU8Q6kQ=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2EYB/DjvMyappVOS00dkaJLa16mNvOv5X3p3ByFaIggFSplaRcv
eCq7QVlWnyxLipRcKWKiZtlEpJVYkGRB0QWNyKgGYeqQbvi8H84ZjPHj/z7n
PON5n8CivfpiCcdxO/59//+yj9zYM9BVosCirAk9kWH59yTMHOr71WX1NwPJ
zmiqVVnWJzK7Q1opK1VNBZA90PChs6yzgdkbyw+OHlFrmH1xvLm9Nr/bnxwA
eVf01YuezAociBtU+unXkNeiPai88/spP/I6SAJCbDKTLzkYqj2NFRYpcwgK
im9Pbt7nQ1aixsXRqB9cTQ7Dl0fpV5rmV5E34IXltcoUzLwRb67vKj9j8iar
UGkL6nzy1IscgZONJXHV/syR6B31clwolJOjoJkZend2pyc5GtUvj7hyhR5k
NdZ/9uGXOjDHoJl/WeXWsZIcCyejXbd1eAU5DnOZn5yPapk3wc+0MJGvXk7W
QFcaMjqzyp0cD5NGsTt42I28GROup3fPZ7mSE3BlQjbfGiUjQ2geGFttnb7s
vpTyRFTV2YZK2p0oT4RlJP5QxX1nypNwod6+730BnedF5raI6rdA2e3gFN0g
pXwrcs5uDHU44UD5Vsjs71ZNX7KjPJnmvZCwmCdje56qY7/iz6K5FCzeXwnV
p6D22vgD+Ud7qk+FVl3XOxlG5lOF/XBpNE/qh08T5enCfvl0NE4eqE6aZf1n
iPIM4fO4TOF5PlOUa0Xv16Jt4JX8qa8j5duE/4ffhh+xtt9JYay/LNHzsxBx
7ttsonkJ5dnIC21Me3aYzTdbNH+d8Dx0mFderGkrJfM64XmzTjTfHOF9QY7o
PuXA//fYaIyVcrPInB4jP90MeeUuVK8X9sPrRe/Xo8TSNzjez/o34Jdr/9GF
KFZvQOWAThMzt4zqDcJ9MBvw9W1Qffgxti+5yJfeaPJJpn1CLoqbWyXVLWQ+
F8emis5N3SGbc/Hw8an3c3VsH424FRdhaWsmw4jk+Kma5zYyb4TS2tDRe572
22yELrxFUeHtgb8rlmSW
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQNioVt3b8xWcoDwPtg/v/PHrI0NxmdwmGwRvezd
WkUon8MhUHqS9NsIGF/AQeKM582JbxWgfBGH+fvuHjw0AcaXcHiZuOvsXlsY
X8bhfkDKsr7V8lC+gkPp7gAbix9yUL6Sw61c3+DpgTC+isOriAPq5yfIQvlq
Dg4BSTMC38lA+RoOX+8/KhOPhfG1HGSSH9td3i0N5es4CMXxiZ4yg/H1HG5F
yKXN3C8F5Rs4zFtgGplgCOMbOjjMeXVr3U5JKN/IwVPqysVjLjC+scPGdflT
9KIloHwTB9Z8buPco+JQvqlD1HnezJkPxaB8MweVwos3f4rC+OYOnb8urJL8
KwrlWzhoH5f4uuShCJRv6dBXULoqOhjGt3JQKWecbPZeGMq3dtD50Lduez+M
b+NwetvWlUUFML6tw8tpRY5r7WF8Owe2UMbNHw4LQfn2DsUb13cGVAlC+Q4O
lud2Lzj2QADCbwAGb47W6a+SUD6Do8OSk4vLuEv4oPKODs4hf8xY3aB8BicH
3iIj68tNvFB5J4ezUh9eTRHggso7O3zYfPFvrSgnVN7ZYeLj4mqn7+xQeRcH
H/P67Y/1mKHyLg7czGurXk1mhMq7ovIbXB1q513eI/YQqp7BzQGSfpmg8m4O
7y1//XPSe2YPkXdH5Tcg+ADzSsVQ
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H9MzHEcx/GPyvWDWlIX15WSUM5NIiXnXl1SqktXd2Hm/JiMyczC5qiO
+RUxq8x/mUwoTMz8yI+LXcbk5yxr+Rmh0C+K70rYvT+z7/e73W6PPff+ft73
+eNCVqzPzHFijJn/fv5980duulRbs3YsHOrUhimTXX+4cjOE5dXvXnYuhOyG
8OagcSeyuL1h2fGo+54QTPZFaOBH+4TT3KPQ/CL9fJ2ZWwmfD7XZcZ7cwZDt
O5y/JXcMeSw0QvvyyqdB5HHom9Al26zkHo/PijZ39ZZA8kS8yZu6UXFXSY7A
lPaY4E99AWQVhnSU9g8u5VZj8F3otZIyBXkKdhWVa5Qh3JG4eT3I6PxlFHkq
Er6dPrxuJXcUiq91NJn3+5OnYfXWV6sqnLino0eotzc3ycnRsBQKdWuruGfg
QcvxAURwx2Bfgdn/zHc/ciyK/R+X9G7gnolZP+peFZu547C74cjohSruWQhx
efmmp9+XrEGjbE9jYDf3bPicfb6ms4Bbi5puxVHL6pFkIFHzftsjwcdhK/Bl
5KKc3iIyi8fipFsewnne4/Ez9YPb9jTedfBWRQY8HBxBXYfw9FDfxHVkloBN
4WWlJRe8qSegMjSladptMpsDz1yf9r0beJeYJUI/t97+XsN7InJ1h254HfOi
Phen4u/Y60d7UpeYJWGyRm281cp7Em7cnfltYstw6sno9by6vX862ZqMqANf
++Jt7tTn4dBO5yuvl3hQnyfpKTAUR05y2eVCXWKWCtVFF1n0QVfqqThZ2yi/
rxxKPU38PmsaGhSdbWXedB7Ti23V45eqZNvJXH5+OmrOrS9TL3ajno7Oi08G
8v14ny95/3zJfAbGJOtj5VW0DzIkvycDjv8HJ4dtGRjmfNbSVjqE5g3Iq47T
XqhgNG9A2ozCyy1qZ5o3SOYNyC9/dl3+ljrLFHdkoiNW+K1Ty2g+U7yfTWKW
Jd4XEluzxPdvy5Lcv1G8D4yS/SW2GcX7MhPt26t1zHO3Omw10X11OWwzwSk4
QhhW3e8wyxYb2fReeqwS2yRmC8Tn4b//AJcmdus=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2EYB/CZIabN1LblPVMxzTLTzLz/vWze59wKUim7MLAiTA3KtDiJ
4OyDZqWVdiPClGmwNHPYYljrQqSM5agQumh0M1kZkqJR4fN+2A4cDj/+532e
97znWbO3TK5cwuPxZP/u/092ibbfHdQcDMCiLMnqtgsHni1n5qG2uL+poWsN
2RG6Kt2lsTxmV3QfKTnbYscsQJ35Y7Lmpj/ZAyMTPY9Uccw+aBnVvukzrCb7
47rvOYfTC37kACTNO9RcKWEOAr8iMt5U60sOxq6T5p6u9z7kEOi25QRHpDGv
g+xOVNxIrzd5PVRT+wdMJi9yOBo/lPf5CpkjMNk+vk/b50neBDuBavrPggc5
Es037M9MJTFHQTose3SrdBV5My7GDrZ+HxKRoxFUbnw9K2TegvTL79y1DUJy
DKSVrtWtBgF5K/Rhqd+7K5hjseGTN+e0lDkOw3t2/Jh+vZIcDz9tZX/9c+YE
HBW285o6mBOh+el17XgpcxLEiRM1I3Pu5GT8zvnoeCqXGXipnFkWonVbNAeE
SgMF4kNkXgoSInPrXXazPAUb3EJ+tBldKU+Ft8f45+azZC4Vler45Ds3WJ6G
PMljw0Qiy9Ng5qtKZ6V8ytOhexI3FTK+nPJ0BGa3mos6nSgX40yd/cDbnWRO
jHaz82xHtDPlEszwtafmo9l6iU39DCzxXzfnrGZ5hk39TOt6XCaMA6O/Xv1m
9bOguV12PrzYkfIsWHqNCyeEyyjPxgsvy9fzrmx/2SgKa84cPsbW59j0z4G0
u1GsvMv2l2vdj8u1Pg9eHjpTHhoee9L7XB7cJgUii8iFcqnN+Ulx8OnAA5OW
9c+3qZ9v8/0yGKZXKIrKaT1kNucps+6nl+Hb2Nq6jbXs/xagKvTJrDKfjAKb
eSiA+2f9kFpO86MvgET35QCMbL7kGL+/wIXF0DxCbj2vnBybJG3a7BdkvRwO
2+16LQ/Z/Cpw73BHYbiQ5h0KFJYMZRbtIHMKnLhqui96T9YrUD1axeftFuAv
YgRPOA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtMU2cYB/ADBIdAGbJSqohgFcMtbLZcC9o/UGu5iL1CJIQtxHkBAglq
JF7i0ajoGMtANMZbooYwrTgxYQgW0w8aazZ10Fn5sk0tQSCofCBQFEFNn/fD
6UlOTn75n/Oe8z7v+5yVlXWGH305jiv/fH65skNi7r7bVS2DR5OqAXvjFXUA
M4fCq1lS3bWV5AD8minastPMHIqDtW3zKb7MYmzX909ZLsaQpZCNZew/VsC8
HNqQkeKzE9HkGAxv/bdOvZZZhl2XZ57dur6CvBrtW2sGz65iXoP/01R1t0qj
yHG45i79O7F3OTkBiREDf/lPR5KT0JAg3tWtZ06GsULcdFq7jPwdAhcUVRP/
LSWvxaB9SG6JY5bD33fBGntUSlagw/LP0MxEBDkFx1uqlfujmVNx4Wls/qKf
JOQ0qC+8COs9GU5OR7dqm/tAjZicgfLKV66k0W/ImWhqbo/t9GNWomq3+w+f
0jByFjT9Y1UYWELORuBVd4XmAfM6PHKunvoQzLweUZY5Z3k6swp74ttOtd4O
JQO/R97oGSz82mMecIpO7JgtFlGeg+j5x39mTAZSnoNVBWecZb+RuVyUJbZo
nzQEUZ6L/ofKt3GuYMrzUG2/c8/Ry/I84f2cGvYH6/bu7gugXE31/IryDShK
P9TjSvajfANKy+Q362ULKk+uQZBf577xUz6Ua7zyjVA0v5nJsc16zHuZ0wrv
57XC93H5OHjJYZW8ZO/Px7vM9/O5yYsoL8DjZZPjbaGsPgVe8yv0qm8h8kxz
af6aEMqLMC3qPTyXSvXiizCb1Hqgo2Yx5Zu86rsJA3eeTQ252fjFQvNe5jZ7
rd9m4fdyOuH40AnXj9fBNybhfZCFbNMJv5fTQ1Qvz3Icof0CPZZMiCWTEpof
r8eeu7rsDDfZpseWc52Xw5PY/jMgUuoabWklwyDcv7wB2fKixpAfyDYDRr6V
KWrj2X424shwZfPwDTKMuK+znef7qF94I4zOkz8PRlE/2Yzw/O9YP5ngsn7k
E9PJMKFdqbB3XGTPm4T9aDNhuCpe+bGR9acZYUER1hErGWaMnanP6VSReTMq
7bI+Bc+eN6PL/cuYFKz/S/D98+4KRwMZJdCOP78X0kTmS3AzyiFLeE22laDO
58Px61nh+AQZjYGQ
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzGtI01EYx/F/zlxtYd7mZTOnS0SWiZeczjR/23TepbJeWGQ0EhSzeqEU
C1Mi1Igs3eiFCqnNyswXolIkoSvpJgYirTBKy8owpZm4bLh1wecE9sDh8OH7
nBOiO7G3yIXjuOQ/5+/Nxnd//0BPqQyrsqYYHNqOCj9mDrqo669DB0PIG1Dn
estUcoDZA0enfg2XOILJPngveKZfaGX2x/P5q42decyBUNTGrHi9lZKDIXYx
TrltYpahIqOyaKksiByKkbqZ8ZmbW8hhUOg/hbkLmMNxxzpUrzsYSJajMMog
auuQkCMQpHL2ZdnE5EiYe9uHeXLmKAhFL8sHjQHkaLyTuE4KbP7kGNTHfl03
sYc5Fo5h6cW+CT/yDpSZdPya48xxaOo0a5a6fckKlNs7ZdGJzPHgm7e2RMyJ
yAnIbzFK9NHMShx+1V84ftqHnAi1OT9om5R5J+zLmvZTEcxJ6PkuvqYv9iYn
Y867oMh2wYu8C22mp6LLFuYULJv4Zz+qmIEHT2onl6vI1cCHZkXcGwPrKpy0
LD48EsK6CkJet37W4EldDeWLgdbHUx7U1ZD4T39paCRzGmz3DF9oGmNds3af
S8Wi837BOT7rqdh9TD6yFMB6GrqSZMXhjzZTT4Nm34pivdaduhZS5+hIglVA
XYtRsXXW6EHm0nHlPO/e5CHW09FsEf68ESeknoHYS/M/VEMbqWf89z4T1t4x
R6WI9Uzoq+zm0ttu1LPwTWl3qiPJ1VmoaShNPCPlU89eu1+djZz4qrvTkTzq
OXAJltuFXSspqz2H/rOtmsslf6aeS+/Y5P3zb90a9s4=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd031IE3Ecx/HzoflU5nyYmmvqEhs6Vmq5XNY+Lh/WpnMbWGEIEliSgdj6
I7TwCDNGJmn5ZyBFSM00FU2xkaUlaCn+UQpKKYPoQW2EpK60B/Y9YndwHC/e
9/tyd/wu/lSlucybYRj93/PflTtERb2DXRVSuOVUzyaqC0+HcWagbJ18PN8d
T/ZHR4bV8sLMOQSvJ/2+N6/FkcNxxmRfsd3hHAXBYGSoNZ2zGCbbyJLwVSw5
Ds9kJz4vRHOWQieLCXipk5ATEFgf679ZupOciBGDhH23KCbLENK+LE6Vc07C
lKjqfZ81hixHw/hC8PzQDrIC9m69RPsmmrwXM87We3YL5xTEWFWdcwmcUyG9
jmPTLVHkNMzuOnt3NJHzPhgmjCNt5ZHk/aiudT2veCgip+OC64E0RcVZifst
FuEAIsgHYGpISfa9Gk7OgGTA0ndtPIysgqDIq8c5HEo+CMfTDTZZyTkTpVUl
P8c+CcmHYOnqtBqrOR/G17nddXuuhJDVsGVKy2XD28mAcDFc5BQFu80C9lHV
ssyxlXoWipObtBMXg6hnYar/7crMGpnRwNDemFPWu426Bk0OS41m1Y/6Ech7
fAXpjWSWZybb8342G86eqY3LEQHUc7Aub77Udo7M8szk8ubn8noebtb59H8o
CaSeh66OytuKk/7UtZ5mtfiW4drUKATUj6K+qUJVE8vN55nRoW1wWjQm3kJd
x+t6z3msnvd98mm/cD2f9oMv9QK4/09v6gW8bkC+svaJQ+FD3QDvuCRXkO2X
2t0Lcbw4teO89LfbbCGCfB5Vf7nlReuNnvfDyJtn9Fw/ZKT3+UjzTZ4Gz6wJ
aTeWVrOG1mk9rzNm8g9ab6bnooP97z8XKSth
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtI01EYx/F/pltuTXQ5rzMvSahby9umc639tjm3iRjV7CIZUhjRDBOi
1G6GWEQmViBiVEiCdkMibC2dGVYGssJCqcjeTBYR2Oiycohd2HNe1IHD4cP3
nIeTuqtuU00Ix3HKP/vvyVZMxeDQHXsagvLpxvc9On1AwMzh+jH9a9mDVPIy
bLgi+hW1mzkSmYdMB6sWUsjRyB3hJ0/2Msfh67UtTY1gluLL0KzXPJBMTsHd
6A87ZxZXktNwSrync0k9czpaTBJekzuJvBoaOeeqCGfOwGjYROaATkrOgvZ9
19iNvkSyHGX8vLCJmQSyAnZpXX6XhjkbL9r95wyX48k5UB+2eXiBOHIuPm5z
N8w1MOeh/Ue1Zf9ULDkfjlGB+eqnGLIS6fWTb+YlzCp8d7Q6/W8l5AKoLj7e
axUzFyK7qqXP1R9NVuPIVKOIq2YuglgYO+wdXkHWYPP0mbaXSczr8LOXf3xW
LyZrodv6bUd5YhR5Pc7m1ry7VB1J1mF79+0eiZwZuOfrWJvgjgi6Gag1dLgi
esicHmu0CttDr4i6HkbbgiqshHUD7M/uj7xyCqkb4BovmsvwLKduREhKVkB4
k9xsRL9+7MnTeJrHFaP8VrupZpDNL4Zf5Dy5oGTvTUhedE8U+gTUTf/O40qw
qrRzurKf9ZL/3ptRKTtved7A/mfGvPzC0b7acOoWfFYHFg0KHnULNrblyEJb
Q6lbUVZwwuFRLKVupft+XbCX0j2O+w1lgcua
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mlIVFEYxvGTY425ZWWjprlnapM0WuOWzuPoqLM47khaGEaQVAguWUp1
C6M+FJmKhUhE9SGQJhIiNSMLKkOkaBkiiKhJqSizxEwxW5j3fLjnwuXy438O
L7zcsKqaol0ujDHjv/f/lz+q0pu3b+wJh1OTurVBucppJTeDeeru6+rrYWQ3
pIcpyhqM3D6wqSt2solQsi8qgj0tla3c/jgTMPLq1wbuIGj7o4c9m0PIoRiL
7Dp67mEwORyOH9UTA9NryJHQNo1FebtzR0FbanN7UhREjsa6qJDilouB5Fh8
2qtKqhlfTVbjhT3vaa2ZOw6WPhhizgeQNyK5scSxZM6frMHwg7TG+gHueFSa
BzF434+cAMkt4fDUBxV5E5T3IrrVX1aRN6O4uyOwScOtRfPLg15shy85Eduq
3jvUH1eSk6DJ7uo3ja4gJ+OZrs3V781ycgpirBG+hn3cqciSDvzWnODegoaY
jva2Xh9yGqYWBrYeU3KnI7NkXrs425usEwzceZQyEe3wdFoCysrjbbXhy6hn
4Mrjy/s96um8lAG718nds1Yv6nqELIyOJE26U9ejtUXR93Y7mWUiwtRpL7/K
eyYSTn+dyRhaSj1LbikLZx11zfoZJXUDLIlHbjniFNQNqOtJ1fVeYtSzhS6Y
5cBDca3pc/si6jlw/u8u1HPllnLl55kRhac0612Pu1I3CvNNcksmHLrwfFD1
js83C/PNwn0L7fuPztkFszx8S55b0Mf9pM49Tt0qt2Sled+p5ws9n/Y9S71A
3iFYEjxUAJfQ2DmPnnm6XyifB8FSoXBfMCuiPTD2F+7/Jm0=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0G1IU1EYB/AzN8tpmS1dtlabUyR0jKa59lLt2Vx7s6kTrPBLb/Qh9qFo
EbIZ3Agb0QqmphFlVITRetE0dC1qFUEYRmVkfQmHEVhJjqCRLVex5wb3HLhc
fvzP8+ecU7J7f9PeLEKI4+/3788ucfPd6IBHARnNGq/sOaO1F7EmsO9ex3Dp
SAk6Bx7fHh2abWZdAPzQJVUlj3UhvOwYHns4JEcXw4GBwYsnG1hLQZ/j6FR/
kaHlsCP33PSUnrUCbpS19UiOrUaXQfBjv6Q1ugpdDtnWX9O2lBS9BrR+Uf6k
inUFtI/p+y8EVqKVEHwez5+MSdAq6Jrxdcher0CvBc9Vn+SwkrUazj7q5Qe2
FqOroC/85l3y63J0NZS3Tbx6YmO9DoTzXUKDRoyuAcv5SVHkRBFaA/XeAn/3
00L0enixa3vi+/tlaC30xIO8DwkRWgcWpvW3OrAUrYc0cad3HlqCNkCWvGIu
L7wIvQF+LI4cTdWw3gieZyMPxiN56E2UjdQ8QPWpmaQpJsyYAVAOChZoTi/E
3AShKa/fnEQzJih1dr9tuZaLuRmOhzx6v4zNzeAOqisF7QLMa8EbNhjvXCaY
18KR3vH74jgfcwvXjAX6ohPiUWk25pu5fQxlYgWZ3aUTX8f9jBW2tVTdOqhI
GzO5De+bypihTOzU+eyQx7/p+9zJw34HOoHzDnyvnzjvpHInlddReR18083N
m1WfMN/CNUOZuKjcxe0j9VQ/ZdKA98DFNFD9jdz9QJlp5M7HKBM3Ne+m3tvN
fY8YZdL0v+8PgfknGA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/GjE2atpZWal3nNzNTmLXM6536bOrepkWZUI7tYmTRMZgmV
ZKtUakyaBPamFybChFRwkCleMsiSSkNEiwgLFbtAJGilIlvG/s+LfODw8OH7
XA4cTmhxecFZV47jpGvPv5kNn0OPezv1YXBqXj5wbOezIAEzh2ZpWXujNZTs
jvINphN9amZPGGsfHL8zE0L2gjZVguJ6Zl8I8wzPbRHMIkRGTPvHm4LJITBF
mfti3gSR1+4dXekRBTGHoyQwoMB6KpAcAZfByqlzH0XkSHT8UldHezBHYVdT
2/uu9AByDGQ25VdLuz9ZjIbPUxl+037kONSciX25Usccjyx33upipy85Ae8m
rr0ypTEnQtRU9qWwfzt5L0qrpkqaXZmTIBhfNNirfcj7cMXiNaFxYU7GWNvb
hfAyb7IEcUW3rP2tXuQU5Jvjo91qmVOh1po/2I4yS6E/ws8/fX8bOQ0PW4a9
705uJcuw1MKvnlUwp0PV/+08xraQ5ZiLDUu8sJsZyFO9GJqVeTptBBxcvuPk
JQ/qClT2HkiTLG2mrsDQgsdBnWETdSWEFQnS8ZtC6kp0zVti/UdoPZeBPTJx
4dM51jMwKbxduryfzGVCF92gHr0soJ6JHdrGSV3rRupZCLaPvJbMk41Z0A93
D4z30HpOhd/CnhurSfQ+RtX/53HZsNTwuj8Vsf3ZqGvQp1YF86mrkZt8/cmM
mEddDQGv/er3ey7UNXD+H67UNfR93Khr1+3X4uIjqdzWzFHPWddzcFiX0FER
5pA7ey4S63/8UQwuO23MXdfz8DNlxa4Uz8n/AoM75bY=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQNioVt3b8xWcoDwPtjHfuIQ7xGC8Rkcnr07tc5u
syKUz+Hwdm/cqvQgGF/AoSlScsZTFhhfxOFpiZma0CIFKF/CQf+76IGUUBhf
xqGSz3JDKwOMr+BgcF03wdxOHspXcpjFteqadKMclK/iMDd8g/vJLbJQvprD
N6ZHejZnZaB8DYeNhU9fr4mE8bUcPnRkPDp4VBrK13Go1/3/xpMDxtdzCDPe
pFmVLAXlGzi8ampWE14nCeUbOlw+LsN8ix3GN3JI2rHB8tBtCSjf2KHp8f6i
Rn8Y38RhZdZcCZ2t4lC+qYNcR9bKL6IwvpnDsr8r5NXmiEH55g5mUpyLPy4Q
hfItHMwmH8nwFILxLR38igWqpx0VgfKtHJqOh8f+8oHxrR3Y5VhCjlwShvJt
HE5WutikqMH4tg4F1z4fSlQUgvLtHLiZ11a9miwI5ds7CL04cGh1EIzv4MAj
fKi84CU/hN/g4LDk5OIy7hI+qLyjQ/aJHfsu7+SGyjs6nJX68GqKABdU3smh
qv7XwexVbFB5ND6Ds0Pxamv7TYsYoPLOUPd8tIfIuzi8t/z1z0nvGYTf4IIm
74om74om7wa1h4EBAKFysAw=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQNioVt3b8xWcoDwPtgrhJVuyxOD8Rkc2gQblxZt
UITyORwWWtyqZwuG8QUctt04xLrsnQKUL+LAvvNTi90UGF/CYd+d6QGNRjC+
jIM+75EWvu3yUL6Cw+/Vez//+ykH5Ss5mC3rOzqDD8ZXcaieo7QoJEEWyldz
CD3AbNuwVAbK13B49nHmi0vPpKF8LYdT+/9NPCsP4+s4LHL9faa8RQrK13OI
Oe/Jufe2JJRv4HD6kuX/nckwvqHDDB+VII5eCSjfyCFO6+uXbHkY39iBNZ/b
OPeoOJRv4vC3SNG31ALGN3XoK6tvsrknBuWbOew8HbktPBLGN3foEb8w6Vuh
KJRv4aB9XOLrkociUL6lg0T8nkt9bjC+lcPiJ61JzmkwvrVDX0HpquhgGN/G
4dcP50XlOjC+rYNKOeNks/fCUL6dQ7nobIb+ZTC+vcO5xIiPn2/C+A4OU1X/
RjLMh/IbHBzWub8PKueByTs6dPcuVV3LDJNH4zM4OTzX/FRpGACTd3LY+Elq
flUGTN7Z4eW0Ise19jB5Z4ekE0q7jBtg8i4OQtzie57tgcm7OMxtuFrFvw4m
7+owy6/x12MuqP8aXB2cDgbLacvD/OuG6v8GNwe/YoHqaUdFHAAd0rVH
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlX9M1HUYx78BIYkEJJ7yIzgwnCFhgKiAwvsOkRMOhDt+3R0Hd9ecK1yA
YjjMPJw1NIWO0DaJIqk0UDZFE6LcVxM1W27ultY/hWNRWOG58gcMtRrPd+3z
fLfb7bXX53k+z/fz4/lGO2oMG7wkSTr07++/f+VRlZweOlEdgxnyZPoa9edv
zldYwqnR1o92nYwm9kNTZN57WcUKB+G3Y9aklEk1cQg6SyaQ41J4AZwDxmZn
hsIRuLA0s2PqQhSxGoYzLamnFikcg4W7O35stEQSP4dAz97W/rZniRdhPCn6
kmoqgngxuodDJrpXKhwHnz2tr/Q0hxPHo3ni5QG3O4w4Ab2/azYWLFP4RWiH
pvfmvBFKnIi+4Ctj44cXECfhYr1rW41O4WTUNh+6U1c3n3gZOiMPnO3IUDgF
cHx+o61BRbwcq+6e+2lf5TziFWip3dpjMYYQr8QLv4Y7Z/sonIoDsQ9N0odz
idPw9v5PYo97K5yOB3m/+DXpnyFehaD4xPCrj4OJV2NsaUzyq88rnIGhsPbO
wdtBxJmMgWjNxj1bHxE7gTlzzzfUjgeS16BwU9y3d0MVr8G6z/p6Yt9XvBbB
f4SoPKqnyWtxL2CwaTplDvksFBxryd5wOoB8FvNr8M5u74GfrbPJr8FkfNvr
RzY9RT4bb7mq07ZHzSKfjcvDqxvqv/Ajvxa3U6ceaRN8ya/Fd2GeW+1BlE/K
gWt0y3btfSU+R8wn6RCly09V9TxJXocdH7i/VN30Jr8OZeakvs0xjzNnPGMp
F17quCn/3mnyuUje/+d9jTxJPk9kZx5m7psX5ddDv2LnmdEEms+pZ/PnM5/P
fAHzBSz/emzpTc88eVgiv57FF4rjUQh/7+ONt959gsYrfGemfrlQfF+pSMyP
IrZezMvMSwYxHwws3sDiDWx9jfQe9MBI52GM4o2sfualYuJ7NH8x2y/GcjGr
v4TFM3YylktYfCmLL2XvXyrul1yKI0M3VFci6LxKZeL5RxnbvzIU7Utc4vOm
D8UzL5Wz/S8X53MylsvF+ySZcKKvpj3BQvcRJnZfTeL9kk2sfjOr3yzW62Re
NrPza2Hnz8Luo0W8H7KFxVeIjArWDyrY/MxLVnE9YGXxVrFfyVbWnypZfCUa
d06dq+5R+lmluL5yJeL7fXyXtyjrXyX2T1RhYe7B6+ajSj+twvBfgUZzHfVb
uQpHNV8PXwylfizZELA5Kd29i1htw8ffdL/mX0/9HDYx3mbDtYHv//7hgT/l
t4n9vMsmzi+z8SM2sV7JLtajttP+UT7Y2fx2fHUpbWLxKLHTDvMSl+7qNsrf
ZUf15YGz7kFimY0fsaPjuv/kpynkJQc8/dce7phH3xu1Q9w/MLY5WL91iOet
yyH2F9kh9p8RxtJL4nj1//wPxWaXCA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwB2IQDQNioVt3b8xWcoDwPth32TAIH+KE8RkcUr/x3/LZ
oAjlczhs1OoTEYyD8QUcLu844MjJDOOLOIS0nfZ8tl4BypdwWNJyZMLMQBhf
xqGSY85Uqz/yUL6Cw/Hs4AtMLjC+ksN0rrZr0nVyUL6KQ8Omae3Tr8hC+WoO
C/8eqt4lB+NrOFxk+O/8t0YGytdyKJprtEjnnjSUr+Ngc2BpQho/jK/n8MOI
7birixSUb+Dwe9WrC+01klC+oYP+f8PNr5lhfCOHZlGF+pkdElC+scPjO0GF
jWwwvonDR77Qw5r64lC+qUNA0Dfp9U1iUL6Zw9ftrTu/3RKF8s0d7kX0tfd8
F4HyLRwOaDu9XVME41s66D6XbuBigfGtHH4mFv9t3CoM5Vs7rHN/H1TOA+Pb
OMzcv7w8VEcIyrd12C01Ze7O9wJQvp1DqeaUyZM2wfj2Drw5Qq87CmF8B4fw
KKN1RUr8EH6Dg8OSk4vLuEv4oPKODt94dzb+MeWByjs6THxcXO30nR0q7+Rw
4qhteckuDqi8k8PGdflT9KKhfAZnVPUNaHwGF4cPmy/+rRXlhMq7OOhsZmEz
64PJu6Lpd3Woqv91MHsVG1TezaFtYrZVtTxM3g3NfHc097k71M67vEfsITNU
3sOheLW1/aZFDFB5Dwdu5rVVryYzQuU9UfkNntDw+m8PkfdyYFLQ+sW9+g+E
3+CFJu8N1f/RHgAuHtxB
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2EYB/CjomnTNC/TdHkjLVSGeZn39nifU+cuLnEoibBM96EsCxmI
pwjsS1ZYESQRUZpOF1nWUol1Y6ZYmmiBXYhATYiWSrqFdmHPG5x3MMaP//k/
7/MeWETtYaXWmWGYyr/ff7/kw1cPDt/VRYJDVrG0zW5q8CRmwEM/OnenJwLt
DgsDuiQfDbEPtK4tpw9uI/aHyZl4H6MxHB0ENU03F4VFxAKYEh1cWJoMQ4fD
V8tFw3EBcSSM9sd62WSh6F0g62vP1w7uREcDr/a1tHpWgN4DflqtQpVIHANZ
z8YzLfUh6Dj4+H6h7tyVYLQQTrZfnqvr24GOB90tffCJOOK9YN1tCXWtD0In
wPVL7u6WN4HoRJCv3n9pyiNOgq6N22HRnXx0MhwQZbl9mAhAi2DoSNyaypk4
Bdr0z5vXO/3RqaBZnhNFbfih08CXFzgyP0KcDh1aa0dVty86Axqa1h84VRBn
Qk1j9a+xxe3oLPBdND81KIn3gbhitUoWQiyGlc2hylNbfNAART3G3qhOb4dZ
wPfthXk2nD/tYvpUvRVzykwOhG1OjKdaSZ4DU6aZ1XfrPMxzwTk8xs4zeGKe
S83PA92o6fH0I3yezYMXK94qTSM+z+RzzeZT8wuovIDarxCuzvJsXclkfiFo
Yi9IXjWTvgRmvc4csslwH1bC3ZcpouYXgfXe1EZLgAfmUtC32p/oet0wl0L3
8Fv+mMAV82L4nmbfzBGSvBhark2P8D+7YF7CNVsCPJd+/VKHE+alECYpTeP3
4jy2FBz/V2fMZVQuo/plXLNlUKFJMB6N/C125HIoSWl9+EWI54Ocuz8r5/bN
cjhmyBAP3GBwvoLqU2YV3H3NCur+SqpPmVVyzzNTZlRcgwrf90/H/VgV7v/D
YbMKEs9+W8s22/D+5dwcyqk+lZupnFGj57Gvpvpq7nlmNXces/9//w8nzXs2

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtMU1ccB/A7BGUUFFAKIgpUfAxrsSiFgsiXUoq8ub0t5TEdmRCz1QR0
bihsWI2P6RQVnxHd/lg2hiJbsyDP6JXBpmWQDDMXM80STRadWWTOoKDDbfF3
/rinSdN88u3vnHvPOb8T/Xa1tcpLEIR3//v+/8s+antHr9upwSuNpe1fUp0V
rWYW8E5PU+fCrmiyL74pb23oKmcORKgw+vOnj6PIcyCadpl/PMccBs2DpPo9
OcwR0LR9l195N5Ichb7gyo8qApk1kMatcWnGBeQYPB//yufkxvnkxQi7KDVo
PRHkpbD3j5zOTmGOhedycs/AwDyyFiHz18VKXsw6eHbe+V6VGk5egSvu3IN+
nrlkPWrWN1yNyWOOx4qoiamUljDySnzgXtBkvxNKXgVJ7yvckpgT4N+aKPZ9
piYbYF40U/tbEHMihibvH9j7RQg5CfvqBrY9OzuHbETYW32jjRbmZEhC0og7
iDkFzpIZ4oZTs8mrMX6gPXTdkyByKqLTN+5/fyqQvAbB9+X+C1aWp2F50NK/
zvzEcmD7Gz9MVBWSXcBLQXxZsXUW5elYnqqzXfk9gPJ0DP49Syrb7E+5CdcG
U2u39vhSboL2W+/phsYZlGegbsfkVef56ZRnQDXtYt0fx16j3Iy8xB2d93TT
KOcsZHJ5JsSD+mXee7wpt6Cl9xe1J8KHcguXZyntyuLGX4tX59+Lcs5CNh4Z
J6dMOvb82cr3EXK498tB5NTwUNKYH+W5GA/o3vkigdbLlcvleXC3Vx/XlbP1
y8PRe+/Vm56y9cvn8nzsPepMro9keQGXFyj3QyjEykN/Pk2XX6e8kNufIuX6
oQiRa/ON6vNsPYuU48lFXL2oNERMaJs+bNnE5hOVzydzFqzK/8PKnScul63w
ioqdVF1g50/i6iU031RNfJmgonoJzmtdl290k2UuF2zK/YENGbYXBh/LTKq3
wVEW375FQ/0g2+A/u7+25gHrDzt6w4+f635E/QM7Pomvut1cwfrJjoBNwQ8/
3kyW7bg0diQufJjGF4qV46MYBW2NmVUdrN+K8fW8ts7RXDZ/MTe/Aw9vL9kd
t4vN7+D62YHrN2OePPen/pcdMLu2/aPfx+6DEvh9/my9ZZCMEtxtNiT8eiyY
6jnLJdBbznTnDJOFUlzfbl5duZjuI5Ri6FJH65YasqsUb/qGu04b6f6SS7Fq
9FDtoh52n5Vh2WHLiGmIjDKMiTcOnzCE4F8J0KU3
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQNioVt3b8xWcoDwPtinpEqt/cgJ4zM4ZCh9dny6
ThHK53Bw8n+e+sofxhdwSJ86ZWXKVwUoX8QhIUr2SU43jC/h4Fftr2ZtAePL
OGS8MdV9O0UeyldwOFZ3tUD0oxyUr+TA8eQEe7I1jK/ioHF9xjLmXlkoX81B
Ym1wnc4pGShfw+Hg54XFsiowvpYDX3v9MoFJ0lC+jsP5l4/eb2OB8fUcFrn+
PlPeIgXlGzi8ampWE14nCeUbOvyftjP50UMJKN/IQVI6O2N6Loxv7BDvvcdh
zyFxKN/EocfqX5pzOYxv6rBy/rMN2rFiUL6Zw2rBdxJqm0WhfHOHJD/NFf94
YHwLB7M3z+6uYYfxLYHhyVTCaywC5Vs5OB0MltOWh/GtHV5OK3Jcay8M5ds4
aMuKSaYnCkH5tg4z9y8vD9WB8e0cNP2URVxzBaF8e4fdUlPm7nwvAOU7OMiu
/nMtxhwq3+DgEMO+aJa0K0y9o0PkrLULRXWg6hscHTxXrlulOocfKu/kkH1i
x77LO7mh8k4ObROzrarl2aHyzg6BPYbaLK0sUHlnBx/z+u2P9Zih8i4O4VFG
64qU/ttD5F0cjHvffnc88BPCZ3B1eG/565+T3jeovCuavJsDk4LWL+7Vf6Dy
aHwGdzR5d1TzGDyg/GdQeQ+ou2DAE84HANDRwUc=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQNioVt3b8xWcoDwPthPurtMcAEXjM/gUNrzjTtj
oyKUz+HQu/1FOpcfjC/goOKvv/P0CwUoX8RhQ+reOQsnwPgSDk/XvTB1MoTx
ZRzYvc/kzT0iD+UrOFx7nG2xRhPGV3J46umv6ZYqB+WrOKzmXT/L96QslK/m
8KizYG8vM4yv4fC7vf7+GhEZKF/LYZlJ0LXf/dJQvo7DGsGHx9lOS0H5eg6H
K6bVzReD8Q0cWlL0j/9qk4TyDR10G2/GcX+RgPKNHMQcH+esKYPxjR0sjtZX
z9slDuWbOEzrzytY1QrjmzqsD2Fh+fhODMo3cyj5tVLJ0ArGN3co2XlI4bCX
KJRv4RDDIdUww1IEyrd0CL7W2XNJVhjKt3JgC2Xc/OGwEJRv7QCJLxjfxoGb
eW3Vq8mCUL6tA2+O0OuOQgEo384hPMpoXZESP5Rv7+C3ps81dSsvlO/gsMLx
8NFjklB+g4NDlPZEj3MV3FB5RwcmBa1f3Kt5oPJofAYnB/l/Z09bfOCCyjuh
6XdG5Tc4O2xclz9FL5oDKu/i8N7y1z8nPTaovItDYI+hNksrC1Te1aF23uU9
Yg+ZofKuUP8zQeXdoO75Yw+Rd4OGx0d7ACRCsJo=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQNioVt3b8xWcoDwPtj/i09XnssP4zM4/K5Ka5Hc
pgjlczhknq99ZxMF4ws4bHDt8ZjwTwHKF3E4vzJV8vh6GF/CYbq080TOGBhf
xuFRQbRDzil5KF/B4eObJyXdL+SgfCUHe7PimBOqML6Kw895812iI2ShfDWH
7HM6nEUTZaB8DYeX045U+t2ShvK1HB561n17+18KytdxcMxVtcoMhfH1HG5M
u2GveVQSyjdwuBf2sPIIN4xv6LDH8r1D0UQJKN/IYRPDooZuARjf2OHg4aVM
1yLFoXwTB52ti0P/7BaD8k0dFvAzSf1xhfHNHPbLz5aYywnjmzssnVosuNNB
FMq3cFj8pDXJOU0Eyrd0iEl69FjnhTCUb+XQ3btUdS0zjG/t8K1rnXjsF0Eo
38ZB009ZxDUXxrd12C01Ze7O9wJQvh0a396BN0fodUchjO/g4Bzyx4zVjQ/C
b0DjMzg6rHA8fPSYJC9U3tFB2WvatagVXFB5J4cPmy/+rRXlhMo7ObRNzLaq
lmeHyjs7BPYYarO0skDlnR24mddWvZrMCJV3cXhv+eufk943e4g8jP8Mwmdw
hapjYAAAE8GkdQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1Ik1Ecx/Fns9nmC7XQaW3qJiVL1iiX6bbmflsuV8/qIrAIo6gYBAlC
BUWFPl63snyLQVRoNMg1WSLDtosgojKyGkWJFMRwmiS5mzlHRMX+J+g5cDh8
+J5zOBdHd6LjgFfKcZz5z/y7sqFqHY+GT1cjpyW74Zhteb6ImcPLI4l98ZCO
LMcF/9zB4FHmtdjc6HtQk9GSS3C7aVQmu8FcjiubZt7obMwaaMrG7IqpKrIW
4cFpXudmrsbzO7di3v5K8kZI7023FbyrINegp6tn1lPHrMfrT5Yz/KCGXItk
yj8fT6rJBmSFqbuWQ8xGeFabZK8+byBvxULibaaqknkbehdP6Tut68l1CCkn
k9+GyskmmPoqwp3+MvJ2RH3XA5fCKnI9BgTbsNLJvAMf9O3H70dKyQ3QJkoH
hg8zN+LkTCwW+F5CNmPLnFooWMVsQX6rZGzp6TqyFTe/+iRfUsw7keFn5d0e
Zhvee9MK/YSS3IRRdTAS59eQ7dgfvObyjheTAam2Nls4UpSzIDLnQLp4ovtn
PesOvHhmO3/usZy6EyuG3suBdgV1J8Khjn5jG+u78MOc/eU05lMXmWtGIPpR
NamRUW9GYd7Diwt9EuounB2x2h8NcdRdyP1XKfXd8DR0RRLGPOoicy0wXV1c
djxZsed6C92fyplz0z4agpvel6S+R9RF5vb+v19gTtN5XtR50XnPP/8GcIzZ
Vw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0V1Ik1Ecx/Enba295DR1UzOdK0JWiC85m5n7uemcOkWygkaZBIYwoaQI
WdkeKTDshdYDUhmiZDCUsojwIkN6EYQgMLEbjbIJhl7MtOxxLanY/1xsBw6H
D98//5uTcfL0wcYojuMK/93/Lzvqw89fPHXqENKS6aiQ6Ojawszhs016cXwo
g7wZyVey+W9HmGORJmyofrKiJSegp3hIIvEwJyFuxKE7k8ecinhxajTHm07W
4qZ70ZrNMetQd/nL2qIzjbwTzlFRaeG3k3fBc1U24G9PJWeiZ75/btm3jaxH
7bA+o8DCvAfnlSemT/Ep5CxwQkfnXR1zNurnG87JhGRyDhrW5tduxDPnQmYe
X6hxJpHzsHxHsX7dryHvhcd39oL5F3M+Xld59RPHmA14ODM7OSWqyQXoVUWl
BMuY9+F3S6+7uimRbESH622reD+BXIh7Ne0Bn5x5P752G/Knha3kIoj90ktz
JcwH8MF0e6PmUxy5GKudjzXHfzCbIH8g1lvHmIFruY0z3Q2xIfPAYJGuKfON
inoJapv1734ms16CZvOtlzF9MdTNsBwKGiRWMh9hzhI+z1swtqKqc7QoqZfC
sdtje9+qoF4a0cuwo7Lro8Mrp16GpWcTf9oSZdStcLkDr5wDm6hb6T+k1MvD
zZfDXuAe9mVFU7ehrWdyRD1L5m1It1Ub1QMS6hUR+yvC57lKRGn1AcVg0BTq
EeaqoIh+5FoQvlOvgt8YWDdnrVK3h5u3016O+wsnsuZS
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1FlMVFcYB/AjmwJqAWGgSkWmoqgwslQcUJw/wy4gszIwM0RsojXBRIMo
RrDexG4P1TjW9kGTPjS2GklRShuxGriIGuIaNIqJMaAYY13iEE2RCQytme88
nEMyIb/873fu2e6X/Pl2y+YgxljL/78P//mfxv7Xhc5GLQLyGnY9uvdkWww3
Q2vbupFf+5LJszA9MOZZ4uSOwomIcv0c3yJyLD4dTp/0nuBOQFN1xrKHFdyJ
yDh1YMo/mEReBKd6x1UczK3F5aVxu19VLSQvhu5Zyvkdnk/IS9Cr3hj6ZySR
nAp/y9arehP3cvzZceC7eOMCchp2z974cIsyn6zD2YmYQ9rXH5MzUD2U3hD+
PoGcCQx/6You4c5C3stR5cxP8eRsjM219y9byf0Zzl2PD51s0JBXwd80nhJ+
JY6cg+SQRyNvJ2PJq2Fl+lud0dx6hNlndHn7Y8i56HGn9C2M5M5DzHP1Ursl
mrwG6dGpY8cGo8hrYXC8c29YwPN8TDPzdEPzR+R1cK7wlN3aE0k2YLD73rsH
77mBJP/N63pvRMAKsHe/r6/xdBjlBaKVArzJ9fmNOp4bpdyIpLKqXM3pUMoL
cfLCkOZaIlkplMYvgmd0Z6txfCblRfB2DU7tiwunvBhpXSFhOYd4XoxvPI15
rUlkViLORymR3l8q1ZeicvX+c6O6YMrLpPmVSXm5lJeL47H14vuU9dL6KmD+
PnNFyNchlFdI86uUxq+U8ippf6uw7+e7FzWP+fw2YGf7GsMfvzDKJbNqRAb/
vvfFDzMol8xMomFCoB8E0fMmcX6qSTwvZsbN+d4XR6Po/sCMibQjbSe30fkp
Zhy/Hznx2yq6b6oZh78K7h6up+eZBZ0d24/qXLOo3oKBK/ktzX+TFcmqZGYV
zx9Wab+t4n6qVnE9zCat3yat30bj/2sI1NuQffD1eIE6ETCzw+HM6mjSTgcM
u5grklXJrEY0amg+Y1RfI71fMnNI9Q4xV7ifUb1Duh+14npRK+1frXT+tdL3
XyfeT9SJ36dSJz6vSjlzit8TnFI/cIr3S3WK94m50DjQ3XP3PBkuFNomc0JL
5lK9C+1rtVtT+6kfqi5aP++fbhQpe6Yyv6X+CcmKGzvuv720KZn6seqGq7Q3
wneW9+d6FOc/bbvtI6MeHaVvLC2z51F9Pb74Mah5TnYs/gPc2/WH
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQNioVt3b8xWcoDwPtjvuFF8YqoojM/gcMzu99/N
2xWhfA6HKTL733VGwvgCDj2JCy+68sD4Ig4L7yrt37xWAcqXcLCK9DgaHA/j
yzhUnu07+5sVxldwiOea9fKxlTyUr+TA8/Xh23Ob5KB8FYeV+z8XaHyVhfLV
HF7nTzJRdYHxNRxuvvq5fVKPDJSv5eD/e1Zl5AdpKF/HIb/GP9XVF8bXc1iQ
bOxzqFEKyjdwcD2aVz1JFcY3dCiIqzuo4iMJ5Rs5SEpnZ0zPlYDyjR2sXj9u
WD9NHMo3cQhbNtsonAfGN3W4MTUhas0FMSjfzKGh1P6LlRqMb+7gMueB0M5O
USjfwmFXgc73YCYY39Kh6Xh47C8fESjfymF7wbJIPVFhKN/aobt3qepaZhjf
xoGbeW3Vq8mCUL6twzJlr1smhwSgfDuH0t0BNhY/+KB8ezS+g8OSk4vLuEug
/AYHh6Of+YOjCnmg8o6o/AZHB/l/Z09bfOCCyjuh8hucHDauy5+iF80BlXdG
5Tc4O0x8XFzt9J0dKu/i0DYx26paHspvcHGQ9/C1FFvFCpV3dQjsMdRmaWWB
yrtC/csIlXdzKF5tbb9pEQNU3s0hPMpoXZHSf3uIvLuDce/b744HfkL4De4O
TApav7hX/4HKe0DN+2gPAK/XwgY=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIU2Ecx/E5La25NLNpTZ0us1JbTjNdzvbbnDpv81qQ9aJMoTISraV5
yWV0xQsa3UsszGtGkpampC8qKulNgwkikimiUmhF3lCp8P8E7sDh8OH7PP9z
OI9bSkZCGpfD4YT9vf892SXY29rRnC7GkiYVdonPSvp5zBw0F7cNctvdyFZw
GI4aSzzCbAtdbpzwjhWzPX63NuVlVruSHXH/syF3YR+zE7QO5mVfforIrujv
l7vLZMxiNJZMZuWXuZDd0df2vGW+wZnsgU6vq/UDY07krTAO7r/RmcrsifT3
ba8N7UKyN9ou6CudxzeSJfh2uKbqjT+zD+p1fYp7ZRvIUnT5mIkabZh98e50
eU6GxpHsh2PGzRJeuQN5J0rPFBbJBwRkfyDlRW9FNvMu3Kp5WCd2YQ5Az9zo
tUuP15MDUXBAIW9JYpYh6HjW7UMt9uTdKKg0dAoG15GD8DR8IiHbmlmOD2fV
8lQP5mBIXwm3fNXZkfdgptry3LCSWYG0BzXcvKq1ZECtz1mQXibrgYOWj+4K
Q1lXYmSH2O/kNtaVEDoOjZZX2FJXQdcRJw+cWUNdBe2T0tC0Vj71EGwPliR1
jZD1IeBn+QYZilhXw8i/cnRWy7qazo9HPRSbIm8ak+tWUw/FrHdFfu2JVdTD
4FfyfVrZTdaHYYrffn7e35p6ON7+sklMziTrw5fP42ggWvzUEzjJ5mtQPnQq
TzVtST0CtR29go9OK6hH0HmYU49EfLHUy+KiBfVIRAcUvhySsB613Pqo5es5
0SbzozEhm1tUSVZSj4FIEyMTNLAeYzJfC555U+74dTPqWvofs4qlHguuq+cc
r3F+yfpYkx5H+38sGXH0/hFab9K7WZ+i/fH0HXQh/v/6P/sNHBk=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU3EYx/HTxNKm07xM56W2kWIaUtrFy3S/LafTzWnNWEphWpKU0UzL
qBct36iVYUS+kETUZOXUSLIgV4hm1zfVCy9UoASKQpQXLIdpxZ5/sHPgcPjw
ff6cBw5HVnzmQImA4zjN3/vfk13ig339D0/J4dQP5fGSkO45T2YOHuNelyt6
ZGQPjN0x+c0YmX2hXXusT12SkgMw2dxYdKyTORhFDd4rhXnMYZgN77gfs4FZ
itWy3nFr/hayHAvybR+aWjaTt8Ia+cn2xRFOjsSlZZk2v4I5CkajMK9tLIwc
jcXT6o1mFfN2xNjr3JtPhJJjcf3dpGhiIIS8AzcvTBe2Sph34uRKdd+LKxJy
HD7ba5KWp4PJ8WgXtDRGJDHvgs569ZBQxLwb5tqmufLyIPIeFD+fmF99JCbv
RZ3jfafkdyA5AdKvgbfb85kTMbq+ZjR8PoCchOpXpiMOPXMy/IRB9im7P1mB
a/UdEd1uzCkwjywMFsn8yKlQxOlrREc3kZVQmhYPG0KZgQpbsrK3zddpC8+c
Cl7+g1XmGR/qKtgU8tKoITKnxt037eeFlSLqPHP7eJ1nLg2Grhuakj5v6mk4
15+rSPjFugYCabRDaPOirsE91dDwSwnNc+kYXvAxFpSzng5TQVzPWTnbL4P3
/gw8CO168lHHuhZl6oZnolbWtbz9MjHiXVu6bGD7ZSK+/ttP1YAn9Sy8Hk6p
qnzqQT0LW7TZieJOd+o6WPtHxW/DyBYdnP+bgLre1RY97b+mdPZsV1uy6ftw
dN4AoVv3xdlb6+i8Ad8THavq2CU6n+NqSw6dY1euq5FL81M0z/MAb57b/99/
ADs+CYI=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU2EcxvFpmeZ16jZXOnNmlmaW99vMR6dzOudWGjkTTWkglqTmFAvl
OCKjchESibcullkimFp5CYmhhAZGaUpaRKBGSWIObYJ0w/f9Qw8cDh++5xzO
+3uPMOfsUbUpi8US/zv/X+nBO/a0/8lpd6xrMcrPNHIpl03NwrjdaLhJh5DY
AveqGn0EKdRsbOnubHxtcCPm4MOFaDmvlpoP7yb1T00YtQvemDcKF9p2Ebuh
RNvZfm3Zldgd8si61h4/ag8sRX06MpcrIPaEzPJtQ8OAC/E+8DNnLG5xqb2h
M/5pda1wJvZBQ+F4auDsTmJflOi67pzXUB9Cx6qDzv3HDmI/TPHMHo0qqP2R
09MRpp/mEwdg8n35yBURdSDapVNzRSbUQbCouO48kuVEHAx/p9vZGZd4xCFo
s1/ge3ZxiUPx4OY5+15QhyEir6j2ZDeHOBzS75MDtlepI6Ar0Dw+kUItwkL+
4HLAiiNxJIbLYkWnPKkPY31/HYij4JW8mxOXb08MGH73qbTm7HUzgKZfKQo1
2pIeDXHqWrCZhJiJhk2Rf8SY1ob0GAwZ7FLSC61Jj9nUxRvNiDfez4rd1GNR
P2G12hJkRXocVmx6K9eC6PvjcH+4ucSqmH6fBNaO+tKCb3akS1Dm9WpVrSDr
YcVDVdd+l+tD1xcPmzMO85cLaZdi/uPeiwe1tEs39QQI2tYmMkLIvJgEWDYb
MyVDdH6JMMpmLSqTyHyZRBRMGPTZQjpvGfKKjc9MjtMu27Q/Saju2r5/4DPt
SahRL9ZkPKTPyzGofFnP9NEuhypLL01Po88nw8vDfOZXPDGTjOcFLSpfLu0K
lDeNveB9oV2BA1+dGcut9P9RwmU6DewbxFAi8F116Z4+YkaJyW1Vk4IlDv4C
PSYCAQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwB2IQDQNioVt3b8xWcoDwPtjbGK/cukASxmdwqFi9POrN
XkUon8Oh/4zm27QEGF/AIct5+StRDhhfxOHmx2NmussVoHwJB/W5HLLVnjC+
jMNPg76DkQwwvoIDT6lrhr6zPJSv5NA4vbFZMUEOyldxcCpqn3hhiSyUr+bw
8egTFbePMlC+hsM9n/mb+h1gfC0HlaymUL0kaShfxyHnwUR/tUNSUL6ew/RM
cYaFMjC+gUNc2sJGtgZJKN/QYemmo4s7LktA+UYOV70PRT1UhPGNHSKVLBbc
CBOH8k0cYhiCxQImikH5pg610fY2W0JEoXwzh10FOt+DmWB8c4eqSu3n11RF
oHwLh9Pbtq4sKhCG8i0dFi45Idp/TQjKt3JgC2Xc/OEwjG/tcMl+Eov4XUEo
38ZBdvWfazHmML4tGt/OoVLz+M9UfwEo394hPMpoXZESP5Tv4JB9Yse+yzu5
IfwGBwedzSxsZn3sUHlHhwktzDvux3JB5R0d3lv++uekxwaVd3KApB8mqLyT
Q+28y3vEHjJD5Z0dfMzrtz/Wg/IbnB24mddWvZrMCJV3QTWvwcVh+e7rYqdk
WKHyrqjmNaDxGdzQ7EfjM7ij2e/uwKSg9Yt79R97iLwH1D0fIfwGDwfj3rff
HQ/8hMp7OhSvtrbftIgBqt8TGn7/ofJeaPZ7oZnvDfXfM3sAhBHX7g==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQNioVt3b8xWcoDwPtir7pfPsOOG8RkcLDODi5N3
KUL5HA4VM5+HrYmD8QUcvu1cPZtTCMYXcXh9rvvItb0KUL6Ew3bRfSntuTC+
jIPxUadtZiIwvoKD5OKvaVEz5KF8JQeNGSxGM9/IQfkqDq7S7Fd1LGB8NQcX
Zg+Gb5NloXwNh+Bg7pBFN2SgfC2HptCwZdH+ML6OQ3y8Q+y0xdJQvp7DXI6E
yks3pKB8A4fGyrflitIwvqHDgpmWau0xklC+kYPCy81bb9yXgPKNHcQcH+es
KYPxTRzOucdxf5WB8U0dIpUsFtwIE4fyzRx0ti4O/bNbDMo3dzh5paW19KQo
lG/hsKtA53swE4xv6aD7XLqBi0UEyrdy0FRhf/LdXRjKt3Z4vOdvg7a5EJRv
4+DSUPHXsF0Qyrd1sA//EuMnDePbOXiuXLdKdQ4/lG/v4Bzyx4zVjQ/Kd3CI
0p7oca6CG8JvcHD4xruz8Y8pD1Te0WHjuvwpetEcUHlHB0h6YYLKOzn4mNdv
f6zHDJV3cqidd3mP2EMon8HZ4b3lr39OemxQeWc0/S5Q+W/2EHkXB27mtVWv
Jn+E8BlcHYx73353PPATKu/qEB5ltK5I6T9U3g1NP4z/DCrvjspvQOMzeEDd
wcAAAJtcvvI=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1Ecx/FnDrq55m1uq61yOmvlk9l06XS23y45t6KGsKJUksBIEisj
ukDwFHuTkWirBhaDCSpeQUkxViAZRAW9KqSQJIzIQjRYuiRnxf7nhTtwOHz4
/jmcF0dz6lxFbQLHccZ/+//JltwzHBo8m4mY5s0irdBwX8zMYUVxT5nWpyGv
g9Xc0dh8lDkZphfhgDuJWQaDyKNrG8wgK9H9IOu6o55ZjbpO/4pRwpwBhf6D
orJiGzkTF4LDWs/QVrIWV+Wctyy6hbwdn3pS+5oczDrMNi77JSNq8i4MdFRr
ZlOYeZSOvzG9rFORcxGY47tlvzaT83CyIbV4kWfei7G8W6fPN20i63FkYnfN
+oiSnI/3lZ+NM1EFuQDu8ONXo3ZmAwIS/4jsnZy8D/ZsKT+VwlyIrtCE/LU6
nVyEpYit/TIvIxsxGGmeUYK5GDu1a78sOtLIJfDVzvuqulLJJkw/XRZyCplL
YT4WrjqsSiHvx/G2/mA6n0w247a+dvJhDTPQmeX6WPCcLCCuW/Bjcod3z03W
LVApp7+13mXdinpryzNpUErdil5T5hndeBJ1G5zdAz3Zj8iCDZdCblNRhOY5
OxY2PrnxxyChbseJnNbyt1cSqR9Ai1c8OlW9gXqcuTLMGZei1tw11OPMORD7
3wnUHbjYW2IeaueolyNR3H/tu09EvRz5d2YXLWO/zbHupPsWYhacNP+Tumu1
BRfNf6V+cLWFOHOH6B0c9xeM5eBg
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQNioVt3b8xWcoDwPtgrTte1+80P4zM4CHL9fGez
UhHK53BoiHRbpuED4ws4bF3naB38TgHKF3G4Zh/3QXQyjC/h8Ge+2cz/ZjC+
jIPgnqQl907LQ/kKDgruP9ZuN4PxlRyebp/sfGm6HJSv4rB2T2D5ituyUL6a
Q1/ggzfLtWB8DYeLDP+d/9bIQPlaDt8un/Cv/CcN5es4CMXxiZ4yg/H1HDTX
THy0q0gKyjdw+J5scXbCa0ko39Bhx7GbiiYFML6RQ8HMPP8TBySgfGOHxUzz
p6lawfgmDnwVWmH3JotD+aYO2w9wuc9/LQblmzkobeKYddQXxjd3sPl68F5P
nCiUb+HwIfBy/1QzGN/SwWzykQxPIRjfyqF23uU9Yg+FoXxrh6QTSruMG2B8
G4d17u+DynlgfFuHH95PORp9hKB8O4eZ+5eXh+rA+PYOj/f8bdA2h/EdHAqu
fT6UqAjlNzg4uNo+qTn/Cybv6OC9+aNXoDnU/AZHB3Y5lpAjl4QdAPz/jlc=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCwBmIQDQNioVt3b8xWcoDwPtg/K5W9tZUXxmdw2PbvsGre
DkUon8NBNMJXIiACxhdwqGo6/+nkLwUoX8QhXGW6UtB0GF/C4d/duLC3njC+
jEPXoZz+XdfloXwFh9fPz52w14TxlRyOz5+zJ3WKHJSv4tBUaMKa/V4Wyldz
6K/vf+pjBONrODzrVfhadUgGytdy2Jtyb7KZCYyv4/Ajbn3qBQ9pKF/P4fbl
Ao2cw1JQvoHDf67WpHnyML6hw7WGWd+2dkhC+UYOK+p88zykYXxjh9h+nZn3
8iWgfBOH3Yvk5tRIwfimDg3831viTMWhfDOHfbuEOD5MEYPyzR2mL1u4QkkO
xrdweNwopFGQLArlWzp4vLq+j69bBMq3coj6dNtM9a8wlG/t4KSXMKUoAca3
cXgjHJn6rVMIyrd1aHqS1PtkjSCUb+dQvNraftMiASjf3iE8ymhdkRI/lO+A
ym9wcFhycnEZdwkfVN7RwTnkjxmrG5Tf4Ohwjbcj46cfL1TeCU3eCU3e2YG3
yMj6chOU3+Ds8I13Z+MfUx6ovIuDste0a1EruKDyLg4b1+VP0YvmgMq7ovIb
0PgMbg7czGurXk1mhMq7Qf3z3x4i7+7ApKD1i3v1Hwi/AY3P4IGqvsEDTd4T
Td4TGp4MUPu9HGrnXd4j9pAZar8XqnsYvB18zOu3P9aDyXs7yHv4WoqtYoXK
+6C5zweq/yPUfl+oOgYGAN464/o=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQNioVt3b8xWcoDwPtjrxNt+f8ED4zM4pFf+Vbm2
UhHK53DIF3oTtdALxhdwyLj57s2zzwpQvohDW0XEdYGlML6Eg+ms3VfybWF8
GQfn3lueAofkoXwFh6NzGCsey8D4Sg4/V19NaS6Ug/JVHFYGh7np3JeF8tUc
gna9cVHWg/E1HBbny4ssqZOB8rUcPIqS9l7cKg3l6zj4sBuznr4rBeXrOTRW
vi1XlIbxDRwenHgtmCsuCeUbOhwrmViR7yEB5Rs5FE9ZV8t5QBzKN3aQ68ha
+UUUxjdx2Psm2M9/sRiUb+pQOUHkqicjjG/msHRqseBOB1Eo39zB5FJvueou
ESjfwkHnQ9+67f3CUL6lwxvhyNRvnUJQvpVDVsmPbYzhML61g4COofS5/4JQ
vo1DDPuiWdKuML6tQ/HG9Z0BVTC+nUNAjtbpr5ICUL69g3PIHzNWNz4o38Hh
G+/Oxj+mPBB+AxqfwdFhQgvzjvuxXFB5R4ezUh9eTRGA8hmcHNomZltVy7ND
5Z0c3lv++uekxwaVd3aonXd5j9hDZqi8s0NV/a+D2atg8i6o6htc0ORdHYpX
W9tvWsQAlUfjM7g5GPe+/e544Kc9RN4Nat4zCJ/BHaoOChrc0eQ90OTR+Aye
aPKecP0Ab6jFJQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l9I01EYxvEfm6U0xeVsaemmy2IuG9t01jZ1z6bb9KZZKUZK2WAQU1KS
blzBVpRZNhgVhcM/CO2ilWQyzBKzct3YXShFIZUiIYQZ5NBmVuw9F3XgcPjw
5XA48OY6Wg47eRzHFf3Zf0+2xLXhp0NNMsT1zTjesPu5RMDM4bZk9AsXziUn
YUx9eumunVkIvnBF1RfNIaejLWQwPhpgzoBr5m1oysqcBZloqqZ7QkrOgTh4
UfVzXUKWQfl9V+rxo8x5EPVGIvZX2eQ92FJtf31CxCyHeHakb/lqFlmBSKw1
rTu2k1wAr7bzh1bBrIQheWPxXP8Osgr+j7PlmZ8zyWq4YhfCk15mDRyPH+pe
vM8gFyK7sGNa6mAugn+uzW2Obidr0SO5NR4oYy6GxTk33HVHTN6PcEN7Y10z
8wFMy5tPBke2kXWofbep84qbWQ9f69l79UfSyQbMu/L16x0icgny8xLnozbm
UkxWTwQ8T9LIZXD2BHnu/q1kI65pnB8CjUIy/rUHCJXITslfplI34eB9n8UZ
TqFuAi9HsSYIJVM3Y1+psubZAutmrKSMemNa1ssRmBGsBrUC6uUoGE7YXOxL
pF6By/4mvVtK9lRgaLDlprI+iboF53vfjIk/8albcKhLvTfhUgJ1K80bR92K
wutfo6aJVWO821B3TDN4RrYRt8cGAf9B++KNZeqV9J8Y9cr/7ldhSbf2y6xc
oF5F73Lcb78Ryvk=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtI01EYx/F/bkvLmdYuOlPzVpSO0WbqbLX9Nt00L10sV1kSxHpTC3MF
lSVOu9iLXKkRRBcyzKIwMhmtspTKElLBhr7oJmFvtMKFkC6yG3vOi/4HDocP
33MOT8LO8uJdQRzHaf/ufydb8hL3o/Y9iQjIZ6gZuuR6K2XmoDuJrgF3AjkE
zb5ZXeItzBFIvR6pXe+PJ0tRt/jJ5VcNzFHQ24u6JFrmGHxu6QvZ8XAROR76
oruThUnMifDfHrIdq4gjJ2P7qfdSSWcseQm+yLe2B83EkJeitsTaum0dcwrk
b27VFtQsJCtRpHN1uKejySq0xopcXivzcqgHkj1h0wqyGldF3cUvK5k16NN/
shT3R5HToLpwb6LsZyR5BeYdSrF+aGJOh+hAbGq1R07OgNf+7kGvjTkT5fWH
FZImGVmLiLoK28g1KTkLwXHCTc9fS8grMXbeYWwzMOvQ3NIrOzO8gLwKlsdj
uzE4n7way9YmSc17mfUQS54e3DcWTjYgzKHReWvDyEDPZPjG0gpxwE7gpvFZ
zwsF68b/7eSZM+HicKi/NT2Uugn90b7xcxFzqWfj7HGBZ6SM7MxGw+j+I6ap
YOo58HUMzlTJ5lDPgV/ZePSGncyZoewQzs5w0X2nGRtOq1OFJ4TULai64u2U
fxRQ55nLRWFm9f1RFeu52FyqueNI/G0I9DxMZP34ZVJ9D9iZh1BBW+V40zfq
a3idZy4fafVfp4zdfur5vP8LeO8LaC6O+wOmGt8o
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd031MzHEcB/DfNeroSV1O6U7dIT0J6UFP7l25K10P99AVrXHMjRF5avIw
TkOa5qExkyEPS3N5iJlZHk6JmS3TJMzjlCGmB6w4wnw/f/x+t91ur73v/fn+
7vu9r2JhscHixHHc/L/vf5/0kpouNzYsU+K/elRDpug57e5kDnUixeCIOgWz
GGmDD4M+q8mj8CA2QnytK5DZBy+cnyh+V5J9EdMdoOubSpZBMtB+c1pdAHMg
PiUGv+x/NI5Zia9l+tvHhpMnoN02VCoyypmDUCbb4rX3gow5GC2Old7VDn/m
ULjVT6oPKyaHQ3LSfqjh9ljmCGyvOJokU5CnYjC8atPpIj/maXCRLepK2uPL
HImaA2Lx3bYxzNPR2HVR9qpWyhwFa4nqa3wQORr3Hm3bXnJvNHMMOpzLO+R9
PsyxKBb93HEmgfIZSP/YccNjF+VxaF0wp7f/qYQ5Hp1LQ+J/lZMTkBJh3r/a
TE7EwTeVope93sxJCJNL/RYvIM/EgLZLvDWTrML/8yYDh26eXmcKZ7YCca2N
NXdej2J5MnZFWp4fNjNbkzHZK7i3+iHlKZhbffb46HDKU7DGlqC6eILyVGRp
7rR0JlGeCluicklwsyfLZ6H7+aRtU8oon4X1IXcHLTnUVwtyNXRFofe/+VGu
EayvgZukad3KDzQ/Def966+0aZmtaUjNdcQM13iwPB3Z9bvVlsvuLE/Hd/er
Wx3RbiyfjZZ+T2PBKmbrbDgFhv5wtVGegYKwfemtpa4sz4DXJx9pj5Tma5Ff
EHlutZLW1/Kfl8sU7G+mYH+yBL8viz+Py0ZRyt7rHsfZetZsDHH6IfNaynME
83P458Hp+POhE5yXjr/fdoE5Pd/Qw73Iu3vnKurr4e/79v2+KuoLcs7A/z/B
gMax+49c/UJ9A0aeHJinafFifQPWNJyv0G1g5oxQJC+uKPlNfSMSIzPLPcws
txphOVLrtLGG+kYUupyo9ldTPxdym+NxYSwzchGSPd5HvZz6gtyey5/PmVA7
PuNZVBOtb8K7KcrpK0Kob+J/327CjcKJt8a50v3Lw8Apl82dyczIQ5uqatiY
F9TP499nex6Mjysq2+R0//P5Rj6cTaJLPc10n/OhvdSboY+V4A+KQnBQ
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HlIk2EcB/C3tMPmcl7zKlOLEl0rtZl55Nd5z2mbbq6s6ADpULBaBwXm
HN0XlpJRVHQQgmWolZpWy9J1IFGGkhIRlnRYDSNLsazY7/njfQcv48P3+T3n
+z6Ba4uy88dzHLfm3/P/n/2k+pvNtQVBsMsW/7XhWe8PCTOHNLXvqfu3AsmT
sWrTqxWPDcwSVD5UH877EkD2QHe2xOhfyuwNTWHI0x8+zNMQ/b7icsO+GeQA
ZBoqB2Nu+JODMDdOrrvXP508C+sSV5y/r2CejY0DJTsGtdPIwdDURUQ/q/cj
h6CuyrrWLGOW4Unp63ZRnC9ZDmXz6KHU3T7k+bDNsfpP2OBNDoOxoqbYyeJF
DoenlyK0w8wcgbeh+a0iGfMC9Fpv9HQbpWQFio7u9HEv9yRH4mxj7PLyGg/y
QpithpUjauYouIm8Wvpb3MmLEJZyuknV4UaOxh3r/je/SphjYKy9flCzy5Uc
Cz/vvg/HT0jIcRAXun0+sJl5Ma7MVPUsaGWOR2ZKe9u7OGagOjZoffADF7tN
wBinHVu9lcwl4JatbJ5vx1TKEyDeEh7TaRZTrsS2Zk1s1C+WK/n9cYl0/jSe
KRHO7q07Nn1keRKWnb52wVPG8iQY8sJrtgSxPBmuAx5Sm5T1nywYPwXjA0JG
RNXOlAvMpaJLfGD9cBa1N6UiUTcaOSGF+uPSBOOn4fuf28vMk9j+pKNQWXZn
6gU2frqgXoXrflcbXmSw/VPxx+My/p1f9NfgPja/DFQlPGhr92G5GkPiptJR
BcvVKHjUeLezSUR5Jn+9pkx+f1wWLj++tF20lc0vS5AvQdt3l5y8zaz/JZip
OtmVVzWFcg1qa4oq5Msn2w0NbPXPfxd7OlF7Dcr2ODS+WUntLRp0+No+VUhY
vVZQr4X2SFio415HqtfCWB0TX3eRo3otne9YvL0+G98WjfxRyofsBnO/3SZB
bskW1OcI6gU25SDi6JefCZZhqs+h92OU6nUQOVzb9al8HM1fB/XCkoY+uQPN
X8dfj0UHWb3jxMhjk2j9euqf9gt6/n6Z9DjTJRq+oqDztOiRdfVYcv5Ndv65
/PcVApty+e+LJVdwvgb+9weD4Hsz4GX+kFNwE90XFgPs9z27T5ai+Fxni/St
O/4C44eK1Q==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0nlI02Ecx/HlgReImU5tWnNWnnnNPNLax2PzmMcUTBM1D2ai0qWWZsKY
gjQRqglaZpkjDcoktcI8SinT/SFIhRZihtJpF9oyohOf7x/uBw8/Xrz58fvy
PI9z3uEUuQGHw5H8W//f9HBTbw/cKhZgTV9Ep5qVIWfMyRxMtExdtu1wZjaF
oOSYShNLtoJTdkpe7hKf2QYa94Hvgc1kexgXLjjMBJIdYXG2L6NAvZWZj0az
PmnbzBZmAVpFlap5IXkbevLtLkrrnJh3QMzvfqgZd2R2Q3CVteW8N9kDOq7S
sLCGx+yFz98SV3R8sjdMCvq1z49vZvbFUstCfn+fA7MflCUf6zun7Zn9Mf2s
WqsKIwthWeGxb05txxyAT1kjd3PHuMy7IEvR8bqV5EC4ziVfKTcmB8E3q6Zz
6JoNczBqjSa0pk3kEOx8w1OYG5F3o/rSk0Huq03MocgbF9wTKshhqG+4ur3L
kLwHOtVNu6yVjcx79SzSM7B2/tZrVgDKxbyGxRvUwyFKW8lM5DErwpFp0n6B
J6YegTD/+DrLHOoRKL0eKuppt2I9EvX+8tmWHGZFJCrdH/+QJ1GPwodZ11of
JfUohEwOtI3NUxejwyXuRcAodbFel8A5/ODp8t/UJSh3b1Sf66EerTdfNOSt
HQZVbTR/DCwMu06+V1OPQVlh53ASl+0HJxZWXn68yT/UY3H+fueJVC/qccg5
mvVT+5Z6nN7+SGGuWc2WPKIuXT8vJx6vfQTCQ+7U4yEZeleEKfo+AU/lOjO3
fuoJWBj8pfAMov8noqhs9c6GNDq/xPXzcpL0ehL2HxiNyUin+yJDQ6+Z5/BL
1iFD75HS5YwK1hUyFKebJOc3MT+Q6d2/ZEzmpn9dfs6MZIy41LpxBLb4C7s4
EiI=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0W1I01EUBvC/Q9Bg6uZsTmep08xFpHOzppvumel8maVFQfZJooEYtFVa
WgRDgylR1BShbCEGplJKLxK5yLBS+qCIkERMLJRqGBmlkb1Z0TmBu3C5/Hju
ufdybuIB+26bSBAEw5/5d+Uh3zvgvXVIhX/6aBoNFXw9YrYApfV8p2wgkRyK
8RaIr+5hS5Dz07UYuZRAjkLuwou52QtsBaQP9qscWnYc7JdHqo+1xZMT4He7
GrtD2CpIL6VMzBvWk5Phq3QsTVevI6dAo7YFxbfHkVMxoStqsgSxN+H0mMFy
XK4kb4ZoTaO+OTWWvAXmkLPTkjsx5HQMzfUPvc5ka+DfN1b3oU5BzsD8Xc9M
em80WQs9kkT4JCfrUPOtR6XJZmfCfq4+RtaylrwVEteRgzOdUeRt+HEtOPHt
BFsPj/P5yYg+GTkL/raj5psmdjaelD9qdw5Gkg2oqbr+sEzONgY4B1nj3o6R
VxJyLuZ9G8+kNbBNeJOm0h5WS8lAV1LJS90w5U7AG9vqub/A+82oVbe2uG9z
bka9enTZVsZ5HsSy4RMOfwTleQH5digVs+8uurk+wEI+ar3lRv3XcMrz0a+8
cW/SSucJBZgKa6pa3hlGeQG6zY+fjsSQBQuKe/p6N1zh+y2rzxMKA95XiM+/
BisaQvj+otX9cRYF1BdjRdi1UlnD9cUB/S3Bs6nkxe9i6qezBMaMUld4JffX
utpOKyZN7uDoac5LYfN0iU51cF6K97IK25dm/s8d////N8MI5tY=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQNioVt3b8xWcoDwPtgnSiTV7RGB8RkcXsT96d+z
UxHK53BgyDk6vTQaxhdwOMCXuOvNVwUoX8RhnecSbf35ML6EA8c7j3/hzjC+
jIPT/bRJ/KfkoXwFB3utODcTPhhfyaHm2IXHxiFyUL6KQ+CtBqmitbJQvprD
IuuU+cufyED5Gg5f7fYLr3OD8bUcDsrsm3d5lzSUr+NQr/v/jScHjK/nsP2H
QcRHeyko38Dht7HxOvFMSSjf0GGP5XuHookSUL6Rg/BhRV3x+eJQvrHDQ+3U
Q9w6ML6Jw7K/K+TV5ohB+aYODaX2X6zUYHwzh6/bW3d+uyUK5Zs7hN5k7eyo
hvEtHHYV6HwPZoLxLR1iOKQaZliKQPlWDlNV/0YyzBeG8q0dvDd/9Ao0h/Ft
HNhCGTd/OCwE5ds6KDqmd5b+E4Dy7RyWKXvdMjkE49s76ApqfJx1EcZ3cPj8
b1dkEzuU3+DgEJCjdfqrJEze0WGF4+GjxyR5ofKODrOvcf9cZsoNlXdykP93
9rTFBy6ovJPDWakPr6YIQPkMzg4+5vXbH+sxQ+WdHZgUtH5xr/5jD5F3cTDu
ffvd8cBPCL/BBU3eFWoOAwMAWGejsA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtMW1UcB/A7QEAYr8Eqwh4MFBl0VZgwGO34tkBhMKCUtvQFISjLIkyE
oROQ0aEsmOmEbSELi8sEswcIgxHDY2O7iJ0zKsrIiK/EGBa1OCPLlLVkDjX8
zh/3NmmaT77nnnP6O/f8tpRXayvcOI577b/v/7/sI9F/fGWoMhKrWkx77weP
Z855MnM4dLY3KmRwC9kbNTGaqO+0zIE4VF7Xs38hghyCWu3LGzvOMocien/7
3uR85g1YlN7tHPh1MzkCV2MvdqVlMkeiStU+4f/BJvJTSP9a2VAexBwNw8qH
xqOHN5JjUC8frgqY2ECORcqawerpXcxSTDVdiDv/ZThZBmfppYpvspmfwwua
/tGl3jByPIa9bt1Y9mZOwELLm9HBA0+St+Oy8u0W10oo+XlMftEtLzvCnIhk
e3PjmfEnyEm456+f2vos8w4kXdSW5DRKyMn4e6R1bOn79eQUFL4TH+fRGkLe
iSHnMUcomFPRc6e1PH0vsxyOzlplf1owWQFL1nWf5cF15F1QTzhewkwQOQ0+
Pc5StZ0ZCA+d/63jeOCqbUD91s9cFQVkTolXr2jkyU5/ypXwq01InW3xo1yF
oLshkkUJy1XYppDprv/C8nSk6x4mPaZmeTrs9wOKzDVrKc9A5c3Ra7NjvpRn
0PnTeC5TlGfCHNeRPf06mVML57Op4RYRu+zbx+bPwpxf2z5XPu3HliXKs3Gk
o3Jn42YvyrMhHfbwTDpG5naj6czsVcnP7pTvxp4dzSPzMjKXI7QtB6v3yY3y
XBzoS0273M1Rngtf9/6GhRNrKN9D5+1BuchcnijPQ0Pz8mRlryfl+bhpVxys
G/emPF+0/wJRXoChgeqTMguZ08AlPf7G+arHVw0NvgpbXDgZ6EPjNTg95+s6
l0j15jWi+hcK64lC4XhboXB+XmROi/a33Ed/KqH1oEVUTuec+QJbXys8X140
nivCzOjtv7510nooEr0PRaL9F2FxeOafpvVsfZ3Q0GH7u388UPJkm05YL16H
P1OWH6lkrP56dMwfaFQ9oHpDL6q3Xjg/rxe+b5xB9P8NWPIbO/wwke3fIKwv
bxCeD1csHI9i4fnYioXz88XC+nJG4f2CUXRfjKL1jaL7bcIKV7hSVhdAz5uQ
p75hv6Ng/cSE+4/GTS1eZN6EPnnkvpgpGs+ZcSn8o5Fbuex5M44mVPx4uow9
bxb2I96MbUEx97pmWH+y0P0iwwK/qnW/t9Ww5y1YG/zJwVccND9vgdWruys8
k/U/KwKl8eHTK2RYcc369OQmX+qfNis+r8+QvxhN/ZW3orRN7VB8yvptCd63
3W4IGCCjBFbvMNuplBD8C7wB3Ck=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0G1IU1Ecx/GDU2bdEM1pLp2bU7OWrebM+bzfHtzUNFokohlEJFQDR6lZ
K2qQRZJIUgYiFkREMKZMephGBoPAkB5AkvBNsCKoFzbJVsrQiv3Pi+3C5fLh
e87/HG7OMcfB9jjGWOW/9/+XP+lNT5577UpEFNQnvc7P8QjcDN39IeGEN4ec
CL+9ZBds3Mm4px53hEMKsgSjTYuwDnJn4Keqt0ti4M5C6OOHF+51OVmBK2+P
vhP03Eq0aX0bUnuyyXlYvrj/5fKEjLwN2gXpoj+fezusuL7EOrLIKgRWHohs
w5nkQkgbHe3+FG41BgKnH8vStpL3YGXOITb3SMkaCDd05z3TGeQi9A1ZE+Tv
t5C1GM0emh6p5i7G5GzL0+aWdPJeXCp0jnQE08glGB64e8p/lluHk8d/ndtd
wF0K75+BbxmQkMuwI0/85bc1lVyOBt3lZ5/V3BXQTGUWBLo3kyvR6R3vO+BM
IVdB5g7Pt+m4q/Ewt36h2J9M1sN0KFySYEkiA/YZ3/TcpBCxC8itvzPf+mgj
dUO0XYbo9cyIOIVqVXBvom7EzV6R79MRvt8E+dqb2dIg32/CzKuqnq6pROrm
6PUuM7xjjtvqw7zX4NqgvfyCXEy9BrZ+zc74q/HULWhuLRo7o1zXR7qF/peI
upXuF6YeY1aLH2Wra0Z1iHotBJHH+f3WEvW6mF6HTneFfuI+o/n1MefHmO2L
nueKMWuImc/9lXpjtF2NdC5jfwFubO8y
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQNioVt3b8xWcoDwPthH+ttHJQvC+AwOL+L+9O/Z
qQjlczjcDFByN0uF8QUcehSFHtZxwPgiDjbN/vJNGxSgfAmHGIHjXJyJML6M
g8+plhBdcRhfweHAcjaxReHyUL6SQ3Jpy4WWdXJQvorDpSmb5jw/IAvlqzn0
BT54s1wLxtdweLKM8WhotQyUr+VgfNJ1Qs41aShfx6GcId7+3mcpKF/PIcx4
k2ZVMoxv4NBil6jLv1ISyjd0qJMVX/rpqQSUb+TQ+efytY3OML6xQ+Y1VT3u
ieJQvolD8Mz/jwNkYHxTh4Cgb9Lrm8SgfDOHrro48TVfRKF8c4fTv150tS2F
8S0czKQ4F39cAONbOuQz/m5bZQ3jWzkk396zZ/kbESjf2kH3uXQDFwuMb+OQ
HcEemDxdGMq3dZic+mFyzHIhKN/OIXXuMqbqBYJQvr2DjZFPO18CjO/g4Ot2
7OgTWwEIv8HBoXR3gI3FDz6ovKMDj/Ch8oKX/FB5R4drvB0ZP/14ofJODvL/
zp62+MAFlXdyUPaadi1qBZTP4OzwU2dSzfIcTqi8s0PbxGyranl2qLyLw8Z1
+VP0ojmg8i4OgT2G2iytLFB5Vwcf8/rtj/WYofKuDtzMa6teTWaEyrs5QNIv
E1TeDU3e3eG95a9/TnrP7CHyaHwGD6j6j1B5DzR5T6g5DAwAhaHCUw==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAGIQDQNioVt3b8xWcoDwPtjrvAs4o8IB4zM4ZCh9dny6
ThHK53DIOltxfJ0vjC/gMCv96rulXxSgfBGHOwuPpUnPhPElHGRXf+5KtILx
ZRwUloU0WV6Vh/IVHF6ZL3inpQjjKzl8mnb/4JtIOShfxeGQ5okNFttloXw1
ByE5XQNrQRhfwyHV2ctUYb4MlK/l8Fe7X37Vb2koX8dBdH3x+bJiGF/PYe/6
k0vPLpSC8g0cYs57cu69LQnlGzowinR8/vdXAso3cjjnHsf9VQbGN3bQ2czC
ZtYnDuWbOOx9E+znv1gMyjd1MPsUpeF9XxTKN3OQ9/C1FFsF45s7aPe7nXM6
LQLlWzjEX98ad7kCxrd0cNJLmFKUIAzlWzn0bubU3ndfCMq3duBa/CPO7agg
lG/jEMO+aJa0K4xv6+DSUPHXsB3Gt0Pj2zuUak6ZPGmTAJTv4BAeZbSuSIkf
wm9wcBB8IyL2QYwPKu/osPe41TuNxzxQeUcHZa9p16JWcEHlnRyMe99+dzzA
CZV3cviw+eLfWlEon8HZoW1itlW1PDtU3tkhsMdQm6WVBSrvAg0fVqi8CzR8
oeoZXFH5Da5o5rs5VNX/Opi9ig0qj8ZncEe1r8HdgZt5bdWryYxQeQ8HJgWt
X9yr/9hD5D0cildb229axACV94T67ydU3tPhveWvf056zyB8Bi9UfoMXVB8M
eKPJe8PlAUAe1LI=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0V1IU2EYwPGTa1mMyo+1Zs59ETNtDT/KaVbn2dLpdFubkEKFoNVFeFEp
IhTSCsputptgxbCoLrZgZuTIMheMKIrEi1zWwJQycSBbLQw/Vlsf7HmD8x4Y
47f/+z7nvGeK9tNNJzMYhqn/+/n3TS7R4UejDzuUkFacLcm9OOsQEjPgdm3s
SfgV6PXgXpy8zDtBnAXR/iLtz5QcLYTes7LbLTeIxZCabm2OGYklEFdHXYMR
GVoO7NSEdH4XsRJuemTPWk9J0dth7GokFPEWoFUgPJbXc3RVgt4BledzNn3S
EBfD8Kv4Ens9H62GTI+zqS+5Da0BTwHfGWomLoGwK8wWvcxDl4JC3JYcnxaj
y2CD/vWCpYO4HLy+d+Hl6Fb0bpC+mFmZMBPvAU/ynkzVL0JXQOGM7U43n1gL
vuyvYpV/C7oShh5ckYo/CtFVcHwqEPBGifdSvRqCO/WxgU7ifSAd6RruG8tF
74dSg3ukYTwHfQDOvF983qYgZqH0aX7hbDcxwKW5dsfcQHbadoAuXzU7dDcL
uw5ajpQNdio3Y9fB2yeTP8IrAux6UPvXrqtwZmKnzByE3luhgOgzDztlpga8
ox9EbyR87DVg0l54/EVDei18q0qk9JolNt1r8XdyGbDPYzeAgHf/3MK172kz
dVDuiC3rgqvY67jrmXpqPmXGiO+DweczQoa8OCHw/cLeQO1voO7fyF1vb8S+
Bs9h4tpuwvf9G/ebqflmar6FOr+Fe17mELWfMmPlPh9YufPtVu76oJWab+N2
oGynHLT9///+AJCIOsc=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQDQNioVt3b8xWcoDwPth7qStGf5eA8Rkcun5/eP/u
oCKUz+Fw4fGK6T6ZML6Aw2qbO7sFeWB8EYenLFuSnm9WgPIlHA54VSeJhsD4
Mg5RG5kWe9+Wh/IVHM6Ed07s4IDxlRxsix6uDTOWg/JVHLw3tXXLdMtC+WoO
p2L4Wyy+yED5Gg5rZlq0vLWF8bUcPIqS9l7cKg3l6zic2v9v4ll5GF/PYZHr
7zPlLVJQvoFD9saKguTPklC+oUPSjg2Wh25LQPlGDv+zkjtOPBeH8o0d5Dqy
Vn4RhfFNHEp+rVQytBKD8k0dQm+ydnZUi0L5Zg4tLCdPcUwXgfLNHZwOBstp
y8P4Fg6nt21dWVQgDOVbOkxO/TA5ZrkQlG/lUJKxfJ+/GIxv7WBj5NPOlyAI
5ds4fP63K7KJXQDKt3W4xtuR8dOPF8q3c/jGu7PxjykPlG/vcOKobXnJLg4o
38GhbWK2VbU8O4Tf4OAASQ9MUHlHB+Pet98dD/y0h8g7OnAzr616NfkjhM/g
BFXHwAAATKuP2w==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02lI03Ecx/F/M9Ncpi7dNDWvCFNZZuV9fLzmsTnnhba0qLAsC/GoKNH+
RQ+0DDPCHhhlKGpJ2tBMUcuUZQcdJkr2RMvKoMNhlgcpFX5/D+ZgjBfvjS+/
/+87p305iZkCjuNi/r3/f7KXOOVepybbGUvShQw4zJoHi5g5COWRj/Z0OJGN
8XOLZ51fGrM5gp/13zo/7Ui2RJm6cqT5ArM1Hmp6VlYFMNtBKTEoH5tyIDti
aFCxs1bB7Iy7Hy0Ev2o2kDei4tVNjyAB8yZclXrUf4q2J7tioqvjxv4UO7Ib
4m7bXnvdakv2wMKBXSfqp9aTpWgpNtQWuTN7QlI46XvmmA15K4zc2srErdZk
L9hVH51I7paQt6FX3uA2kM68HelcklhVISbvgPeU2lU+akX2RsqIYWlJIbMP
0qLLzT88tCT7QnRn6JCumNkPIqGk63PXOrI/koZLy97YMwfgcMFs24pUETkQ
JjWzu2VaC3IQfp9vkmRMMwcjX9NcqjrFHII6l9h323vNyUCq2qspz9lsyTyg
/WmWpM5dQz0U3f3+P1zHyXwoGkL7tI9tTKmHwWHxxXNfnQn1MGQ/aX8w2CGk
Hg7TPK+AwbP0fT4cVcPCubodrEfom49A7dOa48KCtdQjMdA+NP12lvVI/Xmc
DC6xlcPqBjZfhkvnDNpHM1iPwrBpSdacks2PgsDRbV7YyM4XrX9efpm5mGXz
Y6BrGVgoslpNPRaappwr0l3G1GNRMZ5fGDZjRF2OSb/5xTDpKupyKHxO3x+X
GlBXoOj6YJf4PZlXYOn/KKAet+z3cdh28ftMaA+br0R48h9vQxk9L16pf19c
PCy+WYp1Ytbj9e+DU6Ex0DnLtY/uHyqYHhF9Lcml/eBV8HvZWf14jNyjgq31
+JeKy2x/EnByc/9cZjwZCQhJnU5X2tK+8QlwtxfbHNxL+9qTsGyfE+n86/AX
sAcn2Q==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdk2tQlFUYx9+4iEoola6wAgsYRsRAoCyLIPsHubncdmGXhb005Qyaojkh
TeOF4c3R0gxzWfxE9sEPMCNKmZd2JeWtgWJymCKKnG5Mg1NKk65kEDsI1exz
PpyzMzs7v/ntOc95/uc5Cdv21jQGSZK0/7/v/7/so7Jc6b/YlIgA+fTNR+9u
Wx/KWIJbZ+++dyGBeCnufDDT+puBcSTcYddCNQ/iiVfh+p63TxefZhyFrnXb
c6NKGcdgMF3f5R/UEMfjctys2fVLHHEi3oqe0eUbGD+NsYfbPSfejSVej68G
Ph/YORFDnIzMna6W4TDGKdgR2978tXMtcSq0i1NXb7eridOwYFHFnrgVTfw8
bhcda7v3EuMM5KuSzvsHo4gz0X827r1DasYb4I1p2DOctIZ4I3Zlv7JCtqiI
s6CdtiWXT6wm1qLVrs+7bGacjRS7buhGNWMdznjy7O6+VcQ5OPyF1emvYLwJ
tukftUmPniLOxe/PTu/PMDLOg710YLn/wyeJN8Pd6HM7ehjn4xt9R8ian58g
1qPk+t1dGGUMfNs4syzZSywD/erOM977keQLkFCw4/hrC8RyAdZGTd5xdTBf
COPulJt/RzNfiD9+euZI+mHmtyC2d37ckc3234LudYYfNn7GfBEWJdPiiy0r
yRfhqu9UunpkBfliVJ0/Wdx4JYJ8McYjjr08V0UslWAmwvvGfNbj5Esw6vnu
4a1/wsmX4tSRYM+Eczn5UnSNh891ZzFfhg3tf84WKMvIl8F3afRR62piaSvm
UjsO9exmfivedDVtOqgJI2+ApqwyR3UulLwBgfcURL4cFdltH0+mBZMvR3jw
hQNT7sfIVwi+AqZ3Mp4LORpCvpKvJ1diRO2b6oykfqQqvl+5is9Dqhbyq0bT
sOfGmJf1b8TQXytrba/S/2EU9jNCszByU+ejeorgJROfL0y4n+NfKExbQutN
fJ6KSTh/jVBfYLlGWF+D1EshS7QnWf61ONDm/7TpHNWDwHItfx6lVrg/M78f
zGh9f+wT1a/sPszY15ur/+isROsFliwIik/xh/fO6wPrLbyXLfz9KhZ+f6mO
96gT6tfx/Sh1fD+SVejfCtfkvoOFs2xerBge2vx6y7WltN4q5F/P3y/qhfdQ
z8+/Us/Xkxr4+UeDMM8NfL6K8H/JxucFG6y2zL7mxMVAnrLAik14X3ahvsCy
wIpdmB8HnwccuNi3tzPNTnnJDmF+HOjp/171ZQw7v5P3cAr9O4XzO+n9Pwiw
9ALtI0n/AivQ+JM=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlX9M1GUcx7/xu4g8Ci5AlPNszYAwQeAA7d7HBeLxwzuOu+PuOO5WY/0A
UzGnocg3Z5SVP1CqTVsza2qgMHMYitZZUQajxVjkmo0Iao3140rTuws06z7P
H89z2+322vt5f368n2e7RY+vq24IkySp/fb3v1/2UVr6Bk41qhEinzZ/1vX8
2vmMJci96lzNxUXEMfjrlj4j+DRjBRaEu5+cjGacgNkq68MtJ1TESdh2cMI9
aWecCrdFt+N7ibEKV7qvHX7FlEasRlPULklzYSHxAwh3GKbHFIwfxDt1va2R
zgXES5BUerK8pzOVOB27n9Amzf04nzgTH587sLdTwTgLMwvntOufSSF+BJ9d
NhzU/5RMvAxb1u7VbDIzzkZJ7w/tHeeTiHPwVrw2ajRwP/FyyDE5269OK4lz
sSv4dVfyXCJxHlRTia+/a2ecj50RXw7FvJlArEHQrz+yOZNxAYbP9L3fvP4+
4kJc+OKlCX/bvcRF8L8XvX1ax3gFPBtc/wz9Ek+8Ej8vVec8+xDjR3F0seG7
5Z8oiLUwNqUP/53MGHg1u+HKIQ+xDGwaMK7Q+O8hXcezrMNx3aeDnyfHkV7M
s1yM0f5vrl32x5Kux/W4sy/M5t5Nuh6Nl/o/GjvL9McwkuKb6VTcRbrAUgn2
7Qzvn3AxvUToX4q45uyisR2sfymqTuwpaehj+iroa2bzIkvZ/KtwxrdvacoI
269M0MsE/2ocGo8NHM2leeXV8J0enWtNvJN0g6AbMB738lOBKuYv5+vJ5Yj/
NUHpU7L+Fbfvt/D3JVMsnwohv0qk3RwZ1vjY/pUIZO7fdqyJ9a9Czu7fbui8
xLLA0hpcGly5+blzMaSvQUtb8GJjVxTpRmSejojK2xMdYhjR3tFYuDWNWDbC
5sjuaVbf0v7PXiPCVOnB2O7ZEEsmtL49dl45GU5+E/4oCN4szqL6somv5zXh
2MC3yqHUSOpfjbSyygJlFzGq0TG1cWvxDdZf0L3VQv5mLDa8Me44TvnAjMGr
88yODSxPM//evGY4MjrKvtrC8q3h50MNn49cI/QXdMnCMyzC/ILuteBUz7rO
LCfdh2Tlz8PK67KVvz+vVcjPJuRvE/K3ITb8ZMvMgTvIbxPurxYbu4u0HxyR
yF9L7ycQ0uVawV/L15fsqMhv+3Aqi/W38+dlO0yvLcuIeDGC/HZhfofgdwj9
BfY6+PcoOYX5ndT/T/I7ad7r5HcK/jr+POr4fOQ6YX9Bl1x8PbiE+V0I/b+G
kV9gqZ7PA/W8Lgvsreffo+Tm84VbyN8t+N3C/h4+H5WH3w+C7hF02cPnd9hD
c0nSvyt+N+o=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQNioVt3b8xWcoDwPtiXZCzf5y8G4zM4zNDcEq22
VRHK53DIFhB8ox4D4ws46B9/zebwTwHKF3GI2bb64NyZML6EQw+jg+tLaxhf
xsFgRfPffxfloXwFB12xJWL3xGB8JYeKrxYW36LkoHwVh8Wc0zek18hC+WoO
D4qNSqSOy0D5Gg5H/xQIzfojDeVrOeTX+Ke6+sL4Og7zz/PwTb4kBeXrObR2
zrOVUYTxDRx0li4Q1+qRhPINHa6+beB4/VgCyjdymLiIecI7Oxjf2CFs2Wyj
cB5xKN/EYc55VU+2LjEo39TB7FOUhvd9USjfzEGgvTDl/iIRKN/cISbp0WOd
F8JQvoVDd+9S1bXMML6lAyT8haB8KwdFx/TO0n8CUL61Q47ThL18C/mgfBsH
JgWtX9yreaB8W4cPmy/+rRXlhPLtHHzM67c/1mOG8u0daudd3iP2EMZ3cAjs
MdRmaWWB8BscHKrqfx3MXsUGlXd0gKQPJqi8owM389qqV5MZofJODuFRRuuK
lP7bQ+SdoO75A+EzOKPyG5wd3lv++uek9wwq7wI17yNU3gVqLgy4ovIbXKH6
v9kDAK1cosQ=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQNioVt3b8xWcoDwPtjfdNKprRGC8Rkc+t+42y7e
ogjlczgohTczs0XD+AIOhz3/Maz/pQDlizj0y+n8Ce6E8SUcLp7PKpRShfFl
HDxXrlulOkceyldw4NOft6vgmxyUr+RwSrKa+Vo6jK/iYL3O6nr+DlkoX83B
ISBpRuA7GShfw2Hd0ljFt4IwvpZD7IQlddEp0lC+joMPuzHr6btSUL6eQ7ZM
vskMaxjfwMFp958u9zpJKN/QQbrTav0dFRjfyGGGj0oQR68ElG/sIGalUMRT
Kw7lmzh8/nXs6J1bYlC+qUPJr5VKhlYwvpkD04z5vz0aRKF8c4fAHkNtllYR
KN/CIZjB4txGQRjf0uG55qdKwwBhKN/KYe/x9vs/6oWgfGuHb13rxGO/CEL5
Ng5CLw4cWh0E49s6CL4REfsgxgfl2zls+zBBX+osjG/v8J8h8H9CCT+U7+Cw
XnrN9kveUH4DGp/B0WGF4+GjxyR5ofKODvL/zp62+MAFlXcCus/qncZjHqi8
k8NZqQ+vpgjA5J0dfupMqlmewwmVd3bQ2czCZtbHDpV3cfAxr9/+WI8ZKu/i
wKSg9Yt79R97iLyrw3vLX/+c9J5B+A2uUH0w4IbKb0DwATF4puQ=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XtIk1EcxvHlhaVrXubdeZl20XRoTk3z0h5vc85tllDamJmaFilagpQR
uFRQAkunZS0KutAEZWVkOrUoQSmjQFcmqYg51DBwiC0XIRWd84e+cHj58D2c
9+V3AgorsoutGAxG0t/1700f9yM9A92lgfgvk1A+EzB3z5magYGQtxvL3QHE
26E52t/vk0fthNFtuTfVTGpXfA616th4wiP2xBf/kWpNAbUPrk/FjpptqHlo
H49K15X6EwdCltO+Gv/Mj3gXrBUSo8GJeg9KfLnZ2gJf4mAsNPF+XBzyIQ7B
3cWHxtV5LjEfZ0Wp1Q0l1GGQMiNt3814E+9Dfjkn7iefOgIWQwUz9bwXsQB1
bryaW42exJHo8VqYXZv1II7CirA8Y86WOhqGsmn9m5PuxPuh4fU4Liy6Eceg
aGpwUPvdlTgWfNNVXe81F+IDKM1lHi5qp47DsfwhsSKXOh6txaZWpZZDnICI
fm7Q1yrqRCQIpA0OJ5yJD6LWWNhk7KIW4qVy92s/Ft0PhPq6e50qIFYB5is6
j7w1uj8J9g/Wj4uGiVVJ+FhstgvW054MJfO+hptGezKq9ra1qp86kZ4CmWhk
2JhIrErBY25X73imI+mpyFEIdJWBxKotZqThuak53Pu9A+lpmGA3nrbI2aSL
YGbrL/+O3kG6CM311n2zefakp8PCV1/SltmRvsUMMRShLeIPF1ikizefx8jA
WN+ntcl12jNgxQv5xeqkXYLbEyzLo2jaJVu+n4mdkhsTig5iVSbYlYJ4Qy39
fynYZZzlxnN0PlIsTwfVh9fS+ck2z1Mlw4B32x39Cu1ycJZeDXVm0/nLIXrx
7QzG6P1kYVyotvGYoT0LyrpIxeQSvf9DkMbU9M6HueAPxnoCaA==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdk3tM01cUx+/Ke0ynBTpkbAUiWqBhCCovlW+BCQhFaCmFFhJHYlzCNkkd
cYE5f2Q+ssSx1ddiYpbQmKCwQRANouJ+m8MHBiOZMpclGwuLWVymHdl4dNKp
6bl/3Nvkl+aTz+/cc84955fYtNOyXcMYa332PP/nP53t/KWB5iQEyFuwvzJE
92c0Z4auL34a8owkEofD0jbe/3sj52Uwnp/Uvj2TQByNMM3SmfBOzrGon1o7
Na7nHI8THw1EV76lJ05Ag71nYtHzOnESjp1JMRgWXiNe+Sz/odhvWjivQlXY
sMc7Fk9swH8haXEn9JxTUTWUmphd9CqxEcW/tPuj7sURp+PupPmOq5xzBjo6
j/+846sVxGtwOfcxXO5Y4ky0+lb33xx7hTgLi65Ec2sO57VoujI14z+nI14H
v2suOWI0hng9ik9OaYc/4ZyNiy3GOauGcw4yGj/uHjkdTZwL33yRZ7eRcx4e
vfv9v1mzUcT56Dp1I+azSS3xBoTaXhj0XuW8EXe3z0YYhpcTb8KGzIqDS7dx
LoD2D/W7Xgtn4MEbSVnvpRArQNmZvp7kky+TN8GR5i69/UEkeRNOm66OXlux
hHwhZpcMdzxZ9xL5QkxcuPfP/Xl6nxVJvggH3M157fow8sXQl5pzdT0h5Iux
58sfLut+CyL/Jh7n+vyF6aHkJWabxfOUzVgwHv6w+50I8iX4fF/QhV8bXyRf
Avf0rvbCOZ6/FAN9O4+mO8PJS8zKYBwMDl3fyc8vQ9te37fNPTz/Fin/FnRf
+lE3Fk/9sHKxH6Ucge9NQ74C1YfWpAXvDyZfIcWbpfsxi/WwSrFfpVKqb6t0
f1slXyXmh8RKldifKnlWLdYLiRWJ1Wrp/i3wDk4s7omh+mERvWIR56FakPXp
X3Mmlc/XCr1//FaOl+YLq7RvVnFfVStGruc9MkyTZzXivqIGmoRUX2Qvj68R
91+V3mc28f5hk/bFJvaj2qT9rxU9aqV9rMV4nPfh0WXUnyp5Zpfu346K7L1D
0+l83+zS/OzS/OtwY3Tj7vcv0nmoE/MpklfrpPrrpfwSK/Xi/qn14j4zh1gv
HNL34hC/F9VB580WBOKdNK8nAYYTu3rzC856GMU7aV8WAl51IjLo67aHR/6m
+AbYHZl9rqT/Kb5BPE+RWJWYNVIfjD0FzR7lZw==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQNioVt3b8xWcoDwPti77v8g7CII4zM4LLzIKv10
lyKUz+Fg07lHe1ocjC/gkFTV9LuKEcYXcfBksNQ3WqQA5Us4SD6a1h9nA+PL
OFw0S3v+6oI8lK/goCu2ROyeGIyv5BASOH9zT6wclK/isNXdbv6ynbJQvppD
4HWJlf0aML6Gw8bCp6/XRMpA+VoOL/c0FexbIw3l6zicMNhd0nNWCsrXc9jw
U6hP6a0klG/gcPKqW+5Bcxjf0GHppqOLOy5LQPlGDpsYFjV0C8D4xg6l5mqp
W1PFoXwTh4nu4npV18WgfFOHnacjt4VHwvhmDi5zHgjt7BSF8s0dZvbNyzpU
BuNbOLSwnDzFMV0Eyrd0iIw/5BEVIQzlWzlcSf3GqbFTEMq3drAP/xLjJw3j
2zh8/rcrsoldAMq3dXAO+WPG6sYH5ds5XOPtyPjpxwvl2zvMvsb9c5kpN5Tv
4DDxcXG103d2CL8Bjc/g6NA2MduqWh4m7+iwfPd1sVMyrFB5J4faeZf3iD1k
hso7OVTV/zqYvYoNKu/sIO/haym2Cqq+wdkhPMpoXZHSf3uIvIvDe8tf/5z0
vkH4DWh8BlcHbua1Va8mf4TKu6LJu0H5z+wBaNq1EQ==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03lIk3Ecx/FHZ+U1r9xTmubSLNOQzLxm5sdjHvOahllKkUogrpBUiBzm
hEoDA0UKyROsvEhK7VCzzFoNoSyEFUUXI0OzsgJz5rLD7+8P94OHHy/efJ8v
PPBsyClIO2TKcZzs7/PvZodPvz54TeGOJc2EDwlFUm87Zg426a1jBT0byOao
6Hoyx8uY7fDCd6TozJSY7AinroysvBrmtXhgc0K0OYjZBY+P25d+bHAji5F7
8c3U7Yn1ZHcEa65wAlfmjTjVul4lz3Elb0KPf1f96UYXshd0zRrNohmzN7S1
gp6naevIW6GfNPyKfudM9kWH+nV22F7mbZiu1+X29zmR/WAi8ekfs2Dejrp7
TYKKPWvJ/ghWlymbBtaQd4CXiAutS5kDMFhV3aa8xpMD0WJr6rwgZQ7ChVGH
gZZuETkYofmFdQf7HMkhyPz+KtDTsJoswTlPwz6umTkU+uwiQ/l15p1I6P0m
Sw1iDsNcwgfz8kQH8i5ckvhr2hqZw5EVe9dy/iozkF88d8Mkg6wyMheBmKHJ
fDyzpx6BLckejtIjZC4Slq1zB2LUrEfisofs5Y4RO+pREB52+FR5lKyKQnxH
d6dngy31aGiFlXn6ZCH1aNhPO/IzvA11KdQ/bHdnHrWmLsXQI8kXLx2Zi8Gs
sL98IYD1GCg0t+6M91tRjzXqsWiPuK9+6ET7uDjM9D4zlIosqMeh+qTg1tv9
ltTj4X/288+IYdbjjboMHrLz2sx2skqGeq2V/nIA25+AGl2RMvLnKuoJOF2j
kCjdyFwiNOqwY8UD5tQTUVI2f0/RuZJ6EtzikkL4zhXUk7D0v5pST0Zp0/ht
/r2AejISg8pu6nzJXApSq/x8zE6ZUU9B2+BzftSF3sfJlxvy5fMqOTIyt3cX
ui+G//ewHFaCKyVTtSY0nwpTsfe8VdfCUkcqfS/9klVGfdjIXBq+hsz/jvSd
pXnmifA/nmEtoQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzm1IU2EUwPFnLd3aAk3nctM1HSOsxihX003nzjabs21CUgTZC0lSsGLQ
C4OlbUZFBQ5rJRVCoEi0mbHE1guU+7CwF5OMwsAIasySxJVSMWlW7Dwfdi9c
Lj/+9znnKW12NrYsIYTU/Hv/f+kj3D70KOSQQVoJ/Xujoq01j5qAxSa+GrlX
iuYCN7Juz8lG6lxQnysLJGZL0AIQ+LpJ9TXqQpAE5y7s01IXw/TwKGfrLSm6
BLpmLjk4r1ahZeDrm+J351PLYSG82M7aK0Gvhl7t87nWK8XoMnA9VpnGnhSh
10JQG5r8/EWMVkDfJ888z0OthImuCf2aqAi9HlIBSUWTiHoDsDrHU1/bC9Hl
kOXkqw5HV6JV8DK8jScXUW+EN4cmH4zsF6I3wfWSoZz4VAFaDSbF2zH2GeoK
UH+Lf+jnUFdC8repx6UQoDUQ+iG+4T6Yj9aCvyXh33UzD10Fp2LNHbH+Fehq
KDUcOH88lYvWwbN38vmF5bTXgN38NBrT0a6HO0X94XFrDhpAmhp9UZngpe0F
6DzNvv9xN5oYQNUx88swvAy7ARSDS7PVPg52IyQGX/9pK6DdCCNRnevYQy52
E7g9yYgjkI3dBKEB52VlE+21cPaiQ3tCivO8tTCrSaaMSvyfbGbMZ5iYM/d5
zYz71YHUYtcIA1nY6+BosEp/t4dgtwCffds97f+uT3cL7v+ZNqmHHTvLB47I
FrHXM85vybSXYWLF+Szs1sx5xMY4b2N0e+Z9vPbM+5IG7HHsDbiXkL8yzv0Z

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQNioVt3b8xWcoDwPti77jYXvCUE4zM4PGVmWbJo
vSKUz+GwnFGx6bIHjC/g8JV7kdL/HwpQvojD6sdcnW0rYXwJh38LdNufBML4
Mg7POhap9t+Xh/IVHGqbv9T4iMP4Sg63f+fHaybKQfkqDsbzNRPkN8pC+WoO
k49t367NDuNrODBO+bxPNkMGytdysPn0Z5ryfWkoX8dh6equvk/6ML6eQ3LA
2h3fVklB+QYOKYe3GfbwwviGDucUbR3dQyWhfCOH8ykePskrJaB8Y4cLn38c
uBAP45s4cNT1S5+KF4fyTR12P90kc3+ZGJRv5sA0Y/5vjwZRKN/cwSLL3qhX
HMa3cBBoL0y5v0gEyrd0WPykNck5Dca3clApZ5xs9l4Yyrd2SDqhtMu4Aca3
cWALZdz84bAQlG/rYLhLWv1RKYxv58C1+Eec21FBKN/egTdH6HVHoQCU7+Bg
eW73gmMPoPwGBzR5RwddW72Q/c94ofKODkwKWr+4V/NA5Z0c5P+dPW3xgQsq
7+SwcV3+FL1oDqi8s4POZhY2sz52qLyzQ+28y3vEHjJD5V2g5v2xh8i7OHAz
r616NZkRKu8K5X+Eyrs6vLf89c9J7xmEz+AGVQcFDQg+ALHirEQ=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQNioVt3b8xWcoDwPthPn8nj5CAG4zM4JNULzbXa
qQjlczg0/5p1aI8/jC/g0PZ7u8PCnwpQvohDzPqCFpfZML6Ew5KWIxNmBsL4
Mg5pa3f/Z/gmD+UrOGycdtNb0QPGV3Lg+PxOu71HDspXcdA/c3Gt1jNZKF/N
4UkEz5wTTjC+hsOfaR9tWwpkoHwtB/vo9ODjh6WhfB2Haxx1yf4yML6eQ3ye
kNV3HSko38AhLm1hI1uDJJRv6HDiqG15yS4JKN/Igf/LuuC3RjC+sQNfhVbY
vcniUL6Jg1xH1sovojC+qYOV2oYba3rFoHwzh5Xzn23QjoXxzR3yeyslhSeL
QvkWDn8Wsyg+vyAC5Vs6RH26bab6VxjKt3JQKWecbPYexrd2mNtwtYp/HYxv
47C5oPhzVAWMb+sQGX/IIyoCxrdziHbfz/VrgxCUb++w93j7/R/1ML6DwyX7
SSzidwUh/AYHB6EXBw6tDoLyGRwdeIQPlRe85IfKOzpc4+3I+OnHC5V3QuU3
ODkoe027FrWCCyrvDA1PDqi8s8N7y1//nPTYoPIuDrXzLu8Re8gMlXdx8DGv
3/5YD8pncHWApE8mqLyrQ3iU0boipf/2EHk3B+Pet98dD/yE8BvcHLiZ11a9
mvwRKu+OJu8Otf+bPQBs98OT
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzF9I01EUwPGrQ4umstnmpjOdw2q4Ndq0TTPdccv1c0X0zyJJI2MQLcpa
D7KH/CWBkUXpiIZRQ3uItClW0mYiCBLB1miEJfbQw6RiRG40hi6nFTv3ZRcO
lw9fzilrv3TEkkkI0f6b/z99Bc0Tb8atMkgpon/pnLyqyqcmcMH24Lt9vAy9
EaKB0/OVR6l54JWXNxcmpWgBFA25fXdd1GLQdM9+6T9EXQwb9vsvPpotRUvh
7bW5DmG0BC0D8+/snFgVdTkMb7889qtnC3obCBai9k5/MVoOClHQnxWXoCtg
uW3M8oGhVkK4JKnvOF+EVsHPh6Gz3leF6J1g2arOqPeJ0Wpwzjzm9Byn1sDt
yaWFtl4RuhJynukOT7kK0FVwn617wjdQ74JMp+sPwwrRWmDCn6fzegVoHayc
sSWvT2xGV4PDEnGcepqProHQVJJV6Kh3A0+plgTW+ehaiN8aFbXGqPdA92L7
ncXn1HUgEYd+9PXz0PWwgy+PDgSp9XBywD0oVFIDGI+tarNMeSmzAJ9yb55b
OZiLvSGtN0DQMxebX+ZiN4D1nWf6oxfNppkYoUXRxwQ6aTdC6dp7X3VkE/a9
cO8Gx/O1Fc2mmTSCvSsxYx3Oxt4IXI7bHnZkYDfBiRbN6BXZuj7VTXBA1/U6
pOJg3we2kVr9iyGC+2kmDGRKKxLckVXcZ/B+NGXSBEs1iTWDKo69Ka2bsX/D
bsa7hPwFyTXcpw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0X1IE3Ecx/FrKkunpOWWU0s3RTYVy4dlTmufqXMPuYlCSgYSoZQZBUkZ
ibX+8IEoQqL+SIlyMEWbsEpKLLBCi5JKSq2sBk1EinKCbNM0Kvz+/ugOjuPF
m8/94E528HhZjYDjOPy9/z3ZJdk7MOSsk2NNHo20q2VUJWTmIFtube60y8jr
IT964oLNyBwOR2uE+MZ8PDkSX2/Lf1V3MEdBGVT/tlbDHIuq0s9ffMNx5Hio
Hj73/p7bSpZjzOnvdyUxJ2KhbfZYZfkWchKap7cp95+KJStg7o3pfHMvhpyM
PrXzk3sumpwK4YfX1dMC5jQ0OaeuWg5Jydvx+GVX3oGWKHI6BqSzrkXXZnIG
yu0dGRWhzJm4uUEQvaKTkLMw5ratIplZBdf37pMVnWLyDnQPTUlexDJnY6Nj
otZzNpK8Ew3iDu6yfRM5B/36+bKGUGY1Zo4o1autzLkozj53353GnAdlonDG
p2fehRCbv6poJIK8G+9qvMGKQWYN7Ammj1lPwsnAvuuOW+JUshXo0T4dGZWG
UdfCGzZ4fkUVSl3L6/mYDGs7vGQhW/Mx/mBi8b1fRL0AgvjkZVEf2xfg0TP1
T4WbzBXyeiEqU9oNr06zvY53vo73/iJ47o6vNomDqfPM6Xl7PW9vQILp2mRl
Twh1A9rd9Y35PiF1I1ra69SNcWSrkb5/AHUT/d8g6ibEGcw5kl4ytwelF9NT
ApsDqfPMFfN6MUQBjjPfrqyjbv7fVjPvfAvq+3I1d7o46hZkXvrh0w4vadZ6
Ce0X1mwtoR3H/QG9aALq
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtMk2cUB/B3mlFdKZYCBZEJiDq2bt3GpQIO+2+hyEVKr5ShZoatwVgy
EXE62ELXLCoulRLAJRM+OOs16GQbBnRiyy7oDC6T2SwYoqAxwzFtIkxgppnL
zvPhfZs0zS//nuc0p895k6u2m+wLOI6revb+75O95Nbeiz2OFfhfQbXnYvvI
mlhmDkkTv7hTBpLJi3CnS7Fr6XvMUvgluXEviZmjMdN7pnGHN4kch8oZ758K
MCcgzz1aJB1MJCdhPHy6tCa0nLwC656GfdT1DvNKHNDL7G1HXySvhiuhKdJz
LoGcisnvXLUD3cvIr2Dzg5qJRzLmV/HzJ2M/iXPjyUpoRJ+NSb9ZSn4DModl
NOxhHPlNRNWW+N//mDkNNzeOZ0+GYsnpMEx/e7UvnzkDDU3zfsdpOTkTUwev
f62+EUNWIb/zjqy/mXkNsrap09yxzFkIGkdaOlTM2VAMxc14x6PJOagobJFO
XGZei+qOBfWSdOa3oFVuaa/bEkXOxcRhVeatNhl5HbbVz55/zsashutelfte
dyQZ+M3+9+LUfrIT2CT68otlOpZrkKypbt4VklKuwYcvD83Zy8icFkWnzp5e
1bmEcoG5PLyWq7Rcvi+hPA8/Pl5irtwRTnk+Lg3lPEy9S3bm49e+m9O/z4op
1wlyHdLdfz3R+BZTXoDE0PC1rOALlBdgOD74oF1K5tbDcaVvYKSfznOux+GA
eO54Jju/EJ5PF/bd3szqBeaKsLfVkdOYKKK8CK13dzZqn5C5YvSc3d6u3LiI
8mK6D2GUl/DtLMGj7PmQVsnyDYLzNyCl+FCg8iTrX8rv5yxFpaK18Poe9vv1
CEj2b53Ts/nq+fPmyqDvPqiz97K8TDB/A3++MCDP8lT1fEEEfd/Ar/cJzBn5
/WEU/N9GSOrS1o64WL0RkVPR8qCczudM/BwmQb1J0N/E78eZUaP1XIo4QufB
jMehC2+7ROy+mhEeNbi7dpLuo8+M80HP6/HDrL8F3qtHPxDXs3oL/347LYJ6
C46nFI9mDLL7b8XOnq+aDQ20L7CifuuJgTI57ZvT+my++27PNpF9VrTZg22b
TrB9LMcR75WYlgAZ5Zg8VKc5o6Z9dpbDUSEyvvs52VcOrd+8XJHI9t+GjBvu
3asukGHDvoYf9sx2kp02qKbuj3WL6Pnis+GfiGq1X8eeNxW4Nv/Hgb3HyKjA
yVvfd3QFYvAv9HKVtw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtIU3EYx/HjpdAsdTmXl1U6L6XL4S1LbZ7fvMx5m5iGMZVmYIFGdnHM
idaB7EWQlToJQoTqhV1UmBKVFhUmRaikvtDohYRhJEozpVRQK/b8g+3A4fDh
e57n/w8+WX20wpnjOP7v++/LHsmxJwOWKhlssvKVjc4d0WJmDuMrlfUbT4PJ
btgXooxNKWX2RlfNiZY2J2Yxokzty6ceBpH9oAjs8xQKmaVw0rqv6sXMQegu
nTF2XNlLliHUsHDb9HUPORRlxptOSXLmcJQ3GxJCzu4m78ei1hI+OColR2Lx
U9mN4+XMBzDY8EDeORxIVmDq7TzvFcEcjW+W+trlugByDIqWLGcGJvzJscif
jNK7r/iR44DpSyUiNXM87sraped6d5EPYqpNr+v6KCEnYHjm/joimQ+husnk
79PqSz6M+PEmY1i/mJwI3c/PCWHrPuQkxKjvPM8e2UlOhvrl90qMichHEKw6
fc2w4U1Wgi9eLtUGsp4CQ4S5taWXdR6miHerFfnMwCZXsKmv8bJZAKKUiqJX
szuoqyCaF0usEk/qKlj7xtYbfN2pp+JWo8uz6bJt1FPxfkhprOl3o54GS0+1
WVFCFtIwEmCdM3vT/1w6dPJmzWitB/V0xDUt/Fa9Zvsz7PcJGQ7nqzG05FWo
O7+dutphf6b9PiHT/j6cBnWX195UPdpKXYOGjokXki8u1LPQOTAp+SDdQj0L
Bddj5K5XXaln21vIdpjPwcXHyXzvPY56Dop1sT0XZJu8refS/VZtFnIdep7D
fB48XLrr5loXqWvxI3FtI1Xxi+aZZ6nn//cf+zb/rA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tIU2EYx/E3NRJt6tLWvNUcaV7K28q77rfppnNuOm1lllCRJVSaIkEX
ZZSCSqGk9YeJlAimlSBikKYIoRKkKMKIIEoyA7FS7ObwUrHnDbYDh8OH7/u8
74HDCThdmlvkwBjT/L3/PfklMvYP9p6XwqolubbM/81lATdDc2Dt/da+ALIz
Wo4MDPgVcnugXhJ4p3pdQvZCtfmTvLeDW4x91xRORg23H+Zr2wMb3u8hS1CQ
H1ldGMYthfmcuKm9bTd5LzJMqpT+dX9yEN5GXxw25nIHI8VXPy3r8SOHghnO
fn9u8SXvxymd0ugezx2OkLXr8tVSH3IkXsd8djG+8yZHobLrbuzxZO5oREpW
NxI7xWQZtJ31+a5u3Adxr6HkUnfNLvIhmJxlVStzInIM6ixT3d7rO8mxmHoy
VHfT7EWOQ9i4+EfHLHc88ljcZK+QOwGvrqQlnQnyJCdC27ecaYjlTsKi57Gi
n3U7yMn43bGtak7BnYKK4s7hbBG3HK6OT68uNAnJwAFh8HLLtIfVJiB+cvDB
2AcyU9japMCJbe0tvio+r8R8hFRWEkI22ZmlQqceG51L5vN2ZmkQLnqJlkRu
1NPwbKkxwmeCzFTQdPV0B7a6U1dhkxk2T1aQmRpHC6J7yqW8q/FI8XJ0zFtA
PR2jK+55BWXbqafb9QykHl6L2arm52fggrJxyO0hP18Ds6C2eFVP600aOEhC
La6PaT+WCUF5dOLMDd4zbdczre16k9bu/Cxbm7IwNJ7wNfgj31+HCZ+lhWYP
F+o6GG5FhTnVOFHXw/r/OlDX0/fdQj0blW0zL0SzjtTtzHJs55FD77smt67P
gez2l1+KkVWrR+w6M9h2GOj8ZZo34Fu8ZUMZPk/zdp3l/u9/AJQVIpc=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU3EUB/Cfj9S0pZs6rbTp0hg2h89yznnPNrf5mtssCZKRRYFgZT56
YIHXSOqPSlkpYQaWgqg0sBiYK5uEaUqBCvZXWAQZoW4WLGfLMnbuH7sXLpcP
3/M7997DSTxZW37anxBSuHX/fzIXv8JqG64RgldOalawHpHPY0zAMR8caR9N
RIeAyhGkuaxnHAEt5eeLP7sS0FFQJdNqQx8yjgVSRydO6hjHgVO83GlZEqAT
IGmmbWUsnrEQxjvHba3yvegkMDhc1BIdj94P1tqfpuUHcWgR5P3wdO5b3INO
gXjl/aoLasZieKYIDje370ZLQD1x7oo5mXEaHB7xpPll7UKng2p1oOPsqVh0
BnRzqaBZdww6E8TW3gqPjY/OAod0Y1MpYZwNXdO80R5LNPogpFTmTIzpGR+C
2OMv5u5ootA54D7R8KfFGomWwqO+qei2BR46F+Yoc2DMRy5aBqlc0VrXbAQ6
D4oGLIPJ3eFoOcv5wF2O4jv5O9EU9L3tvRjWyBggVS458uorx2saYIFzs9pd
hiYKEGy+m8lxhmKugPbrASOLJjRRwrCl9p6kMgRzJTQ1b4zXDAZhrgL/hJSN
sCEP5c1VkHl75ZfC7vaaFEBYwJOm73fXMC/wrSdqaBiSUU8fE+yvxnm7MNfg
eT/MNazzWjh6LMNSL/yL/bW+9aSQ1Z9lUgTGW+kHAlsDMS8CQaFOyh/chnkx
9Ns+8Kfj0HQx6/9LWOdLfOtJKbjF5qv9Z7ZjXsqar441Xx1MTcgvNY6iSRnO
A99Hl7G+T+9bT+tZ/Q3g4jxv8WTv8BoMwKnPkM1fY/bBAC8nc1dFXzC3s3Ji
hKE8YbXoNe4bGEH63tbz5hPuJ22EqjrT7+lvuL9241a/G4vrzTz4B+HOIwE=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd021IU1Ecx/HjNNMk0LS5OXVzlYmKNW1OXbbffGjaNl2KZFZvCouwskxf
pOkWPQzpAbR8WS6VCs0oI4QesCUZBSJksSIiyooIIg0xZ6UV+58XOxculw/f
c8+fA/cm7Kwtq5YwxvL/3f+f/JJW3Ll3q0YNnyYNhUOTkQUR3AzT5TPjrbcT
yCEo6z7QuruSOxx7ZYpozy8VOQrm0zmZZV3cMrR5w3peZXHHos6+6/WAW0lW
QT9kSgyQcquRWH/zgrwpnrwSl1/KdYHTceRE7Mnf3unWciehu1YZ1dMSS06G
rmKs/+kjBTkVz4bm20aV3GmYrh2zVh2KIa/FgnZ/s3NYTtZgScrxHaGTMnI6
rr+oPPKmkjsD9RkjuQ2j0eR1OKUZjPfYuLX4nj03n5cmJWciMya0e8q1nKyD
e8WJJKbmzoIn2OmJ+xFFzsa5gw2928q5c2Bb41LXy7j16Fj1ZyvrjCSvx4Mn
znez9mXkXMyaP4Ucs3BvgOauYvWHBm4DZnsWt3w0csN/vQNCN+K5oT0o+m0E
dSOqL16RNLnILA8K2cSXtvZw6nm4Zhx+PCJfSj0f3tT2o1f3hVIXzAqEXoBG
+5y7pjeYeiGURdZsae8i6oUIC+xv/Ho+gPpGfzsEMxOaL43fl74PpG4SehE2
n9GkBJ0Mol6ELVXpN+rUCwZfL4bv/5BQLxbe3+S/3iGYmYX5Zlh09sGJNDKz
CPtb/M/LrEK3CvNLIFElz4X1/ab5JTjcpzcMdDHqpcg4++2n8aGXeqnQbfS9
zvg6bLT/FK3n/bPhL3VWB7c=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCwB2IQDQNioVt3b8xWcoDwPtjv6Ok1TBOH8Rkc2MOsu6N3
KEL5HA431/2vCkqD8QUc3ufvr7IWhPFFHNavKRHL2qMA5Us4XOh+F8WaDOPL
ONhWKLdYCcH4Cg4JBjfc+aPkoXwlB/N/pyRWzZWD8lUcmKO8nlwWgPHVHDJC
GC54l8pC+RoOjJKzws9flIHytRwEc9h2ztGA8XUcYtJOxL6Ik4by9Rz6G+MP
B9ZIQfkGDn4R1YYfr0lC+YYOK1bt6uBShPGNHPqMXzPeCpSA8o0deqz+pTmX
i0P5Jg6KCxpFHM+KQfmmDl11ceJrvohC+WYONl8P3uuJg/HNHQxim5fvXSEC
5Vs4SMTvudTnBuNbOpzetnVlUYEwlG/lAIkfISjf2uGH91OORh8Y38Yhde4y
puoFglC+rUPBtc+HEhVh8nZo6u0dSjWnTJ60SQDKd3BQdEzvLP0H5Tc4OLy+
o96i3wSTd3QIjzJaV6TED5V3dHAO+WPG6sYHlXdyyD6xY9/lndxQeSeHCS3M
O+7HckHlnR02rsufohfNAZV3dnhv+eufkx4bVN7FYfnu62KnZFih8mh8BleH
2nmX94g9ZIbKuzoE9hhqs7SyQOXd0PS7OfiY129/rAdVz+COqr7B3aF4tbX9
pkUMUHkPB+Pet98dD/y0h8h7QP37H8Jn8ETlN6DxGbwcmBS0fnGv/gOV90KT
90Z1TwMan8EHzXwfVPcw+KK6t8EX1T4GP2h4foPq94OaCwP+cD4AmGjwgA==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQNioVt3b8xWcoDwPtg7eb15w8cN4zM4xB1Q+PVm
tSKUz+FQLit6vMIVxhdwWMX34pTFFQUoX8RhVUqUSmkxjC/hIH5DoWSrCIwv
49D4206vv1Qeyldw2BObd0B0rRyUr+TAzn7v49SnslC+ioPWylaG3t8yUL6a
g++Pn0bBOTC+hoNo0eZ5l3dIQ/laDnum6Hc1m8D4Og66FZJrq3ZJQfl6Dk+m
Hml+oQ/jGziIV7+3aCyVhPINHYz+p0juXyAB5Rs5zBG0Z7v4UxzKN3Y4enDx
jQNJML6JA89K88A988WgfFOH5pbDd6YfEIXyzRzazk6XjNCB8c0dAnsMtVla
RaB8C4dfP5wXlevA+JYOcR1uL22PCEP5Vg69mzm1990XgvKt0fg2DoZus3Z6
nYXxbR1m7l9eHqoD49s5aPopi7jmCkL59g724V9i/KRhfAeHGPZFs6RdofwG
B4duo9Q7sxMEoPKODrxFRtaXm3ih8o4OUdoTPc5VcEPlnRzOSn14NUWACyrv
5GDc+/a74wFOqLyzw4QW5h33Y2Hyzg46m1nYzPrYofIuqPwGF4f3lr/+Oemx
QeVdHZbvvi52SoYVKu/qUDvv8h6xh8xQeTdUfoObQ/Fqa/tNixig8u5Q877Z
Q+TdoeIw4AGVfwaVR+MzeKKqb/CEywMAnZPGhQ==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H9MzHEcx/HP/E66rnSXrqjLr34J/aKr3Osud0qn+5kWs9EWNxnyYyas
E6P+iBDmRyOjqER+k7hqxNplGWaWndEiP+b82ChWmPfnj2+33W6PPT/vz3ff
7z7fk2evMeUMYYwt/Pv998s/0oyrDfW5wfgvl/JIdrfyupiboetYkPVgtZw8
CnjfafmYzC2G0z/MlNIdRPbBctGMw+353OPg2JFwaHsYdwAklRHNifZAchAU
WwdST7+dQA6GPrt72Xc59yT4+RuKYorHk6fggrxzredk7hAkbdO91BcHkMPw
PPPVw9a3/uQI9NnaTyoyuSMRG1XD3K/IyDOgu+t2rTKLeybYk9V5ue/8yFFY
+VQzvNyLOxrxNwuckshx5BhIfGPDHYW+5Fi0ha6+GPBbSo7D64onGWIZ9yz8
Eq1QNmkk5NkI36ttV7f5kOPh7e57u/v2WLIC9V9lJ/Kt3AkouewWfsfpTU7E
GUX0g6py7iQUdmWXdNV6kedgg7Xqjl7KuxLaxp6V6OAdSIzS7RYtJduAjaFl
B/ZfElNXIb694eT9V2SbCtO8Qr4c7eBdjfU1CcpLp3hXY3Noa2+OnvdkXPCv
vf44zZN6MsaMbd60tofM5mKAGQeWbuB9LlLP1VVPPs67BjWJwdaQFt41yFwU
VbcumHctvD76SF1SEXUt0mv3aHKuelCfh3vfPM2L8sZQn4dnHkXW3nTeU3Ds
mXtvZaw79RR03Hj6/flPMktFYL+jbbZrNPVU4Xo2X7jeNsgsDQ6Z632ZmM+n
CfdjOkSXfPqhsrtR1wnXswXY92b9FvWPkdQXoL5uTVnk4lHU05Ff0NeUWz2C
ejoiLg8bEbeH1jM9du3LVWwJ5PN64X7MgNKdQ284l9D1YBh0PwacVbXcu+9H
z8tuQLLld9xwLT1vZsQqdWmjqIIMI7KOnq+QRPDzYMQ1V+l0mYO63YjKifNf
xDTz82HCt/5bWYUjyTDhQ+fUndML+fwg203C/ZkZHqu8PxTl8Xkz5KoVxRv7
+bxZeD27WXhemQUNsrLym5/5vEW43mYRvk92Cxpbdzt/FvD3KQP//z/JyIAm
qWvroz5v/AG6B2Ir
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H9MU1cUB/Cn24KjLeLAWiwDIbLBYAhMofzQfoHyG0vb19JW+YOY6Yy6
6By64ZLl2W1hJGxxZckM/hpisrmhTMyiEbAPCe43BohkyUY0gw11ZOkGM2gE
tmXn/HHb5KX55Lxz7r3n3vsStu11bF8qSdKOf5///vmnd33Zc2F3Iv5X0HxN
Hftbo2VLmJXvjzZfTCAvQ3twSUDrYUfi+xthf/nn1pCjMe7PeFB5gm3Aty/m
d3cWsGNxa8Hy1uFAPHkNfF9vTffeiyMnov+gIdaXzF6L9o9aDIF9T5OfQcvg
BVfHVCw5GTaTduqlPPZzuKJ7f9PoJSM5DTG7K5YemV5NTsfQ+EV5vJmdga7U
OJMlGEPOhHz5UcaS9ewstLjCy0e6DOQXkPTkkCf911Xk9fgzwjWQso69Adqz
OfbeU3pyNgbKZ04m9K4k52Dve40xUa1sE4Y7b8ysfZmdizduNuqk+mhyHiZ3
peTNN0WR87G1LBD+8IunyAWYOxP25mQheyN+OZa94adW9iZEpmUahxZXkM3I
Her5+PrtSDLw6uf55u7TZAWYWbji9YVxvBB7io70RbRHULwQXcbOSyNVyyle
JFopwvMb052B33QUL0bfV3l/JE9oKV6MYuej7CdKqZ5kEa1YEL/ww3emYDjF
S6Dbn5U/6qN6SgmGL9+c/XFOQ/FSVJw9/1nScR6/FGe+6TioaeD6ZSHzK8Oi
ZF+sb+D5l4vrVcqhjbr22r67HK8QrVRgxXS0Pqjn+pWilUp8WjgweD2G118V
Eq/CgR5bgWmO86vx+8/Pvr3Ox+NXw70l6/z+RB5/szhfZTPGdO/ufGDl+taQ
/lhD+l8jvq/UYHBmubzlFdoPySYaNjFfsYn5qi1k/+ziemEX+6/Yxf6pdhgN
E3c+8PP5coiGAwVZ1U0R9XReFQcOpHzY6u+muOqAt+1c+8o0zpfF/Ycc0i9Z
7Lcqi+dZcor7A2fI+p3i+VCdMLtn66xGvk8u8T7Bhbqw023GEp6/Cxbl9fnM
JrLqguaxc4futXJ+rXg/UYvSvru7MMz5tbhal9Qfp6H7rNaiYecnV2v0fL/d
Yn24MWL2P75qnPPdYn3VjYneeSU1h/M9mI7ybr/fTIYHbdbDDyfC6fujeFDU
L8elxpNVDw41pk6NJfH3yYu6ZauVo7lkeNEx+c624h3R+AcVBZYa
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2EYB/DTNNNMnWWnlVvOGZUXVjovmdn+zrubuygpGIYFhiEU3bGI
jkXYh/RLQVDiBzHFpkWZiVk0LF1GFBYk+KGwi92M1jJzIq1iz0uc88Lh8OP/
POd934cTvWtfSbWM4zjj3+ffmy1+W+/AjVoNfHLpLzZa/UZDmTk0T2jbs7uj
yYFYcaf6+EAZsxwlXfKY2141OQId2p7dNc3MCnR+SbS90jMroR61qMpGoshq
fHJesB9WMmtQ2zCl6965mrwGtdOzndOtKvJabG985pK5leT1GLSHrntgYo5D
6p6H45fbIskJcN56NFKnYtYi/unHILN5FXkjntzb8ca/bSU5EYvjT1cGuRTk
JIQ5Sq/IFMw6XLJ4Xld5eXIyhs8NHj1ynzkFP/vO9M+MLyenYiygYUzljiCn
4ZSzvHLOxLwJH2LddYnWZeR0zBrfB9ablpI3I9iv+9jn8+HkDExu0Oj2xjJv
QXtM0XjyoJycieuRXX3PjWHkrSjOGx56l8lyPbyczVt1iOXAy5CzNR5ziM8C
MBPSXz+fsoTyLIRPRfAuPpTyLJi7mnKre6meM0CmjpsLtlO9YMDQj7DSiv2s
PxtRBcXp/NWFlGfD97/JKM+BKe1k31utH+U5dN8FlOfioD1Df7OVozxXkufR
/vN6X54nrufyJf354nquAN/S534btDPUXwBd49dfWQ4P5YViC4W0/3fKiyT7
F6G8IunaAY2XcqPYglFyf5PYgsRcMZ0vgHKJOTM6Bsb4x0o2XzMSevwDUpsW
UW4RW7BI+q040fLiLj9B84dVcl+JHVbJ+Wzi+8EmmbdNPC+HjfafpPmU0Hdo
QWLhv/8ATn8q0A==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02lIFGEYwPHJK2sz703z3LXU1Kw1j9x13We99vDYQywVpFVaCTTCzExB
m2JNP4QYQYdEmqlIq0KB5ZqEeaQVCmJplFKWZGRiiYnaYYXPS8wMDMOP/zzv
vDMwvJwTWr0ZRVGqv+e/Kzm4aR0P7+bxYUNfJXWGWdO77cQUGLWT4dXdPLQ1
8PO59tU5xHYwojttm7vujXaCx1SUaLGB2AUaDf011zXE7jD4VLilad4L7Q2O
TcaqxRBiPhTJy/Tfj3uid0GHLLqu2eSB9gWO5/YLlCWxP6T1jlxTiNzRAXB0
ZeZGTYMbOgimFeXL8+s70cHwJbu5vj+MeD+IhQoBX+eKFgDPJfvX8JQLOgRa
X6SXvEknPgC6jEOrV/N2oEOBV3/OSTrMRYcBXSRZEvoSh8ORcLHV1LAzOgIm
rConPBad0Afh9kxFTmwucSSUlgTOju8mFoKnqfB+5XNHtAjaZQva4m3EUbDS
uLl8RuqAFoOgy83vfRFxNOgKsn48+2SPlsBee/9vtaN2aIBmH+Xr0F40DTA3
6WfYd550KdO0FEr2DK7qVaTHsOZjwCbfYa6qgPRYyKhtu+UcRHosGKP4x/z7
bLHHQUprdby+wwZ7HLRI+waeuKKpeKbpeMgMvCQfOcPBngA+yivjmS1bsSdA
3lDnozET6TKoMZh3vs0iXQajnS+XXq2QLmfNy2FoQFx8qssau4JpWgFe8uRI
7h1L7Eow8w5Y4xh/Sja6Ejb+JzPsibAQufY7JtgK5xNZPQn7Ms4nAce8rfTz
5U3Yk5mmk6Hs5lg3d9ocewpr/RTQXBQEWlRYYFcx90urmPdTauZ+QA1JEWcf
fAjG9Wk183k9atb+NKx5DRzODGk/yV/H99Ewv08Pq1NaKDSKJPcaKJzXsua1
zO/TQ/wR51NxH3hAKrPT//sf7Zk7sA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1X1M1HUcB/CvgGidD3CcBwEFHs0nmIZwBhbxPhDlIeS84+E47o6Vwdog
7YxBgpc/Tc0W2YnMf0wn2riCiLGbxoPpr0uKatg6lz1M1lrNKZQec8mOKWXd
5/vH7/vbbrfX3t/P7/vw+93nlr+401QXxhiTHn7+++aXtuLcyECDDiEFcqcP
P7CviuVm+Mhl+Cl1eDl5IeYv8PhvO7ij4NrROZcZxq1B14TukrcvmRyHM11f
bDpYzp2IZncvSwomkZNRvaPMeW47tw71b9Tf8Ew8QX4SJn/kgEvPvQI9K539
t996nLwK3RnmY15vInkNdr65X/LFcKfBVj9mv+lIIK9F0tz4t1mBePJTyD8/
2aF/hzsdM9uzxt1Tj5HX42/1zEuXV3BnwDiQXFQ5GEfOxO/XTc59kdx6ZI3u
bTs1HEveAF/7e9FnddxP48t2X0vzJS05C7vdmh+K5nFnw/x+Z0Jr+jLyRsTV
XvAf2awhP4MrL1im7/4cQ34Wt47vMvTlcuegIOePPd/NqsnP4bJRPiENc+fC
n9sRETsRTQbqTnaHtZ0mS4D6puzrNfHcgJH4zpNDd6IoN6A/4eNP/SVLKc/D
7tVfBevKeJ6HqesrD6zbT2b56E4p/iXTx/N8LG5UTx128nyT8n6SYFYAa+rR
wiuvqygvQMPY4MWrQ2S2mZ7no5Q/dGFptrZnPuVbkOaNiNxwZAHlWxBM69jj
aXyE8kJkvPvXjEEmS4VIKT5+zfoh3Y8VCfMXwX0gfPBXO8+LhfpijMcHJjuj
eF6iHC+V4MQ1VbBbz9f/vLB+wawUY6M5LU3DCykvhWfkR+03iXx/W5WWBLMy
qML7WiePzaNcMDPiTvbsXN7ae7n/E0bKp0OWhFw2Uh2/tikNwZJgWTAzCfWC
JRPNf4PmNynXx8zC+s3C+s30fIJUL4xn5crxKEdY8ppZVe99qhdyWTCrEOoF
SxXC/gWzSqFesFQp1Fcqz4NVCfuvQpV1/Se7dP9QvWC5Sng/LMr3CxZsa09P
jTgYEbJkgevU1Qva38JDli3C+VUrzxfVwvkJlquF87MK+7cq7ycJloXxrEa5
P9QI89egde/s5w09kbT+GuV+mA2HjjZsbEui/gAbAt7vH7iW8d+zTdkPZBvu
LR7ad1+/iOrtGL271Gx1kmFHY577syVdS6jejvMB97r4cbJsp/Xy/uZA9J8a
bUBLORz44OuzzaomXu/Aohhfy6u3aLzsEPpnLVZvTdEUvEL9GrV4baD/bWMr
7+e1aHrZc7FMS/1frkXo/16NfwEMYAzB
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1IU2Ecx/GjzpcUy9eltdINC502nEvdWnZ+823zZZuTIurKEklQCc0y
pdi6MIqsi4QQkxqCphtJaiFa1ASlYERpIBWEmdKFGRkROitXsf9zsfPA4fDh
e/7P81wc6cnTlTWBHMfp/j3/32yJjzx6PFwng0+r/GimpWE+nJnD5ehLfU0P
pOQwLIn6WyZNzFEINitnvRvJ5Dg0zA8sd3UxJ0D7Nm5lKp1ZAlms+3C3K4mc
jOmegPOLEmYZhs6tt/ZV7SanQA5zj7N/F3kvugf4rYMxzKmw/1FfU7dLyHK0
PFUVvHq2k5yBuc6gkdeVzApkZzm5iIc7yJlYOdFvn8pmVsI9q/GOVyeSs+C9
NV79aSGBrIJm3Dofr2Dej9Zhy3pq23ZyNsZc4fq7X8TkHKQ0zrzzxDPn4lej
3WqsjSerIRV9+PjjdxxZA0Npx/uRY8wHkJYSurSmjyVrMVXhum2biCEfhFR3
6urZzShyHvZFp37vnmE+hIp6uftnIjMPL2fxVjVvIwOtac89NWbqNqBkcMix
p4d1HeYir9R6TJHUdUjafOlWr4ZTz4cn4+aFe/VbqOfjxXReS/NEGPUCtFk3
JuscIdQF5goFvRAZo6KQnBuh1IsEvQhJBqNG7AimXgxLhzJd1C6iXgzf/xxI
Xe9vmx5Hj2cNNcm8vK8bUJ5rHVtUBFE34IxTy4/0cjRfgot33jwRL7Be4n8e
VyqYLxXcr0wwXyY4v9zftnJEBN1vW+4MoHmjYH+j/36cSTBvwjfNxma+4jPt
b6bvaNnMgl4B1fWvazqXh/8Lx8gEdw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQNioVt3b8xWcoDwPthfn/F3UxEnjM/gIC8zg1Ng
uSKUz+FwgclSvM8Dxhdw4ObYK3j/owKUL+LgfdrGTGgxjC/h8Hj7sfilbjC+
jMNqG6UMjcPyUL6Cw+0fBdP3KsD4Sg6l+zckV0yQg/JVHAKWvi2Z9EcWyldz
+Dlvvkt0BIyv4aCat0v72moZKF/Lgb/55J8GMRhfx2HTiuNJTTrSUL6ew971
J5eeXSgF5Rs4fH7YujDsqiSUb+jQX+m4TOOkBJRv5FBls9AuVAXGN3YonrKu
lvOAOJRv4nCs51B52X4xKN/UYVEjz6YlgTC+mUNttL3NlhBRKN/cISbp0WOd
F8JQvoVD7bzLe8QewviWDr2bObX33ReC8q0cHs02M709Gca3dohhXzRL2lUQ
yrdx4M0Ret1RKADl2zqERxmtK1Lih/LtHPYet3qn8ZgHyrd3kP939rTFBy4o
38HBuPftd8cDnBB+g4PDT51JNctzoHwGR4e2idlW1fLsUHlHh43r8qfoRXNA
5Z2g7meGyjs5FK+2tt+0iAEq7ww1/6c9RN7Z4b3lr39Oes8gfAYXKP8bVN4F
VT2DK5p+V1T1DG5o8m5Q//+Hyrujybuj2e8BdScUNCD4AEU0zNA=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtI01EYx/E/c5plulU6L812SaKpDC/L21r7bXN5yYyiEGYKjrRi5SSz
i1muUOliDa0XQZCV4ipREitfWJBRiyUipGkEEaH4Iqy0pNyQWbHnvHAPHA4f
vnDOi3NkZuuech7Hcep/6//ORrTvyUCvRQ6fZrVL1RLpFQkzB/ewdVD2XEYO
RpNqcvRzEbMQtRdGfro8UnI4Yu51D9nbmKMwFjvTUKpiFmPJblqodErIUjjP
va+KmNtAliOpY8IaqmCOw51FT1lZcyx5E8QH4l7Pz4vJm/H0ceVNTTRzPD68
mtEKFOvJiRAGTl4WFMeQlSituHs+yBZNTkKS1O1VO6LIyTgctrD3qCOSnIKm
FkvWGQlzKr6XDPaXOUVkFR60TT9KKGHeAtdYQ2ONK4KcBnOh4r53NXM62qca
zYaKcHIGTkbc4uyd68iZ6Kuq/mU6xZwFo2aqbsSzlqxGbNfi+P70NeStCAno
rv16nVmDd9pWfuQn5m2Q6Q5eqvEKyVp0bsz/qHrJDJxWvHGX7yLb/MzpUGRK
6TkmF1DXocPVfiLkeBh1/XLb9BgPvXjIXRhK3QCJd3goY3YVdQPcia11jiMr
qWejtt4zaHkYRD0bvv/Io26EY2BC9FYcSN2IxD5+UNq1FdS3o7fHekNZHEzd
z1wOCtLr+yeVAdRzsLs5OYHfyKeei7O3R5+JvrCeC5403hPStaj19TykXv32
R/fC7bMtDz8yPV698jf1/OW2MU9T30H30Nj8zBX4ne9nbie975z2LzSX7gs=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQNioVt3b8xWcoDwPthHThaNmsYL4zM4bPm+aJHB
WkUon8Nhu0LAm+OJML6Ag6LYAoknPxSgfBGHwg7H1y/nwPgSDlKd8vrXrWB8
GQfFf+8fbbskD+UrOMRzzXr52ArGV3JoPbdpqlSNHJSv4tDdt/v81kOyUL6a
w7Neha9Vh2SgfA2HG32C1x7IwPhaDo2mnV9NtaShfB0Hc+vQg9rzpaB8PYcN
P4X6lN5KQvkGDucUbR3dQ2F8Q4dmUYX6mR0SUL6RQ9/3BI/cq+JQvrGDWs31
i4fdYXwThxtTE6LWXBCD8k0dzD5FaXjfF4XyzRxWFpy9mNEH45s79BWUrooO
FoHyLRymqv6NZJgvDOVbOrycVuS41h7Gt3KAxI8QlG/twM28turVZEEo38ZB
dvWfazHmML6tg+AbEbEPYnxQvp2Dc8gfM1Y3GN/egbfIyPpyEy+U7+Bw9DN/
cFQhD4Tf4OBwccfVLzd+cEPlHR2UvaZdi1rBBZV3dDhx1La8ZBcHVN7J4cPm
i39rRTmh8k5o8s4OVfW/DmavYoPKOzsUr7a237SIASrv4vDe8tc/J71v9hB5
Fwfj3rffHQ/8hPAZXKH+/QiVd4Wqf2YPAJ8EtIM=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GlIVFEUB/CXTlZOmopOmdao7ZNZaWppNv8Zc1Kz2RxndJhoAfsyQ5tB
oYUPW2kRlwpaoSC1lTZRK+NVmLZCiVZQRAgWrVaWC5UVnvvhvoFh+PF/58x9
9x5u5Mo11nwvQRDc/77/f9lHlVN7/ZI7CoPq0l7b0+s70Z9ZgEblsq5viCQP
x7K1L1z3HMwBODKnpHSPD3Mw5m81qUsuRpDH4OjT1sLfduZwPGnWpCl71OQI
7A6+3SiamKOgyGgpyqwZT54IQ/HIhyP8mSfjaluFkJo8jjwVTd9HZTvXhZM1
SKl97FdVFUaOhpfL/uJd3VhyDMq2ede/Xso8C4cOF8Z3Hw8lz8a3YzGGej/m
WIyL29mmXjmGHIcQ46rEzrrR5Dk4bOp7vXxARY5HYJlR0MUyJ+DUgYLABoSQ
E5HwsfPVuWHMc1GrXdW72RNMnocZb8NEXwVzEirzuypd1UHkZCi9zxe+rwwk
z4fW0e0yhjGnYECwDCzfMIq8AKm2XwlDDf5kLYznStPya/3IgEdf1uh/gnIR
qNHdabobynId1H8ePZjb5Uu5DuUdBUX6nmGU67HleOsN1RtvyvW0viGUp+LL
vP4/+pif2sE8FQVnk7WXTwqUL4RXhKZfefYX5Qup/uughTRZLrNg4P9PNCAr
sbiuI4bWIyziLS6i9fhQno6WppSNG64Npzwd0VcUPgml7P0yELfvU49OGkF5
Bs3bSMoz8Whs1/v9AWx/MnGkXdlXFa+kfDFvcTEmZB5sd9bQ80IWzSOrz4K7
pf5mawOrX4In9W3dz3tZ/RJZf6NsfUY0Nid9ntrB1meS1Ztk/c1wTi9Pf7yJ
DLOsn5nfD8mMwfvCi+ot/H7Cgh3l7qQiNT0vynLJgurrz1T3w4dSvZU3rHx/
0cqfn2SFwxl7YX3UAJ1/Nm9k8/Mjyixl0/v1Ub1NVm+TzZtNVm/j51nI4fsh
h59vUWYpRzbfdr4f7LJ5tvP7IcksOPj+cMCyd/Z0xXYF1TtQWNx/y32G7b+D
n3chF33RFZurPXTeyOXnR8zl7w8pFxmnL5yZdJTdL3nw8wR92LUugOrzYPZo
HvwIJYt5+PByyraZJWQpj9ZLFpzonBkVt3oa3V9w4qm2QjH6FVl0Ym3799sr
IoPwF371vlI=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GlIFGEcx/FRlCTd8r6vdTO0VDRd79Wfx6q76rprJiqKKYiRhBZIvajY
pTyKMIxSkYrKzNQUjCzNUltZNcUOLLH70EIlYiEzU5MK/8+L3YFh+PCdeWbm
mYfhF5amFxlyHCf5t/8/ss12T3dfV4kHNqSNzhMW2xbzmDncuVZn0NbLJ5vA
tKsRmzKZzcGPKT5Vvu5Otobgg++a9jqzPX6qGkp65MzOCDYqlL5acSO7Y6Rk
9zPDeGYPdBtbNdVXuJK3IchMWDmx4ELeDktXX/8IC2YveBj69BgdcSbvwH1e
TdTkPSeyDy50VGUNPXYk+6FV865AlMXsj/40y/d9bQ7kADi4azJnjJl3ofm2
pql60p4ciJb2F9O/vtmRg2By/KzTWD6zEKp5/sBniS05GCdODr2tH7Qhh0Bx
JmCnUYU1ORS5Jo7KhjDmMIzf7W49VGZFDodYNHv06YolOQLLyV9MVCnMkbCc
G1S3p1uQRXCyn5mrPWdOjkJ2Y8dVGx/maL0OhD3puzL8kawEbgikr4PUrMcg
NWFYMytiPQZmVurDZfNbqcfCV+SXMfCVRz1Wr8chLmMt2DhhC/U4lIz29E/2
mlKPx8OR8O9eM2bU4/G85+Xi9DLrYizxelVrQtbFmHDULpw330w9AW7rE+Oh
WrIyQXc8LlFv/EQIpHVTOTfZ9Ul61yfp3o+T6D6PUoIpXvW+3zJ6X06K8j55
ZOgyez8pZLdqxEXdrCfr9WTd+eBSIGntbPO8SPOlTNGdby4VLu1rU7kh9H2V
qSib+qEu4LPvL8PS6U67vEXWZWgODxxtucR6ml5P01svcnjLBNbiA2TIsfdg
3urYHDtfjv5cz0eupjTeoBwb/ws2vgLZ+eqknCxar1Bgdr93+J8qslKBY5cn
H9h+Ig8q4PwmC+a1bL2no9RgtbItwgZ/ASIPKeE=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tIU3EUwPHrI5+oy2xqvjUjTaxp+UhrxzmdzrdzOrWklEVYUKRGJKsb
IRaYbyQMwuyPCZagZSaWrcQoITFCDSvIjAwhfJCPRFvFzi+458JlfPje373n
dy/zKz6TrTXnOO7E3/PfLzvE6t6B7lP+YNKC9NZSwtEiJ2YOHnlPtZt1+aFt
QDY6q5PlMYtgxExzs9Ga2QWGnwfrHPS+aDdw/2QzOKJi9oRLtm1aWzNmX1AE
NM+X5vqg/eH49OfVghZv9E5Y6FquOjfmhd4F31/7nP266oneDbz5xzknOXMw
dHgGarWTHugQUFzXK10lzKHQVhKe+uLKDvQ+qGsodL465o6WQKsi7LxbHnMY
eIVXj/sUu6HDwVhacu3VrCt6Pyw6qoeC9jIfgIGaen1ltxgdAct9Vf0rU9vR
kaArlMY+zGGOAk1SnejLMxd0NBQsfYgI3NyGPgiSxNZ+5RtndAyUn9QPZoiZ
Y0EUIvEYNW5FHwK7u2tFicPMh0HOX9iUVDNLoSKouamxR4QG8OrcmDgSiZ0H
KOuMkfa0sx4HRi7LeKzcCXscnJbVP3W844hdBh1xQ8Mv3R2wy6BiIDM2ao31
eEi/V5ug7WU9Ht4+Hv/5fs0euxwClC0TBR122OXQMFNWKVu1xp4A89Hrv2Wh
VtgTIOSBpVVELeuJpCdC+I0fq3EGW+wK0hWgH5gUj3huwZ4kNJ8EqZGX+2ZC
LbAn4/vgsCeD7va7J+Jp1pXC63klmPsGr9t3bkhNPYX0FLI+FbJqJHssqyyx
p4Lp/2iOPY30NLI+nfR00jNw/yumeXjmbzhfptBAzGeCvcX9i3NNiyYbSOey
8Dl4ADFPbMjC7/ML12cL54Ns4fvjs/H5Zqb7GMj1nEo4H6jIfkk3qITzcDlk
/hyyf2JDjvB+nJrMrxbujyfdoCbvL5esJ+Zzyfy5ZH0e+X7EfB5ZTzqnIfvX
kPXEBg35fvlCQ/7/5/0BB2yyIg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1IU3EYx/HjXDUd0eZbvk5dNdZy0rR8SW2/zbmpc1qmhFIXSbsyMLI3
R9QIqpsKTCGSLioNxPeFlk7SXJmWGGgp3pjQhZBgrcycM9YLe/7EduBw+PB9
/s85FyexqqbUzOM4Dn/vf092RZT3DdqqpfDKqT7+frDDFMLMod/qWu56mkgW
wNH9ttdZzizC8OycZXkTcxjqFyArbU4gR+K2fHXcnc0ci1DXzLCqNZ6cgF7J
Wln9RwlZisD8tEvCSOadMMe57vVUxJFl2FhXXBY1xJLl+FLFn+/5HENW4K6y
ZdruiSYn4XGNaofMwJyMOeeD5ue1UeS9GNP0BH9yRJJVOG+T3Cmf305Owbl0
mbnPzJyKIXuIwNkYQd6HtO+VcuNCOHk/agI2rrdlMafhhuXVRdf9MHI6jnAZ
72xi5gy8qdNln5SFkjOh0jcNFE6GkA/g9OyK40QicxaGju0akQiZs/HB/DNI
PiAm50Apln9rmhKRD+LQKcXEahSzGnW7x9bNJcxARVPnw/AkshVY8dgrrm5h
XYPumI5n08Zt1DVQ5iSXDS9upa5Fq+bl6OsoslWLeM/kRIYzmHouUm8tr2le
BFHPxVT/zI85l5C6zq/rMBntXGoUsfN5GB/NuXDWLqCe5zvP6X3nrXq/boDl
inukum0zdQMO31Tt4V/jU8+H9//nUc9HbXuW+skjjnoBjlamdJ2R/lZ7ewGE
gZ2WpYYA6oXgJSjcwvZf1Avp/etec0a//Ua/XuS3v8h3H2fynbeafOe5Yt/v
tRb7nS/B10y3R5u8SOf/+w9Fig21
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlH1M1HUcx3/ARSRCPHmIgIdUpJxccaQeD9e97+SOU3k4jnvigC0bjBEl
ycNMmOPnSrNHuWVu6Wz2sGQaNHQWAubPEmc1aeSy5jKnOJim48oHjBCr8fn+
8f3+tt9+e+39/Xw/v8/78/1+ljzf5KwLlSSp9b/3/y971O6jg32N6ZijoClz
Mjr8/XjGEgyT+9YXDi0hjoDmQfeV6RrGMeic+ivvaDTjBJwoTZo48EUa8UJc
1Bt2ftTAOAXGtk/jL6YyTkPLpcQ7ni4NcTqy8neq/u5fTPw4hm0bugLBVOIM
1N962fKqgfFSbIuImOlpSiHOxKh64+9fvpFMvBzf2IYOj4wsItbhQl3r4loV
46dxJ26q9lRGEnE2Qrp+mr22dSGxHj32C+PNIYxzkLL/pQnX8UTiZ3Bru9Vn
1TNeAf+PUQ0fXFYTr8TxGxWlZZ8wXoVAasONPWMLiA34J7redNLKOBeK1nLz
8+YE4jy0b9ZOnH+CcT6yJpLleSrGBfhuc2FBbUY8sRHaVHVS/fo44mdx983e
xJrbscQm1O37LLRjP2MgK3bpn3tGY+ZYBt7S1/229zliyYyWQ/mmwx8z3YwS
2+nhq0amW+D163ub0x8l3YLQtMzpyEPzSV8NvzZgH3klkvTVeGzt7vP+7nmk
FyLnnZtTZuUR0gtxYPAX9fcpD5FuRWRYT/v190JIt2LuvIaSbqP8D0xzuo3y
z8yxVITiVZ1fjenCKL6I6pEo3g6NvSRXfZDyyXZs+fDckPoyrZfWCPoaTOZO
z1p04aSv5dfLAkvr+Hrkdfz/SMXYHmjM69A8THox74dUIvhTIvhTKtRfKvhT
hvK3s7WqbSqKL0Nfb9MuXVUE6Q50vRbWf6mG+gEHzi4KXt8VQyw7+H4pDgSP
jN7fsoD9XznODBs3tQ7QfihHYKylwzLF6imHZvbsD4YgixdYcvL7w8mfH9kp
xDux/IgqfOW7tL9UwdcHgeUKvn9KBdo7p082HmT9c/H9hIv3T3bx50VxCf11
C/ndQr/dQn634L9H8N/D+yl7+H4oHoz2/3z713t0nyQv7kYd2zqzgvyCF41n
+r8+d4zdNy9//xSv4L+PXw8fus3fDp9OiqJ4H7KMOteJcWLFh7ZBR4HhXjTF
V/LzAJWIejHujx0b2bwQdKWSnyeSn2f4hXg/xp9Kz9mwjOaV4hfmWRWyB5Kf
vNJG8w5V6C2adG6aT/NQrsIph7JXHiBdEViq5tejGtd2N5t7TCy+GldfWJZ3
/3VipRoVkmGkLzYB/wJKO9kZ
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd021IU1Ecx/HrVLCm5nIu3ZZuU9KkZk2XD7P2mzp1zuYUIjKKiEaSlaAW
4Yu6iZhChZCmpSU9aMZSWWRog7QsSUGwDKWISu2VJswQ0wqs2P+8cBculw/f
e87/vDnKoyUFNgHHcYZ/7/8veyT7epyOYhXcculndPqXMn9mDvYLaYlqu5Ls
B6X0bedtM3MQZoYuLU9/VZDFMD1JUJ6uZg7FzC3FuQMaZjlszsLFwDsRZAUO
18v0/vPhZBXajp181xTJHIXiOVu0b/Vm8hYoxiYTP7yXk2MgF+VHNdiYYyH1
OX7zRaeMvA3bS9rPj6qZ1VgY1w1M35CSdwAtsx+7+sLIO9H/rbt/SsusQXly
Sk1wWyg5HrUNWb4RY5vICQivOfFwMYRZC2vBkqy7UkLeBUFT6+9sPoSciCqf
4RG/RjE5CY4f0taKomByMhqnLnt9XthITsEr60Az/4xZhzJHd621QkRO9fBu
bLVEio2nmPdg7lN0VVxlEFmPp666OOloIBlY5fJXj5RvcJsHBIrYX0K7P3UD
lgL6Lv7RknkDOgyDr4fCAqin4f7wvbPCctqPT4Pl0VWjrYf1dJxxWlOTlllP
h+i7WOKSsPkZa81nwJ6qKooZpPNwxrXmjR7rMxFQqtGNV9I8PhPFb3qfj/cJ
qWdhVOqarQ9aTz0LzRPClXYt69mIzLk+UdjBejbqqrx7vxwicybEX5n/aRhY
R90ER1dJvfqgH/UcPHBOSkbkvtRzIPTurJi95kXdjDK7Tv/4LkfdjP2Fmq5S
1are3XPhvn8C6rkefe9a8x7mLB77Wzzm59H5V2h9HvUFWm+l/zjuLy+w+8M=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdyl1I03EUxvG/iqxUbOqcy810MlJnDF0258vc4+ZeUkGIJLLCKXjTCMGX
iNSSLiyIBmNeCHWVqUVKqdS0bCSRGWTibOKFUaYkGK0trDmzqNj5XeiBw+HD
90jrG481hHMcp/q3/y8bYfWjp8PWdITk0+rVP25tCZg5jPZH5rkeSsl7sFwy
pRGbmPnwDnU4kgJpZAF6+7cn5HeZRbjX5I6PMTJLcE3TnXtlOJWchvFpnn/k
ywFyOqrqP9dtSJllEAYHZn/1pJAPojYnIyB8JyFnYtEWt/BRwixHiq7H0moQ
kw8ha7tdG2xMJivwRrUWVf1+PzkHluBa8EYCcy5m/F2XZE0ishK2gMV8zpNE
PozJF33hCyeZ89C3tDzv2RSSj8B7ZtJZN8Wsgup7TWbFh0RyPuSn1C9dVcxq
PM/WfR1sEpALIKqdcNuMzIXIkvFWA6YEchEcDT7H6YF4cjEMmtX22S1mDc62
bD4OO8Fcgtwn4oxPrcxaFCsrr8Za4sjAdWXD0k0LP+RO4IF40Omu2Ee9FHde
956PbomlXgr98W1VpJHM6fDsVaE3cyWGug5zY56Nxc1o6nrUZNvNby+QO/W7
etlOd5bt/OcMsE6PuebHWTdgJtm33s2Pom7c1Y3wjc797kjcS92ELru1sC2V
R90E+0pzmy5A5syozL/sXFFEUDej+X6RduQ2R/0ooiOGLq47wqjvMleObwVb
f3SKn9pQL6fu1/4FH0TjlQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQNioVt3b8xWcoDwPtiv3r3szkI+GJ/B4dKZr9v6
1ytC+RwOEyx5IzNDYXwBh01/5hlp/FKA8kUcaqzeLeqeC+NLOPCuf/pMUB/G
l3Hg8Vht+2mpPJSv4HCs7mqB6Ec5KF/Jofb2/TfpkTC+isO/K1Mm3JwvC+Wr
OdR0qph1fpCB8jUcnunyWWyUg/G1HFrPWm2Y2y4N5es49Jx+yPfggBSUr+ew
NN9QWc0dxjdw8JS6cvGYiySUb+iwb49cCPMbCSjfyOFq9EPLl//EoXxjB94v
c156z4HxTRx290xYXr1RDMo3ddh5OnJbeCSMb+Zw8kpLa+lJUSjf3OHimvOf
VXJhfAsHm68H7/XEwfiWDgH6C5RKJESgfCuHctHZDP3LhKF8a4ftBcsi9URh
fBuHde7vg8p5YHxbhzfCkanfOoWgfDsHl4aKv4btglC+vcO3rnXisV9gfAeH
x3v+NmibQ9U3ODgI6BhKn/sPk3d0KLj2+VCiIkwejc/g5LDUyvjE8rkweSeH
jZ+k5ldlwNzj7PAkS9PqbzuU3+DssPhJa5JzGsx/Lg4ytyMcBCZC+Q0uDnN3
2ERPXgeTd3XwKxaonnZUxAEAKC6ugg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0nsslXEcx/HjUi5tSDoOuR2HkGaFVI7Lh9NxOa7HUiq1IbGaSMxf5VFy
Mo4/0JhLupkpFUcs5JpRzFZWKcLatNAa9UfMmZbW7/uH82zPnr32fr6/59nz
/ISJ6THJ2jweT7Zx/rvSwY9t62q5YI//WvZX6iuMLxqTeTD8VuU80Cpk1oeT
yNfdL55sgjVVm2hYj2yGuKzvVT7P7ZgFKM7aWjWTRLbC6Iqj+qMe2Q6eA5+U
4nBbZnsM19W8SC63YXbAnXKdqwsvrZl349n7Up5ETHbGSKqlaOCaFfMeuKmb
TwdN7WLeC2mSRLo1luyGkbzpoW2+lsz7gJrFyScdFsz7caVl4lZkCtkdQkHC
+ti0gNkDlf23dRTHyJ7ItEib+JFrznwATeIHQ7J5PrMXkNg+UZpDPohe22pB
rQH5ENK11AUPxTuZD6NflO/Msyd74/7cjUTJOTNmMU7+mvJyXN/B7AM9G92j
g+NkX7g46M2tBJP9cCq413Ct2ZTZH6thX/XzwslAVmpDTxSfmYNGD8D5rNV2
rePUA/Au+beBc8d21gNhOt838CiGmQtEl2V5bceSCesSZLuUl5WqmDmJRj8C
YUBKYfYf6hrmSeESKTKTptH6Uoz7l+qaT9Pzg+BqzbdISaD3C0K9t8erhlp6
/2B0DytmV3OpB0PZauDaM0s9BBVfirVmflIPwWB0XzXXST1Uo4eiSFnv+FiH
vq9s83qcDGXJy2XxDTQfhtH2tsbMDHY/FwabjsvtilGaD4dDjlaZ1xL1cJy5
GbTgO0g9AiGLEz1GRez/cxHI1309ol9B+yFSo0fCRHHp7Ow96lFQPS2wEXym
HoU3Td2F1z9Qj948jw3LiidVJ+j+6M3P64uG57gyx7GT5uWYiStRFK/QvBxq
oxT/finbv5wc2pV16hCOuU+Oxoyxt6kltL9jNhsxcJqR383ewsdfiP0qAQ==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0VtIE3AUx/HlJZyWzbLNy2pzq9jcWrrVpqntp3NXbZJiwYJV0qAoLxVh
DKoVaC+piVZkTwmRNDdQGbJmXuohL8yQRF+CIKEHQ5hRiZLd2PkTeeDPnw/f
83ayauorXTEcDifvz/v7s+FXB0J9FySIKqLvWDc9vSpg5kA7oh5bGs4iJ+CH
3NkcdDHzwNNXaivimVPhiB0/I/aKyWkYaq9Z+WpnFuL4SHpT46qILIbXNzZ3
voxZAsuk9T2/eTd5D0K1RZndM7vI+zA99VHQI2WWQVMxsTmnUUjOhq76rW/i
VSZZiTeGAa2by6xC1X3jQ//1DHIO9rbNmlYvpZNz0fCormJ8NI2sxrTZmfRN
yKzB57P9t7/0CsgH0W4WqNzzfPIh3FC6H9dFdpK1eNGgXKmKYdbh1HzA+e5a
KjkPXfZbawuJzPlQRlr9g207yIeRa+oK2sLbyQVoGeAqhj8wFyJ6P+YiLAyt
exQ65iOYdX3nyoIpZP2GDhSqy+8kn6buAeR2aaqxlu0X44q3QN/fzaNejE8H
JJo6Oesl2J8iW+6aYb0E3kLJOdnrbdQNuFhy72Xyk2TqBth7W42uwFbqpYgR
Z68lebdQL4XoZ3gqL5JI3YhwRmSxk0f2GCG1PZhz9LBu2tBN6PPXd6pOJlA3
Q2Q5ms9/Hk/djGehef6kkMyx4NjdXEVcUxx1C8p1NwcXVLHUrUiK9bkXOzZR
t+KEQ+2/LPmlj3YbNC1LK8Wjq1F7bLS/TL3sf3v++TeLFtnV
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzwtIU1Ecx/GbJklTsrT5zMfSKIvha76m7ed0m06dMyhDJVdkhFLWkgQj
XEoEEQpOhj0oqCjzmaap800ZloipzcxIiLBSCDVMyoZU+D/BduBy+fD9n3PP
9TtWcCDXhuM42d/n35st/sG2ruZ8Ada1KPHQbOo+5MzM4XHO1dW2Vj+yPY7/
7jmpP8zshD5B2LSD2ZfsAoeysqbg+8xuCLXVyEdVzF4wvrY1pD/1IftCP5iX
YZr1JgtQvBz0LsuT2R/qhRXJF90O8i68z+Jvqhz3Iu9G8uT3e+4i5kCoW0Kj
R594kvehz6ivqHJiFuLstNlJkeNBDsLzKeWN+Fl3cjDKr5suFCUyhyDnVPOd
apMbORSFR7/aGE8wh8Hv5dKVyD3MIkQp3qClyZUcDkPF6TO1l5kjUH6+pDRm
hk+ORPuwq51ZwxyFmB8DM9eObCdHo3+v9Fu91oUshjhPW61pZY6Bf9EGffiC
MzkWcwZtXIOEeT96swMGvHnbyBLIe+byMLaVDIxLKje6fiDrAEnGcrbKk/U4
JD1qrA24tYV6HDIyQxq1AjInhaM2RDxR6khdClV9uSy3jczFY6zDtDz1k0c9
HjuVhsnMms3UE1AT92zwhTvbn4Cbk7xfD0Q0z8msugwrjp2XzCIH6nLY+Aau
8urIOrnlPKewPE+ngM/ayHDkIvt+IvKHOnonOllPtLpfEkY8FuernMi6JAwN
xhYVGu2pKy2tU6K5saBKmMV6Mh52veW/8rKjnoyUiJL2T0Jb6im4eHuim/+R
rEvBuTqxpOUuRz0VC1Gra1LhimS9p4Jn21A8r19aN6ei/zdTV1nOc2nkz9TT
rParLTusrFPTPWj1W5lL/+8/33AVkQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1Ecx/GTTjM1tNJpeZlamegYeb9V+znzNqe7WaYmiaBERoL2aiIu
RQkrIYxe9EIok4k3UKtlZmyFERWWdlHoRUQQZYqTbNnQVrH/8+J5BmN8+J7z
nOecs8jqel2NG2NM9+/7/5f7iI/dnRyti4JLNvniOWmt3YMzQ6VZZXjWF0n2
gtnaWDaj4eyPlIsxA7aVCHIA2gzt96o6OQfjx8LEi+/pnEORpLR2ibol5Agc
73ty+tSHcHIUJP4/TWZw3ofGj3Pqt+YwcjTKfBNfvfTjHINFzf6519Gh5Fg8
7ggpLzkRQpbizvrmaljvHrIMTu/26h4J54PIXlEeaG3bTY5H69nlS6b5YHIC
Smv71x3unBORNt3S1PMgiJyEoczbT5VfxeRkTC3pi9W9nFOw1DUzJp8LJKci
tiJt+pGacxoscYrloYYAcjoUVn14nIRzBgrHV5Xa1F3kTHTX2LpPmnaSD8He
ORJUubaDfBi5U9/OYJbzEZTdGL4ZKPUny+FkWmfVeT8yYN8+cWEj2ddlIzB7
/93awroP9SzsVV5/X97vTT0LoyP112QVXtQVsI3PbjYHbqOuwEq6449C5kk9
G9JxkWdK11bq2ei4WpfRJCGzo4IuMMvhjzfmoLnnzUPxJ3fquXD9f92o50KV
2mL+LON6Hnzchw2L3Vuo5/HHs3yYJufFz0M9qOfzx7MCwfwCaC/Hx4naRdSV
SLyy/CvL8lvu6ko0DmbKx24x6oUoLU8YaYhyUi8UvJ9K0FW03qrLrIjO0069
iL8eKxbMF5ip+esZ1YLz08DQ4rDWDdB9QcPfn1HDv0+LRnA/Wv54aPnPMwq6
RSs4Xx3/vKAT7FcHt4hYh8/ghssWgZmev1/oBfel59+3RS84vxJa7wvNL6H3
YuwvJg9Nqg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mlIFGEcx/Gp9TbLc71zPZA0kczyyuPnfevurFmaglQSqWCmZiiyppmB
JnlggiCYVGKlmOV6gKyFJR5gBhW9SEpfiCVtmAeaduD/ebEzMAwfvjPzzDzP
43g+n8/ez3Fc0r/z/5Ud4tMvRvpynbAndUhRLWqvWjNzyLB603Fv2pGsh5TI
nQuSbGZjLKV1Sq/rMptjbrTk8pduCdkKbasRu/o8sx247cDUWW1mCXhlvf9z
VweyE6TO9nKr0sNkFzg0ZKYOjNuTXfFn64bL9A878hGotKfcekOY3dHV0Xmp
qtqW7IHBqop2+2UbsicefFX8MlAwH0OG4ejZNjNmLwQFxHo5ZVmTj2M6eDGK
n7Eie6N1rF1Uk8p8AoXNPeX6KkvySdxqyA0oc2D2Qf01RWXgZzHZF63+Iy0r
L5n98FPJy52Dmf2xpqweWv9kQQ5AneVs43oB8ykY1xRcnL9vTg6ErM7rqFY1
cxAWc9wCdmrMyMHIqPJO/7hkSg5BTtHmwL4zzICh6GnpcpPJniuAYrfmpsZn
xtRDsbo7nFapS64IhTTPfWrNmvUwFI9IA/02D1IPQ6/tE+Vc/CHq4TD5bi5W
i1kPx36J+5bh4wPUI+Ac1/I+vcuAegTu3hQNzmeSuUg0LBSWhW3oUo9EqWJr
LLdbh3qUoAvMRdN6sB4t6DGYsVEvNxuz8WPgsDsz5adm48eirye/2fOcHvVY
TIwHlRQNk7k45E4Mjr4bMqQeJ+jx8OjX0vGpZ+PHC74/QdATBD0Rj0Y+iCft
tKkn0nprUU9Cgq9CueApop6k+b9csmB+kjXfx0k1x4NUcL8U6v63O+UW+ntW
SeF9Z2UjVEXmZJrfD5lgvmSa66uSac43x6Mr9NX4a2sjep5HeMpvH+0otl94
zf2n4mGUZ/rtdgHbf3JkFWRuTy7R/oUcyisP0zwtzPAXbD05uA==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tIU2EYBvCjklNnOU1Nm+UcYuK1Vlrz0p5pm5elbSupTCMyIVoUapFo
1rLon0CYIwulMA0FTbtOEQvNGlFQYYIQSBYLkSIvZF6macXeL9j54HD4ned9
v+/lcE7Y0dP6YleO4zR/r393tgLzLL0PDVI4NKUYibabqz2ZOTxpqnNp6wkj
e+B7vLX713FmEXqujMy6eDL7wzSKCH2zhByENY2lp+TZzCGImfSaUw+GkiW4
pvhYK5YxS7FcdGu5wbiRHI5CVUe0S9cGcgRsXaLLE97MkUjM6/R4rw8hR+Ft
v8R9ukZMjsH1nKGU0MX15DiUy158PlfAvBknlqotLy8Fk7dAtnIsuK8xiCyD
JXhsdGZ0HXkrLPUtyhof5m24Ke+t+zEQSE7Apk+6O2dXMSdCYgu43nwwgLwd
uWWiyjqrP3kHtPGN0jNBzHIYDgh0RTfWkpNgLp4yF7T6kZNxKKPPy/6AOQXz
dwUXviqZU3neiSMlhYtvxn3JCng1zx9WW5mBWN/I6fpBkcNGwG+8f6Bdz3Il
CgRN9WIV2ajE6+HwmUVvlqehrD1Z8aiJ9afhvvhe9weND+XpiE2N29c3tpry
dDx7lTQRafOmfBesP3325peQjTxzKuRHmzLflQspV6FhWLjQkkDm1FiIqT3f
etKTcjWmHg/+rgogcxmouGh/bmhzpzwDJltZZdqcgPJMXDUZkipDycZMTMrt
y2lxVM9loer20NPAL26UZ8Hxv7hSnk31YwpHnk3P2dI426hxrud2Q+jWUfHN
PE39PHM5VD9LeQ6vP5fXn+tcz+3hnc8zp3XeD1reeTz3a+EqibIL25dof52z
oaPvgaP3pcP+fFlnqXSF+nW8+fTO84Nno/7/vH8AVuIv/w==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzGtI02EUx/F/bpW6anPZcpuWW2nS1mwu1zRzv82p0avZneGiGeKLAlea
QRcYZVCUUdGFCkpYOmXYmlFYGxHEpIIEsZbR3pgxoou6BdpKWsXO86YHDocP
X86jaGje0pjGcZz27/zb7Em2Pwj49ymR0pQxMz5cLhQzc/B7w6ODXgU5HQOH
36TLLcwiXDyavOYcyydnQyDuix5oZ86Bt2VCfKWAORcf9KEFYctycj66w83K
8cvLyEqYeVYD9zqPvBI+RcQpLGAuxG7/VtWjzlxyEerjn8Uz03Lyatgbe8cr
ncxqpLkdbR0RGVmDJzvCHwt/SclrMTsn3jRgY9aiqz/kPj2SQy6B5nr/pH12
KVkH3zY+PzYhIa9D7+3oPZWduRR6WYY71rmErMfe98Gg52s2eT3qzmlV/FPM
Bgw5dsW+v1tMLkPDc+VjnYu5HPUndbbRT2LyBpzt6Cro47FeAVWeRNrkYH0j
RGqtfCiZRa5Ei993xnqE2Yg1WUWxG8MiMpDk6pJ7WoUpu4A7L9xtgtZF1E14
OHWhWPaK7DLhS2RVe/EJdm/GoYC1wvCDdTN22kruHlTSf1wVekzPQoPShdSr
sGLz1bCtJ5O6BTfDgkR3qYC6BQn1pWOe/RnUq6G+z5+nPz+fejU8gbeSl7lz
qdfg+K2RoGSMR70Gk2U/f5s108ZUr4Wu49uM6WkiZVftf30TOWr8A5ayxpY=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQNioVt3b8xWcoDwPti/f/RRT1MUxmdw2BDf9Wvr
FkUon8OB21N1pXMijC/gkMV0W30DI4wv4hCuMl0paLoClC/hcOCSy8wZPjC+
jMMF/n0TU8/JQ/kKDgfmmLKpiML4Sg6fFhzkFa2Qg/JVHLj934X5fpOF8tUc
VF8LfIiMgfE1HHrmR03cOUcGytdykGJJn3VwrTSUr+OQYReyT4ERxtdz+JJ/
3jeqUArKN3BoSdE//qtNEso3dKg5tu4e1ycJKN/IofPP5WsbnWF8Y4ciydzr
b+vFoXwTh0M9/YKLlWB8UwcXVT6d+4JiUL6Zw+/CBfW+GaJQvrnDhTV7O5uv
iUD5Fg5OB4PltOVhfEuHyPhDHlERwlC+lcPCJSdE+68JQfnWDgXXPh9KVITx
bRxOXlP58ptHEMq3dSjdHWBj8YMPyrdz4BE+VF7wkh/Kt0eTd3DIcZqwl28h
lN/g4MBbZGR9uYkXKu/ocPQzf3BUIQ9U3tFB/t/Z0xYfuKDyTg4njtqWl+zi
gMo7Och7+FqKrWKFyjs7THxcXO30nR0q74wm7+JQO+/yHrGHzFB5Fwcf8/rt
j/WgfAZXVH6Dq8N7y1//nPS+2UPk3VD5DW4Oxaut7TctYoDqd0eTd3cw7n37
3fHAT6h+D6j8M6i8hwM389qqV5M/QuU94fIAkFzNDA==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2Ecx/HDnFHeMHdRm5dN7IIOazNda+l+bjrXbIsiIV1DCnoRZlEr
xfDF7Pamhd0gHL1oEgUNg4KCuaIlUhl0g5KopGgZUWRFZG0ctWL/J/B54HD4
8D3P8+ccjmbb7o3bJYIgmP9e/+5sKZuvR662lyCpb2aD6OnuUDEL6H4y7lGO
asjzcWg62HpsL3M2oi9H9h/NZ5ajb6ItdiaiJuehv9Uri7qZC7Dj4tlZYwaz
GvdEVZfeW0wuwdZowh0eKSKX4lGzTzYULyQvwcS5G/IZPfMy/HzzrjPXU0Au
g78oM/r0loqsRZbphbp/MXMFSifTfuvCi8grIDzbtaf9Yz5Zh9Hnto47BmY9
Tg6knJiszSNX4tWsKuLel0teibv+4a7O20pyFb4aEzOWCuZqBB7kDJ2/oiAb
oJGOv/0hysmrEHD1JmJpzEa0tA3bWzfLyKsRvHBf0TeWQzahoeZ9z+ME8xro
bIGw4yFzDWI3p33lBuZaFIbEsS2GhWQzPr9eenj5wWwy0BIYDCq0ZB9g3SRW
p9qyqNdhKjPcK1ZlUOcsWBDXnuq5tHMBdQs2+HXl0iNS6lb6HvOoW1FsdxqV
l1Op1yP5/0mo18MbMpmvDQjUGyBRlyXSQ6I52TkLNlQe//KrLhqnbqN5U9Qb
kZ4yeODT6e/UG6l/oG6fa5+d27+W289ZcMx93ufgzm+i96Dla+L6Om4+Z8HJ
dSc338XNd3H71/+f/wdZ2gyT
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlH1MlWUYxh+BgAQUEE4I5EEUR3ogQEDgQFxgfBy+5JzD1zlwFjXZMFg5
PkLA4I1Vf6gYH1tbYgYmaHyY1QgUyze+slpuxI6Za2sIa2hj0moBjkG1cz9/
PO+7vXv32/Vc93Pf1/Ps3f3K64YyO8bYif/e/7/8UeUPj31WEQgbLSdGPfjA
pHXlzCCvHLXO9e8mdkZPzP1mRyNnd1xMTHmucz2A2Av9UmRYWy9nH+i8hk/O
ZHD2h35gcsljWk0cgMejk5m1as6BCLH4znZ07yLei+cXzh9L9ea8D9X1p0pn
658lDob12j8vHXvgT7wft6y12rAqzhoEhfYev7noRxyKrrsua31RnMPw6L3r
qdpvfYnDcXTiy/Azbpwj8Op6y/DkWzuJD6JjqTy4Scs5Emrd1K7OCz7EUbAW
z8U+3HiGOBrGcGf2i5HzIYzIW9M++kNFHIO4fdfuDbZyjkX3djvf9RTOcWjS
NHS9tuxNrIU1uPLlvhHO8YjunCzXeXJOQKO13o2VehG/gL11WzqjH+8gTsTp
1t6gIXvOwOolp6aFJE8bS4C7JtzvzqYH6UnwXJTHBwzEUhL69mTcjxx3Jz0Z
n/oNjvyUuZ30ZFz67uM3XGq2kX4YblUR2tkWN9IPIyQhNO/W78TsRXG9pGCW
goH4wPLgCV4/BYXmiKtVgcQsFbVjufExq9yfKvbD0hT+NLjuGK87/pDr6fDz
mV9s76B5pHSEeAT/eW6Gz6dD2Yd9do3dfH6dmAfLUPgzcDqi7NeuUu7PVOyf
ib82bphanLiepdCzFPNlI2fwbErZMM8vW5FPjpinlAPzgfb0OydcSD8Cu4D9
T1wGXEk/gorbo1/PXud6LvZkvH/XfGWrjZGLtrftR3+zEEu5aJ+vbkxecbKx
rFjP9GI96HElaWJqeifvR4/K5LavtvVQv7JekY9BPC8YxHwkAzaZfrO0hnTZ
AN0nV/uDzvN8jCLDiOzU6amFBO43wnRuqMdbQywbFfcjT8wbeYr7qmA5DzOj
1r/vrfL88qHe+PGHmGWeX74iv3xovnBwjD7L88vHmqbj5OXKp8lfgIOtSytJ
MjEKFP4C3J5KqKu54Uz+ArzbXhHXqKZ6rFCsj0Ko07NjVf1Pkb8Qtv+7HfkL
cXnsZ9X3/qSzImQdah6ZD7Unf5G4Xiqi+7OeaPMXUb9rNmYmkWFC9YA28fOL
jPwmsb5swpsXZm+q5oiZGfoz4Qcc3nGg/c3iPJJZnEc2o6H5yTcV/Y7kLxb7
RTGd56atH0nBcrE4DysRdZSI/UolivxK4GI/1PCocwvtbxHrwSLmISl02UI+
xv4Fe4LjTg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0F1IU2EYB/C33Joi6ObHtDadSk1rNdRVc9Pa43HqcZu2wjKswEZejRK0
KF26U5QS2cWoK4kIGQjTFlNqK00K7EOF5ceFd0XMhCzJuigb2Rd7XuKcFw6H
H//3+T/w5jpaDjVvJISY/37//vTIDz8YDTjzIKZV0/PHYvZECjWBELe24n+Y
i44Hp1T2Kf84tRS2l/T61Gs56DR4eTI5rb+POhMmkrrS8/XUSpCNObxvplXo
HIi6SJNaRJ0HF1/MRHT12eitwLT2eGa8WWg19FwbPPJkXYkuAMPXyUI7Q70D
7MM64+sRBXonhFPvSn9EtqC1cKl95XyugroQLKvywJXmzegi8Mumlj70Z6KL
YVtC+Kj2fQZaB6e9Dkn3GerdID6bpXGH5Og9EJzOEP9sot4Lbz8OnGu4nY7W
A7u8MJ50PQ1dApJsUf3EXCraAJ135sfk76iNMNluLjulpi6FNa+ka7E8BV0G
lxcdNxaHZOh9sEtW8KVvVoreD22DpabhfmoT3FcMBeesyWiARo2HDV9IjJkD
cL4Kjc8/QpNyvrlyWB2ZXe9MT8CcgYC/5Zb2WDzmDHgibS7muwTzCvhsiP5i
tJswrwAVW2uQ+8SYm/n3OTO/j1RCt8dpdKloXgkDowvyKSWdr4IOd/SZ00f7
q/j7SDV/H1ctyFl+H8fCwd4ijeiqCPMaaGgs9rfm/TbF8hqc/xYzseD7Epy3
gE3vDka0cThvhcS4ex3LNzdgbuX3EZug38bvI7X8fRz1Es7X4T08XJ0gPyDI
BSZ2vkFgzs7ve/o//wNX3gGU
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU2EYx/GThs50brM5Na3msLKxRmle0/Zz3m9zllKI/dFKKLQyNQIt
XGASReUlHRRIBSJpSUlqlpJGo6iMopKyP0JH08rS8pYmdmHPS+wcOBw+fM/7
vIdzjr/h0LY8B47jEv6e/67skGW337uVr4BNE5rSRU3VFxEzhzedNy/W9vmT
BXinVySG5jGL4Zzfqvu4hFmK6tsmK9ciJ3vjhdjg0RjL7IeXQpPX1LPVZDl+
XVJW/hQwK5DUf9XJsnMVOQDtZ4Y/dVxZSV6LJ7miivApP3Igxp8/7PDMZFZi
aOlpU3+bL1mFhnHVNen0CrIalc4aufs65o3IjhrcGzDoQ96EEatZPKVgDsJb
yQ+f/SXe5GD4XT4wktXjRd6M+vMHC5tPMoegwc3UIX0tI4disWh2jYvZkxyG
xrpiSReYw7HnfXd305iUHAFdsbis3swciVzDsEU1upy8BWlh5Z0WNXMUCgcm
H+z29yBHw9fbMlpdIyZvxZH1F2pr2pg10Bcon077MAO66+fi89qFNhuBHTlB
rUUKEfUYSMaksgmZO/UY9DyK/BZocaOuxYyw68RCCNmoxYZoddZ9K83jYnnz
YzEgPLVvTsd6HMyTou05h9n6OPt5XDyqKhzvfNi1jHo85lQ1x5oKXKgnIPjs
19mYXrIxAaXl8335zU7UE/HYHH205K6AeiKqLcVl2lln6kmw/f8O1JNwvOFV
t2zIkXoyHOTKedeWBY2tJ8PV8Ubp59rvNnMp9jam0Pv7TT2Vtz6VNz+NvifZ
yDOXbj/PmM7bX4fxiPlFrXqGuo7WsSOD93wZvK63N/Q0z0r389yr5+2fyVv/
338AuoATBA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzF1I03EUxvG1F7NmNXVuU1d7KaKcjKY157Tt2UvbGlFoSVR40Wp0scQQ
vGi78B9kV06aUd0krMISxUFJaknDikoKKXpB6EbQLInCIbRqwVax8yO2A4fD
hy8cja+92c/n8XjGv/vvspG13Ju8E9Aiq4R1LKO0jAmZedAJxL9PDWjIhWg8
oTl93MUsgeiA4U0mpSZLMR1tsPTdYFYgXtrq/WhnViKw0rbY/VxFVmPalRE+
2MysxU/Ba0fSuYm8BTMdK/z2gY3krSg8OX95QM68DYMOX1nYrSRXITA9EX97
v5JcDVV65qUpUUHWI/bqbJO5jnkH5KFl07nOcrIBn7Q3v/uvKcg1UEbbPh96
KCfXIuKW64OzMvJOzF9/1yKpYN6FRdGV5PjVMrIRvv3bB9NFzHXweHs+3D0i
JZvQe6Zz6NhB5nr0c++DG2KlZDPCo2t08bkScgP8/bf4oWgxuRElS1OPh5uZ
d6NSsbAU6ZOQLSj+KpUlZOvJVgzanjx9Vr6ODPDVVSnxcFHWHHDxvGBirnUt
dRuCXalHgaEC6jbcnpyVvVCKqNshFowEv1xaRd2e1x255hxo6jHohN1C6s68
7kT1qLDA2Lua+h5ciATMIRWZyzPPhX11XeMLegF1Fw4frYl1aDPWbHejNvzt
h23qV9acG8v1qbRdn6TuyTXnob9s9uaayzPPm9f/+w+LAcQX
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2EYwPGjTrO0ms5Ns9WmqYnK8JbpvOxxTp3XdklEa2GiRc2lqMt0
lYPM1DKyhDAiqC+ClmEiTYcxLU1XFikR9EVEEhRZE2vRDLuw5yV2Dozx43/O
87w7sKDyakWlK0VRir+ff9/k4hQNGwfVweCQVeShzJ9Y9CemYLHnre9LYxDa
E5Yefh5jqYmZMLhc8SWNTewHus7yqROTfHQAmPlF65s1xFxI7t4428Ym5oP4
XN91iYaHDoZWrk4V9mA/OgQYdVphJpM4DDpCWk551+5Dh4MrP8Lu1c9FR4DR
Wn/3gBtxFJjvr/Te0+5FC6DNcsYwPx+Ijoahy+6TlyKJY+D8NddyT8MedCwo
Db+iXeKJ4+AKm9/c0xaAjget/eDTGbM/+hCMcEs006HECWBRjT8/OcVBHwa1
YHNhboY4EYaPN5UVVxEnwYfH7zdCNGy0EOLnOhtCR/3QyaD72LiTKiNOAYvm
1fc4GwudCjONkpSKMOI0WGOVVNrafdEisHUM+Ku++aABvNyeNK3eQesBgtJP
t2u3mNjTwZs10VCzsht7Ovis+XGsnF3YxTD2WmgJX/LGLoZbLW6GBdUO7BnQ
1GwfV/d5YM+ArqU6nfjHNuwSiBpieCTcROslMDhQ3S045ok9E35G3b7YW7Ud
eyZtfhZtfxbwtmbfJFpJz4bZQOtqNxOtz6bNl8LXJPuWWEDOJwWetCCJ0+eO
PQfq+pNFzx5R2HNAfiMmknGVgT0X358L9lzoNX7imLnk+Tza/jwojeySvrvg
hT0f1NOGF/MjaH0+TE+mNtSPkvMVQGuXWqjjkfdTQDtfIW1/ITj+z67Yj9A6
8brI0WX4+20OgwyKS2MHaoN/O6yXOc8zyZznUXLnDnLneXriZYdNctp+Bc7B
CxTO9+tpNtFMKZ0NNOuVzvNNNFNHafv/+w9lT0K7
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tIU3EYx/FDOp1NLXOevJVO0sItyc0ttzR/02lzm6BdJGZECRGk4BJr
0gVOgXuTC8w30ahMQ7ustBezckViaaUgWbmEijBBMrooQmpRVuz5v3AH/hw+
fJ//wzmyyprtB5ZxHKf7d/6/2cPv8njvVKXAr+m8M5Ysc3kIM4fLUlvZzS4Z
WQyN9cqofQfzShiUg76SuWSyFNXO4cb755lj0eow/R4AcyKyY+zf1J4kcjJ+
udId82LmFETUtzcctq4lr8Pp1Iq97y6sIadh7NRZScfbRPIGPO3sHjmYzpyO
cPd6t7wmgayAJVQlGnofT87Aa1/Ji1oz8ya0aBuWTzjjyJmIS+4vnxAxKzFq
7rOOy2LJKsw6CncXKleTs6BL6xpzO3myGobUSMWHKGYNNPFhbTMtMeTNuHgv
p6L5tpScjT2VHycUn6LJWgx1e67X2ph1eFLa6xJ6VpG3wOab7dsvY85B0cOp
QxiJIuciPLrPbptaQd6KRa5scV8dcx6OeEtzsucjyUBngvvuSzN1AdiYm7Hz
0WQEdT2uPm87KqmjeUGPqC9Sfppn9/NxTf+4fyCO5oV8WOVNxuF6CfUCuHyS
hXY1WSjAguLciY7qMOoGqJxf5/S9ZMGAZ/259roeMfVCfNf+/JOfEUI9wFwR
yhoz5cENwdSLkGQs0fI3RNS3wdFUpTueFEo9wJwRHd43/GAizQvGpfu44qX7
hOKAbsLJS68e8ONB1E30Pwt5/m6m7/3ht2CGJOjWsc/NM9Qt1CepW2gvx/0F
dITftw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQNioVt3b8xWcoDwPti7Nj2PYmOF8RkcFH+1t85Z
pgjlczgIZKxZ/MoDxhdwyLUzumTxQAHKF3HQZu3wfd0I40s4vFfftFRFEsaX
cTj+R7rcqFgeyldwMJFesd7xiByUr+SgJX7Kbx0XjK/ioPPHmmODnSyUr+bA
JP/Z1KtBBsrXcDAPPb/25CFpKF/LIfZVzqP3QjC+jsOX/PO+UYVSUL6ew5m9
cY9YlkhC+QYOdbLiSz89lYDyDR0WTOXgOH5JHMo3cjg5dU3gaw0Y39jh9vEt
t64Xi0H5Jg6zTgntWrBOFMo3dbiwZm9n8zURKN/MYfGT1iTnNBjf3KH6aiUv
QwKMb+HALscScuSSMJRv6fAzsfhv41YY38ph+sMexnsfhaB8a4elVsYnls+F
8W0ctGXFJNMTYXxbh5KM5fv8xWB8OweXhoq/hu2CUL69wzN9JeM8TRjfwcHX
7djRJ7YCEH6Dg4Pfmj7X1K28UHlHh4s7rn658YMbKu/oEKU90eNcBZTP4ITK
b3By2Lguf4peNAdU3tlh4uPiaqfv7FB5Z4eq+l8Hs1exQeVdHJbvvi52SoYV
Ku/iENhjqM3SygKVd3XgZl5b9WoyI1Te1aF4tbX9pkUMUHk3qPxHewD0RK8b

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzF1I01EcxvF/GjTdFttaf9e01BmhNVZurWa19syXaWFdaEuYhiWEgouV
Ba4wmWQhdOMbBY3KvHBRuBoRsbkuIpQy7CJhiEIrEBsr2CxamDIr9jsXduBw
+PA9PPlNjpqzaRzH6f7efy87vPX5mK9VhZTiJvuP1qduGTOH0fDFtmgwnyyA
2+mxP2lmlqDWcOPxkIRZDluurvmrJ4+swJw1WVxdwZyDlvnZNH4ml5yHmw+s
H4p2M6swt+xoLDqzjbwdvU2RsDmwlbwDlxX3p0Vq5kL09WQ8inXlkHeitsbH
Vy9mk9VYFxtYWW1k1qDg6K2Q7aGSvAdO7etP7Q3MxXjW36npdW8ha9Ex4f2Y
+V1B1gHhznqphXkvcobOfTnxMousx8kRt7ZOxLwPP19c9ydmN5P341VBdyGn
YjYgcF79qzaNuQTd699OCm7LyQcgE2YFF4KbyAfRcE1nm4nIyIdw+sKp5cmI
lGxEw4bhO9kVzIcxphy8649JyCYcs0yMzxuZgZC4p2XpuDhlFyD9Jufj/Ebq
ZiTE/q4VvYi6Ge6QcGlEL6ReiiV1f4fHnkG9FFPKeHRQkkm9DD6vY1BTL6Be
tvY/V752z1UO266+qvdOtl+B3OTUO0Oc9lz/mbPgzbix/VKA7Vtw9d50kP+c
Tr0SdTatt021akr1SgjTR69EBxZT5qoQK/mdLNUkqDMvUD9COxz3B/4EzGo=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0V1Ik1Ecx/GH1F4cpZaurenULZ2JrKXNvZXPb043dVuUEdKom15QtKi2
vEiWjbzwahErCiqiRNoqXWm4ESFJUTezwC4kiFoQZGmyhEzmRW/sf4I9Bw6H
D1/+hwOn9NCJ1qMrOI4z/N3/TrbE+8aejHQpkNJ3vm5mcMS9jpkDL530O8Ol
5NXwR7+0Z+9izsVwf17BzUQJOR+LytlJdYBZAr0n86PHxFwIVQ+nij8tJpfA
wpvKzucwK3D2Xfxb+345eTNCnZd1OeEicjkiZwYABXMFFpePXNviLSRXQp4b
O6V9LyNXwTvRW/ZawqyGa8ZhK+rbRNZg6bD+1cU5KXkbAvMdFb0m5mpIZV0d
V49LyDVIaIzO0R8bydvxzB6qnDrArIWx/OHbIb+YXIuFaOteZR2zDqoPe253
ZzHrEZ8LdrfdKCAboDnYFxwP5ZON2L31luK0hNkk8A7IH3si/bEN5J2IRcbu
uk8y1yH1v+vJPKzjXzsxlUcGPPdN/OhAbso+4IFsKPrGnkPdjJD5+YuX0rXU
zUhWBbzBY2uo16fbV4/r06LkHa2IugXKlivTrlA2dQuqHmWurL2winoDipuc
BvG9LOoNcOjORT+pM6g3os1VHXYrfvOp3ghRxnDP7KWFlDkravzzS+aJJHUr
EoblX/Xqz9Rt6fbZBPNN6fYJzDXT/E/qzYL7W+idtHwCc3ZBF5hz/PcfBerT
cA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAmIQDQNioVt3b8xWcoDwPtgvmPyxkYMXxmdwmKG5JVpt
qyKUz+Ewy79s0vYAGF/AgfMEf2nzJwUoX8TB6uy0m0XTYXwJB60fD/MNnWF8
GYfAxT+uKe+Xh/IVHKSYpjxg44HxlRyqVSuUi3PloHwVh3s/WGtXnZOF8tUc
TsXwt1h8kYHyNRyeK+27tsAXxtdyUMlqCtVLkobydRz+RXela26QgvL1HB51
/LguwA/jGzio9l9x+1koCeUbOqwTPPXs5SIJKN/IoXOqO6v8BXEo39jh6MHF
Nw4kwfgmDhYOykwOn8SgfFOHLPM8voZQGN/MwUyKc/HHBaJQvrnD78IF9b4Z
ML6Fw9wdNtGT14lA+ZYOOh/61m3vF4byrRyea36qNAyA8a0d1rm/DyrngfFt
HAqufT6UqCgE5ds6KDqmd5b+E4Dy7RyWKXvdMjkE49s76Nrqhex/xgvlOziU
7g6wsfjBB+E3ODhkn9ix7/JObqi8o8OHzRf/1opyQuUdHdomZltVy7ND5Z0c
5D18LcVWsULlnRwg6YkJKu+Mym9wdjDuffvd8cBPe4i8i8N7y1//nPSeQfgN
LlB9DAwAU8Sg8A==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tMjXEYB/CzOrohXY9uR3U0opSKk1L6ntNVF+earQtzWeuPMhSKtN6S
bkuXyWz8QVIuszhhOKHUSmMkm0K2xjHkevBHrdEwz++P9323d+8++77P731+
7/u8vtt2anMsRCLRxr/nvys7JOnXuw15MvyXOaYj+1Rs8AJmEaocy9sLrviS
baBUvc/5qGJ2gOWZ/ariXz5kF4xGvOuquczshrrb40qDitkLBWXbX3Td8yb7
wO9h45e7UmYZSscnPudmLCL7YbK8KepSp5S8BFlHhs0WP7zI/lB4lodbpzAv
x2tx3fFHXZ7kQPQYjza2ODAHYUIWZzKqPMgrkWyWGCpz3MkhqDD1FJSr3Mih
aJjakrTj2UJyGL7bp/cvC2ZehcH6vqJ9PRLyasgvaDcllzDLYTvbYrtWzhyO
0qyYqGt6V/IatB8rdLwF5gj8ahP7vn/iQo7EmFX1mPQH81oYphsm3cAchW1D
MmMY50yORnz024PDM07kdWg9O+TaOMocg6zEHruZK8xAgFTinruVzAF37ldP
TJexXMG/n1PArm16c8KAI+VKFBou16oPkDklfBW5tXtnHSiP5ZuLxfx8p081
u1keh5+zxowKa5bHIV/ZdMe+1Z7yeGQGNCc9Lp5LeTyaKi1vTmyyozwBjzzM
H1scyFwCAq+KreQN1pQnYmggumiP0YbyRJivjvwudbWlPIl/P5eEqua8yBJv
Vr8eqeFlN0xBlpQLLErGue4xyQOvOZQLLErhr8el4EDZzL28i1aUpwryVEGe
BkPnzpagLNZ/mqC/DYL+NwjqVdDUhwSID4spV+FbxMysMojlar6h5tdzav77
6lUL9qfhPx8aNJsKS5RTrB8Nv99eDX8/Ii1/fWgF31v7dx4jv/qb5lG9FucV
/QOD7vOpXod5zn1FuyYXUL0OHYuTX67qY/OkwwpH/+8nRsi9Onx6tbQyuILN
nx5RoanV9ltofqHHm5Py1eNH2bzrkX0oLPP5B3KvHrrR2vqnUva/paPI9aSo
sYOMdKiDT8v2uLngD6ygWJg=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XtMjXEYB/A3JyVEuRxHt1MHLeR0ObqSvko5up6bSa5DMalWkgnztqlY
tApZY2eTNdbcYtFx6+iyksWwkvxhaYu10SHrhsLO8/vjvO/27t1n39/3fZ89
r8euTE3KFI7jtP/u/092iTfWPapNk8EsU/jAVavJQUdmDheH61xfGTzI06D9
NdjYtJXZAaOfCzKLOeZ54J8X3fGtdidLkJ1q15AUzewC/yfjItyVkt2hKNQf
zJ3JLIPkeIFIGu5GXgxHyfsJ0TZXsidUtoYqU7sL2QtOlzbmVu9gXobLnhlD
L4udyd7oSXJLrWxwIsuRrql84C5h9sX21Cv5NvxCsh8mKwy7P/VKyP4oGdmp
TO9cQFbA4LI5vW0J80qEet7pvnFWTA6A/tD1Hl8ZcyCalEN6j8fzyUGoLNHv
b8xlDoZDUdaej1XzyCHYe2FKjr2CORTJPz4ELvkzl7wKtm7WuuY3zKvRrDJe
4h/OIYdhf87ofatNzGtwsPb2aVWeIzkc/T4yRcZSZsBZ0velrNzBbB44srR1
LCWRzK3FijC5rqHfnnKBuQjcN5X6OHXMojwC0omOF8Gm6ZRH4nV958/u0RmU
R6LL/tS+sQTWXyfI16H0pKj+4zbWj0LL0GxtctZMyqMwbG/I/x1A5qIF/Wg8
aQ395tXH8vWW5/n1SGurf/rWQOc5JWpvZZ6Xb5lGuRJSZXyIuGYq5RswGDI+
ESG3oXwDjuvfPhb3iiiPQWFZWuhRqS3lMYgLOvGgT87yWMvzfCzyTow/S6uh
93Fx8L5nbRNYwvpxgjxekMfj2qN34nYXNl+C5bx8AjqcTAPnHdj+Ei33ySda
7pNTYcy7/Ni1A3ZmQyXYhwptLWGHcx6SjYKcU1vOB7Wgr8aimIqu5Ov0faNa
MJ/G8jw0UJ/xW25dYE19DTYl+9/Klk2Gm/sCc1pLQwvF2a8ja41jZvMCGwXm
dPR/h6mvwwzRzbyBc9+pr6M5Oe4vBeZVQQ==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H9MlHUcB/BHhLQBlyfc8UsNGGcgZfyIHx4/7n3AHT/U437B3RV/UI1k
syWTKwL/8BFZ6TI1IFwxskSthZKwuThI9qADdCT9cJiVNow2cGoqOJbJoFqf
zx/Pc9vt9tr7+X4/3+/3ns835pUd9io/QRBe+/f73y9/tGVnB3q2x+J/3Tcc
bZr2TarYAmrjJmfTBmPIK3GjJmlSu429CjOeTuvbK9ihaFhsa7MdjyaHo32u
YPFJO3sN4lQ5lzzzT5OjkfTTc5UZuexYrPeeaY3YtY4ch4+GTB+eubuWvB4x
3RW5LXp2PHRv9Cde7VpD3oCJ5ZfH1P7sZ+Hcd/5bb3YUeSNOqW+OPjEWSU5C
93f1Nn0GOxk5+uLk2MoIcgom7oorb0+Fk1MR4Lf0ja6J/QKqj4Xp3tWw05A5
vHvXJ/1h5HQEeNcm7u7TkjOgPmwRjCnsTOxtunD9iKQhb8Jj1TbDkImtR0df
9kst3aHkLCx0+sdMf8/OhkPIHO9Rs3Mw/rL7wdzPIeRc3GrbaTxtYBtwQp96
8fOO1WTg65qTno0aykXgyM0Dy357wLkRFXtTX7w2QxaNSDZ/7Cu5zHkefjQ0
+4fdUFOeh9qer/ZbG8hCPgYiWzt891ZRno/arixD7zGyUCC3WID6hNFHVaWc
mxAVPjXzQTPnJgSFnK+rufUU5Wa5RTPUd0K197UqygsRvDMl60pjMOWFeD3v
8DnVZ5wXYat5ZPiPHJ6/SF5PKJY/LxYr5i+B5dRBU9VZnr9EXk/YjHznQnqA
mcdvxhfGC8MjEZxvUaxvi2L+rbgavK/6kYVzhQUL/KI3/B3YFUS5Bdsv9g1e
8QVSXoof+iYeXvuLLJbi3Kj+z/gpel6wyutDYdGKJcG2VOml85WsmFvs9zSu
4POx4fb1Z5qebyTDJs9Fm2K8Dccvdb4V6OX92eX7gV2xXoUlO+aDfXsW0nj9
Dvl5wiE/P9Eh34/kUNR3yv9fOBXvk1P+PkpOvJnQ2tLcy/svw6bxgU9HJnn/
ZTC4HlZYorgfFLlUhsEK3dC6QO6fcvzenp72awsZ5ZhOmK1PtnI/lsv7TypH
d+E9e10Q97NLnsOFOyGeqvn93K8ueb9LLrz3/gnd6eU83o2e2cijDdVkuFGn
aRcOneT6bhSVHPil10P3i+RG4iHzeN4Y3zce7Fj2+J0vs+i+ggdTe1bH17yq
wT+bFJxK
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQNioVt3b8xWcoDwPtgbViY6xYvA+AwOOcXTn1dt
VITyORyWcbKbMQbA+AIO+Y/N6j58V4DyRRzufpnEuWY5jC/hkKb7qM7OHcaX
ccj+lPu09bg8lK/gwC8XsNROEMZXclDaf2f7zzw5KF/FYbahj9OOG7JQvprD
n+Zd02cbwvgaDmL3ts//2CUD5Ws5yMw7cLPnojSUr+PQaNr51VQLxtdzMDVa
zcC9RQrKN3A4HrDiUp0djG/osID1QNDxKkko38jhxFHb8pJdElC+sQP/geCl
TBIwvolDA//3ljhTcSjf1IG1RFa7focYlG/m8C724PbEYzC+ucP0ZQtXKMnB
+BYOX7e37vx2SxTKt3Q47PF5nuIeGN/KQd7D11JsFYxv7aB+L3BhKStMv42D
mRTn4o8LYPK2DmaTj2R4CsH4dg7X2dqvy34SgfLtHQ4qt2gwKMHkHRyYZsz/
7dEA5Tc4OOQz/m5bZQ2Td0TV3+Do0MJy8hTHdJh5Tg5Rn26bqf4Vhso7OcR1
uL20PQLlMzg7vMs98tX4G0ze2UGlnHGy2XuYvIvD4ietSc5pMPNdHGI4pBpm
WMLMd3Uwe/Ps7hp2mPtcHe5F9LX3fIfJuzk8ZZ32bft0mLybw8U15z+r5MLc
7+7grHP1PHMrTN7dYb/8bIm5nGIOAHI4ul0=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1Ecx/EHDbwUZl42ndPcsOla5K10XuZ+0zVv07QMfCGRq6lo2Qsz
wQweRQoRKRsUXUzF64uJWUioJHRRREKbZWIqmYrgJTDDUkKp6PwD98DDw4fv
c86Bc47EcPmU0YbjONWf9++XHsGZ7r6uAin+aU3tuG6J3O9C5jBiyXh5sVnC
bA8f7XJMaxzZGUJubPzxui+zG5yi6oqqaskeyC+ZOm0TRBajMK1gcrTxILMv
5m6X9+5s+DBLUTb4bj40g+yHV/KhJ8rn3swyvJWnuy1+EjMHwHxfWflVRT6M
1RLX8M52L+Yj2Fra/qWdFTEfhV1Oz/DkVXIQHjWJMocHPZmDseHy88IbGTkE
ddfFOS0mD+ZQ6B46fGtTkI8hcmWe77wrZD4OWdmE5XU8OQwt01/ej28KmMMR
IqzPzrpBVkL61P7BQAo5Ahbz6He/S+7MkRBPZcK51o05ClvZRdvl3a7M0TAZ
10xZbS7MKgT3evnPFZNjrLoaH4w/HAJ6DjAD0SH6m07nmHmgqKuzKq2UugaO
TZtndQPUNdhr21G6bKIei8VAaWihnHosJJrcquIdZ9bjsDLtXxlYwczHIWKk
r2FwlrrWarwWFQuGmgUzzX/Can0rczqMqe/sEc5Q11n1+N3z8fG7/+cSYKxr
tbnWQD0BuhdL+bBQT8SVvLb+kwK2f3wiFN4Cz9xs2s8kVNe0HOqwZefBJ6Hm
mYOi/zP1ZDQ2D7nf+kjjk9G1LqovzaPz06Mg0y79/D0ar0fC8kS/UzWddwoM
qfL2nX3sPvApCFtdnDHb0f1I/X9ffgOJMvY4
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIU2Ecx/GTmoaby9KtecttSYqapMvL1vT8tmkedZt2EUsMyrCyBaJW
hkIuLXuRRCIZGISVMTGMoiIvJUla2otCBKXoAq1XEmlQtlS0Yv8n8DxwOHz4
Ps+fc1GXVuwq8+I4zvj3+ndnS1H4aOC+XQOPZvkrlY3CRBAzB/+Yhu6OJ2ry
Gnzt62jfcpA5EAsVx5alEuZgWN8MKw89VJGVMM29//xxL3M4QtvKl26OR5JV
0DZdrz4lZdag6vjYZEbhRnIUrjqnsg3tEeTN0Hy45br3M5wcgxl3qXosgjkW
KeXD7651hpHjcTRjz6BqFXMCmvx4lSw6lLwV5pnc6IbGEHIiRkfSa070K8lJ
WPts920vJbMWzfqlw+aaDeRtqK2fH7J3K8jJiKocf/tbzpyCBdkRfihLTk6F
MD01KLsYTE5D6aimX+sIIuvQWjbbWuJcT9bD3el35ouReTsMSZYLsgPryAbw
RT9KbGHM6djX3nNDHh9IzsDJgQJDmltG5vH0pf5bjEtKBuyjvYMTfRKPHYCX
KnZecod1Iy6f8+79tN+fuhHFcS3C69O0nzOhy/h85EVIAHUT5gL6zi4ms/Pm
lfMcZmzKbZss7qJ5XCZaXNV1pl9+1DOxszkxzue8D/UsOAemFK/CV1PPgiW1
/rErwZv6DkQKVp2im3WRuWzEP/DxTbnE5meLukD/z5e6IOo5K5/HkYMZ3fyS
KYH2c7mi+SJzeSv3O/JE8y1oarHr6yLZeYvo/awoKk66W6VZ5j3dSt9z0WPO
RvPnqNsg8e6pnW79Tj1f1PNpLlsF//0HgGzwPQ==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tIk1Ecx/EHFVI31GhTm5ZzdlljjHJpbTP32+bcTSqE5rrDSAgUhNmF
SurB1iBIWin0IhCcUIE2nG0glZAmLKEoSPaigiRXgWAuCGOy7ML+J9gOHB4+
fM9zLtXurtb2HI7jNH/nvy8bpYciT0IdMqSV0C/VOFtmxMwcprcahU8j1eR8
WFXOsZiLuQQBvXlHf0pKFqHUqdN5AszlCJvK1jT1zJU4MzXji72uIkuh9g12
nxMyy1B84mDjlQObyVsQieedlNzZRN6Ggg/hmwF/JVkOsefR4NuJCrIC4w+i
7l4lsxIOXY9N5JaQVSiXhLZfnd9I3omoYazw03Q5eRdG51wX3ruYa5FYab88
P1RGVuPU5+7wdR3zbrxcGP4FRSm5DrNz3mtnZ8XkekzVeOWcjHkPUsN51V/f
iMh7YbXfeDd+mFkD9wvZYzW/gaxF0LLcel7IrENv3N0XH11PboC+7cex/RXM
+zDSIDstf15MbkSn0T9ZNFRE1mMyqv0mXxCSgRypYlUwQuaBV5LE4kBJIXUD
/N7ciY/HybwBSeXtnvudBdSNCAW7BlRH86kbcTcmSN6rE1A3wXerQ3upah11
E9qO1AY9st/6dG+Cum/pp+FZMm2+ie6Tom7OXM+bsaxZXTOqVqg3Q5D78OJi
/3fqzdS/ULdkmrfQvdiwZnVr5n6cLWt/W9b59kzz9sz3cI6s9zmy/m/5f/4f
Ppnr9A==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2Ecx/Gzec9LXtZJ09StjBAZpXmbzv2cppubi4QQ0mAIETjQ2JQ1
RZwhBYGWlxeGYiSEpLlYean0hUFClL5JxBeZYS5okaURzYasC/s/vTgHDocP
X56HP89zpHWNVRfFHMep/r7/vuzhz03NOk0y+LWt2rHcXGqQMHNw35uovTsj
JYfCUndkTmFkjkaIyWH4KGKWoPbh5c7SwVRyPJz1eTZPBXMS3DvDbbqtFHIq
emPXAkcymGVQ6N7F9VuTyUfBRyzeWf16mHwMFtsN47KN+ThE883rl9aSyOmY
nmwYUCYwZ+BKusQydTaRLMf3hPmgZuch8gl02Las0kTmk+i+vdJq1SSQM7FY
5CqrWoonZ2GlZiPf7TtIPoXIH0Nu3RBzNpJfrO++qWTOQUu797lpjCfnwmf2
pIUtHCDnoaDePGCclJDzoZYb+83GOLICHwZzst/2xZILUN+0Oy2qZi7EVVdd
l+tBDFmJwkz99SgjcxES4zc/9fRGk1XQ3neMpQ3tJwMxXyT8Nh/ltx34Gfm0
Yy87gnoxsrq2PMXzYdSL4XQ09strQqmrca3HpGhNCaGuRtvw8hy/EUC9BPrc
9plNOdleAst4gerRCEe9FNXnMx1m2W+Vv5cK+mlBF5grg///FdP+AnPlgl4u
WK8R7K9BeMBEy+c+Ea3XYnR2lX+VFETrtXSfwdQr8HJBaW16Rudhr0DG48Dg
nG46D06HFN/S67ztfdR1uNUZ8OT9BTKnx7d8r08tp/3sesH8lRCnpnvDx/do
vkq6j180v4Hm3aFuoHXsOfPffwA6sPdU
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtIU1EcwPHbtFTUUtOpZT6mDrM1fLuptZ/v16Z7KMuZkFH/NEycSKmo
t6KiTGsVlEFSUa4cG5mYiY+WsB7+EYlEJBGJBhFEysTH0qzY7wQ7g8v48N25
93fOhUUcrlUe5TAMo/x7/fsmH275wHCflgcOzUuOy8oLjX7EDISqW2VXRiPQ
7nCz60u3pobYBwzVXhUjvsT+8Hl0kGd6Go4OArlu3aCrIA6BuwM6vxEf4nCY
a0qwNTeGoXlgfXhVr34Xio6CWybD6OMoYj5on694ZbO70DGQbAzcW9EXgo6F
uK/ePezUTrQAojfa9avBxELgeJwRXYjZgY6DO11i/vmDweh4OMn63jgxGYRO
gPfF45qZCOJEeHTsdpBgIBCdBDb7S+unaS46GdgGyWIanzgFYitF1rHSAHQq
nH6lrrJL/dEieFt9YMH2cTtaDIL5TvPgZeI0eNOYk3GET5wO7R0Pok0uxBmw
dNEcWLXoi94HK/fdWucy/dD74VBd1a+Jb6RLwNPF1PT9GjHA7pJI/9waNAvQ
E1k0nTTugz0TGoblGaKVrdgzYcl76NRashf2LNC+fjY2NeSJnTKTDVbbNpWm
Dn/PZgMnPNbuaSTrc2C+f3K9JcADew7oZ+ubs5bdsOdCS/fUCHfGBXsu9Jlr
rwsr3bHngeJS/B7Xs67Y8+CcXpvWHEbW54Og33VLSieazad6ATS12V9oe7dg
L4CwApmY27sZeyEYhj9wJ0LQbKHzPEwRNR9lppiar9j5fowU38cm7FKoN6ZL
ntxjsMvwvNYkjk6ZKYGfYvvvLOESdspMKd5/AXsp1eWg1iSYdbwNh0FOPU/u
PI9FDo7/Cw7OpwBpatvgrBD3CwrqPBTO52mhOqOk1iup/SghsePHcqZl1WGL
ktq/ippfRc1P2aKi9l/mfD5Q9r//AbOIUyo=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1EYwPGjtvCWzanT1jS3VERqlNfMbM+8b173bkMnfRBJ+iBYpBCu
i1NIWikFqZRUgqDlXKOMEvWDK4ioCDNEgz50kzAznRarlpeKPYd4zwtj/Pif
c/a8h8mqj3I13oSQ8r+ff9/0ERvuj92tlYNHTqXPgMVaspWagM2xqeXcqAzt
Cx3S8UWLkVoIbTLR+zO+1KHQ29o9XtcfjY4At1dPn6SUWgq7J88eahRQR4N8
8V1MlGoHWg4Xlt2/r5ii0DFwqXrurWo0Eh0HAVFBrURAHQ+pBrvvBCdFJ8DK
z7qLT+9sR++CoSPiOKs/tQJMmvB1SYMEvQeudptSvt/Yht4LD2a+JYueRKAT
wTZV0fimgjoJvhwealmxhaOT4XVnVaXtpRidAs2fZeMf1NSp8Nw9d761Lwyd
BiX1wpNdj0PR+6Azds1IekLQ6TB8rN+oCKPeD7ppS9urSOoMsOcvcScCqQ9A
bubsqQm3CJ0JCyHGGpeF+iC0zFa3z9qC0UqYqnH5xY9QA4jmHI8GObQZYEzS
cX1kSYhdBRtEu1HVsBW7CtQDdmvsNTTJgmz9aqogLwh7FgQvhIqdYjTJBu/o
BHfAYCD2bHBtGWleTUGTHNip6ZquvOWPPQec9ybXTof5Yc+FFxLnfIeQ9lww
Nbkf1lo3Y8+Dm2Mz4mdSAfY88PyfvbHnQ4DPbdP8ZS/s+Uwv4NtcwF9P1FA/
mKEc6iXY1VCU1jT8UeGDXQNL6e71LAXOY9Yw5xfi+68qPb0Qktq//lA5fnlM
inAdPuYiPO8T9mKmFzO9hOmMSSnTS5n9ZXwDtQvnLePP72BMtFBemWg/Lt/A
/Vr++5m1zH5mPeH49w0cv5s5Zj/TiY4/LzA26/jzOHTMfj2/g575fT3/PIce
513G/Qbm/gzMff/3H6xeXkk=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n9MjHEcB/BnHSudq+s60Q/9uFxSR1x10g+9r3R1dzl3VzENw4YSa9GP
qc0e1VRrR1tafpVZCSnE8usqMmZmSKzR0MjyI1P4p8LC+nz/uJ7t2bPX3t/n
8/08z+frtzXbvM2O4zj9v/v/k11uae3WtiwZpjQaK0m5bHktZOaw5WBJ6blm
P7IDlIqR2ltqZjEkVl3RxHdfshQpdQV5fBXzPDx6q72RHMXshbIslbj4hQ/Z
F3VSrwfbA5llEDpw22+mepMXIGthf/5g53xyAAR/hvT5AcyBeD8Y4Se74kUO
whejvLcngFkBn60HftXEeJKX4HnPeH1UrQd5KdT2lW/EV93Jy5BprcpsfzWP
rMTR7npB2VrmUFTUJM706ZlLDkP6U1HmsXdu5HCozps36oqYVajPO9e/VMa8
HNmWfe6u1XPIEVBV38vQSphXIKzXUiC/JSVHYvFHT95xBnMUJMK5HUMdruRo
WK7OCu4akJBjMDVP5pVwbBjbpLnvQo6F1eNI3c0RMRlo8tf1h90l88D6462n
5yhYrsYlz5brvXpnytVofNiQL8x1ojwOfaLyjHGDiPI42PkGTQgvzKY8Hp0P
Ir8FDpL5eBhaDiVsa6f13Cq4fJW6jbpRPX6VbT0uAevSlRf3yNj+CZjkTJOb
c8mcBotjlqTeHmL7a5BnNUZHjLH+Em334xNt13NJtvX4JMSn/lbN1LD3tdP6
007rT4eqUsGNgY2OlOtwok843hQupFyP+z+dU9Jz2Pfrbetxybg2WhXi8ZjV
T7b939xqaM9fbJafZP2txvDrhaUhxWw+Boh2SYbLc9j8DFhk8Jcm7GbzXoO9
bZcqjIVkfg2ilcllTptZbkTXBnm3t5DOC4w4dvtsQZqCzBttz8+daTlngqbz
8048oxwmjDXa7/+gZu+bsKEkNP3lJ/IdEyotZ+StAnZ+zWj74XGqMIMMM3bU
2OWKQum882YEH9Y8iXskxV9Xyx2g
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0X8s1HEcx/Ev2vw4xx3n/Lrkbikh04kQeflx3PlxhhnzY6HULZo0wtrq
O2ulLSG2xtQKkZhJWcqw0oW2amosM93a2LJqc6PNj5ZqvT9/6Lt99t1jz8/n
s30+H3l+cUqBKcdx4X/G3z/7pGkDQw8LFfin5fB6paMxWMTMYblx1uX2kJxs
AXnyvPpoFrMIZq2VSRU/3ckSFBs1NjfamJ2w93zEjjQNsww/0oX6jrldZHc0
WPauiU2YFVCe6F9tTXEj74auqdFc2b6TvAd+xp5Tl9/JyJ7oG3+s5r+7kr0w
Y3HhWJKM2Qdd+vm8sAwXsi8qTtcGlaU6k/3gbNsYcieY+QDMZccXw2qdyEoI
V1uW4lscyf5wcAzwflPFfBCFvpuG95NScgCGFvtlhg7mQFTWSaY1JsyHMO1Z
lNfxxIEchMCGlzqNHXMwZHMZENVLyCHIn1A88+ftyYdx8/M1k09GO3IoRrI9
nrsJmMOQbd7a7KoSk49AHnHyatkvETkclfvG1wuSmAFhkd3X6hIyD3SHKnSe
Y7bUI7DFJW/llpL5/8xFon2y7Zyg1IZ6JNIzlb1nFaxHoSiybtjmLutREH+T
SJelZC4a+hXb1MwSa+rRqLtkNmjIsaKu2m5etX0+F4PCicGRD08F1GNg6u61
IehmPRb3I8b0r5yF1GMxI6zWrWvJnHr7fF69fT9Og6nB6dWPa2x/DbQ911UF
A2x9HDRdvQ88Wtj9xMHa/kX5mSV2/njsF3sam6fY/cajaiG/ZqGHvU8Cckty
Nl9/IfMJaBrtLE/zYe+ZiHsh/hOdt8h8IobHrxjWLrKuRVbsqNVGH+ta1Dyy
9B4xsJ6Et3kZxpVZe/wGAyb2Pw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQNioVt3b8xWcoDwPtgnFkszPmOD8RkcBEN2z1Rf
pwjlczj4hf/54REN4ws4iE/jeFz/VQHKF3HwNZ1+8O0yGF/CoWjD6Uxnbxhf
xqGoPvnmpoPyUL6CA5/+vF0F3+SgfCUHrQUdy6r0YHwVB8MdN2p0J8hC+WoO
9VWz7ud8k4HyNRwWHr4roW0D42s5CJsmZGxeKQ3l6zi8/+r35ZsCjK/nEDzV
dfq6Wiko38DBYc6rW+t2SkL5hg6/V7260F4D4xs59IRyeVxaLwHlGzs8vhNU
2MgG45s4yHVkrfwiKg7lmzrsPB25LTxSDMo3c2huOXxn+gFRKN/cwezNs7tr
2GF8C4dfP5wXleuIQPmWDtkR7IHJ04WhfCuH4GudPZdkYXxrh4VLToj2XxOC
8m0cfixhr3viCOPbOry+o96i3yQA5ds5WJ7bveDYAxjf3iHHacJevoV8UL6D
wwrHw0ePSfJC+A0ODspe065FreCCyjs6/NSZVLM8hxMq7+jwYfPFv7WiUD6D
k8PGdflT9KI5oPJODvIevpZiq1ih8s4O4VFG64qU/ttD5J0dildb229axACV
d3HwMa/f/liPGarfxYFJQesX9+o/EPUMrg7czGurXk3+CNXv6vDe8tc/J71v
UHk3VH6DG5p+d6g9UNCAxmfwQJNH8AGbwr9C
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tMjWEcB/DXqRwcpZRTnOhCpFrpcrrp8u3k1Omq07k0ZyGmNJlLcpmM
I7dZWKf6R7JchqQYW7opJ4Th5B5jxjoZM5cmE2mF9Xv+OO+7vXv32fd5fs/z
7vk9HivXZ+YKOI5b9u/9/2WPWNPYdrnAE2Pqj9W9860Mc2Tm8O2p0NHY6kGe
gI7CRJubOmZ7VL5c32Bjz+wEn00PF9W3uJNdkF+K24JVzK4YftYUdd+a2R3B
VRuK2krdyJ7ovGXW3+uZRZ6DI2c+iKodmeciL9sQEZM/k+yNK/mF7aMmV7IP
Hn3o0NUuYPZDkpCrGYSE7I8HMaiVHptBXoAAbcjs7z+mkwOxZrik8dZu5iDU
7kxbp5AwB+O9oGlLea8zOQTTnKW+phJmKSafD1NeqxGTQ7E8NHr8G9M0chj+
2K2O7ZQzh+NRffvBPT1O5Aic7tu3Mj6PORIqLrz7sgPzQgQmVLUkm6aSoxDY
KpnXu5k5GrnHzwqKTziQYxAVlHrALoc5FhIX80dDuT0ZGBhpXVIiJOuBePVw
qE2CHeVxGOWUozlFUyiPw1pZWbvdSZbLUBt3s+v2dFvKZfhp27J7WDqZ8ni4
jZjuh/dPojweZXutmt8uJXOLEHz4y2CccSLlPHNypIbtajL7W1Eux1i/CihP
wLeIoRGZ/3jKE7B911BnQR2ZS4TBvKlYNiikPBHn2l6I77naUK6wHK9X8Oon
QXko0Nd6nzXlSbz5yRBZNWz/VDGO8mTa/+/YsTyFl6fw6qfCTZEWIa6jevpU
Xv007DcURBa7sf2n4W5X9Nai1gmUp/PydN7/L+b9/2I8bn7+4+UvEeUZlueD
DOh8DYrubZTrM5Bef0Se20jna8xA+53Ir95mdr5Ky/FQomtgikq3kXK9Eg6f
ncT9YuoXoxK2hUELn5ZQPS7Tst+QiUuS+qYnKazfMiFw9xkSXaB6Rp45leV+
oLKsr1fx1lfhan9ZwAwT6181b301snRBFws92fpqy/thVGPz/MqK8ivs/miQ
dP5inVc1jYeGN1+Ds7OTX4XcYPM1yBaeqpLI2X3UoiPbq3OWiO4vtDh6/dxW
jR9Zr8WGnoEbKzzIRi31D7vvWeg9Fip9XcHmZ0Ee3bfj4dBU/AVlOXg8
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQNioVt3b8xWcoDwPtjb9c6b4ykA4zM4sG5etFpw
kyKUz+GwflH6QnsfGF/AwTzb71H5DwUoX8ThVzlzsv98GF/CIcm546KZCYwv
4/D2j8mS6WfkoXwFhyOxjKa/1GF8JaD5gfb7Z8lB+SoOUzeysL19IAvlqznI
bIy6w2AH42s4nL1hVeQ9TQbK13LIdRMU3nJSGsrXcfBkZ5j/3QHG13PY8uPv
R9nFUlC+gQP73e6Nm99JQvmGDm/Pf8yxNYDxjRyUfUvDGmIloHxjB1G/NPNn
28WhfBOHeTzTt4lcEYPyTR2mNtguFnSC8c0cVgu+k1DbLArlmzss331d7JQM
jG/h0MJy8hTHdBEo39Jhll/jr8dcML6Vg495/fbHesJQvrVDd+9S1bXMML6N
g6HbrJ1eZ4WgfFuHfTGqB+W4YXw7B6EXBw6tDhKE8u0d7MO/xPhJw/gODpbn
di849kAAwm9wcFgvvWb7JW9+qLyjg9+aPtfUrbxQeUcHJgWtX9yreaDyTg7K
XtOuRa3ggso7ObRNzLaqlmeHyjs7BPYYarO0skDlnR2KV1vbb1rEAJV3cTDu
ffvd8cBPe4i8iwM389qqV5M/QvgMrlB1DAwAax+f2A==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQNioVt3b8xWcoDwPtgrv9fq0+aB8Rkcov9OXti7
WhHK53BwEFb++dodxhdwuPrkYW7NcwUoX8TB5+zjexbtML6Eg5nIQc0SbRhf
xkHZwnLq+VXyUL6Cg4zGj6fiL+SgfCWH836FAfHOML6Kw21/+5uz5slC+WoO
MikqR798kYHyNRzaQ5UkpMNhfC2HeQ7HI8NuSkP5Og4hHYfOlNjA+HoOwVNd
p6+rlYLyDRymHzm7NGS3JJRv6LBgpqVaewyMb+TAfUDBXr9aAso3dghn+3In
zBTGN3GYKzd132w7cSjf1IFnpXngnvliUL6Zw1nnCMmnP0ShfHMHrWiLo/v8
YXwLB7PJRzI8hWB8S4fFT1qTnNNEoHwrh6mqfyMZ5gtD+dYOe4+33/9RLwTl
2zjYh3+J8ZMWhPJtHXhzhF53FApA+XYOq22UMjQO80P59g6eK9etUp0D4zs4
+K3pc03dygvhNzg4XNxx9cuNH9xQeUcH+X9nT1t84ILKO6LJOzlEaU/0OFcB
5Tc4ORz9zB8cVcgDlXdG0+/ssHFd/hS9aA6ovItDVf2vg9mr2KDyLg7vLX/9
c9KD8hlcHWrnXd4j9pAZKu/qEB5ltK5I6b89RN4Nqv4bhN/g5mDc+/a744Gf
UHl3VPUN7qjqGTyg9jAwAAAEBMQY
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tIU2EYx/FTZmlqLrWT1zLzks40zUtquZ+a29Rt6rYyb90okqwkNSgj
OhmBQUZSgVgSRCRo2c3SacgUNDXsojWjK2qQWKGoFM3Uip73j21wOHz4nvfl
cN5nq3YXqPfO5zhO8/f6d2c/fsvDlnv5XvivccneCUXbCXtmDpPupcFK3Sqy
FSoSnMdcMplFyDvjEd484Ul2giHgQ4+xktkZ+w1v6p5Kmd3hd2awSju4kuyJ
tfwN/iPP7IWGfu2caPsKsjeqM+7Kuhs8yL5YEOx42valO3kNtra/+jrgwByA
u7FN0U05buRAyHIknmVXXclBGC097etY70Jeh3nRYt1za+YQdBZXHC2QO5ND
MVFpM3tubDl5PcYkh5IGLZnD0H/gva5rD08Ox7fzz+5L+paRI3DW+KLWZYY5
EgHZGzpaU5k3oPRJRq5R4USOQskx8ReDD3M0LvvMZHLXHMkxZt6IEGmVLrnX
gbwJw49nBHEkcyx2Hs6d7hlZSpbAX7XaKfEgM3BzdfLbsHbRfwtAt8F7atqW
9TgU1cVI7l9nPQ5zXPrczmJ76vG443arsS+FLMRj6TcnfpxfQj0BHZP2mqzD
ttQTMN8zwGhTR+Y2w64wNKa/1I76ZtPnuUQ8Gr8Q7NpL+wmJ+GGnO/U7nHUp
8ruaWvt1NtSlqBguOh7/cxF1GUpOGtvyaxdSl+FefcGloGwr6nLUtAzwPe6W
1OVQRJ5sHA6yoJ5kasHMXDLGooyz8UFs/2SslCuj+Fraj0sxtZBi9n4Ks64w
60oEPliwMOI8WVBiffn3n3F6a+oq9LqOj14SLaaugsGuLO+Xir4nl2p6HkIq
MrJC6wu92PmlmZ4n0qCUdnZ83sTO28z6NNN54NIhyZjKUbnRvMDMQjpsLG6X
jF4k69PhMKJvr1Oz+VKjOK+mNZWneYUaYg/eZd8usqBG+QNrcesnsl5tNu8a
ZO5ol2dto/8DNKgWXpfY15MFDYauRIS/u8jWaxDS7OY3dISt15p2aPHFf+JY
SBpbr0XO7qHhwBFH/AHYjkk9
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQNioVt3b8xWcoDwPtiXnf94/ZEwjM/gYGrFujtq
nyKUz+GwdMWbrTo5ML6AQ++rPxud5GB8EQfLjYfZWY8qQPkSDqkci0xKKmF8
GYdzsbuvNyjD+AoOxjc+v/mwSB7KV3LI0debIvVVDspXcTBw8Hs/sQzGV3Pg
U1/Y8OykLJSv4fA5YclcMx4YX8vhR8nLaWbKMlC+jsPDE6Ie76ukoXw9h0dn
uZMbvktB+QYOPaIGKgV6ML6hw53gMrG7MyWhfCOHO3varX4+l4DyjR06p7qz
yl8Qh/JNHA719AsuVoLxTR1Wzn+2QTtWDMo3czjrHCH59IcolG/ukN9bKSk8
Gca3cBBaezXzQ50IlG/pINBemHJ/EYxv5VB9tZKXIQHGt3Z4kqVp9bddGMq3
cXC1fVJz/pcQlG/r8ExfyThPUxDKt3MQenHg0OogGN/eoXi1tf2mRQJQvoMD
b47Q645CKL/BAU3e0WG31JS5O9/D5B0dLM/tXnDsAUzeyeHzv12RTewweScH
X7djR5/YwuSdHfzW9LmmbuWFyjs7nJX68GqKABdU3sXhveWvf056bFB5F4fA
HkNtllYWqLyrAyR9MkHlXdHk3RyYFLR+ca/+Yw+Rd4O6nwEq7+7Azby26tVk
Rqh+d1T1DB4Oxr1vvzse+AnV7wHVx8AAAOUZwrA=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIU2EYwPFjLpsuazYzb+WcGmtOSc15d8+8bXNuc+GSzCwMI7SQtA9l
gpO0jFQyk0CLIvKClyAvMYl0WbOblywSCSVMLDCsSabuoHZhz/vBHTgcfvzf
5z3v4Xhn5x/M2URRlOzf/f9JLhdtz5NHeTywyCQuze6iupnEFPDlV3TV97zR
TACOj/m7lJgNx4q17PVpLtoZin3vhE1eIHaFztjx93I+sSeIhHVdJxq80Fzg
TFQulej3oHkQUzDdcSiE2BcEoL7d1rQbvRdKuhn1QR7EfPgyaux/kOuJFgCX
7hmamvVACyHa0Hj85HbiQFjMH1VmnHVH74ch0TcH7ZQbOggutQ9wtFnEwRDr
4tdOv3BFh8CINIv125P4AMxftm8tr9iFDoUBRYtgLJNYBL/oQePkJxd0GPA6
mfVGJXE4XKXftbqt7URHgOBIuLFPTRwJZYzXb5i3nNFRUOe3dpi6y0FHw7Wq
Rr8OW+IYqM0x1WY270DHQu65lcc26cRiWFHMMktTiAH2qXycE884WawDCHDi
L9SPsbFLoLAtStx5H62TQHzaqmhz0jbscTDuWHHKrHLEbmUqHlokz42DbqTH
Q0BMYFr/V9ITrOYTYMmxt3Q1dCv2RLheZqv/fNQBeyKM6T8uTqywsCeB1/rw
23AT6UnQMM4yN4WSLoUM/xrZyHm0TgohVfPLEoM9dtnG9ToZ5L3S933oJfNy
GHY3zd1kk/3lVudLhqcvI3/wZ9C65I3npRRW8wowC28UN58m70+x6ilQVEI/
y2u1w64EYRfDTlS9BbsSamYKL8YtoykVaCqD/BnlDOwqYNl2FM3V2mBXwyau
gGa1rYotXY3fb7aYSt1oSIWfEfR6XOASrk/F/09Z9jNYrac0kJ4R/LCA9wfn
NVbzGjzPgsUGDZ6Lov4CONcpBg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtIU2EYwPGTrtRNa9Yu6qbOOcumzdzsomZ73JyX6XRbRGpoFkiBmqCW
oJbDMgktL2lfJIMMFUPDINEZaalRmflBnKGBplkhiYsu1gq7sOcNtgOHw4//
eV4eOHD8TuTrsx0oitL8vf89ycU5fH+gJ0cIVpnlIlr/mMidmAJ56s2zl7r9
0M4wyRPOX1USM0H8i36+a0WAZkHKy3n9k2ZiD8gquv1BkkDMh5EQebNlxBct
gA7ZsWkjl1gIr6YY6R6VPmgRsLQZw9wFb/R2qC2vXUqSEgeCKeNFoDiPjxZD
8UOZcmKQhw6GvguGFu9lL7QEVKOnSxsCiHcDgz1VNNjoiQ6FDRFB/RMuxFI4
dYsbUMX2QMugxrg6k1nNRYfBwNI9/lwbB70HOmaHm26Y2Oi9IFhkN7WmEe8D
/mwqMOtZ6P2w6z3PQKcRh4NPf2Fv1dg2dASoot6WTVi2oiMh1MjbsXCG+AAE
eXM8Tx4njgJ66/fM2FF39EHYmezPUuURy+GZSfTlpysxQGHP3cvaErQBoM1f
PRP2mIk9Gqql2a+bs9CGaPi8bkyrcCJdAb3muhCv8c3YFaDNFY999SRdCUfS
pd0Fwi3YleD+kcUxc/B9KgbcCqSRkxVu2GPAQSC2MO64YleB7MrKWvSQC3YV
1F107JvLoGOPhfrFwlLFmhP2WBj3Mi83MkmPgx/BDWXtuWQ+DvzV103pHaTH
Q093fqPkqDP2eGgfmOY852/EngDnWiYfcN44Yk+A1XDLukKyCbvarqvteiI8
HY0qLjKS8xNt96WSQFcTGkSrpGG3M6WBknLLo5xOPM+gsdsvGXzjNeGcTrQh
2XYfKsVuvxTb9ymtrUFru7/Brg9p7fbTgfX/4YDzOvzev+XWeR2e983qIR3O
kUtva9ADw7GrZPnaJ5zX4/w7nLczdej//B/e1iYk
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIk1Ecx/FHzUtooqbTqfMyTbyskVpOl2u/TaczdysNw8gokiILoQuB
F1wgi5QGWuAbSSJoZTZbKuVdX0QXSAiDgiKIiYioeUObaDf2P4TPgYeHD99z
nnMOT/yZ6qOVnhzHFf59/r3ZEBzrG3RUieHWonJgqL/NFsTMYahiOCmpK57s
h6WJU58zS5iD4DLt8YxeiCOHwlcZ1jRpYY5Ac5G9PCGNORqPzwpHPRpjyXGY
y03+tvIxhixGu6X9hjSdORH9JVO9kY0ichImdCLFSn80ORnPZcGiLz7Mqaiu
M1Zq9FFkCcrGZ1QBtkiyFM9cIVbxvJC8D1G35N1fE5nT8a6ie3lEFkHOgGm1
9+3L/HByJobnSgzGBwLyfrQ9vP9IHMN8AJb3bcLjkjByFrSzn0YCm0PJMkxd
SJFv3dxNzoZjObKj5jxzDtJEAuG50yFkOdaa7OEnV4PJB5FiSAjVXGLO5VmB
qAjnTEtrEPkQ9iqkpaPTu8hKXBs05Wb/DCQDeaWbWd4FZDNg6LJqKvvYfBWG
X8sXkp0B1FXwjEvd8H9C5tR480px/eqAH3U1fuRs/FJLfajnwdJSJa+N9aWe
B0nPDp8sK5nLh8NefVd6gq3Px2LPh636sJ3UNXBJWutsF8lmDTJvz6+rxlgv
4K0vQIvzSq16nX2/EDUNG+NVnXQecyFitfocQac3dS3q700OCb57UdfC3+tp
zewdD+pFtJ9L6e5F1Jfc5g7Tfdeo88wVk6epF/PW67bbrOOt1/O6ntcNvPMZ
UFaeYb8s/k3duP0+ZiN0soYXTindlzPR/9x0z4eJt5+J5tEY43XuyPYOns3/
/QeKLRRa
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwA2IQDQNioVt3b8xWcoDwPtjb37rvcowFxmdwyN8S6NS5
TBHK53BwnKPl2+UF4ws4yMYFJSW+UYDyRRx2XeHTq50J40s49LCn/15vBePL
OEy9uvPWlqPyUL6Cw5nwzokdHDC+koPm/k/TyvPkoHwVh17hp3O3nJCF8tUc
CoNKW5+ww/gaDhJxTzimi8pA+VoO/byvZiqESUP5Og7ntYJvc+2VgvL1HPqs
p2g2csH4Bg62Vp6GSgmSUL6hQ08ol8el9RJQvpGD3sxN72P/iEP5xg6l5mqp
W1NhfBOH05p5G2T+iEH5pg5KmzhmHfWF8c0cFB6LTl0cKQrlmztEePQLPNov
AuVbOMQkPXqs80IYyrd0mJz6YXLMciEo38rBpaHir2G7IJRv7cAjfKi84CU/
lG/jULo7wMbiBx+Ub+twjbcj46cfL5Rv5/CNd2fjH1MeKN/ewW9Nn2vqVpi8
g8OEFuYd92O5IPwGB4fsEzv2Xd7JDZV3dFD2mnYtagVM3tFB/t/Z0xYfoHwG
J4e2idlW1fLsUHk0PoOzg85mFjazPpi8s4O8h6+l2CpWqLyLg495/fbHesxQ
eTQ+gyua+a6o5jG4OSzffV3slAzUvAY3h6r6XwezV7FB5d1R7WtwR1XP4OEA
Sf9MUHkPh/Aoo3VFSv/tIfKeDtzMa6teTWaEyns6GPe+/e544CdU3svhveWv
f056zyD8Bi+ouQwMAMH7yvE=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H9M1GUcB/CvQP7gQEngkh/y49QmQhgg8kOM9x0ixw+P+8HdcXcVVGO1
aEWBI8Xqq8OKIAeJ9kPdGjVAEcmYyHELz7MrtXBp82yObINNi6mwgBAyqHaf
54/vc9vt9tr7+Tzf53m+n3tin39NX+EjCELVf9//f9lHbjzjOF2pgFcT2Zfk
52qaI5kF3J7uTuh1x5KXYuPBLzQjZcxBKLOFttX7MIfg19aK4cv2GPIqfFn/
bfOnOuZIuKf7rgyORJNjMNw19fkHOmYFxtr64n78JIq8FpV9+28dmlpNfhz3
O+I/flvGvB77jKZ2W3EkeQPu1gan9XRGkBMwMiR7QZwJJyfCfyHl5bu3wshP
Ypk6K/WeijkJikaYbhxaRU6Goy3q6J5w5hQ0DYzffLbxMfImfHb8fM50t5yc
ir3HfioLq2LejF3NIdfzFzGnocbuirlQEEpOh6Y6qO6wO4ScgSfuRIj+fsyZ
MHgamq6tDiZvQZVn0vVc7EpyFgafXnc+Ssa8FdWnexq0ux8lP4Ws5KL3lpcz
Z+OSZ+3U3wHMQKzyxYad80Fei0B115bsr9vIghK3NypSXo2j8aISjvDWY/Zx
lqvQmFwxfKSc1asQEOyqrfpjBeU50Jw8kFtxJpDyHLgnVxisrwdQvg2VF/sH
f7bLKN+GvwLtex+msjwXRzyy2fZUlueiZbS6TjWzhPLtUovb0Vzv2//bM/6U
52E24aM9Ha8sozwPawoOe6ydLFcjen7oh/QJsqiWjhfyuefnc/UF3Po5C4W4
2n996pcHLC+ENb5FfeVNlhfhm+8z768fpf2KRdz57IAn8P2XZjXs/DgLGul5
iRoMhU+MtQax9RVz+yvmzkeLlA/vzSidtF9wFrXS/Tu10vkEHSZ6r/7zViir
5yxyduqk8wt66JqS4v32+1G9nvpPoHo9ZL7du8cOLqJ6LhcM8N5fPlRvgNma
fOoNxUK2t94An5gNc7Kuh147uVwoofXMeo0S6XxiCYrS3jk7muhLzy+Rrlcw
Yjxjbl6VuJieb0RCr9/izQdYPxql/ek04t2Wysy6aNa/Jlx0b62tGVhK9Sbu
/E2IVu/IkJ94hOpNXL2Z278ZHY4b8suRNF40c/Vm6fsQSqX9jlLu/XG5s5TO
k/WnBZ3KC+7vwqgfYUH+8VMn1h2l/79oweT8gGXfErofnBbsdGiz0h8sp3or
FgTdQnkNjYcVPREnz14rZPWcndx4wYb2NQU3N7loftiw8nenq0vP7isbbHnn
/Oe+ovvRacOduD93JWmD8S+a+tx3
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2EYB/DTTHBt0cpLM2fOlWFjrNKm89b+M29TZ5ZJOAuk9EMUNJxh
2O1YfYkISqOb9UElpckMzdCUSANTkmASaWg0YXQxugzLmTa1wuclthcOhx//
5/mf98OJPHhsT5mA4zj8ff692QkpfNTTdkSBJbl0Q53zRquUmUPC4QLLoe5I
cgD6ePv+38XMErybKFXKhMxBuHHzvHnwoZwsxbC45HRLNrMMjcK+D5OOCLIc
Nnvpe42KWYET01qt27SevBGvzo0Xn6oLJ2/CXmererJRRo5G8pTn+gZHGFmJ
75nVEwUj68gqzJo69F/8mdVYsIbHF4eGkrdC1CvXbTkpJW9DO9fAX5Iwx8Dl
LjszUb+WHIsfc8/7346FkLdjfKBjbNTCrMFC+UyUsD+YHAdP4/LIj/YgcjxM
U+NxUfOBZC06zU1F6mDmBNxLjB1svruGnIhbT5srC1XMSbC0PbiYX7WanIzj
m6/V1rRLyCkIkzo/Xa1h3oH8o8qh6VBmHQz3W61Rd1aRgUVu92JJBZkHim7b
6oNVbF7vPc/rIQ58VmmeZPup2GeKaS1XsDwVTwYSv0U7xZTvRN2IaLZJI6Lc
x1waIhZeDmldKyhPw5ULfl2OA2QuHe6Vj6s9Gurj0zHc9frnm19sPwOxl7/O
6HuFlGdgsD+lsqI7gPJMNPeMhryQ+VOeSfdd1C3lWVj6/wWUZyE3/mynU+1H
+wbved7gk2f75Nl0n1nqz4HIz1b1uXYZ9efA0pKka2/gaD/X5/u5EMiVc6IW
D+0bvc0bffrzvM3nUS87u7zN//cf4AwEMg==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1XtQVHUUB/A7tAIKq4C8lPfLEMgCQkQhvstzNVhgeSy7LGQMhDNAgo/x
AeSNUGRGsGWwjJqGrAzFmFFDIFGXYhFqoEESnYZHBaYjJZCEsClTTef3x707
s7PzmXO/5565c39nPXJ3K/NNOI6r+Pf73y/72Ke3Xb1Y6In/NRvJy47p4qXM
HGy9h8em2z3I5lhRkpThnMVshRPtE5c6TZhtcWks3ljS5E52xEzx3KO7MczO
yBt/eEV3z43sjjm7bo8Popk94dSirllR60r2xsbgC6cdb7iQN6CxOXL1ORtm
XzjunytpeMeZ7Af5ntxrQ21O5AC83pB2Re7FvAnjo/cLTp5eT34JsYY3y+p9
mAMRGHXW5/OmdeQgjDtJJlYtOJKDsdhuoXLucyC/jLx7e7+q2cYcgsfGXsPo
T/bkzfC8ZN5oSGQOxbmSgaFddXbkLWh1Gfb0u29LDkPZ7UNSbifzVjwq7vkr
eGEteRsqPh7usv+FORyt8TPKA5bMEZjsesb7h9qQX0HlVG7t1AVrciQ8ZAU1
+5etyED/iPf835ZU54GwwatNvT+zugw/5i+s9O1kdRlsHui/aVGyflF4wdp3
rnGIruejIC2ymT5eyvLRiFTNaxVOLB8NJ8fJB7p6Vo+BuvHLT+wCWD4GKk1Q
6x7PNVSPxYj0+K4lhZTqInNxWJB2vv00xJLqcegzRBzY97U51eNxsXV3w6Ys
Mh+PY7rCrWVuZlSXYymgvvyLopVUlyPgssR0cx2rb0fKiUB/yVEJ1bfDTZ4Y
Zn9+BdV3YCbMuBy1yZTqO4T3414VzsOLzCXg8BFjd+F5lheZSxTVReYUorpC
NH+S0HySaP5k4bxIFs2bLOyvTxb1T0Fw7R9PZHp6fhCZT8HA+tmHDVarKJ8C
3eTesqgnLK8UPn+IzCuF/fRKeO14b0TTTP24VNH9UzF7eehZhR3Lp+LDEYul
syEWlBeZS4Pb8sD3W2apH9KE/fk0NMu+NfSuo/dNn4bCvo7rw50sn46hjtvz
dxfJSIfh8ZpUTSl7H9NF86cL31cuAxp/nXzwIMtn4N2q5zomstn9M4T99Bkw
cfczWrSwvAqKC3Wx+W00H1TCeXmR9SokxvUapiLY+cvE9OjzVS9WkpEp3A98
Jlxano5oQ+n86jOxUeFlG1vMzr8aWrMzjU6xZKgRHpRQvXonO+9q4b7Qq3Fd
69PtasH2kwa3IuslDmMsrxHuK16Dxc/M3pqS0fV6Da7drJ5YPMLyWfh9rTp/
oYaMLMRGTJX/YCTzWeg/FBOet4H2oz4LNhYOXb91sX2phZmrJK3nFhlapHJb
Bi9a0/7ltSg4ZbJPGkzWa1F5U5VtTGD7ORtVkv7vzN8nIxuZ8pNWv95g+WxU
H+45uPgRy2cjqjvV1d+N5XPQFvnGYnkRy+fAqro0b+IMy+fgjmn1HZc/WT4H
uYqNzcuW7P/jNbhP2p36VG2HfwCY9Adw
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03lIVFEUBvCHWbnmkmNupU5ZbmlprmV+6riN28xUhJMiCpZh5GSWtjI6
GSVYbhVom1RG6ogLlZrFYJhGKJo4CUJaGpRZTRmllVHRuX/MPHg8fnz3Hu65
nOeckSPJ1OM4Lv7v++/LHusddx+0ZPPxX5rQnvwLii4zZg7ofzLp0eZMNsDP
MTPhNimzOTpTsno9TJit8I6fu0fV7ES2wYvR7pL67cwOOLIsqLmYY3aCWKn8
eknoSOZjQjGxO71lFXkNig5sWpz9aSV5LSSdM4LVXsyusKvZcfhWmgPZHcdT
9U0el9iTPZHPpYW+nLUje2GcL5jsTGLegIhPwnVFClvyRhh5KFINNTZkH9zQ
u3bRJZjZFxfP75fVF68gb8LTC43i967Mfii8MphmK7Mm+2Pm3EBr6HMeOQCW
ypG9mpNW5EBIv4z5uywsJwfhvqwu2YvHHIzXNf5+Y5WW5M2QqWe7052Zt2C9
hevn6iFzcgiOuPXOZyYxb8VOqU9TLt+MHIrYO031LpeZgYe9wR9dJ03+Ww7o
Obn/MG4gc2EYah/5OjpnTHkYHH/3PwvUGFEeDqlHecxAAcvD0dcTkp/XaUB5
BHxLP3wPUxlSHoF+O810lTnbL0DZqUXt46lkuQCatqGFEzxaz0VqWx6Jec+K
47f3sTxKp36Udj0uWqd+NL6ZdhT+8mP9xej0H4MatfF8nR/1w8Xq1I9Fdl/7
o+EOlgu1zyMXoqUpp8prF+s/DqfLs4OPOS6lPA6ebfpL/M+RuXid/uK113MJ
OvUTtM/DJWrfpzxR5/xJUJueyZpPNKU8Cfc0Zd52/csoFyG5WlnL86R5gQiH
3KoqK1rJchHsbSbflleQVSKsbPilTgmwoP1iGC9SHp2uJEOMoqmM0qlGslyM
ubg3BoXxNK8qMWpv9vHOq9n8StAmOzgrLaB5hwQnrg53Wb8iyyUQeV/n59nQ
/6KSYLDx4VmF2gp/AIU/O9k=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIk1Ecx/GnVbpaFy2d5m1zlajZUqfTeen5bd6m81JhRLNXgi9EyFgI
YRRWkBRpmFNfiJAaKqkTFWnO1N5ERRiooZWRlLWYUi2LUlO7sP950XPgcPjw
5Tzn8MAJLiw9ViTiOI7/O/+tbEiPDwz1lijgkpP/+HpVfdWNmUO159ug4fZg
shiDIeLKKh2zB6z2kWKZQ072wmlL3YT1GrMvoh7W3KwOYw6AVKNbGG+XkeXw
brIVBkwGkRUo/x75ssCfeR+aG274jp4JJIcgf86idLQGkENhaopuiXjjTw7H
ffOh61dimCMwq0ids+X5kZX4pVJZfIr3kCMhd/QPvJj1JUehW//KbtrAHA1N
xnP09fiQVXhS13V0IZQ5Bg1tzR2KICk5FtNuldOBi15kNYyLM+r9a7vJcXDU
m7TdPHM83jWqY2dqd5E1WDJ8EF/KZk7A0h33i++1zIkoamoTnb/tSU5CYOfq
1Kk45mSUhZlrb/V5kA8LzOPbuu3kZXdmoMe/696EYafLFcAJY7TFpCBzWpQN
HUmKX9pBXYuDycr8Uft26joMP0r4HDq3jboOY37OebPHVuopcPaPr13w3kI9
BXuz6qeMHaynonFKstwWK6GeipLH1pHJQTKXJuhpgp7+//cq0mE8UKN/do71
DMH+DMjWx57GO9n5esH99Ijo3+SmrnannoleS6lZWSCmngmZPkcjvbuZehZc
70dEPQtnOxP5vhaOuoH+52/e1Q0QycNXJJ2rLnPZ+KJZWdcpf1AXmMsh26nn
CHquoOdCVfXpp/bBMvU8SDZ2l8/XfuX/ALLWCTk=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03lI02Ecx/Fp0dSCttqWM5tuqbQ8sjSzw/aZus17V4bLI82kQ0o7bBQd
6yKtJGiVWUiXtfojS8NKxaNSPKIiSSdkhVGBFGgkuSyiouf7xzb4MV68f8/3
9/DsN+m6IkOBO4fD0f69/n3TR5Re31RbKMN/jSpMWsWafD6Zg6WbjDvyG6XM
Huipz6i255N5MNd2nHjmQRZgX28Qr6jBn9kbWbxOL888si+ejgf+HOCS/SH3
P/zQM8OPWQZTQ/xK7XkJcwCaP58tOjQ0hzkIgiyxOfOHL/M8ePqI1x6Sk+cj
t9fv/qXM2cwhcL+Wt6t80Ic5DO9LHXbedHI4Bo27RG8qxcwLobWH5no6vJkX
wd63r+f4CnIEwirrRrJ/zWKOhEkWfXlgNXkxJKWbb40JyVGouHHlpkwiYl6C
7ldHjpZ0C5mjEdlbbg5sFDAvRXj2YVvzTfIycCWTV7X3zmRejthHRkmwH/UV
qLL07ZleQz0GJ8qvB96eRF6J68siumxVM5gVeFB8wxQmpA7UaEYM5mnMFqBi
6KTb2690vxLD57YrbyuoK9Hceeyd4wD1WKhiPux9McFsicWV6i7hqX7qcdi5
0daiFVGPQ0tW4CPJVOrxKO7/9jhPSj0ewXNE4g151FV4fzFq8WsrdZVLV+PL
TFPB9zLqapf5Gpf5GlS22szpIdQTXPaXAEc1d/8HJfVEeF1z5Kg7+Kwn4tMC
WcRWOTMnCd39AWM/p1FPQon8jPV0HY/1ZGdbkhHKn/f1wkvqKWjyOVPVMEI9
BfK0uQLVFpqfih21d8p0e2h+qsv6NEiVG8pKftP6NJeuxW55548CLXWt8345
OmdD5/I8nfP8Np3zeXD0cCR/9DiYws4LepffS49MTavXxF3mNj2mpLvdG31C
52twvh8GWAtGrVk2Wm9AYQZXn1/B3r82A3JK1cMx7fT+GmHkRD+v5bP/A4zg
Hdu2/t1VZosRjcUh40Z3If4AkAQ1Sw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd021I00EcB/C/WWg6S+eazqnpWCW2zKd8XvvOh02ngY9ED4REi6Iwo+Ew
Qv8VWiDZw2gWYi/KsrBNE8qHDGVqIqHRsCioXmRFVuZAC0tqFfvdC3dwHB++
d8fd/bjIvUeK9cs4jkv/1/+PrInL7j+8d0gGlxwqu4+wMjGAmcMB2Zz6gzWS
7I0JEwTXSpn9cbkm1m9sIYIswkxVbaOpiTkYd77EFb1VMYdCWpcysH1kLTkC
i4aRfb+EzDLUC/ebPY6Gk+UQ/2x7ungljLweO+tPaG/5MUdBcNpstlSHkqNR
N57W2XJGSlbApunvmpgIIcfgZPWMMVLKHIvaMGdCRYWEHIdRdafPO1swOR6O
DaPhKw4yJyBVO4mujiByIkrivLlXJcxbsJsrERdeFJOTYOi1RQzp1pCT0dKT
sctkFZFTIDd6mJJmA8mp2HNWM60cZk6DVTtbbBQwp2O4cLCZ7xOSMzDV/5vf
mMyshPDToK29OIC8Fcfa01Vd1/3JKggCbcbK6dVkIOCrSOwQr3KZB26rh0Ye
S/woVy81r8aj0bRvUVMCyjPxrOf5/MsFX8ozsUkZUzrwka3PwgPHhc0h42z/
LLSO3ajyNZC57KXms5fO53Lg5Iqc5QY6L5/jtl7jdn4NOqR3u+357H5aNMTr
XzeX0/15Leb+9O045cXeIxeFh6OffJewPBdjL+TziwL2fnnw9bQc/2wi83mw
qy4tD3rDch0m9T9WRvWyXOeW5+PqQJuxTEH14fOx0OpV817N6lUA1/9jeQEa
zt1cZ/Fk9d4GhaPR2n0+EH8BYWvpUA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQNioVt3b8xWcoDwPtgbCDc+6hWB8RkcUjisFSp3
K0L5HA5+4X9+eETD+AIOcrdOyOzgh/FFHKJ2KWVa7laA8iUcvn0+eEojEsaX
cTg8Yd4Kw9/yUL6Cw6uXMnZNKTC+kkMCz5tLR2fKQfkqDs2uomxVZ2WhfDWH
zSz/b5b/k4HyNRzMpP3TeWxhfC0Hz0tiN0tbpKF8HYdlL7+1+N+WgvL1HHKD
Zm5XkIDxDRzE7trvKpkmCeUbOvhf103g/CEB5Rs5bFyXP0UvGsY3dvg0g/tf
z3txKN/EYemdh5ev/hCD8k0dGkrtv1ipwfhmDievtLSWnhSF8s0dNq1vk5O4
IwLlWzjEcEg1zLCE8S0dfMzrtz/WE4byrRy+da0Tj/0iCOVbO+yWmjJ353sB
KN/GQdExvbP0H4xv61CqOWXypE0wvp3D53+7IpvYYXx7B11bvZD9z3ihfAeH
FY6Hjx6ThPIbHBxOHLUtL9nFAZV3dGibmG1VLc8OlUfjMzg5LN99XeyUDCtU
3smBm3lt1avJjFB5Z4f3lr/+Oel9s4fIO0PlP0L4DC4OTApav7hX/4HKu6Cq
Z3CFmsPAAADoFqg+
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02lIVFEUB/CHtriNOea+5JLV5JY67jr5H9dxm0UtdFKwYiBSDCNpIWXS
iQwiKjUhUz9kLjB9iJA0KQdkXDKjwTIDrcAIyYgpQxRcKjr3w7wHj8eP/73c
cw73BZw4U6Cx4jgu9+/778setyP9Q48rAvFf5pTh9c3JX67MHPSFbR2jTwPI
NlB0CLaEJ5mdUFvVvBltxeyCvitD7jWP/MkemFncMdcgZ/ZBkKNkomTFj+wP
dXGEriyEORAetVet/VL2kIMQFzl/TNDtS96P5fKu9lgHZhF8hKqgFo0PORg+
HYYPN0ze5FC0zdivdccwh6PPOH9cUuxFjoDdlvj094+e5Ej01uVXybyZo5Bw
NLPzur0HWQz9e9/PPV3u5GjMtpSr9W/cyDF4tfBgA8HMsWjQjcy1GlzJcSi8
3+x9KZI5HrptEy9tWl3ICWjZt1HCde4mJ6JJY24q7XEmJ+Fhoni8p505Gatd
O+u+SJklSI7Ku+ZYLiQfxtLcAd2heidyCgSVzkuN1czAxYNjaxoFWQukFa3H
bs90pFyKMEl40fBXAeVSPB9L/CFacKA81dLaVMj1NzM0/bSeS4M65Lbs9QV7
ytPgtzk1GW+2ozwdU17mb81OZG06L8/AWuidyz2VtpTzzGVib87dGXUv288z
l8U7PwumgXe/Z1fJnAwzgsZTa3LWnwyCs1FJ0/Ws/mwYl3cVqqtZf9m8PMey
Xm2OZT9cLi/P5dWXx+svD+Ynpo1aV9ZfPi/Pxy2d9cCnMrZfzpufHONGyflz
z2woV1iu1yp481Va5lDy5smzQYmK8YEX04NsfirefhX9b2zeKvRKR4yjnjQv
gwo1Q8rk+FV2vwoQJhT9vGei+4cCvNWs2IoG6f5qC1DaIFbPLjrjD817Mlc=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlm1QlFUUxx+BFAUEFVdFjfWFFCELERHQ9s8iisjLLisuLCw8++6Elsri
G5GPaE066ogYH2KsLUscNSwdDfGlRxJFHZ0xCks/tEozlKWuaSD4lg3n+XDv
zjyz85v/Pfecc8+5Z+4E67t5Dj9BEOSX3///yk+Vf+zkt2UT0U8+TWeKpmVs
sMICHN2hN7K+mUAcCO3VriqtUeEwNJZHfL/dX+FwFB9esXlevZp4NOpX/hWw
OlHhcfgjuKrv8vlIYjXSNClR1aEKT4Qt+y7akl4lngzd/W5NlzSe+DXo3XWe
n46PI56K2Ny9D13BCk/DzXNPWpcXjiWORU3XCvvGWxHE05He+k7lriiF30Ta
/cwp1ZvGEMdhSMwm82DfaOIZ2Ov3WV1UssLxqOibcvjipVHEM2GICxR+NSic
gDPNwwN9u1XEs7D1/ZJRhx6NJE7Ek6Euzdl0hWcjpzyssq41nDgJ95af+ze+
ewRxMrqi/1kXp1M4Bed0cr3UPJx4Dvrrp/BcdG9tHGV+NIz4LUTnTApPX66w
BuuiL/Q6csOIgYro3bW7jhBLL/mkbs7sx0NJT0XOoR3pjmMhpHMsaFHW1nSm
/UQQ6VpcifDd2R02hPQ01HSWV2p7BpGehvUb+s6WHRhI+jxEZmQnqQ68Qvo8
6LfFxQR8EEB6Oqo+bT+luuVPejoaTl5XXRpH64X5MJpmNK6a+ELTr89H+cEU
zZEvBNIXcPoCZCVu+K5zOu0nZLD+pAwuvoVc/AvhO3rtWdXIwaRnIn773Z5U
mVjK5PJfhPtJfc+102k/aRGbr5DF+c/i/Gcj9mjAwFk7FP/ZaGudu8bdHEh6
DstSDuc/l9Nzufh1aH0YajCtDO5n6Lh66tj8ZB0+rClLroykeAQ9mx/07P6S
no1f5tYLedS/fmSfhyD/r9ffqR1A9nlsPeU8rv4GlmFg6ysZ2P1kThcWs+eP
xex+Escyt17Ih596Wl/Qwaf9/QWOpXy2/+R8rj+X0Pn2kj3H0hIu/iWcfyPb
TzBy/Wpk6y8b2XoIBSyjAL2xu95rWKbUrwCTMus6TPupn+QCdIec2Pg0gfpF
KGQZHEuF6Aj5aGlvDs0LuRDHfTvfiLiizBcTvry4d3WQmxgmDPs7XOVTEUsm
7E/9ofX8GMWeWy8UsTqK2PklFXH+ORaK2XhQjGXanaeHfq7YcywXc/PRzNmb
qf5K/mYufjO7n1CCF4L+hegOJfsShKyakdJerczbEpy+kHxvaiftJ5ew9RBK
Efn8yuXZPmJwLJWy9ZRLufqLLKtF9n5DZO+zKMIUU5Nxda0yH0Q2Po/InbfI
zhcvZy9YUN8R1LsvgVhtYecPLLjW9POjXx4Ti9x6ycLm57Gw+csWdn55LVz/
Wll/ais3z6xc/lZu3lvZenusbH6yFTs3+zf9ZqZ4vFZuPtvY+NU27j7Z2PUi
t16ysf3g4Vi2sfF4bVz/21ldbef8c7po5+aLnT1vj52rv529H147zUPqd8HB
6moHdx8c7H0THez9lzj2OBA8omXNij/JXubY68CEVNeWiufK+8fJstqJ14dN
ffDJNWI4sW9S5o2ZLcSiE+6lDWdyVfTekpz4Kjm+rWEPsceJzlPPpJhEYtmJ
t92Pjw8wEnudiGseO+V2hfJec+F2/ayEm7XEahcMHVu2/Tie3ntwYdHRB5n6
RGLRhcLSlgxTAbHkQvTkQb/3LCD2uOD62M8dEk/vSdmF0uvHStrXEntd2NM0
p6i2MRz/AbXMLIs=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxFymtI03EUxvGhZtncXOaWTXO6so0mlVNzbqs9zqmlBM3cBhaEgl34G11s
KyxjWY0KlW5kpBBdbIpJ2BJLcWQ2LEIsJTORfCEEaciKXrgXWxc8PzpwOHz4
npSKIyWVYTweT/13/102Ekt3Xxcnx6L8hkarDQfEzDyoN90tMXalkJdBenVS
2FvBLMLE7dZXvlAyOQ4/GxUDlk7mePRcnnAFLMyJ0PmOfpOEMydjiNv9Pswk
I8vx2av4facuibwOnGLSMdO/hrwe825V01k+sxLSZoujdV8ieQMyysZf139P
IKehfKfREpPDvBHtnDjU1i4lb4bM5/r46etqcjoCadfPuKuY1QjurzlVORJP
zoAt8teUNYs5E4eEC6WH3avIWbA+albbopm3oGUkdUfkFQk5G4ov5nv2Jcwa
TM+57bYWMTkH5y8MTjW9ZNaido9B/6yUWYfM0YaTqb1xZD0C5dXBc90ryVtR
7PlRZM5m3oYGT5TKOx1LNsC7N3Ugic8M8MM7a2ZvrFi0ExBUxc5dOiainosO
vfygcjCGei7sfbv0mgUhdSMEx9W6sToBdSOeJDzuGS2mf14eHr594OCfoH9n
HvqHtPPKmWjqJnBvnnvHXvCpmyALDb/T+JdTz8faolvjZW1kZz6Gpf7ZmyLW
C+D3fAjWiqOoF8B1jdOeli2lXghzfboq4mIE9UJUd+gMT+/zqG+nS+P87z9C
tr4Z
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1XtQVFUcB/AbT4NAMFhWoFiYMsUNQuIN8l3eqMACywLLa7EwGyIzYEJ8
XR/lNBbKo2mCyTHHokRskMEwGriN0KAMmmHFNBUmToUTsqkJS0KP4Xf+OGdn
dnY+8z2/c849j7v+m7flVNhIknT4v+//v+yjyuvp66oMwJIs8XXvnNvi7sQs
4RtXh0+Mnf7kZbiY2jCrNTC7IfjKlmsaidkDVvXpg2jVkNWYqfrz9ngSsy9C
D8147R/xI2uQmzcxOejCHIDnMqYxHPU4+Qlc/nvzD1MNj5FXoeO9Oq+pn3zJ
q+Fkvz5h9EXmQIxUDe4fPOND1sIrpvfk8LQ3OQhjX1uPxbzL/AzU3l1PHbi+
khyCJ49cS7FuZ14HzVR3z/iEmhyKS6Wf3umPYH4WrnWBxp+bvchhWHjVP6M2
kjkcrVnWCfM/KnIE9k35D9xIZ47EHm1928sWT3IUCtKOuN0Y8CBHQx98PKBG
zRyD21WDf4Xef5Qci9/W3NkRomeOQ/cr1XdNdczrcXFHUuzzq5jjhRz4MDp0
uP39FUuWgWLHE60+ye6U65Ak1y2EHCLLOtSuaWluOutGeQJvWbCUyPcnJ8JH
Pfl7YxPLk3B4XcWPbWZWn4SO2ICtqy8spzwZ5yxHg71HXSlPhvsfHiqLiiyl
4Grvt/fG55wpT8Got+VWi5sT5amwapt2tb/0MOWpCH17elankKU0VA739o+d
Z/VpsNEEzjt3PEJ5Oj7WXRj6aqUL5elINDwIt09h42/g28sbcPSgbe9ECRt/
I4buLs81bWf5RmF+m1C/d/7LylMOlAuWMuCXlhGlOmVPuWApE9puO4fwBkfK
M4X+s+C3ODoSaSHLWfx6SXqY1jamXa4jQ4/7Luf3PQhj89Xzz6vo8XRckGHg
V1oPKZt/fgiWs9H2nbP1ozDqX8nm5yPl8OMhh18/WbCSw++nlIvhobjXaj5f
RvW5wn7n8uuhCLlkQNeZbS1BRazewLeXDXx7xYA3Giujd/rRekt5/H5AsJyH
maj5xYQg2k9FyCUjdh8b+0L1iy3VG4V6o1BvFM5HPm8IlvPR3ve96pIv9afk
I/utkLV2r9tRfYEwvmC5AM62nfW3mh+i+gJsitj72WQQ5VIhlv4/bKi+ENUd
MfFnT0hUL+RKId+fZBLqTXz/skmYv0moL+Lbo4hvLwtWivjnk4qF5xcsFwv1
xfx9k0pg6b66sNuTzgdKhPNXgsbJ6p0Js9ReKeH3Uyrl+0Mpf75kwUqpcL/L
hPNfJtwfwUqZ8H4z89aYkXm6Ibmih+43zKjt08dGztH9N5tR2Nr5gaeWva/N
8Ne98GbtIvm4YMWM+Px7xZk+9P6/LlgqR83W9v4sFf3/aMoxd9Jxz00dGeVI
jru568r8CvwLG3c9ig==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1XtIk2scB/A3NSuXZRfnMvOyykSHlV2cpmdfLXWars1tbqlZBCvJQit3
TLuNk0WRiZsVRTdIya7GEMnS7JWwK4UlWUaHQ6wbRbXuS052TvR7/njfwRgf
vs/z2/P8Xn5bxPLSXIsXx3GW/9+/PtlLamxtd5bI8Vtu1QvrpMet/swckm2h
lbqWCPJwyE3bvH0LmANwtnypY98Q5vGo7nuucjaGk2WIXFO3QqlhDsG/pRVD
N30II4djxENDZUYksxzZd4t8+02h5Cl4F9KvlpVNIkfiuN9+u6E3hBwFrXLk
y5WJzNHIvC/tt1ZPJCuQUagK33k4mByLww3B5lvXJpBnoKxoS9eUbOaZkOyO
rzzXKSPHoeeTh+9ZyjwLp1YdkSlag8izocRkL3yUkucgzeJqqTnAPBdHrScf
z5Azx6MmqMfxdW0gWYkjbUkF9c3jyQkYKwnqeNExjpyIC2UnFscGMs+Dp3HY
lmcpY8lJ8GvwFKV3jyEnY73z/C5tFfMfmChzvbI7AsgqvHkyrXr6X8yAdnX0
7S8TyDbAlB/XvE4+mvIUNN5s+FNSPopykblUeIVHD0jOjKQ8FX3+O4u/a/wp
n4/JWfv78k/6UT4f3Z9G6/PX0npuAe4Eu1/vDWD5AuF6Lg111d5t/yxhuchc
Ouyu9RtTvw2jPF2UZ6DkRltn70UJ5RmiXI1Ze95+S+FHUK7Gd4VjU9NqMpeJ
HfaSxI1hrH6mcD2XBXfLvR+bA9n+LNzoTq4ovzSc8oWo2jrQVXLal/KFULT4
+M6tpXpcNjYf7e2QPvWmPFu4nssR5Tloan8ovRUylHINdDUzY3y2+1CuEdVf
JPr+RXA2l+6NLWDn0yJs8M5tpZv6AS3utT34/MjD+qUV9o/Xip6PTthP6IT1
bTrheXid8LxcrvB+yEWYOidBepruZxOZz8X7hIHB1FjWH73Q0Iuel15Yn9eL
+mcQnhcG0X6D8H68AfkxdvXdDdQPzijsF4yieTDi8vXEd1EuMm+E5mxtmqWV
zUcefnK6n8vKad6QB2u7NknpYfOWhzNJ8uKoq5TzedgdZ3lyaBmbXxMiUlbu
sg6SYYLE+1zV63qaf5sJ91UOn6C/ybwJro4ftph49vthRmfh1K5QCRlmHLzS
VGFUkG1m/P5/IPNm1Fvc9YVNbP9iOD8GH6sqHof/AFXtlsw=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0m1IU2EUB/Cbc2oty9RNLWtqIalj+JJNTd1/vr/Oba6iRLBgFGhZmsSs
5aKUqOxF7UtZYEiaoqViSVrMD0ElfTDR+lRYYRFEYlabYG/sPB/uc+Fy+fE/
ZzvPuTd8f7XJ4iEIgvnf/f/JLsXO4dGBygi4Na+1LBSN29YyC4iqmKi5NhhO
9kH57bSjTjOzHw4dMcerf4SRAzGhz1rsbGYOhllS9UC6mTkUFr1PWUyjkhwG
+cx84t33m8gRML3yGrAlMm9BrfV8xZR1IzkSgwm9N5puhpK3YsF5+PLz+xvI
0bgnfZn/Wcqsgjo9+233gfVkNb7PNnbsmg4hx2J+aHLZJmeOg+yCxtr3JJgc
j/Z1Wq9JVxA5AXWaSMuwhXkb7ix3KyPbFeREVDdbQwJa5eTtiC0/0/W4O5Cs
gb8saGxuLICcBNe+2uXTw8zJ+BS1YI0zMKegSNPw8IOaeQecnd6nPur8yamo
i2prbRn0I6dhz/W+DrmKOR11o4bUJOcashYeYdFLst7VZGDG99xBl97XbTtn
QYeE5q+/dI6VlOsw0F/dpi7zoTwDyrziZEWPlPIMuL8nD8ozaX4J5ZnoGn2t
eBFK9UIW6huWxit7vCjP4vqzxfX2bPHvCTniensOl+dy/bnieYU82G5NjSlm
2Xx5MF6Mi/Fs9KQ8H01XK1NOKL0pz+fOX8DtpwCTI9OLb5wyygtx5axk5F35
KsoL4VK1nOyqonqhCN+Sl35nqNn5OQvFXF7Mza/ncj233xJu/hJuvwbIJH31
X1pXuA0Ddu+N76+J+KN113O5w8Dtxyj+Pxi5920U79dh5PpNXL8Jz56mHT/2
iPZrN4nnd5jE34tQKt4vSqEa8vTafomdl7OjlOs3i+eFmfb5k87P2cE8p/0L
TOxQxw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQNioVt3b8xWcoDwPtj/+hcUOJcbxmdwiP47eWHv
akUon8Oh+dTlV/WhML6Ag4DX8S4bNhhfxGF1s6G28DYFKF/CYcEFESW/bBhf
xuFFwLqr/TwwvoKDUmBN2+9geShfyWFx5vuo9KVyUL6Kg0z2z4ClL2WhfDWH
hX8PVe+Sg/E1HO50bHglJiAD5Ws5aO/pZJ2bLg3l6zhEPfdxl22WgvL1HF41
NasJr5OE8g0cPi2OPCBvBOMbOsgat1+VT5KA8o0cSn+prz95ShzKN3YoNVdL
3ZoK45s4BM/8/zhABsY3dfi4PShY2U4MyjdzOOscIfn0hyiUb+6g8Fh06uJI
GN/CIbDHUJulVQTKt3Q4lxjx8fNNYSjfyqG7d6nqWmYY39ph5v7l5aE6QlC+
jcNuqSlzd74XgPJtHUo1p0yetAnGt3PgET5UXvCSH8q3d1gvvWb7JW8Y38FB
11YvZP8zXgi/wcHBb02fa+pWKJ/B0eEab0fGTz+YvKPDxR1Xv9z4wQ2Vd3I4
cdS2vGQXB1TeycHHvH77Yz1mqLyzAyR9MUHlndHkXaD+Z4HKuzjUzru8R+wh
TN7VITzKaF2R0n97iLyrw3vLX/+c9L5B+AxuDtzMa6teTf4IlUfjM7ijqm9w
R5P3QNOPxmfwhLoDChoQfACVy8vG
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQNioVt3b8xWcoDwPtg3Jm1m2MIB4zM4+JlGTWiY
qwjlczh8NH7t62YN4ws4OGhnL5Z+qADlizjMXno9ML4Vxpdw6PXun2NoBOPL
OEyOXmMWuFgeyldw4Jz7al8TI4yv5KC1oGNZlZ4clK/i8E7mpodEgSyUr+YQ
s0u5ac52GShfw+Hm1s9rq7lhfC0HlaymUL0kaShfx2Hpo/ovXPVSUL6eg/Uu
hrW2/yShfAMH1f4rbj8LYXxDh1RVQ0a70xJQvpHD1eiHli//iUP5xg6HevoF
FyvB+CYOC/iZpP64ikH5pg6/CxfU+2aIQvlmDk4Hg+W05UWgfHOHde7vg8p5
hKF8C4eEwtjfp14IQvmWDqlzlzFVL4DxrRx83Y4dfWIrAOVbO0hLPH4xcRKM
b+OQ4zRhL99CPijf1kH+39nTFh+4oHw7B2WvadeiVsD49g5npT68miIA4zs4
/NSZVLM8hxPCb0DjMzg6THxcXO30nR0q7+hQO+/yHrGHzFB5J4fAHkNtllYW
qLyTg495/fbHejB5Z4fi1db2mxYxQOWdHd5b/vrnpPfNHiLvAuU/g/AbXBy4
mddWvZr8ESrvCpcHAG6HqCo=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQNioVt3b8xWcoDwPtjv6wiXWsYL4zM4XPvwQvTu
CkUon8MhvuBmzMlwGF/AgVXrmtAyBhhfxOFpiZma0CIFKF/C4cAll5kzfGB8
GYfcsIsfYu7IQ/kKDs+6HEtDeWF8JYennv6abqlyUL6Kg9qWr9PN18hC+WoO
ZlVP1fi4YHwNh/1XS60NimSgfC0Hg6e8yxouS0P5Og6+1n2bt/6QgvL1HE4x
nrdSD4TxDRw8+Zx3BE2UhPINHTx354t/ZoTxjRwe/JQLbTKQgPKNHdoMt8td
DxCH8k0ctp8WZ/2TIAblmzr8K/quynlUFMo3c7D5evBeTxyMb+7QwnLyFMd0
ESjfwiHphNIu4wZhKN/S4Y1wZOq3TiEo38qBm3lt1avJglC+NRrfxiFy1tqF
ojoCUL4tGt/OgTdH6HVHIYxv72B5bveCYw9gfAeHZcpet0wOQfkNDg6f/+2K
bGKHyTs68AgfKi94yQ+Vd3S4xtuR8dOPFyrv5BClPdHjXAU3VN7JYfY17p/L
TKF8BmeHs1IfXk0R4ILKOztsXJc/RS+aAyrv4lBV/+tg9io2qLyLAyQ9MkHl
XR3eW/7656QHk3d1WL77utgpGVaovJtDYI+hNksrC1Qejc/gDg0vRqi8O9S8
Z/YQeQ+oOihoQPAB1lS5dA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2EYwPHjtIzmbTk3TXNuVpimNqfptNyzOXWbTnczaYmpkH0YKKmh
aeXpQ0pRH6Qs6KJdQIaSkmRFFq3EBANBU4mKwASRKFTUzOGlYs8b7D0wxo//
ec77nMHEZZWmExyGYQr+fv59k0tQ0Nf/2CYBl+YVAWtHfM8GEzOg1Q/GJ74S
o7dBVuFl/7Iy4gBw9vZFDnkT84G/PKzW9USgg8HvXlWFXEccBseKP8l6pkTo
CCjnqWYeyokloBnWfhE0haN3g8rTkMKM70LvhZH334T2SOIo0BY9GW+2hqGj
IbU2qm3saSh6P9QyxxVfF3ei42DIYB87n058ALhBEzWvr4egpaDtrxQuehAn
QE3pLOdFeTBaBsXRy0s2EXEiBA6IY4XtQnQSJAjbS4uaBOiDcLPjvl0STpwM
9s8DrXcng9ApYL5zPbReSiyHhokzvkwJH50Kq6XV6xf6AtFp0Lpn/SjTTnwI
urPnTLU+xIdBzdatS5t56HTYMet422UiVsBMvERWsY8YQKw8een0RoDLLEAs
L2rh1iiaUcImY9wsqfHHrgTeD75gXuCHXQV25cDguxBf7CoYXPQ3W0/5YM9w
v5/NgNHnE0sff3Oxq8Ea06IZqUOzarg9yV3tSCI9EyJ1Nyat9u3YM6meRc1n
QX2j842tcyv2bJiTOzdUcWg2G861fXgpmPLErgGRRi8XdG7BroGmFltqg8gb
uxZapqsbVCtoVkt1HTWvcz+PyaF6DhivSGO8LnphzwVORLST27WmcPVckF39
uaJ0rLrM6Kmuh+quNEXvAwbn89zfh80Druej+u/XPLDng+v/zcGeT80b3J8P
BvfOGtyf5zBAoTWhu0qyifsZ8X1/4byR2tfofr/DSO1ngtzkxmfTcbg/mKjz
TdQ81RkztT9l1kzNU52xuP/eYMH9FnDegu83g/MWPJdcBf/7H/o3Tgk=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H9MzGEcB/DHNWkSEUdEaVilJZJU6t6XTkWl7rrrrmZ+Gwv5lR8JD/m9
3Ublx7Br2EiWLUMk9sVi/GN+5NeYETbMjwnphrD7PLPn+W6322vv5/P5PM/z
vd3QWcXmuTrG2MK/n3/f4tFbz16sLwqFR58NyU7XoQx/YQa/2I53OY1DyT4o
93GeOecQ9kf74qctX72F++Ly7lVvNtWGkAegFMx72WzhIFjW7LCvDhQOwfLn
/b/ZdgWTQ7GxZ9iIOTrhYUjed3dBZ+EQ8gjEVIfPCK4fTA5D5lrnqC+9hSPw
zT3nQHhZEDkSLtxw2B4PIkehqWrUzvKxwtE40fxsZpJ9IHk0Dh0daL91PZA8
BhUf5oetTxSOwfRF9dX7WwaQx2L/FZfXNptwLF7rGlZWvOxPHoe2rSa7aYxw
HBq07mnV7/Xk8XCV1DyJDhWOx837m7eU3OxHTkCxc01gQKVwIiIKxzdfnio8
AY1LItstOuEkRE8rP36ppi85GWcN836ULRQ2YM/wXw5WHUAG3u5dZqwzkDlg
SnpVdtvdh3IjWpt+8ZFxZG5ESXhVZcVpf8pT4DhQd7hfJJmnoJPlds5Y0Yvy
iegRcHXVkrdkPhFtvxsdm7qJ+lTZPFVez0x44Ld9fke2H+UmNLf1shQs7UH5
JBx84NtxLNaXcsUsTcnTcOd8y9dHP0SeDl1IhNv3JPXj6agxXmu+HkjzWIY8
j2fgu9+FjT9jxfzJSv/JuHQj4WNYq8inKPkU7Nrsdf75tO6UZ8rmmcr+spT9
ZSnzs2XzbNSfKq6KKvShfCo+xbt/p0R5U66Y5WCd616T/oWXx8iB5/9AR+uV
XFPMcrH8ZKLh9BFG9bnw9aorfVfZheqVXMul8/w0eOrN8jyYEeP80G7UOjw5
N8v9NLPcj1nkfrDIObco9RZ5HstDZtyGhtYocX7FPE9er+Xh+MWH+ltBXane
itIN7itFtXSfsMo5tyI4PSteX0vWrHJ/ZsPW3UUJa4O7Ub1Nqbcp9cp6li/n
yFf2n6+8v3zl/Hb5vmGX75Mr1uz0+/lO78+hvH+HnHPFmmJWQH5D8wtoX/Rw
xdp//wHVA7px
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1IU2Ecx/G5qIQlTrNpuTnny9osh2nWdpbtt+k8m9oLVpDLCwv1wlXT
SVCTbBFU9iIcN4ioi7oJmmZNUIrKF3oTikK8KLCCVCyLMhGUhknF/s9F54HD
w4cvv+fqaA55KuukEonE+Pf7d7Oj2Nf7MOzOQFQ/LW3rPbxGwSzBzQaFLqFf
Q47FkwqjtrWeWQ6u8qAqcz6dnISeD3yk8QZzCiZrb5kybcxKTFdxI6/eqcnp
MA/w2hgFcwbGXNXPT9rTyFlw9D0d59tVZC0KO5Nzq8JKsg7zo8O7TiylknPQ
Z/bWvrUwb4TrcwWvOrOObMBgXlt944W15Dw8Ms3AK6SQN6EgoAq3Xk0m5+Ol
/ug95aKCXIDT05qBcSfzZox0vZnLOrKGXAjl2H7IhSTyFkw26Lnf51aTt8Jm
qAl6a5iNuPLpUszH2USyCf3V2UNpMmYOzeG7bbt9CWQzUlMmvggdcvI2XMyv
e3+thrkIx/TBQEcP83bEHU78dr6J2QLn7e5Q9vV4MpBbZNg7MBUXtR94/IL7
oZtYRd0K9/D9/tEHMupWPJuL3+NqYt2GnV3t9rpetreJ9sVwbRAcr4+zfTGE
ieYW28JK6iUId3uChgOx1EugduwwKULLqdvhOxUZcodWULeLeinOCm6uRU3v
+UtFnUf0/5ZS51Fw+fuCdfCXJdod/9svssQp6k5I03Miss5F6mWi98tE+3LM
mCJLNsMU7cshW3bH9zUwa/kDbW/f8w==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mlIVFEUB/CxDIXMJRvH3XHJJUcdTdNybP7OTO7azKhtGpVppgZG5RIU
vSSXstRKyh23Sh00EkxRQ7HVwFaaDyKVZUpUUJIhLlHRPR/0wePx4//OPZd7
j31SpjplBY/Hi/j7/vvSYxbf1XcnwwH/9V0qEVRUWBqTedDbEVic0GPPrA9b
q2MZs/vIxhg0PND7dUbIvA7J1t/axfVkc0w8zf3Q7ku2hiLbt1xcascsRHmt
ek780JbZAWkr01JSPMhOkDVrWy4X2TA7I7HXMa+m25rZFZLphWuO76yYN+CG
5kLJtBdZhNBEqbCoxpLZEwV6UqGhC1mM1qxRaXWpBbM3BsQ6dhojsg/2looq
32aaM29EX6NtzSlLsi/4Aj/3kTwBsx+U6l9Wt/PMmDehSthlNDnFZ/aHXPTm
+cp8cgDcH5vPNI+vY96Mpon8JPkh8hasXS3on+w3ZQ5EQ/MTfql2LbMElQO3
cuJF5CC425hZpB4gb4WCy130LjRhlsI+OPV81m9jZkAjcTjset/ovzngiKzs
nmGDIcuD0TzclL36BDMXjPDWjrb1Nex/ngzFPilj1fvZepwMBqZDOUc/Uy6H
PG5h06oQqpfDI8gzbmByDcsV2LnHp+OYA/VXYHdVewNfRPvbtmx/y8wLwXFN
oLSzkfqHIMut/OqVTqoPXba/UNx0jBj1HaI8DDaaBW2iPzsfLmzperxwfBlz
OeeVR/XhuPu9zMtyhM4nYqm5CHiYuP6oekn1kUv7cZHY/Kyv/tF7yqMwrHX6
OW9A/aMwG/lJ/2wU3V80YrXnL76yYffPRWP4pEKS7EzzEIMo/zPdHz0pj8FE
utuWxULKtyNjl57q4HXKt+N03et+s3HKldCz1Y178IoZyqU5p8TcrLwxR8Tm
cVCJkqNZbQmxNJ8q1PZIEq52MEOFhSZd+6kXzJwKAelSn0sCNu+DKmTqzBe0
BdL8q5EU49by24AZalSW1KUPZfPxB8nFG9M=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0XtIU2EYx/Ez3dKUcjOdl7TpHOZlaDpTl5f9trk53aYmFimJIhiSUNH6
I5PgQEgEOrELimBUYlhmUClmGpRSFqWYZcIEQRIFKZpCDofYBZ/3j3XgcPjw
fXjeF050zdnSWi+O4zR/339f9kiPDY48qZdjR05NhqLUlRvAzEHrU7LW8zya
7Avja91GaiWzGKLilJnf7ihyECrbqmI7WplDYTWPlxxUM0egWnFF3zAiI0eh
V1U19yKEWY4TZqP7mu0AWYGXFxYsgVOR5FhYGluS1yXMcZhJq1hfaY8gJyCm
U9BxfXo/WYmJgXfvGyKZkzAZ7ly9KQ4nH4Ky505IQnMYOQWnZw2iLglzKiJV
V2dlNaFkFfpNjuXzAuY0VJlHMToWQj6M6vLjm+31zOn4OFTmpwhjzsD8xIBj
ziYlZ6J3fvxW19dgshq/hpqGNxzMR/Dg3OSnOjtz1n/Oxla3MHplOoicg5O+
4XyHmjkX3UtNNfpTzBoonfbHQ637yEC8wmfJlU/mgfbFZsHCWiB1Lb7UbuyO
G5ZQ12I5Wa46E0/mdLAa375ZyhFT16G8s/9usJLM6XE/ptCRNsa63nOey0Nf
trwubjyAeh4k34OkTule6gboy7bSRUYyb0DRI7uhdnAPdSMqEttMUxf9qRsh
2578kOn0o55P/5vM56Ptm61R5/KhbsLR5pREYZOQugmXb38elS56Uy+A8plw
V7qd5vkC+Hv3X1q9IaBe6DnPF3ru48yQmaxq6UMRdTNsfVmap/c46haoWn64
tK82NTvdAq+oBLd/39aOOauneSt+qt3buqRl6kV0nzXqRZ77uGI6h+P+APAC
9a8=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQNioVt3b8xWcoDwPthH/zvupMgF4zM4nIx57Htp
nSKUz+HQ/GvWoT3+ML6Ag8qnlP6ljxWgfBEHH4UAJ60+GF/CwS+ywuOtNowv
4yDaeFpr5Vx5KF/BwffUihjPO3JQvpJDsu9bhxOWML6Kwyr1wvXv2mWhfDWH
G4193Mtvy0D5Gg7CqamBwcYwvpaDR1HS3otbpaF8HYdPkgdYSzdKQfl6Di/3
e86e9VMSyjdw8JS6cvGYC4xv6LCnOPK32TYJKN/I4X9WcseJ5+JQvrFD7pIk
9rY8GN/E4VjPofKy/WJQvqnDrFNCuxasE4XyzRwyU75W6KvD+OYOHq+u7+Pr
FoHyLRymqv6NZJgvDOVbOixcckK0/5oQlG/lcLLSxSZFDSZv7VBw7fOhREWY
vA0a39ah6UlS75M1glC+nYPs6j/XYsxhfHsHX7djR5/YCkD5Dg7/GQL/J5Tw
Q/gNDg7bPkzQlzrLB5V3dNC11QvZ/4wXKu/oIP/v7GmLD1xQeScH49633x0P
cELlnRx0NrOwmfWxQ+WdHeQ9fC3FVrFC5dH4DC4OtfMu7xF7yAyVR+MzuDpw
M6+tejWZESrviibvhqbfzSE8ymhdkdJ/e4i8O1T/Rwi/wd3hveWvf0563+wB
YdfCPw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HlIFGEYBvDJPCrbdjNdXbNMs7CyQ82jtHx0zV1v9yqzAytEQ6HMo8CC
SToMMrLskm4tK6PLCo+tlrYgi41UMDogQyOya0TQCl0qfL8/ZhaG5cfzzcz7
zTvv+G3cos9x4Dgu69/x/5/9lKZ7rbfz/TEqIcZq6VUovJg5vL11PvXSIz/y
OFQ4XqnbnMWsgDXRzt38M4PsDs+18yd1XGD2gqUj/tTJFGYfrO++0FTU40ue
AWv65zWlYcz+kE2+63R833RyAH58Sr4f0D+NPBtY/1j9PYk5ECrNuTJdjQ95
Lla/Uskv9U0lB0E+2KIV8pkXoD33iVblwrwI2WphKT+oIgejRhNS6rWKOQTu
tvdt9i9e5FB0/55uKl/EvBhbK2r6Cws9yWF48M2Qll6rJIfDqh0462f2IEdg
n+2EKjOIORK5xxyKZaHu5CV4uSGzf+DNFPJSxC3Irt6WzRwFZ9OYRsHqRo5G
zpnLDmXnJ5OXwS8290CJXUFeDrVxONwpYRI5BvnPmh52NruSgcN7xjZ9WDdh
1DwwM+l4V9YVMhcLm7fQV61geax4PRcHobF9ZJfHeMrjUNVTVBY35EK5Gr7a
1CXKa06Uq6E7GDzPca8j5fHi9Xy85P4r8Ozpsu3FLeMol5hLwKCsefdw2ETK
E+Brt72IFNj5GkmuEdfLaSXX1yK08vtQrIXliahvfa187sPqT8Sus51m5cex
lCehqCEq5s5FjvIk8XouWXL9ZMnzS8HTAbkhq5DVl4LEqzeuzTotpzwVsgK3
rxWF1E8+FQP2ltXlLqy/aShpzYiO/EX95SXm0iHbFhLVWS6jPF18Py5D3F9k
4HfQkZ31BayfGQhqdHQOP0T9sUjM6cT7g8S8DnVttaWuxVSPRSd5H/VoiPbP
C7TSfqFH2vVDK3LusXr1uC8cXuhtY+frJfs3oNW7+kzzTzIMmNYw3LU2guaB
N6BkTvXRI3cotxhQ3ruxsvc6mxcj4vkdI8H7yTCKc96IHvMIPy+C5s1ixOj3
ks2fCXMCXHqHNDSfMInnlzfB510mFFU03xYTNr0zm+u/sXlfiZ7dboFbN9H3
ACvhLMi7qvKU+At2a3G5
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mlIVFEYBuBTaZmTpmljmaWNUaJiqbmVNq9r5rjMquRCUQqGRaljSQVd
ow1aTNMCyx9hheUSRpE2FJMVKWqEyQhR9EM00pYx0NIkK+Y7wb0XLpeH97zn
fAfu6l37tQVzGWN5f99/X/7IDQ9MbUUK2GRVHg3QXyt34WaI2qMr3f1oNdkB
g4WKxpAcbhc0G3dU187hdsdIh71u/n0f8jJoroT1+hZwe8GrVNnvupjbB3W6
xNrCEm+yAqfr040G0yryGiTdfFswMbaSvBbtVZN5Q1Hcfige6M1yPOVF9kfG
kdv2W96tIAfCe1fFr9oY7iB0bTAZz/V5kjdgwJL2ukTFHYze8I+OhvfLySEI
jm7wmU7jDsUCr/zhmMpl5I0Yy793/HuzBzkMB87UjRcXc4fD7BzxuHMJdwRy
mU6urpKTI9E9cOJkWfdSchT25E+Ur1/HvQnJo4NPnM+6kzfj677nE6GTbuRo
BFovtD6s5I7BT9WwQ0XqEvIW9Cur7Tzeu5KVWNk0Y8mN4AZMnjX1Hd9cbBaA
7XUt15cGklkssrJDWksUiymPxSzTzO40klkcmqIVhX7PeB6HuyuaH/areB6P
eP1MuH2SM+XxcP3sLrfKySwBN7obDsqMPE/AIrfOQwc+8X4iykzq6MifPE+E
eq9/z8RyPl+SZL4k8Xq2VTyPIDFLluyfLJ6HbZPk2yT3TxHfR0hBUVf7kzcd
MspV8P7d1xNpdaRchT5P62iNC5ml4uKJee0f8nieiqsW2dStMN5Pk/TT4Jty
2ZLdyPvpOHxs+mnRnfmUp6OtdX9NUI4D5Rni84QMWJzOFE6lO1GuxuOXm776
DS2yGWpMOnVUzISRBbV4HrNacr5GPB80yA6oSn5VTusFjXg/syRnWoSe//Ij
1ryQ+lrJvFp0vYg5ZHxE9zFrxfdlOmjOBQfYnbSjvsSCDnN9/KdlTTNKW1+H
b1HTv+OCJm1mejp/ymboIZvXcnj00rjNgsRmPfVHqG8QGwaaix7BID7PbKD/
dZb6meL9kSleL2SK9zdL1rOs/+f9Acrifrg=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAGIQDQNioVt3b8xWcoDwPtg/trY/JM0D4zM4PDimJWK5
VRHK53BYZ9lZfCgIxhdwyGK6rb6BEcYXcdCtnPMlbaUClC/hUKLl/rfLHcaX
cbholvb81QV5KF/B4eYO1mOP5GF8JYclJxeXcZfIQfkqDgumMNe9PCwL5as5
OMtMDWt0hfE1HJ4sYzwaWi0D5Ws5yMw7cLPnojSUr+OwZ4p+V7MJjK/n4HN3
CZvLGiko38DhX6iYbPcNSSjf0MHF/L1plB6Mb+Rg9D9Fcv8CCSjf2MHq9eOG
9dPEoXwTh7aJ2VbV8jC+qYOV2oYba3rFoHwzh+aWw3emHxCF8s0dkm/v2bP8
jQiUb+EQ4dEv8Gg/jG/pUC46m6F/mTCUb+WgLSsmmZ4oBOVbO1xJ/capsVMQ
yrdxaHqS1PtkDYxv68DNvLbq1WQY385BV1Dj46yLAlC+PTR8+aB8B4ejn/mD
owp5IPwGB4fZ17h/LjPlhso7Osj/O3va4gMXVN7RYUIL8477sVA+g5ODce/b
744HOKHyTg4njtqWl+zigMo7OyzffV3slAwrVN4Z6j5GqLyLAyT9MUHlXRxq
513eI/aQGSrv6iDv4Wsptgqm39XBx7x++2M9mLwbqvoGN1T1DO4OgT2G2iyt
LFB5d4eq+l8Hs1exQeU9UPkNHqjqGTzRzPd0CI8yWlek9N8eIu+Fym/wcmBS
0PrFvfoPVN4b6t+PUHlvh/eWv/456T2zBwCaNN0r
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQNioVt3b8xWcoDwPtgf37J6uwkHjM/gwLvpsa7s
CkUon8Nh+ew107W9YXwBh59LXezbfipA+SIO/IHXrs6cDONLOFgUszwotobx
ZRx2XWCeFrhNHspXcPg9W6vtBweMr+RQsmGxVUqWHJSv4hCcYtMlfUIWyldz
eGmkeFzslwyUr+Hg7tDxkSEPxtdyaP62/1lkkzSUr+MwlyOh8tINKShfz+FU
491j3LYwvoHDjmM3FU0KJKF8Q4eCmXn+Jw5IQPlGDhMXMU94ZwfjGzuI+qWZ
P9suDuWbOAQbcjDcDIbxTR1cUx9v7pkhBuWbOYTeZO3sqBaF8s0dTC71lqvu
EoHyLRwC9BcolUjA+JYOOh/61m3vF4byrRxOb9u6sqgAxrd2WGplfGL5XCEo
38ZhX4zqQTluGN/WQdNPWcQ1VxDKt3M4eU3ly28eGN/ewXPlulWqc/ihfAcH
XVu9kP3PeCH8BgeHvcet3mk85oHKOzpEaU/0OFfBDZV3dDgr9eHVFAEuqLyT
Q9vEbKtqeXaovJND8Wpr+02LGKDyzg7vLX/9c9J7Zg+RR+MzuEDVQUGDC5q8
K5p+V1T1DG5o+tH4DO5o+t3h8gD+tK9U
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQNioVt3b8xWcoDwPthPOlbWVMUD4zM4XDrzdVv/
ekUon8NBKbyZmS0axhdw4FFY8dvpswKUL+LQ3fc1pmApjC/hoK+XOrHDEcaX
cXj7x2TJ9DPyUL6Cg3HbvOIyHhhfyWENw1fLqXFyUL6Kw3m9gCOey2WhfDWH
WUFzdyTflIHyNRz+lWccswiA8bUcDmw+8zp/rjSUr+Mg6ZufekgQxtdzWB56
fYtprhSUb+DAmtuQ9++lJJRv6LBi1a4OLkUY38jh4OlFNgltElC+scOa67IP
li8Rh/JNHHbKROaeUIXxTR10ti4O/bNbDMo3czjs8Xme4h5RKN/cYVeBzvdg
JhjfwqF23uU9Yg+FoXxLh5ikR491XsD4Vg4nK11sUtRgfGsHt70vsxwuCkL5
Ng66ghofZ10UgPJtHUo1p0yetAnGt3Oo1Dz+M9Ufxrd3WC+9Zvslb34o38HB
OeSPGasbH4Tf4OCQfWLHvss7uaHyjg5R2hM9zlVA+Q2ODvL/zp62+MAFlXdy
MO59+93xACdU3glNv7PDT51JNctzYPLODst3Xxc7JcMKlXdB5Te4OAT2GGqz
tLJA5V0dfMzrtz/WY4bKuzpwM6+tejWZESrvhibv5vDe8tc/J71v9hB5d6j6
jxB+gztU/hlU3gNN3gNqLgMDAKh6yNg=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU3EYx/GTGFlqTZ3zulLJXDo1rbzM20/ndDovS+qF4QtbjdIII0x9
VWsT1Bep0UVKTcKIeUEpMrBVhlJikZCVbwoqkiKwtgzNxEtFz/Ni58Dh8OF7
zv/C/4QaqkqMLoIgqP/e/558yQ4M2W4fD8N/OTL6rA5No4QtoGJw5UawLZTs
BsvStdEHxWwJumIGq5YXQshSfKs523yxje0PRULG24ICdjDer2Zbzo1sI4eg
Jrmn1d+NHYaP6+Orp3Rbydtx57Bfh65BTt6BzqEfV0fmgskK2BcNoRNydiRc
m1oqexuDyEpctyt7pPOB5BiM661TZ9LZu6C250eYLQHkOBjD49alP/cnx6Pb
petKuIq9G82/yrUn3viR92BUZ418WcbeC8OjD3Ord2XkBFw2pXV7ZbETYakf
e9f22JechIoj83WxEexk1LtOPHNrk5JViP4SZNrkyk7BTOVO1UqDDzkVtb7t
QsstdhoGcu0ltR7sdETJZQFHD3mTMyBRxgVNrnmRgdfGhY2KYbIJMM8Yzs/0
c8+ELfBS57BdQj0TeT0DveEdW6hn4Z6jNTbwxWbqWXg4rvqu+ORBXY1pz8Zj
v4s8qavhEhK55N7HPdv5fVM2ivqbNcYhel/QiMbXwJo59uRpAPccHIy6oJ2s
c6ee4zyfkIubE9017tX8fS6i02L2j3zmrhWNrxXtL895PaY8rAn71sqrueeL
er5ofzrR/Dp4nopPeWXm+QvgNSuVOWTcRRYKcdqmT01a5F4ID5/R2pNfef4i
5/WYRBaK8XP1fql5A59fsWh/esj7lqfLEum8oRf9D3rM+pQaF5q88QehqAjB

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQNioVt3b8xWcoDwPtiXnf94/ZEwjM/g0P9dhWXu
aUUon8NhwccfGq7lML6AQ3a7Zd0vRRhfxGGB6Y9ehb0KUL6Eg7TjnziHXBhf
xoH3ynKtYAkYX8Ghh2GVwYkWeShfyYFLY4o1xxU5KF/Fod3v/r/9bDC+mgMn
96aebEdZKF/DwXlL/Llj62WgfC2Hew8k2vyVYHwdB9vDp22OZ0pD+XoOczkS
Ki/dkILyDRyyfj1O/RcM4xs6LIt4mWFuLwnlGzk05bztXn5dAso3dnjwUy60
yQDGN3FYc132wfIl4lC+qcPnX8eO3rklBuWbOaRnP3M+wAvjmzv8LlxQ75sh
CuVbOPxZzKL4/IIIlG/poPOhb932fmEo38qBLZRx84fDQlC+tUN371LVtcww
eRsHbua1Va8mC0L5tg724V9i/KRhfDsH3hyh1x2FAlC+vcOSk4vLuEv4oHwH
hxynCXv5FkL5DQ4OpbsDbCx+wOQdUfkNjg6eK9etUp3DD5V3clD2mnYtagUX
VN7J4b3lr39OemxQeWcHH/P67Y/1mKHyzg6BPYbaLK0sUHkXB3kPX0uxVaxQ
eReH8CijdUVK/+0h8q4Oxr1vvzse+GkPAKj7qDE=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtI01EcxvF/XjBTTFuat9ncbK1ppWl5d8+czjmdM7uprYJCilQyTLoh
LTNoUOCgC/hCloQM9qJSg4UmurxEorWGEhGkFMQ0w0CdhUqFv/NiO3A4fM6X
c4k9faGsyovjOPyb/1c2wo686HleLcS65mXlCnWTIoiZQ6rp3bOpzljyRhRg
yFF3mDkY4+beuKMc81ZoXo1217YJyOHwW0nIXMxhjoaxdabrfNt2sgDvl1ym
xO8xZCHaZYMr5eeY45A/V9upfc0ni+E6k9EiEjBLoFLy3nY/iSZL4ccXjxlW
o8gJuPjgafvsIeY9qJkyasW2SHIivPxvpRkkzEkw+faXjVyLIO/DhpYPa86b
4eRkTByfTneubSOnwFZkltp1zPvhe4kff8MaRj6ARx2PzcIY5lRYQn6Gi7tC
yWkYEDVLOCFzOk7eUTqzB3nkDFScsqkqy5kz8YNXUbVk2ELOQp9ux0BMAHM2
dodIfrXag8k5SB/vMQ1PMcsQKz9raFhjBmTHFnQlUSHr1gOzn3c2721iXY6r
u0Z+V2nJejk6ROpPKTbWc8G3rEzqUtn5XGiUw0PfsllXoLRGOroYwc4rEMiz
Xa5zbqaeh4ae0qy05SDqefASSP8EWAKp5yP53pxL3u9PPR+V8UbV+JUA6krM
d9lXG0NZV8JunVj4uMx6gbv1Be73cSqI1A8nK82bqKswFjk/cz+YzBWipdnb
+uUE64UeXe3+H70a1W+sfY6X7P0ij17k8b9ij/uLYfxafz3X5Uddg4N3k+J9
bvtQ16CxzdEbNu1NvcSjl6DekinrbOeoa92t19I+x/0FU8L++g==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1Ik1Ecx/HHtWyxSa7c1GY6x4y5zQdfMnNT95s5dU60ohCsCxsMxBWG
elHKckOKghmIXVgURYXZVpPN3qQow7qSQruwuumiYHVjGdS04UvF/uei54HD
w4fvOX84cHKdnQdcIo7jTH/Xvz/7lIcePAm7NUho0XK0W5UUTWbmIG3b6NNG
cskSiPkPk8NNzKn4ds8znL6kJqdBOVRlnL3GnIFAdN4ybmXOgvyp89bHmRyy
GpFzxv4mM7MGr+z8u4HBbLIWtoXjkebpHeSdiIk+8RWvs8g6WFW+sk0OZj0u
LK+PZZ9WkY3YdnPqUvjldjIPv6JQe4JnLkTjY9jyRzLJRbBJNqz8DGeQi6E0
qbtknnRyCc4OuU19Ocy7YHN9nvCPKMmlOB+fDWSuKsi74WzKH1uTMZfB3NE1
0nY/jbwHvacMX+bzmMtxZKCk9f3XrWQTetpvP2tWMpvR0bP8MKmFuQKuq6Oi
vutyciUK5Lofl+dSyVUoqOQPPo+mkC0YV9199NaxhQzsO6af+ZVJ+71AS2tx
qEvDuhX2O6FA3hWy14pghaZdN8169f/zvdWIpUz6Vkpl1Pei1TBU/+aklLrA
XI2g12BxYm7Vo9hM3Ybe/vgLdyCZug37/UUG8Rkx9VpBr0U41HmRPyyhXofE
+xZRr6P7rVsSvR4itT4uDa4k7K0XdDtKBheWrFO/qQvMNaA7aLZEbnA0v0Fw
3iGY7xCcb8T38vhaNR+jzhy1/AE7/OQt
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQNioVt3b8xWcoDwPtiv41r7PYkPxmdwyH81JWLl
VkUon8Ph3GQHnnkhML6Aw413zskJjDC+iIP5W8HbhQsVoHwJhycpyyyVnWB8
GYdTPBO3Zq+Vh/IVHF7JTHbad0cOyldyePC1YsZ9HxhfxSFj5hR2oyWyUL6a
w6wV9nwrhWB8DYdDrQ691/NkoHwth08/8vpPbpCG8nUcatXidt/khvH1HOqe
rPQUU5GC8g0cVpbesp/dLwnlGzqcsXviFnRWAso3ctjEsKihWwDGN3ZIiAz7
OT1bHMo3cXgXe3B74jExKN/UwUptw401vTC+mQPnvymc1mYwvrnDzL55WYfK
RKF8CwezN8/urmGH8S0d+gpKV0UHi0D5Vg6R8Yc8oiKEoXxrhx/eTzkafYSg
fBuH1LnLmKoXCEL5tg7LlL1umRwSgPLtHHiED5UXvOSH8u0dBN+IiH0Q44Py
HRwu7rj65cYPbgi/wcHhG+/Oxj+mPFB5Rwf5f2dPW3zggso7OmSf2LHv8k6o
egYnB53NLGxmfexQeSeH5buvi52SYYXKO6PyG5wdildb229axACVd3HgZl5b
9WryR3uIvIvDe8tf/5z0vkH4DK5o8q5Q+WdQeTdU9Q1uqOoZ3NH0u6Pp90CT
R/ABFAnQng==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tIU1EcB/CrPWat6TRdvspHT800NR85ze/UzKmtuS1Ms5CyklR8NIuo
8KZRghmRlmDRyyyzF2Vaatoilz1YVJKE9EAKiyxZ7ylKD/qdP7YLl8uH7/n9
OOfcc7zW5as2WHMcp/n7/vuyR7Kyuf1qjjf+yxhtEOj72xyYOaiGMsurdF5k
G7h6jckGNzKL4eHfPDFPzOyIWrn4UH6LJ9kZspnSdxoVszuelDsncwJmT3T3
rR+rjPQgeyMh4WOnzf4Z5Fnou9l0fbRxOnkOhDNs93ITmOfhx0hWrc9Od7Iv
HnZGtHV1uZH9UJCmf66bw+yPMOnKO/NPuJIXIkPYueroVOZADPfkC+K2uZCD
IG/Pn/bNijkYLm452TV5zuRFGOvyqLjeN40cguwdrzeetmYOxaacgVidSEIO
Q/3hLfatcCKHI/TTwKuLAubFEO8rzHpz2pEcATUX/viqPbMU732+bg9UTiVH
oqKyfvalccxRCIyvbU00OJCXoKZ/v9XrL8zRKPaprjp0TUwGBl/O3RNQSuYB
Za7vox8uLJdBlOswWF7IchmuuF288SzJjvIYtBgPBrgabCmPQXG7MjLcROZi
zfvxsfjNpfzO1LL6OKSmB10u8ibzceb9uKXIjTnYYXuK9V+KBVH+mtsDIsrj
Yf/JUWKUsDweHd0RQ/PeTqF8GX6KWnePhpD5ZRZ5Ahpkd/X3XKgfn2A+npND
VBQk7SlluRzy85cbZx9j80+02L9EpNVeOuXkx/YvCb2i8uxhBatPwszEI73p
DZMpT0Zw5edfMt0kyi3MLYfB1fixWkzj+eXwaxo/MfSAgHIF7uujtmnbbChX
wNj0dGyXE6tfgaO9wuGzIULKV5jPh1Oarx9K6L/ZqdML2X4pYe3pOyK8QNYp
zfebS8GZB3VbhVoyUszXz1tYl4Lo1O8ZCjd7qldhcp1pbbyeDBU2a00tVql0
XnnV3/+1742phKyzMKdGcljJjbf+dP6hxqOW5vNFBWRejYyy4PQXH1i92uL+
aLDreM8tST+r1+BAQXHjajXdN14DZcBJb60zWafBwjVl5zoaHPEH0MRPMg==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/FphZIks2yZ12bO1EY6NfO2/Dl1XucuFamFrlkpCWapkKto
2tUoLHXom6UhatDVW7eFqWklUUaCbwotXU0JMrWLWGlFz/9FO3A4fPie59ye
5/A1+1V7rDkcTvKf/e+RNt62DmNLnif+6XOUfb+Af92OzEFvVpeN7VU+sy0q
JD9EoalkLpYtjPbMflrD7AgXp7Hxi5VkJzzhBogNYWRX1D7f0Zw/6MG8Bsc0
6poBLtkTB6zk71/nujN7Yat/uHrc7MbsjZGQqP23tpN9EOeV53Ck3ZXZD90z
lwvdvMhCfOOVLco97sK8AQMTo5O3F5MD0KptNIirnJlFEEmaBI31q5kDIXdV
3w12IwfB6sKr+YlSJ+ZglOvjl3i8XMW8Ee69w7OvZOQQCDsatv008pg34crr
R3rD0ErmUIyVLvcpyCaHIWLfwVp1uyNzOHL01kXLgsgR6C+JjdztvYI5Eo3h
QU+bDcuZxeAKRS4vFhyYN2OPocn6cD05CoUtN8sVWjJQMDTTs4vPxuuAqO1f
dqa6UI9GZGDKaXs1sy7aokvwwd8zKN+XugQf36w74V/GZT0GYS+M9Y/fMuti
UOxbXVXZSj0WMunjPpOYeixm5u+nl9lQj4PRudpwb5J63P/Pw5FiacNsprSP
7i8FPzqnvHiexsdbPF+8xfdIQFFuc6ecR++fgDKT5rzpGvVEdO4UdLvbUU+0
+N5JiBObjgzMUbcwJxnpWT0JGWlsvnTJ8PWyMX2Pp/lLgdl3ukSkoJ5i0WXQ
C36lc+qoy5CXZqPMrqGeiuS2qSTlJuqp/1+PI0fLtHOdNpe6HG0FhTMZh6gr
kHlGOiHuZYYCRy8NPuC9o/MV0JasNw8J2PrrUqDBdFITs5fWoxJpCRXc0YfM
UOKG26Cnn5lZp0Tk1+7hc5lsfXcp8Wxu/OypRlrvKsQK7IUjDuz/gAp6nbjB
QcKsU2HqjmrL2s08/AYGoyTb
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlWlMVFcUx28Ap1Q6gBYGpGwibQhQVOiAQOn8AR1ZHGAYmGEGiEbbtAZb
q7TRQkkfdKFJgYilmkiwqTEVGSLFdQC1rzWDRuNCiGDiB9tCalK3iRARoqQa
zv1w70teXn75n+2ec27e8s3bSz/wYoxtffG+/PJHV35qqL8mBgvkMQz+8HRx
rD9nhm21++/W9S8n9kXK14Ot1Rs5B+Li+/npOzScg/DAZpj+whVNHIobfzX7
WKo4hyOk96fx9gDO0VgZFjkV0RJFHIM+VLfV3YkkjkVo89l7KzWc38IvVX0N
iyojiOOgd4a8be8PJ46H7cPDp51X3iBOhHVc1UQEcU5C4ybjmf2fhBGvwv3O
iS0DJ5cRr8bjriSjS8s5GU0Tv+9sLA4lTsGfhd3xI1UhxO/g6M///pZQrSPW
I+a47wG3iXMqRnqvT8V+HEychrZPP++ptAQRr4Hj8e3UN5+/TpyOLuVmXcAx
zhn4pzNVf/vHpcSZaJrc3DrZu4T4XUQ4n41VpXHOwlBYR9fAo0Di9yQ2wGQc
dk9mcQa6sy+4h5dpF1gBRlw3p2899SM9G1HzV6+s8SwmPRuOhPa8a7u5noPZ
xL1fHtn2Kuk5kp6LPd94u+5Uc/9ceE6MPG8IJnu2VmRlLR6lz83nJGlIXwdz
y+oEn299SF+H79prMuqjXiHdiEvurF2fDfqSbpT09SIr63E1zPNfRyDVw/KQ
0vpgJlvl+SVm+VJ9+YjKM6XrehaRXoAjQ+O6y+HESoFYLyuU6i9E+0Rtfc4M
r28DEk/4aFLbeH0bUPfV3B81Pfz8JjQcHD2r+9ubdJOUv0jKXyT1rxj9x7Z3
JFXy/hTDPRVgcex4jfQSdI75zf6qp3mhROpHiTg/tUScNzOL/YQZXtHxc35O
iq+YUXPJdX50gOKrZjEfK5Xyl0r7UirGVyV7ZhHtYRHtFYu4v6oFT7QDjc/0
/Pxl4r6jTNxfRWK1TDwPK8e5ixkP4yYoHsrF+Eo5tDuTM0eb6H6pkj2zivcP
VtFesWJM+/1Hs0Xc34ol94N0Hp0/+duwomDfmKObn98m7pdik+Znk+5fhdS/
Cmn+FeL9USvEfWN2kWHHwv/Ei/ztqHVmGo4fYuRvp/18Yljwd1Acxv4H0Mu1
xg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03lIk3Ecx/FHN+eVR6TzyHJeZWneebt9Nu95S6UZJhTrH6Mir/DAkRZU
TjyCqDQqw5XWwMRqMzssIQuFLiLBwoQgITcynJrZwb6/P/SBh4cX7+f5/X7P
8+PxOnA0X2HOcVziv/P/lR3C3QODfaXeMMkg8bqwQ/zLgZnD5SMdvNFHXmQr
hDfoVMUlzI6o/Dg652zH7ARBsqJXpRWRXbFNPxEgOsTsgdhXF40HjZ5kER77
F36bcmP2hnhZUNtZspnsi6jQyX123ZvIW/DlzLEhFY/ZH10jTrNd0R7k7VhS
jl+NLdhIDoTvrM1CqNadHITgPRE+P366kUMgNwj7GhXMoRAL/W4vPXclhyFD
fbbQ1p45HE06/cT+cy7kCAxc6pY2OzDvxNZPedcqLITkSJRrh0XP5M7kKIQU
N6iHbjqRo+FbZdYeqd9AjkGn8n21g4Y5FppUfX7VOuY4vJG08V0m15Pj8U4x
b+2vZU6ALe9O9Uw7sxjdPvKJiGFHsgTptzQ9fh0OZGBuRbf3pCV1JVAxmBsf
vWBPXYobo12VtuVkpRT3DC3B7mOsy5C4aznSIoV1GYoCWtPGT9hST0S46rtR
+sSaeiL0MUsrsiAB9aTVViZBPfhB+NLDgnoy8ppCA/in+NST1/SUNc+noO7K
24fCKR711NX3K1PROl1WIzNaUk/DmLth5ryjDfU0BPbzBZHNrKdjMbCtVn2Y
rT8dhv7Xv+ucyZwcL0YSqsp1VtTlq8fjMtDSyHvwuZiNn7F6PC4T1fVLT0t7
2Pozcbq1NLbGk82ftWb9WciMqr8/HcTeLxum/9ecejbtvxn1HJT1xknuXueo
56CgKExz3PuPxNRz6fvNm4xc2q9Fk5Wsf5X8BRdNDko=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0l1I01EYx/HDWuzfFmK6qamp0xamazRf5sta++3V0BuLis2KoOiFjRqV
JLGCf150YYkIpdkuIiUbkYbgQI2GxBpC9GJRRBcTEja7iGxI1lhRsedceOBw
+PA951w96mO+fSckjDH9v/3/5CvvQOjJhLccGS2bI0KgCkpuhmVNYcmZsJos
wMzOXVx0c2fDNBActKbLyErkHTQazw9zF+DU2ZXUbQd3MZY2Xkm9iJaSy1AT
UnsaZdzl2BAa+Xyjs4S8FfaG12GfwL0NsYc5j3patpArYZs8+ir6uJhchfj3
oaW38SKyFtLqoF5YKCTrcFgRdgVyuXfCk+4ORa5uJutxOToekycLyDU40qcd
ivm4a9H2oMelyOKugyq/vvpldz65Hqf9sZPDEm4DDMmOyrYFFbkB6RGpOvFG
SW7EjkSRKJdyN6FLFWB9o7nkZnhdsr3HB7mNuKX57WZ3uXchsT15Sd/ObcL1
3vuasXXcuxFpnw2IMzlkM5xPv3gwv4kMjFa0fqp7lp2xCLjvjN1TacnMAtv+
tGG9M4u6BfNT71c+/lRQt8I7NxV+N00WrahoHfjQEZRTt621aMO1fm+zv1RG
3Y6556auzhmBuh0T476bukNk5lh7X3Sgf/GC37rK3zuRmV8JdSdqe7+uWmZ/
mTO9Bd+aUn+suh8Zi9xx6nvoH8b+ApXRvLQ=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlntMlXUYx9+AhCISEg4XSQ5EDRHPAgLhAPEcRO6Xw/12gPccOJdERopX
qHzXZuRKCmOtRbkzcoKoNEpCpMvbBRNJHWOCbbqdBrOllZCVwBKq8bx/PA/b
Gfvs+1x+v+f5/X7vE2xqKjQ7CYIw9t/v///Kn6pkcGSgIQRWaS7ZWb5x09tZ
YQE6Z8IOxfYEI7tBt//E7Eqmwp6QotJqe+fVyN6Qf8VReKFLYT8YWC++lVeg
cCAYpt2i7zgprIbr1W5judYg5BBIvfP2x0eGNiCHwjH/FR9bsMLPwJTH67bF
vCeRw+DwYKLv9jOByOHQmOa17uzYeuQI+KHlkrHbV2EN9JRMn41pDEB+FhYn
m1xT9/kjR8LV+oycupN+yFGwd2DD0ZKbvsjR8E12b/iEQeHnoCPdV9MyrUKO
gdCdEz8u+igcCxOnr94LbfRB3gIGtwDpvXhv5DiY3b5R+6BtHXI8DL14okLj
o7AWvtPLXdL5J5ATIFXa/yCyzQs5Ed6IMt/oEj2RkyDzZH/f0x+sRX4ePHZF
JUy+6oGcDMfHPtrrvvtxZIBe3bejF/xRlwCeynp3qrL3UdR1cHE0ad/u826o
68BJHb7kfuox1FOgclNHxpX97qinMP+tsDlJU/zVLSX+Vuyfsp5UGL23tqhy
J8aTGAvb4Ivvtb+HzSg6YyGN+adB0PLl8bg5JX86RB/57b5OfgT1dOiYaW5N
ue+KegbTM2Cgv6lTU4X7FTIh4lOXNbHtaC9lwmsdDdrWIMU/C+7GLy2naNag
nsX0bCh4M3KTyyEX1LOh+VRC8ifdAuo58PKxyc9VPzmjngNllVH9u0JWklf1
XHB3PtNy+52HUM+F1fvqhP55uP7FVXuJsZBP40n5LL+exgc9s9fT9cl6yNly
cGhGgywUUHsooLpUAEEZufGqvofRn+lCId0PFLL8jOVC5l9EGYpYvYug5eDS
1w192B+5iPWnmK4Pilk/i6FnZFp1KVBZfzHLX0LzAWOphNZXLmH9KaUMpbQ/
UinzZ/ZCGd7Hf9C/jJ0nxjJjoZzVv5zVn7FczvJXsP4zlipw/fPoX4H1vYX+
lZSBscRYZixUsfpVsfoxlqvQ/2/0N9D1gYHqkoHV38DuZzXbfzXth1TN/Kvp
+RBq6PmCGnZ+atj5rWHnt5a+X1DL3uNa+t7KtTBx7tqf1xdQF0Sqq0XIO92+
zTyIDCLuD78nIrOXROiacl88EYPx7CI0XDz35eQwsizS74tDpOsTjPR7oTbC
5YC5252eyGCk8URmLxnp/u1GWIw4+lLPDmSZxXMwXTBRVpvoew8m+j6IJvY+
mGi/7IxlE+2/w8TuXx2Np65j56GO5WcsMX97HT0fMrN3MF2op6yuZ/uvZ/mZ
vVRP12uvZ+8NYweLJ5gpq83sPTfT90k003wSs7ebWf3NrP5m9v230HhqxmCh
9RUtbB6ysPNnofORbKHn3WGh90Ww0vlFbQWvX71Vcyqcz8BK749oZfOQleaz
W2HPiD4xbgH9ZSvod4SP/+WP86HDCpu9wubfn1DmRRsE66yH9ywjq20wEtD5
4fBdZLDBwnHXV2Z1OH+KNjqPSjb4eeMfByL1OK/abdgPZNkGG4abP2sbR3bY
YGCh/Rc/UObfF6D12gEPQfSGfwFdP08N
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtMk2cUB/BXLiJ0ZQ6hWkvlMucmZUzucnH8KVAqN9vS0narxpGxS8o2
QVmihPFKJsFFiWQzGg0qNRRnUTOJA0TJqxuGbd9KUjc/aDbcTUPEzMll3diW
nudDnyZN88v/nPPkzenzJtV/YGoIEQTh7f++//+yj8JyZewLZzICmi26bte8
/2U4s4DJSG+Fz51EXoGBZUkdU3rmlfBf9jmaHieSY9HWlHDGepx5DWZcOcpj
WuZ4ZHuUsw9/TiAnQl+ldh19hTkZfe/uV58sX0deD+eT+c+fuNTkDejp/+PB
9mjmlzA4K3XXvx5PToGqueFup1dFTkXvip17vd+vJadh6KPwiTYN8yaM3Poh
KWuXkpyOPXn5Xav615AzUDnwiU0WzZyJZuV7t2faV5Oz0P1he0fhXQU5m3MO
MlaffsPRyZyLUy3n7mxKZt6MkOOn/9KLceQ8zvk4e/9AfclbseQCzoXY0aX7
fcvXq8hbsHF9xP25cuZXcXgoUjN+L4ZchPSrqhd/amEGos7O79BNPBewCIyt
/ax39NFKyovhiHCdUJWxvBhqj9/nyCULWrifr7iTdZPqRS3sJy70xaWy/hI0
ao9cj+6LprwET+Wj+/3Zz1Bein3tizec55dTXorOHmd+a0IE5WVI0FfnKc6H
U14G46F0TdiBMMp1XL8uuF4oR9upqWuKH0MpL+dyPXqmd7dq5+g8UY9HeYv/
aNNonrAVstAL+x58uozyrcg8PDNXLC0UBfIKqv8lYJH5KeWVCElMWZR5/JRX
YrenoOiyS6D5VVxeBetrGRebk5eov5rLq7n5NcEWOQvbuP5twc8jGILPg4Gb
Z6D6xwFLXC4Yg58fRq7fGDxf4iyYuPNNGBi7rfg2nu3bFLxvycTtpxapQ2HL
c7ppf6jl/g9cLtXipE+24M6WUb+Z9hlJ/WYc+Th05N72KOo3wzk5Mj41SvWS
GfLmjIKpDjn1W3Cu+KuJW0oyLPDJu95ZqCGLFtQMdpc1XCFLFrSMGQo3z9N9
EOpwSTU47K18lvrrsCQYl3buIYt1KDH7c8J1VC/VwdCY8t2fSna/rJA3xjzs
aiLDipjfpJseE7uvVow7XrixTkb3XbKiodcd0nqG3V8bpq/9LWpyKYcN/fmZ
kwO9ZNGGqtz24ek0ep9INgzvctvT4tj7xY5v9pYWvrmBDDtqfQcPedVk0Y6X
f1WJUWGx+BcQ9qjA
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/GjKJaKTVO3Uue11DTvZV5qv6nzMueWwjJBKVZ7keYlVCSF
ONnUrEllgbSw1ESU1SpBw/aiqeWlyDeWgVhUGimC+cJM0xcVPv83HjgcPnx5
Dofn+R9fTWmO1prjOMm/+/+TLnd1n/lZkR+2tCwxGloKxx3JHDbe+FpOPfVl
3oElq6XzumyyAJMV3VamTR9mVyxURybcN5JFCP/tZjmrJnvigu961vVFb2Yf
vJ51dLsqJfsB+9TzgkYxcwC66qLFCyNezPsx2W0oHbEnB6F9+JMoJNGT+QD0
U7nL35s8mEMxFmGu0L/byxyGlnNCrt2THIFpd9ueCdUe5kiU3S1RjVlEzFGI
O5H6oNGBHI3iTo1dfYmQOQZfQ7RDDqHkQwjte6jeNLszH0bg5+z2SltyLK7o
hmdaLG7MRzDorwvi/MhxOJl+Q/DtpStzPNLl+unePHICakdzC/4oyIkwpf3M
qXLczXwUr45b7vEvXJiPbbMEa512l+akZOC9dnVn0IDzlnmgdk7TNPeImZMi
MUrR4HSauhTa1i7rmjbqSfAybk7lx1JPgsu8ZciYQz0ZlcF3bjf3ClhPxsXg
0XWtiplLQdyEuW3kC/UULM4E6sJrqcuQb9dh8JDR+2UoNyZIejuop6LLXz4d
M0TrU7d9fxqClf6usmJan4bxqYCVDUfq6Vi9ZhIWrFBPx9b/QPuTgcKKtX6r
XGY+A8/LuvLC3Gi/5WjlP1TvMjHzcogHyvsb3lLPxMEfHry9DTsvPhPZ+sgQ
mzo6PwV6n9SLRTPUFZi97BJUdobmIQvON5WcNIrND5+FwtgSJ15N86QENP0f
m6uoK2HoGUz+9Zi6CvW3iuJrvIX4C7G/9R4=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw1yVsog3EYBvCvldOUjBnDsLWcY85nng85JCWHEm6ccygkpUQmxAVNuSOa
ERdKm75cuJniyuFGUlxQvkTIymnEHPL+n3p7+r2PuqGrvFnCcZz29/6aRVEl
bJs7NPiXLad9VLKgkzNzeK54PZ7cVJNdYbwJyrdWM3vCPJ4c5f8eQpbjwF72
bTYx+6EuLN4wUMocCJPbzvXtRTA5BIbKko2nImYNeoyCtsoSRNYiVpxvK/Bh
DoWxbmPQqVZFDoddFCrmTgLJkbCkyFTnzszRaLKL84alAHIMlB3FEsO9P1mH
6YzZCL2UOQ7tnyPCrl5JjseKZc80cexHTgAuhmplBcyJWD9VXa4u+5KTsGWV
Fi7eKcjJWOhbO9NpmFNwpfcK7270IafCJI415LXIyWl4r+/90gve5HTYl12G
RN6LnAE13zrZ5/AkZ6KsM3L/RcmcBdm9XGFTeJCzURM1U3TU707OQbDjcD/V
JiUDCVMPb7zV7d/DwMxV70DumwvtPB7TPhy5Mc608/TnuB81T4u4
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzWtIU2Ecx/HTalnmTM1OS82piYbocGrTeTs/N51zOi+hFd0IyRAmCOoI
WtZBu/jCQC0orNRMWpgkdhnJtEhJrLA3I4ug6GK9kEpfmDm1rPD/vHAHDocP
3+f8ntDSyl1lEo7jhH/v/y97+JIHjj5zGJY1LVjevfpU4cfMoaaka1I1EEpe
hyGzOgZFzD5oV/ZWLs6GkP3Rlt4rlTYzy2HKHS6M1DAH4WdO1G7XqIIcgoJ7
X+RlP4LJYZDXnlmtEJjD4Wprz9y/dxs5At+rfl/ysgeRd6C+dk2oxJc5CpEd
PW/s6YHkaFxrudJxuiGArMSRYbuqUcYcC92UMbKufitZhWHb/auJrXJyHGri
R9IsY1vI8Si3vj/aKWFOgKOxyWbt48k7IVqEmeQIZjUkl9sXDOJmciJiD9bb
Bm/5k5NQ2+Yc4D9uImsQfmzVBfUUczKC+6vt514wp0Clb+03jvmRUzHX5XFy
IoM5DQc8OlsDs3zJ6bi53fg2YciHLKBuovT8RA/rgOeNuUP6p2QR0Lx0dIx8
YOcz8Gw8fGbBi/UMtz0tlriipcM1G6lrEZOmLH78VUZdB1lVXIqzjizqUKFt
GvS+7k090+3/TLeeBd9v/vw0TxazYHEUpibNsa7HuKyh3JXP9vXQFS+qpXrW
s2EeffjI2b+BejZc0S0nbBXrqRtw/NT8E3P3WuoGnG02J1sVHtRzMKWZ/6NV
sp4Dm+M1/zxISt240qJx5Xku120/F82fq63aX2w/D2MB05MXfTyp50FhMGn4
brZvQvXtFOFuJ0fdhD374u5UhS0Jyz2f7ptdtuhmroB2OO4v+aX4jg==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0V1Ik1EYwPE3N1dtTGbZm7Olc9SSKUtdW2ra+2xtc7pc0zDRkj53Ea6s
KKht4UiMLb9YShFR0UWTlkYz7INVZkWUsggCRQjCC71YuCzS2Iis8DkXew8c
Dj/+58CBJ/tQc40tiaKosn/7/0kWXTsUCjbJYElzTP0upuFwKjEFe9U1myaD
2egV0CsZjnrriUWgdYn9+YtSdBrktCrjFj9xOmxW2nweLbEEZunbF6zhLLQU
BB8GRTVKYhlUu5h3zuZM9AZgfKHM/YH1aDloHNPyFD5xDox1nxG3HJCgFTDF
vXQ1PLgOnQeOZY+mr1mJlfDlqNNVdDYDnQ/DQXMHf1SMLoAfN5TGJ0LiQqjj
/fy8R52OVsGV7uMnAm1r0Vvgoq+pxJlFrIZo48jjg29ptAb2Ubtpq494K9y9
NfMgt5G4CGonk70e5xp0MZx++kr6upK4BD72P/e2jqeht4EpMvEipZ24FKLH
3syrFlajy+D9OX3pETnxdmjvvLNxgEPMgIAz4Ij0pKIBhPZVXz0nRUt2A1jt
irF5MZrSgqW/y2AbEmLXwvVxQcyvFmDXJdqtg1jeZVeffSX2HVDdUZDLbeNi
Z5nSg6MlPtIU4GHXQ95DLk/TtRy7AcIZc5FeER+7gdWN8K04/kenJO+NOA/S
y6EvNEGPSpKxl8P5m5+e0VMc7CZWN0FdQ+H9U7JFZqlXJNpdAarO2V/alzHs
lYl2s0yZIUmqiAvu/cZuZvWd+P8F7CxTVTiv79irWP+z4P0Z5i8J3vQI
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0kFIk2Ecx/F3K2zhyLnNtZa5aTHExlhzmlvZfltubtMKgilWklmGtkCT
IFxSO3mobKZRRIeo0MKatIOJ2MA2g6Q6BB4kJGxCtDJSiZbDtGL/57A98PLw
4Qs/nsOb39h6uInPcVzZv+//zY7MPTwW9BQgqQWzd9Xc8y2LmYN3zj+bN5JP
FkBS+bb1xCFmEU7Nrk20/FGRpRj0GXQ9/cxyjPY+HmuvZs6F6c2d+Mm4kqxC
aKXl3bSOuQBd4tO3eOfyyDtQbwvs5D3fRlZDMPlCPcVnLoT0dUfNpYO55CJ0
1q8XRq5sJWsg9Jd7QlEFWYtXwxvmAw3MOkSqpcfdD7aQd2HpYd24Us+sh7/D
MlA4KScXozbj50xNCbMBXTc8povKzeQSmNTPpp92y8iliN6fcosUzLuhdBww
ygZzyGU4PxpWRVzMRpT2TTQ7xcwmBH9fj8khJe/BscbonOaLhLwXwSXFPW8z
czlG2gbqtDnM+3D70zXex0Ux2Qx7KHYG77PJwMB21wdDWJS0D7iqb5q520Dm
LBBKwhfaYlnULciel8oWZJuoWxEcar2pPSqgbsWyprfz0dmN1PfDeznx0jOY
QT3NXAWS/x+fegVqj+iH2gvWzMluww9jYtWq/ZW0z4bMdQHv175F6nYUd3+P
W8aXqdvBVxUlMp+sUK9M65Wpe5yD3kHH50jbd6ba50zd41xp+660/aq0/Srq
n81/Af4f4vw=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0FtIk2Ecx/HXTagUcqmbzrR0aYxmy5k5bW37+Wpz0xlkhEtapHQQbIQb
1GrkFqkdUJh1IcToYncxExxk0oEsOlHMrC7CG0UWw6KV65yBHfD/BL4PvLx8
+PJ//vAUtB5tPCjiOE739/v3Z0e2+/qt4XYFFjVn1Ij0n9okzBxCXl6rDhWQ
lyPpQWfimJlZgoWJPXsPxPLJmbgXcTyLdTNnwze665zPwJwLkyTQE3iylpwP
2XB54KKUWQFPkXudy7GGXIimsLLVFs4jr8fIiSCgYFbiq+FuxpApl7wBh/P6
nBP21eRiyNstIv/7HLIaohVnKs4rmUvQZWjZmHZVTtYg/jxxRF/CXIq3toj7
gzubvBn9UZeH/55FLoNT7ngd9zJvQZtn6lBQxFyOwo4Xkz+lMrIWFzr3ZQ1+
kZIr0BMZkNuKmStR9rLveNHNTPJWjKn4+KCTWYfLO07PR1OYt2G8xZb4PJlB
1mNgpjdpKpFONuDO47PTP7zMRuzvsP96OruKDKTPjt0PNZJ9QIPp0cM3egn1
KjQ1lw45FWnUqzAy59+UE1lJnUezqt887k6lzsPfJR6dtqdQr6b3Wka9Gjt7
Nark7mTqNTh15dVt2YyYeg2sWu+NqJrMbaf9v42LXWDOBFdIZwwHOZo3CXot
PlbOL/DqbzRfi1TxtZPvLiWom2kPHZ/AnEXQLXRfjObrltpXJ7i/fql99YJ5
q2DeKtjf8L//ATC55ek=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H9MjHEcB/BDFIXDdaWT6pwf/RCV6sTp7a6ulOruOmOWXxnimEl1K5bH
/GxrQ2eSH2vRxKpLpiHSobiKMa3+YJhzCtP6saZ20rC+nz/unu3Zs9feez/f
7/P9Ps/jl75fs2M8j8fT/jv/X+kQrqt7WKsTY0x90c9MVj7fk8wDf1Jbjq7B
j9kF7gNLBj9sI/Mx2HT3fu8fX2YB5nl3Ny+8RfbELJfum5Z48hyYk8zZkV99
mH1huhI+SeJOFmPUVpko3T6XWYK2FSVD1Y+8mRcg5UJd10sBeREsr5sby/fM
YQ6Al9OuS0+qRcxB8Bl91Sbt82IOxtHcHr2fiLwUv8PCjB67ZzOHYMu+2tKL
HZ7MofBr6T8l9SeHwSX/jKh1iwfzMpw8p4s65EMOx63SrtuBm4TMERjNHJo/
udmdORKFHm+Kfh0gS2H0bhcHdAuYl+O4U0urSzE5CqZAeU9VJnkF0s3i+jBu
FvNKNKlMl7n6mcwyDJc751tXk1fhYG1NgSpvBnM0Wjolg7/dyECS8nmzVcYf
MwfM+CkQ9gmnsXw1FNqRiIlKZs7BPDnWbww1Zoqns1yOvfKzDdPKKFcg+6Fq
pXSY+gqUt1zPcc2iPAbjfQNsrpVuLI+Bznz/cfsDV5bH2puLxWJZsLaxayrL
lQ7jK1Ejqrr3NpGZF+fwfHHI9j9vKLrDzIuHd+VIZ1okWw/Owbw1uDEv4d2y
p9RfA9cJ1Xk/DJQn4G10kZPHB+onoKSxQr8uiNY/ESH1ooWWbGYuEWXlZvcz
nZSvRe2AV2leBttPbi10G5zV24tpf5PszSWh+HPhuI/91E+GMa5Xo3ejPBmx
Muvh1zbKU9DtP5AboqI8BZbLEeHvDZSrkJVR8ThFyAyV/fvDqezna1I5vG9q
+/lAjYYXpz4NH6G+Gv4SZ+tQHBvfpIZhR58hrYL6Goz9f6ivgTx46/nMrTRf
DTafVn6XNVFfg6tcR950I61PKtLSLV+CvjEjFbZhxTV9EPteuFT778eUCol+
nCGil/pa+/tDi0vJR21fplBfi+vWE+mKndTX4k1VQ8GxTgH+AlKdWUg=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzXtIk1EYx/F3atcZmrnltalpl22YZlpzzv226a4GaURkF2wgQsliFFlB
NUaRBGpmg9CMLiDlbqlJ0f5ICLMQTKNJYJSQRKSi0X2Zq9hz/nAHXg4fvs9z
3nTzkYrqCI7j5P++/zc7wl29vq7DGQhpVllTIrEcX8TM4Utf1DNvRzp5Ka7y
zGvrC5lj4bBaphrG08jx6FRcz1eeZU7AobqxnRE5zCmoV1zJtXeJyGlIGm4y
vvOvIWegX2u51DybSs5EumdfcUsh8zrkbqzmidpSyBtwb+C+3jadTBaj1OqY
enuSWYq69qxg+UgSORvyR5xbMZ9IzoHaN3dRd4Y5F49zeCJnDPNmpOZd8IvM
CeQ8yHSv0O1dTd6C3tYOVWMMcz5eO6oqXcNCcgHujD1xtI8KyFuhkfpfRJ5n
3gZJk3ZIPRhPlqH9YdHeFg9zIewDu/cHypjl8OhmKuqiV5GLIEkVJtYcjCMr
YJ8wN0y4VpKLsfz2zwPafmYlno9mfv0dzQzIhnw3no7HhmwDjjrlyu5bZE6F
yTfrz22ys67Cjlrx4LdE1tUw3PV0Zl2Loa7Gnlb3TYGUdQ28ya4HL02saxDk
yoNVx8hcSdh+CZIT3n9svsz2S7GiNm6y3sr+H2ZOu/A9mxYRaeIA3xlNXYdK
SbN+6ASfug6zPSN/TguWUddD2hO1uKBxCXU9+JHuU59aeNQN9N6cMtQNyGuY
/qHq+xUyZ6T5z9SNmJEF5tXZ36mbFs7bTGG9LGw/zNx2mv+g/Av4Be1Q
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlH9M1HUYxz/CQSigEHCKkHdiJpODRAMFhHs45Nfx++CAO3597/CKdpSV
TpjA+LbSuaVOyNK0FdQWTZBGRCgIfKM5yWYb0nBrubDbrFzl9QciDLHaPZ8/
Ps9t391ee3/en8/zPJ/P82y2HzA5vBhj3f99///zn9o8NDrgjAIPufUJv35g
SQngzCBtwvhp+uhmZD94y+/kV19bOAfBd8Nt8VG+nENBc2xwPqJPi7wBckOH
WqeNnCPBp6NgsvSJBlkLU1lPVCNbOEfBjfAW79mXNiE/C85tPx12jT2D/BxI
49dVXY8ikaNhPm0ipD+L83YYuep2xbZHIOsgu1qvPf7hRuQ4YD+++rrz93Dk
HTCxY5Wmdx3neAiPcDacfWUD8k44PLCp03xnPfIuuBvjmPTXcX4BMh2uwRPn
1MgJsPLGwtbV18KQE+Hl/fPNz2/jvBvqbg/VzjSHIu+BIf2Lj1obOSdB7G8R
8hoV52R4b+tjC/s4BDkF+rMfmJoCOO+FW/pO1fo7wcipcKihZ7xI/TRyGvh7
Xzpy/12u6yE2OPqf89NByADv7HT8fEFClgF690Y1RH+7DvV0+CKib/hWHrKc
Dpbzl7rDdNxvgICQyabX/uC6AQr7TmU6hgJRz4Cx68l/R7sCUM+Ah4FX3lxO
QGb7YIvx/Vnr52tQ3wfOqcvjM1f8Uc8Ea0xHzg/NyDJhliWul7NAs3Lz+z1u
3I9lw82N7vtngvj+2eJ5LAcWdZ2tPY2rUc8hei7MBh5vWCzEfORcsR7MSOpj
hIyy5USfrLWo50FsalzZxD3uzyN6Pnhpty/59/L65JP8C2Cg/8CZuCo/1Avg
SPvSN86LvqgXkvwK4fTb3pd/qeHxF0GH62CLYeEp1IuIXizuD8VkfTF45oOX
h5VieJC0tGKI4+eXiAwlMHUttenQCI+3RIxXKQHdoMo38RTuz0zifYGJvBcT
XJj1X/wsAeuhmMA9OP24LQzvi5USf6mYn0xYKYVjHc7kFg0/v0zMF8pI/ISV
MlJ/M2hyCpLUF33Qb4b83e3Drjhv9JvhYG+K/stPGPrNeN/Leo+/HPtzFfrL
iZ/oSjnxV4j7Q4V4X3IF7Dr510K6suhZr5D1rFLcDypFXa6EntHb6huRmJ9S
CW0fzVxV38X4mEWMFyzEbyHxE2ZWkr8VSk7Ex6iOqtBvFc9TrOJ5rEq8DyAs
V4nvRaki86Fa7HcgLFdj/bi/WnwPrIa8vxriJ6zUiO+Z1Yr9C7Xk/deK80ep
hUbD6bG13Xx+1IkMdcRfJ84bpQ6C/wxVu9XcL4nzSSuRfCRxHkkS6S9J7Ocu
ifS7JM6HOYn0n02sp9Ym7gc20S8RXbaJ86uL6IpNnO9zNjI/7OJ6rV1872An
59vF9yiT9V2EFbtYjzniZ/Viv2rrST8QXaon59eL/dZVj/E+xH7nfM/Dc4TZ
foyDsX8Bu22kug==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtMU1ccB/CLIDgriMhDUXnoMChNM1vBWWV8Wywg8mwpLR0kG0njAxZw
uIno5ArbUIzLIGR/DDDRoTWKD4LyUDCXGJRkgYkL6B8aNUXFx4QEUwqZbi7+
zpJ7mjTNJ9/+zrnnd885kYUlRvscQRDs77///bJPsPnKtbailfigyQSf2u+7
nngyC3BMuEoGWyLJ81BU21zdmMbsj0PG0tTHrghyIHYf1r183sS8BGF+Wvdt
NfNyPF24VlN/KpwcgdieAde78TDySqQMnvR2Wpk/RoHhfIxHxwryakTHXLKO
O5eTo6HM/G1q+wLmtXAFV3nuqF5GViJWfU5QXA4lq/DP/B8Kj4czf4KhyHhd
snkpeR2Cdc7i1m+XkNVovbvikaMlhKzB64K+zi9vBpPX4+FLxzeWpiByLK6W
KqdNc5jjEHB+ZOfkwUDyBoR1l3XU/L6Y/CkM8WMH/pgNIG/Erj3uDg8Lsxa9
t2oeuiuZN+GUVjPgaGbejA/vjzkertoLIQVvFpE/g7vF5+CYjuUJqBorPDbW
ynKgrO3ikawKsgisyVgVaPiK5Tou1+FaaENz94Q/5XocVdvvN35BFvUo1v/c
63fCj/JEucVEjPoe3jGT4Uv5Fvh+rd70ZxVZ5CwYMNw18uaeW0G5AatSfxm1
nZlPeRJmlPUHHMUfUZ6EH+uKtPvDfShPhrLdyzvuJ7KYzOUpSNtQ2elUeVKe
grYLJQ2qz+dRvhUD/fF791wli1u5+lTUOcv266fZ+Klc/Taufhs0x/6a1kn0
vEIaJjbOvtOrvClP4+rTYYupSxkqZ+tP5+ozuPVnYDB08kWDP+tPJhpHFTOn
Y1l95vv9pH0d7VxAeRbO6G7031xK/UYWJtuH334XxMbjLGXJ1ytky41srt/Z
8vVI3P8Fo3x8GOX9FY2oqJztKzpL/ZE4CyZufhM3v4mb3yTfT0IO+qcWmmy7
qR/I4fYbl0s58vchmOX7FWYk5vwdNzeJ7Xcz9q25NWPPpPMhmbFFLH+7road
r1zk+5z8dZmBjFz5+RRz5edPykVS7/NdGGb1FtxJqPcKecDqLbieH9UXpqDz
LlrwanGe3XWELFnQWXo6TxXE7h8r8qs1tnvjlMOK9tKyKVs55aIVAYqQnqc9
ZMmKin0xz0aj2H2W9//99i/ujaTk
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQNioVt3b8xWcoDwPtjvuFF8YqoojM/g0LBeydTi
oCKUz+EQV3aA0T4bxhdwOKpwasFdbhhfxMFn2v4zfesUoHwJh52aXJ+9ImB8
GQcul2M/urlgfAUHe0atIydq5aF8JYcDR9d+fbVTDspXcfjwftkhr0+yUL6a
w5SqiZ1OmjC+hkPrbX3N6DIZKF/LwTz0/NqTh6ShfB0H0ciLlYZWML6eg+af
Gvuf+VJQvoHDem05C5cPklC+ocOktxkaddYwvpGDbuPNOO4vElC+scOpuPWf
9pnD+CYOmddU9bgnikP5pg7BM/8/DpCB8c0cuurixNd8EYXyzR2us7Vfl/0k
AuVbOMzdYRM9eR2Mb+kQ9em2mepfYSjfyuFJlqbV33YY39ph+sMexnsfhaB8
G4elVsYnls+F8W0dYtgXzZJ2FYTy7RwUHdM7S/8JQPn2Dp//7YpsYofxHRy+
8e5s/GPKA+E3ODjI/zt72uIDF1Te0eGs1IdXUwSg/AZHB3kPX0uxVaxQeSeH
iY+Lq52+s0Pl0fgMzqjqG5wdfMzrtz/WY4bKu6DyG1wc3lv++uek980eIu/q
wM28turV5I/2AH8oqqM=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03lI02Ecx/FfRpeiaHnmUfO2vDXzSj+e82pukzA1Q01RdJGaRll//DLB
ogOPKLCI1PCohCa4RJub2YGJkv+UaFToLA+ITDQx1Aqf7x/bYIwX79/z5cfz
PBPknJHm6XEcJ/r3/f9LH/NjXb3yInts6mf4t3Lb8S5DMoeBO33cQLuAeSeO
n2q8r4wiG2Nc+Pyu1/R+ZlOcF3ptyC+RLXFxWC0fcCXbIKRIZfJMsY95PxoN
szJUG3bM9ijZkjw9UUB2hE/32CWPGltmZyzrTXqGDtswu+L99770Nm/yATTL
jLO311ozu6P7Cv/Adm4vsyeSVLsULWlkbyg7E+3ihq2YfdD2uOeqvoDsi216
Gy+cqiyZ/VDQZOFUbUb2x+v+5jF1jgXzIdQKLTwrPpozB2DhuTTFIYx8GKFL
/Z9vnDRjDoR35pVWZZspcxBSuMARuQk5GG6OOzS/hXuYQzB7pzSiI5wciiFF
V3tpMfkIMoQq/dVnu5nDsHm+5HBUanJuap6aMAMeJq4LDaPGm+aB6755n+5l
MXMRmP/kUuVVST0Ci+s9aZU7qEdCFlmjNGo0Yj0SjwabzxmUMXNRED29FZPX
Zci6jrlo7Xl8NAxlu+evltD8GAgi8q+Vr1OPQbnb7fq6TuqxSGvoaDRzpx6L
FoeEcf+X1IXaz/NCBI30PnzzlXocrC2nZmrrqMfh7JOQ8M4m6vEQyw4MLVlR
j9d5vwTteXyCzv4lau83nwiDrR0Vc/W0/0nw6bF2mSxn58MnIask88+7GepH
0XfCqd/OgPpRlBW09iWb03mKUFi2otiSSl2k05O17wOfjFjlbCFGab4YxR8W
X2YLWIeOebH2+6jFOGhrbpWfTfMlOuslGLwQHZrrzO4jL4Gm0C14rZpZLcGP
06+W/JbpvkrRILq8OqXP7jukSP81EeC0Ruul2s+rpZCv3Jq1BP0/UlD5NjVz
NYnWp8C4uiT3S5Mp/gLKeD51
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0GtIU2Ecx/HjluGl5Vy2bFrOlTKklmleNi/7zaXOy+YlKygKysylQc0i
IYlOSTlfFIUiJklhRKg4yDBRKUyxhiAYaBi98EWg2E0lmCgrK/Z/gnMOHA4f
vs95zv850acvlFZIOI6z/L3/PdmlPNw39LxaA5+WjNLOxi5bCDMHhSOo/mRf
NDkArVPXljPKmeVI8LyfdIYyh2FyOl7ucqnJ4ShtuNj8s5I5Erc+btSdlTGr
8cp7bmImPoqsge3Ip5Gqpp3k3Yh26BccKzvIsZD+miu4EsusxbhdtWvkZiQ5
DsbjlYfejUaQ98CeWfZa7cesgySwPrVRqyLH4+6D6bpay3byfqgXXvTNzIaT
E/BE8qglxsCciPWqcqd7fhv5AG7frzbURTEn4ceJN/2n3irJydD0BrSNWZlT
0DauGHzs2kpOhbzBcWa2I4ysx975CD5oA7MBCy01ph7jFnIanhoS3c/aFeR0
TFV4ArUDoeQMBEt7rn5pYs7EkKq5fWBRTjZCdl7x1elgBrrTNXbtaIjPPJDX
6eqKeUjmTHi5dG+famIzdRPMZd5k/xwyl4XQb2HKJSXrWfDIBm54kzZRNwvN
m/FB5rSv2mTUD4q6yFw23GMZtZcHA6hnI8pi1Su7/KnnoDDlev9nnZR6Do4e
S3DVaNaNvp6LRf3a7yydx2c+l/7PMnWLqFsgUcetBXd7qeeJeh4S73xfMQ2v
Us8Xrufzheu5AuF6vkA0XyHN40fzF+JSd5qxt4Oj81lF+1tF+9tE84nMFZHn
qBeJzl8s3B/Fwvn4YuH7wyJzJcLvQWS+hM5B13DJ//f/AN7fLqk=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlW1MU2cUx++kKAOr4KCABXkzDgHZAEFe1z9VBHmptAVKW/qCC5kJGkDY
JDBHZdnQjDlB4xe+DGemE2UDRBBELxMGkmgUMliyF5ORbItzwoJO6DaZC+f5
cJ8mN80v//M/59z7nHtuyL4KXdkqQRDef3H9/89+isLewa7yUKzQvGpI7pMR
4clYwANT/1HnYAixGyZ6i8/NvMnYE87u3rCxNYy9ca+1787NK8HEfmhvP63+
xcI4AF73nh7JkjEOxsLVyaErpUHEoTj1XFbR37aJeDMaq7a7ls8FEm/B4vXG
h57xjMMR3+G7zdgVQByB4YX26sDNjKPw/cjfoweNSuJopHWrfzt5eSPx6xju
OTviEsE4Bp+6irqxOn/iWNy4vqnA5ZEfcRxCbv/ZlLiV8Xa4vfeJcsLmSxyP
hC90lux6BXECOrwe+23p8SHegdSnwz81WxknQlPtWX9m1Js4Cdt+VTrcZYyT
0Zk5pzu89hXiFEQGKvzfKt1AnIpJVavM90cv4jSkxuY2rbMzfgMdqaH7w2+t
J1bh3O3P3vGoWUcMKTuAq/MnX9t4h+npGBpLfhw+u5Z0jgU1/pJfO/pPPNPV
nL4TXo+8FfMKln8npuXH9i9p5KTvQvl4/42pax6k78L9/m+ffLdILGTgQvqt
0W/8Kd6RAfmh2JSpRubfjVXBEU6PDlZ/tzReyOT6y8Townq9qYr1l8Xlz5LG
C3u4/vZw/WVz/myYIluy7tYyPQdxH//xLF18mfQcRPXIViecWEN6LpaiWt89
f4DpuZyeh/HRtMM1A26k50nzCRrMJTmfq6NXk67h/HvR1VlxOtrM/HsRln1m
2nTBnfR8fNhSnlwfRPHIR+6Ohr7ZaBeKz0dQVl6S4qLrCov5mO+5/+8RH1Zf
K2VopfkcWs6vxfnBGcVEALGgkzI4dujofpdUK34dVvbVKvLrUd2Rouo+K5Bf
z/Wvh7Y5JlL2gYzqcywUSBkF8HC5XPfw1EvkL5DWEzkWCqX9oRAGU2znodDl
FXYUcvULpc9DKJLmQxFXv0h6P2IR6hqcw+UX6bwFg/Q8YeDmzSA9f9HAzUcx
d/7F3DxyLBZz82NEy2x1vfoZ8xu5eTVK64lGaT3BJM0PE/e+mqTvt2ji9odZ
ug9gxpfKS32TObTvHGYsC9plew2xaIbm0omMsl7mL5HqKMFHsWU/tNk9yV8C
+YENvx+rIhZLoDI8KdEo2X61YKsmzDvjIDEsqJxe+Lo0hPazw4KYAeWrP79N
LFq4fW6FOfOmu/Mr0mFFX+Xnxmgf0h1W6KePN08GEovWF/u16cFiA9v/Nozk
i22OAea30bwwv02aT7Shp7J6wVTL6tuxbzx0IM5BHGyHXki82+VF3x/YYZvp
tU7VeuM/ENMTuA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1EYB/CTM5VWpstep06dK9TULDXv2f7bvGWmczOKoAhJIoQuSgSG
+ZKmjEqSFEO70QdTR0VFYW7GpKyoL0VYgYXEwA9hucDyQnZjz0u858Dh5cf/
nOc85/DGVB22VPswxqx/57+vNIQd9x13anTwyqMfPd7Z5FwpmSEyb6DL9iCG
HID+0mOLl/ZLDsLgk+D1HxWSQ2B3L7O19GvJasy+em47aZKsgaWsMyvCEU3W
YnzuSNewVrIO+UMXBY0YRV6Lr/PqAPXLSHIsuvv0gf0qyfFoEXRjKVUacgLi
YqOtzdciyEnw722ztC6Gk5NxvlkxOLFH8kbcTozKyveEkVNgmi6JO9UkORXj
Vw8ctdnV5DTsTfg+UxMteROEHG3t8oZQcjoeDakCPB0COQPtkQenut2ryZkY
WdMcz3SSs6AZ34Wg9hByNlTKUOekcxU5B8PPWifmGlXkXLidi2JipuTNcIR3
XH44HUTOw+QGXdqhdcHkLaiz5+rvXpdyPc6kVn/o2ScZCJ4KETxCoNci0Gd4
PPo0bAXlBrweHJt5P6ek3ICet8r53nQyMyLpnq9fRps/5Ua0u+tOGGfJzIQb
jnfCC81Syk3YuTv1Vq3ut96b56Phyhun8ElBOWdWgIqzKYm+p30pL5DXY4WY
zl74ZUz2o7wQ9Y0LIzUDZFbEnV8EpeJm/ecLSygvhvf/96G8mN6LUb5Vvl7k
zErk68US7n7bkHbuy6zBNe+1yJmVUv8/KOfMtnM5Z1ZG/XyjvIyrX86dXw4f
bcKC0v6TcrPcMMv7F83y+i4znT9J+yvoHWiAs8jZxZlZuP0WeX2Rs4tbz6xc
/1buvlb5e7k4s0r5/VDJ9f/ffwA98Uat
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQNioVt3b8xWcoDwPtgX23ySfMoO4zM4eIgdcvqw
QhHK53BY/1h5gog3jC/g4Ol3f+GxlwpQvogDn/Xc4s6JML6EQ/XZAxsPa8D4
Mg6L/4vs7ZkvD+UrOKz6pC7+/r4clK/ksGbd9n1njGB8FYcHPbd0HLxkoXw1
h3M+srafd8pA+RoOp/ZZ7TpyRBrK13KwObA0IY0fxtdx0Fwz8dGuIikoX89h
5ieebAkhGN/AgVv0asn+KZJQvqGD/n/Dza+ZYXwjhxk+KkEcvRJQvrHDU6bt
ZZMeiUP5Jg5ztr/rluWE8U0dqup/HcxeJQblmzkobeKYddQXxjd3iDezZbt7
VhTKt3AQWns180OdCJRv6TC34WoV/zphKN/Kwce8fvtjPRjf2uFIwIHZDbuE
oHwbh8d7/jZom8P4tg7FG9d3BlQJQvl2Ds/0lYzzNGF8e4fVNkoZGof5oXwH
B8E3ImIfxPgg/AYHB2WvadeiVnBB5R0dPmy++LdWlBMq7wh1DzNU3gmV3+Dk
wKSg9Yt79R97iLyzAzfz2qpXkz9C+A3ODu8tf/1z0nsGlXeBmgMFDWh8Blc4
HwDXWaAS
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tIU1EcB/CLZQ/U8rGtTVv5KDOVfJXV1Pb10dSZuYdmE4UeSi8lM3uo
UcMVJkY+MoJeaFn5qIWLtDJhFK7EMtAaSZZBQZkZihUS4jI6vz+2C5fLh+/v
nN+5557rtWO/KseO4zjlzP3vSZcg7X5H6z5v/NeYdL+uMeS4gMwhNsW8p9jk
xTwPRcYpmSmP7Iy6Yz81Pq5kHkbTpT+LHngyC9Hc9MaSkkFeDGOI5F2DPdkT
TXzHPZL0pczeOK/XCQqrlzAvg7Ds8UjQHLIv7n8Y+GwoEDP7QbalR1w7upjZ
H+631Bd+7SYHQnLE72pfmwfzKuSZXklOzSIHw1B840rUOXfmEHwr1fm66UXM
oeC9HOyeHhYyh8Gyd+fp518WMa9GZb9zxQs5eQ3Cm1RZ8hIBczjG21Vqnw3k
tUgbsC8/XcJnXoeASllvTA+PeT2Cs3S3OhvJErROnp3pTo5A7/at4xMDbsyR
UJvLz/SJyVGob3jOrzS7Mm9AgFgg2rWdLEV7/k3NKj7VA33SmtmL3rv8txb4
7qbJ+V1O9dF4nfN7vt9DyqOxvrejzvTRmeUxqAjNGby0jVkbA83FO/X8QMpj
kdikb15+eSHLY2HhlJZthcxcHBq6rx92KFzA8jjkxlR1Lqhn5jZCkevf80tE
829EekaovsCbxsvg8p0nGBPQeBkOdSgi103S+HjEpk6F28soj4dTQWhEf6kT
yxPQGP20yyRi1iag85nkh98nR5YnWtdrE236y3HX43Z7XxK9n9xm/Uk2/ZNg
5+n/x6GF5t+EielHmtK59H6bbPYnGSODK04GlVKejIMtEVLDNdrfzdb12s3W
9VyKzf6lWH8vTmHdHwqb9SrQNlYV5P6S2aiAo9uTI/nDtD6l9X5AiUMra8/V
GKif0no9RiWSZaauz1HUXwUP4aev1TXUXwVxy5Q5cy2dN9XM9ygbmjzBzqNR
ZXO+1cjUhWW8/coMNbqL4iKzfdn51qpxL//gRMZRZqMaiqA670Ih/U+pcC47
kD10jYe/N7hCSw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU1EcB/DrI/PtyjnNZlOJmk7MRz42m/v5Np9z29XItCis0EjQQNTE
S6EYPUgr+kPs+YeiJVPJVuuxSTZJDMzSkgJT0IgeIpWP7Ml+5497LlwuH77n
d+75nXMC9pdrSmwZhin69/7/kkfE3jH2lAWCVfOq1oWUomIPYgb8lJ2XT/UH
oB1BUb26dZIlFkBKqV7u/skfLYRJp+8+HZeIfcAiCFO2yYnFUFF/4E2vWYL2
hzah2HJQShwIxta9U7Olm9CbIWNcPNzQ4YfeAlKZfteHGTFaCupY17lDCuJg
0McbFIY9G9EhEBPHmmVXfdGhMN20NCHwIA6Dk7cGPNniDehwsCTonacHfNAR
8ERYVe2/4I2OBC/vKNnICeLtMBx0VC9eFaGjoKZ+xVzWSRwN09dfsgJf4hgo
t/nZ2BnnhY6FRLN2k0wiRMthLmihOlztiVZAYdpj5xX9enQcvFC12Hu/W4fe
Ac43l4pTB4mVIH9uvPZ0SoCOh9MRJW9b9xGroH/+/DbfEXc0wEOL4ot0xtVq
DmDcrenwco4b5glUngCjhlffXi+5YJ4IZUOGR2P30BxlJgn3wwHzJGg3Toie
iddgngxf5Su/E0NJnswfz6RAT3f5xdBCR8xTIKTP3iH63FrMU0GSni0XdeJ8
HGUmDaz32xbzNKi7MvZA9N4O83Qo2B3RXRH4R2XN08HF7nbNxws2mO+Eyq44
Ve8NBuspMxmQdyZcZt9gj3kGNM9U1iYukvVl8tfLZVJ5FjQ2lylqJSSnzGRT
/WdT/efw5+NyqPpc/n5zuZAVU393JpT0r+b3C2pqvJp/PiY1dT55MN83+qvO
ywnr82A5pOV4+xE0R+WmPIg8+3kxwYRmNFS9BoYGlVXH7pN+Nfz1mCgzWv55
AmVOy+/XpKXqdXyDjj+e0/Hvh0mH+/HDaoZFz1oNLD/nWKqeBVv/4BWXrlWs
z+ePB8ocZVM+/39MAfbBMH8Bk1ODDA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIU2EYwPGTZlnTmrflLZ1WlmInc06deXmcOu86t4WkJiH5aYWUWaiJ
x5AootC26kNNDEzNaKF2cVNsWlZWVlYY2EVDMTJCy1BcXir2vMQ5B8bhx5/n
POfd8SkoUhRaURSl+vv7dyeXYPedzla1L1g0HWPsMlxq4hNTUFDpqIsw+KBt
Id2hrVu2h5gPZQs99lqzEO0M10Z6f3rWELtCv7FUIxQRe0J+1sdPcyZvtBAm
6LsXA72IfcHQMKY+I/dCbwaDcvy2e/VGtB/M7GvQhdoRb4Pwcsd1o7QnOgBc
bhW/PFrsgQ4EJ81V4/Uv7mgaVFXLg2+lxEEAVyaH9QY39E6ID5sS59DEwfA8
elymGHBFi8CmiCc62LcBHQJq+vfI634BWgx1Jc3DQb7EoXDa/KrFbdEFHQbN
7x9c0A0Rh4OuIzJXo3dGSyD/lOxr1EMndAT0l8ZH7vcj3gXdeVt6vHiO6Ego
1DValdc7oKMgJvtXXoYHcTSU+Gs159v46Bj49mFr9Y4TxACNm1KGQ3rRDIDk
RWf9o1HSY6HU//F8YSbpsbA9ilbdn7DHLoW+mfXKnEN22KXgvTTwLHx6LfY4
EJ39PhdrWoM9DqbbBxcrXNBUPMwHnj/edID0eE5PgFZ9kZbOtcWeAE/6oo4d
MaIpGduMjP08KpH9PCaRM58El4d4841iHvYkznwy1FRbd4zsxfMwyTBrb6ha
EON5qRQYcJ+e1PJJT2G/L5XK2Z8KtWPF5dK51djT4GStOqLcG82kcXo653zp
ENi+clXoOdIzOP9PBjR1vhM89bTBnsk2kwkVdW+6BJ+tscshLazy3hiNBjm7
M3LgWd8sm9SssNgkh+ycYP1h3+UYy3wWft95iyELrIQBZt6NBYuZLJiSmJek
9KzFJo4pBWdegft+4LyCs18B3knpEkELOZ+S/b6g5Ozn2MQxpWLvA44ZFe7B
y/TffwDQC17L
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd011Ik1EYB/C3bX7QnDpdy7XppoiJ2tBZ2jTd3+l0OufHoiy7KAdW4IXk
JEkjX4yiIKMyuwgj0j5k0mJFRdmFGUJFkEHoRRGElSXFAoXpiqzYcy7e94XD
4cf/nOc858Cb6m53tUo4jiv/N/7P7FPvuD/ub0tDWD8tLUnuY09UzByuvYnQ
fn6cSo6Gz3zaM+lijkepcrdldsVAViFX+kHecpk5CSmxRcvTJmYdFFE39aYb
erIByx07r0ZomNNw/cXIYXlnCjkdcXdGRj++SiZn4P286lFmUEfOhE7ZmD7Y
ypwFr/fX8P6AlpyDJnfN8735zEZo2qol575vIOfi7YxzusPBnIeFvuMZiT4N
2QRbtPT3kj+JnA/9SH/fRifzZiiWhr45htaTt2DxpG2XzcRcALgfzF7oUpML
Mfru2eCVmXXkrWjvP6JJHGA2o84T33NpSkUuwqZ5Lb9WxlwMX1XA1RWTSN4G
W8mno69DCeQSZCerNQdamEuR8HVicsylJFuwyjWu7uuMI4PeOzZsHpAYskLy
sRjKyzC1GLe9+RCZL8OM4tTBlToF5VY0NZt8HWlUj7eK9pfj/JynxxqMorwc
ervTrPZGUF6BxjN52bITMsorEDCH/liNkZTbcGt8Vv1SR+t5G2oLex/OGaWU
V8IzVmy5O8xRXimqX4Xu3tDTNi/V46uE53F2yKW3uxcG1lBuF9bjqhH+PySU
Vwv74WpE9WuQc08WWXCW7ss5RLkDfl/7ReOeaMprhffla4XncU5Rf05Rf3XC
9+BF5upF++uR3/8jWDaxYgnnDUJDZL6B+vti+QuH5wHL
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQNioVt3b8xWcoDwPthP7w1gvsgH4zM4WJcdXvVw
pyKUz+HwYK52qWQKjC/gMGd6wbS3nDC+iMOvfd/4L69VgPIlHP7a2pfFe8H4
Mg6u5tmtIc/loXwFhzLLlRMkOGB8JYeoVYfmzW6Ug/JVHO5xchvpbpGF8tUc
HnUW7O1lhvE1HG5u/by2mlsGytdy+HjxlNQKXWkoX8chpPH/xStOUlC+noMj
e/ddgc2SUL6Bg62Vp6FSAoxv6NAsqlA/s0MCyjdyeL59jaFhCIxv7JC7JIm9
LU8cyjdx2P10k8z9ZWJQvqnDLIWt/M+ei0L5Zg7OOlfPM7fC+OYOZpOPZHgK
wfgWDiaXestVd4lA+ZYO8de3xl2ugPGtHKY/7GG891EIyrd26N3Mqb3vPoxv
4+Bq+6Tm/C8Y39ZhqZXxieVzYXw7h8mpHybHLIfx7R0u2U9iEb8rCOU7OCQU
xv4+9QLKb0DjMzg6WJ7bveDYAwGovKPDM30l4zxNmLyTwzJlr1smh2DyTg7r
pddsv+TND5V3drjG25Hx048XKu/ssPe41TuNxzxQeRcHvzV9rqlbYfIuaPKu
DkwKWr+4V0P5Da4O33h3Nv4xhcm7Oeja6oXsfwbT7+YQkKN1+qsk1D0M7g7c
zGurXk2G+c8dLXw8HLYXLIvUExWGyns4lIvOZuhfJuwAAPsnxNQ=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tIk1EcxvEXFbV0lanzlqVLYolNy7wstT3LNHU6N29pFyhrKBWU1IiM
6jW6aFCUSnQTQ8oKK5tmYTNcmkqJQWH7QwkDL5SXGl3W1LKMfifYBi/jw/c9
h/MezgnM35uhseM4Tj37/P1nP2F2k163W4R/MsmK8gsudwiYOZTmhLrrGwLJ
zkiS5Dww5jIvQPf2+CMxHLMHjNKRhtL6ALI3avSj5aKNzIswb9Jy8o4jcwCS
X2rNWtkSsgjKnP62XRWLyUFIvNmn+T7mT14Ge5H/MamQWYxrEvS+zl1EDsbD
dC4/qNKPHALD2aYwtz5fsgTPGmue2wczh+HEztCuqVM+5JV4O8E7jw16k1eh
ImD4g0rOHI5DOrVFXOxFXo1LUv3FiTYhOQKRXzaJFQOe5EjYXaqeTuKZo7Cj
v6Xl1rgHORpXlCVTg3OZpdB98a0uLnQnr8HTrtMDlmMLyTF4Iyt38HrnRo6F
5YbT0SE563HQVNXaHb7O+lpol1dWlDcsIMvg5z344UI5M+Bf99O4JYre54Ha
pSl9q9tYl2N/XYysoYbMy/HCGPRt2pXNvw6B8oIy7Qzr6yB9pb/e+Z6Nj7cZ
Hw+9b2VV82fW10O1J7j7uw/r61EXKyoUt8+nnoCvM0/yjjuxnoB6v7uP3yhY
T7Q2nwjl3XMJmiYB9Q24anSZrI1wob4BZkFzyc8IV+pJWDLT0x1tmks9CW7j
HkKTcB71ZNyWt3d0+tB8fDKMgtLCSSWbPwUr4iRZrSOsp9iMV0CwZ+FYaRFb
v8Jm/1Nteipc3dsO7vvIvi/Nej/4NDwynQ/17WHzK6HVq2KjLWReaf29XDpM
ja9/HfGcQz0duvt7KyWbnamrENLo4Bh5zumfoUL42YkfcgN7XzV7/tZ8Eg/S
fhlU+M2pf287wNanRlpiZ8dQHK0fauvOq63Xa7DpXIb1+cCsdfVlqmJ2HjPQ
qzHPETeTDRkwn7nvtfUbO3+ZcLG/VzxaQUYmLrfeOpgdQveBz4RFMexckko2
ZGLcPU9jLmP3Jev/ffsDwfRMpQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCwBGIQDQNioVt3b8xWcoDwPtg7W3yd80sExmdwmDWNt/zX
ZkUon8OBlX35pXdxML6Ag80ztyMRzDC+iMPc4hUZZmsVoHwJB5Mpy8u4YmF8
GYezx/JcRX/IQ/kKDhMfe35mUIXxlRyy298Yr02Ug/JVHO6KvcmNniEL5as5
LLJOmb/8iQyUr+GQs9pju5oUjK/lEP9jppZEnjSUr+MQfvCFI89yKShfz6F0
r3zVegsY38BhAeuBoONVklC+ocODE68Fc8VhfCMHh/t10YJuElC+sUOpuVrq
1lRxKN/EISDom/T6JjEo39ThX9F3Vc6jolC+mcNvvnT7g64wvrmDX7FA9bSj
IlC+hYPQ2quZH+pgfEsHnQ9967b3C0P5Vg7r3N8HlfPA+NYOP5aw1z1xFILy
bRwKrn0+lKgI49s6KDqmd5b+E4Dy7RzWS6/ZfsmbH8q3d8hxmrCXbyEflO/g
8I13Z+MfUx4Iv8HBYfY17p/LTLmh8o4OE1qYd9yP5YLKOwLjq7ja6Ts7VN7J
4afOpJrlOZxQeScHnc0sbGZ9MHlnh8AeQ22WVhaovLMDJL0xQeVdHLiZ11a9
mswIlXdxCI8yWlek9N8eIu/qwKSg9Yt79R8Iv8EVVT2Dm4Nx79vvjgd+QuXd
HN5b/vrnpPcNqt8dTb87mvkeaPJofAZPNPM90cz3grrnI1Qejc/gDXUnFDSg
8Rl84HwAkETZ+Q==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd011IU2Ecx/HjlNLUpebUzGquKFHzNTWdcz+dzqlnmylhClZIgmBgy8g3
yuMgDEkyNVC7GBlEEoYmZq+0LpZXIRZZVyWZXkjWlmS61Xph/4fYHjgcPnz/
zznnuTjRNQ1ltSKO4/L/Xv/ubIUdmXw8Xi+DS1alpHZ/l9cWZg4Ny/1HRyaj
yb7ofpJ1YVM1cxAKW9WxSb7Moeh9YwhpG5eSI8AZhOhpLXMU5hXhPrfndpOl
cJy1nLSHMMsw/7154AO/i7wX9c/WA1TCTvI+GKPag3vGosgx0DuGWiqtO8ix
KDBc+/y+hTkeppkAcd+rSHICuL7OrkEZcxKKxKoHZVe3k5OxMmM7pUhiToG/
WapMbIsgp2JRNHWu92M4+SAsz2++M9cwp3k4HSOmpbG46jByBmxTZeV7cpgP
wc/Z7ydPZ86EaMDk0AgSchaM0xXVdj6ULMfxt5PHXjczZ8O+rhpuimdWoEly
nbtyaxs5B+PfIk2tdcxK8BntUwsJzMDE6cbVqmayAKyXLPp28CHUc5GdwneK
TwRTz0XjHbny3nAQ9TxUDo3ekMSThTwcCI6xDc2yrsKq81GlcTPrKmjVLyyf
FKzn4761JzHypZh6PuYCL9Vt6AKpF+DpdNaXmIUA6gWwrG4trzKQOTXWAh92
/ExjXQ3rxOyv8xI/6oU4fDk5zueiD/VCOr83dQ2dh6Ouget/EFEvcp8Xitzn
uWJ8zbQ78xLWlK5ejNTulR+55g2XuRKP55fA33u0dbnPi/bzHvt5j/1aj65F
RVXK3TOy39R17hZ07vOcnrxEXU/vt1Evde/wsFBK30nL/N9/ABNjEzM=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1IU2Ecx/HT1HQOfCmdK6duK8NKDqlT02nn53ybOkUtyaUGBiLShamR
YEgzZhZM07LETKICjV6U1WTmkurCim6yEMMu6mJQEFbrBecKtWL/52I+cDh8
+J7znP85HOWRxvI6Ecdxmf+O/2e2pBUTdstRFTxyCnU/9E/bg5k5pA+o+a9W
JTkAAtd0wmFgDkGXW3ZJsqwgh6G+bPrXnWFmGeaiFk2H1cxydD5/tlwyHUNW
oFV3/tVlX2YVtpmGFtqqosnbIbIaKv8MR5F3wDxjqbj5SU6Og1KxqDYnMO9C
fVR382xNJDke+dWC4uzVrWQePZr+nR2BzHtQEJQ9Wd63hZyABntvw8SCjJwI
P9Hao1gTcxIa5mN5SV8EWY39g2uOUjlzMhIjrtVWn5GSUyBe7RdrUphTMTBy
/ZYqmnkvzBGzF5aawslpaK8SMqwHmNPxvrKny+wKI2ugKzS/u29gzoC7tmWl
Y2IzORO2YyMGPpx5HwYfj7ZWxG8iC5irWxLHPQwlAy2W8XOlbWQjUO1/40pk
LutZ+Lk6ZTjtH0I9C+ORd21vioKpaxG6GCZ1SoOoazE0L3GPJEuoZ3vbmI1e
k8/kh5pA6jmwjDX281UB1HPwYiaz9fgUmcvFt7Tfq1p+I/VcjNrfSl/K/ajn
wfP/iqjnQeJzr+3zxQ3U86FPPWVz8D7U872v53RI6v7iynriFjxdhzJzwm7f
Tl/qBYjRFadJb9PzjAXr5iuE88HrlfZwMfVC9DlaTmpd/tSLvG0s8t6P06+b
X4+DhxLHmlVrnnm4Ynqf7zRfMd3HVgl9n4/CX13v7DU=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0VtIk2Ecx/G3JajN5WZzzkOpSyRteZjNZlPf39Q5nSaWhSgKJWiRhjRn
hSnNspvSiDxE2UVI1GIU5WGkggSxMkyiFpOkCy/qItGcWZ5YdmD/56IXXl4+
fJ/n/8DzRlfVH6oWcByn/fv++7JHdmRo9GmtAl65+bql2ie9QcwcROq12eKR
aLIfXhuurSgPM4sRd0ZvrvREkaWY9v8pt3Yzy5H6saevKI05Am/n3htjP0SS
o/D1VZetMYJZgaR7U/WiuB3kGFyJaasJMG0nx0I6vdh07k0EeRcutfhECyTM
8XAmdd48cSecrMSCoXWmxBVGTsBkmHu2S8ychLbMY3sCH4aSk+Ebb2+XDcrJ
KiTc6l+o9ISQU2AKPTU1f4F5L6rGZr5vDMrIagxPlNlLy5hTYZN8k8cOBJP3
QXOSV3WEMGtQ1CA+3+OQktMwxNesNtcx70dx4l2FWc6sxfFugVmUwpyOuBjf
zyuGbeQMrBZ88WstDCJnosK373a4XkLmwZf+qCgKZwauqqo/9R4Ve20BSstV
j02KQOo62N3XE8Mmt1LXQTInlbllZC4LjaPF6ZpV1rNg1b1wvAwVUc+GYymw
pPx0APVs9LqEa/fVQuo5WBYNt3rUrOfQ/9lCXY/IjckJjZts0UNkUmmdF9n8
XNSOPxtzDtM8Sy52Gntc5Va234CUjvkV3XN/6ob/53F5GHdknDWP+FHPg3vg
3a+WYFrP5WNNeaP5QR3bn4+D7cm7fS77UDdCuPlR02znJupGur/fvLcXoMGm
5fv7OOoFEETFrwttHuqFWEhb38hKWPbaUkjzFqkfoHM47g+veuRT
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tIU2EYx/GT66ItzWwuTWtzmqVFzdkynbbfnFOnm7tAhFZQgRWVXVQC
LXNKFrUySTHUrhZZlku7mqVMqKwsyqQLGUhkRUIgleEs7YLP+8c2OIwP3+fl
bO95T9C6beZMN47jUv9d/7/ZR7j8xp2mzRKMaUB5VdpY0eTFzCFe1vpLfSWI
7A77/RclvHRmb3SuVRcoOGYBjr7c4bOrSUz2g1WW+a5mDXMgyrRS1dyJzGKs
KN3T479GRJag1OFTfSxvNjkEy2/OvRf9YhY5FBvUq061y5nnwT6nO6+3PJAc
jrIjz/WCwQDyAgS2VfXty2BeiKAQWZf2yUyyFFnmqltiP+YI2KUH1m8/6E+W
oXjLV2vdaz9yJHqCN9V2hDIvxsg9kfX62xlkOXr+BNxZmcu8BDGhjW8uHxaS
o+AxWuGhWMK8FNWPfVpO23zJ0TjRHLuy3CYgxyC5/3Wbl5VZgXUPJS2Rlunk
WHwO+5YXYWSOw5fKbFWDknkZWjv29w4V+pCVGEr96F6kYwZyN9a1GYRkC/Bp
kSRya9g06iroEx/c74vzpq6CcUt456A/mYvH99GW9OJJrMe7dDVWZMhs2ZKp
1NVwE4cP8y9NoZ6Ac4/O7uTnelFPgGe2TNFd7Eldg5+et4t+y2neokHNK77j
vJxPPRFle3nNvasnU090nueSXNYnITil8lXGBZrnkiEafdq5dICtT8bTmQP9
Fd6sazFwrWukwNeDuhb5hcPtm+snUk/B2PvjRj0FBSe77wrf86inQpSsjxbW
T6Ce6jzP6cDnNeT3l4+jroMuqvDWh4VsvR6mQxHzx5eMp653uX+ay+9LQ1fz
yx9vhtj+GJz3y2Jw/r+c0XkeRuf9sbh0uxF5YR2OTAN7viZoL9rq5xyn5wsT
0qsbzvguYOfBhJxLCuXVWrLdhLC0YIEmi50vs/P5gxmauL7dz4bZeTTDsTZn
pOjGdPwFr7czSw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03lI02Ecx/GxLo+mZm3eTc3Cplhp80htH4/NeWzOrSCcREiS5MqspMOO
ZRD1R+WmRGSaHWhZKWZ2bFYTW9ewSMv6Jyr9p4hooGnaioq+zx/7DcZ48eb7
PD9+z7OI0kptGZ/H42n+fv/9so9obY+1qyIS/+WUeZ0xLPISMvOwadHjEVdv
BNkDuzdnf2muZPbDurBSnWcg8wIIfu2JllvCyYHoNZVOjquZQ1FlmVBt/CYm
h6NuTX7nmJI5Eif1jcdOVi8kR8Gu2FpncoaRl+CnI/KVPoo5GiMv7A8ubQ4l
S7BFMW/+zach5FjYJOcGc4XMcXgfmT1qKQwmL4f5a3n0gdQg8gr0OS6kbTgS
SI6HMEAaM1AbQE5AbM/FtS6riLwSLb78YJecWYp+5VhzRK+QnAjLtthJHZ85
CU130vT1HQvIySjxCDaeTmFOwf7moV7Rx/nkVVh/VPE5/SFzKj6f2p5xXcac
huPdnjH33/uT0zEoM88MeDePvBplTa38mhZmGVKeW1seffAjAyGBo59MZrIR
6Ay5dnsw35d6BrLWuBJnKXyoc8zLhPraCXlZj4B6Jvjhkmnvq3OpZ8GQWXfP
5zybz8ItZ92y4AE2n41qqyYt+Qfr2Zwux7DgaPmUmq0vh33MV1dcxdZXuO9n
VED8e8CR7PSinoO9B6f7KtpnU8/BE3v6rp0WD+pKmEZ31GROzqGuRFdHZUOc
nvVcOLtf/tov9KSey+l5nPk8HDFVrKoRk3n57vsZ892fh1eANusb0bPQWdQL
UJB08PZo3AzqKoiVqhRRO+sqzv5qzvpqTMWa97UZ6Hl5hWgc9p5qlXpTL+S8
P437+4WGc56cbtNwzrcIL++8Hn/7g9ZHES5n9NsfBbH5Ivf9bUWc89FiQnD3
kEtK60ELwfb41KFaNq9F7pWO9sVn6T7atNAYJI7vQez+6lC9tKHefIMMHcKu
uoZLkui+G3Xu/webDiWHE4rffvLHH/LLQ3E=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0GtIU3EcxvFTmJcu6szm1DkvrVjOLNPmMi+P8zqnNBKLLENESUkQjYiC
dPqmItQ0K3AZBppYOhlSkoZhSZZCoZmGYiYpBREdTWNlZIW/34sOHA4fvi/+
//P45xQdzFsrCIL27/vvy480436P9WQAViXGNJQoLdnr2QKMzqrWyXZ/siM2
WOvhcIjtiht9X0PiRD+yOyTrVq6U17Nl8Jxy7B1MZ8sh2J2Z7HvpS/aDX5Kt
vUvDDsDK27Bd5gcKshK5Hy9ry+zY27E8FDB6VOlDVuG4NV39sFFODoSlOcv/
i4QdBE1B/4S5yZscjMfdV6vrXNm7sVj0Ki2z2IscgvKq65Mn2jzJe6D3Gh1+
Fs8OhYM8dy6qWkYOQ6LZab5Fzd4L8Xte6fvbHmQNFP3vbCNp7HA0KK71mqPZ
WtiLLmM1+VLyPmgWMlWG6S3kCCwXN5al5bP3o6VnXDooZ0di3P7CuM+COzkK
bu1vCsRSdjR0fekKtS87Brrg7LqS7M1kwD5jTaf41G3VJqA5IvR5SwNZiMVI
TK2dx5SEeixOWTsuGc+RBR28ZR8+1dS6UtfhztaUibAnZCEOOyWq+fph7nHY
VOj2+WIx93gYCwOHljy5x+Pb7+4jFQ7cE3B2x8CPvAPcE6BvtdzddtOFeiI6
vNu6RgxkUyJO9xgjtTZn6kn/n2dKgs+9X2PHwvn+yXgxplxc3sj/l4yK2ZzK
2TbuetgMc47lqbyPHpWdTuread4nBUFilaWrmvY0peD8rdePpDO8rwEVA4ez
fqbS/iYD1AOypaYZd/wBJ0DfUw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQNioVt3b8xWcoDwPth/q/7/948kjM/g0L1L7VX0
fkUon8PhS+fHfw0xML6AwwbXHo8J/xSgfBGHOZVRj5bOhvElHPb86pGWsYfx
ZRwOButaK2+Uh/IVHCzPx9mX3pKD8pUc7M2KY06owvgqDq78J39W58pC+WoO
PUc3hi5+LgPlazgkXdu87KA5jK/lwH5FvTSlSBrK13G4d+d5ev8MKShfz8F6
F8Na23+SUL6Bw6UTN4xWa8D4hg7c3eaVa/dJQPlGDhMXMU94ZwfjGzuU/lJf
f/KUOJRv4tDA/70lzhTGN3WIOs+bOfOhGJRv5rBy/rMN2rEwvrnDWecIyac/
RKF8C4fgOVOkqwxhfEuHCI9+gUf7RaB8K4d3uUe+Gn8ThvKt0fg2Dk56CVOK
EmB8WwfvzR+9As1hfDuHaPf9XL82CEH59g7futaJx34RhPIdHIpXW9tvWiQA
4Tc4OKy2UcrQOMwPlXd0WOF4+OgxSV6ovKPDxnX5U/SiOaDyTg4TWph33I/l
gso7Oby3/PXPSY8NKu/s0DYx26panh0q7+wg7+FrKbaKFSrv4gBJf0xQeReH
8CijdUVK/+0h8q5o8q5o8m4Oxr1vvzse+AnhN7hBzYUBdzgfAHmztz4=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlH9M1GUcx78KqXiCYMcJ8uMAozHAG7/kp3RvTkE4fnjc8fM47k4Xs0GL
JVgTM75ikmUahMtK1yqbGCIMzAQZdOgo+sHKTKJk6WSVY5m3wRCQ6Mf4PH88
z23f3V57P+/P5/m8n+/zDd5VbaxYLknSa/89//+zn6rwUl9XVQiWyKkdizjb
FOrLWMKHlaowr4Fg4lWoPOUd0V/J2BPHJhe6dIGMlVinnP71zW+DiH3w6VTs
oeA6xv6wjw95JAQwDsLIPq8Df5xWE4fg6ShFx92ZQOInoI2vsQyHMn4SJzWR
rb9lBhCHodrb1We03584HI9erb/drmQcCdvsu+E+z/kRazCcuPeo5/cbiKNQ
5V8d904K42hYvsty67/lSxyDTQd/tiqmfYhjcWe+R7pQzzgOD6KSc7un1xNv
xv1Gt7bDRxjH4/01Jz9T/qgiToDBOOPX2cA4EfualDezljFOwusvW9e3T3sT
J6O292rQNT3jFDzy2K0dTGe8Bd2djYE+40riVPjfKoFnM+OnoBs0BUaoGWth
2XV3IvLe48TgWQZyEuovT2iYngbLoVjz2L11pKehpcLZYmkllnSIznivVz/C
dB0iAlS+u3cyfSsGLKGDgQqmb4XC5ULdZIsX6duw+sysNWOIWN6Gsxv1v8Rd
9SQ9HVOLV0obVhLL6djbZ9iSOOtBegbOpV0b+sLXnfQMVA33DNzoVZC+HUNT
a03m59eQvh1Nr7j03C5fTXom1Isj3yQ6ieVMbNS/PWo+x/QszLj3HlzYzPxZ
yGs/nl5xifpJep5lPbz+VKqcKra/bHT6tV/+IXst6dk4GlMxfsrO5stB1icd
baGnmZ6DYnNMx54QYikXH3915gVFLdWTc4X6eej/MvmvsAm2vzyMuh95Zi6P
7W8HNqVqCj7/ne1vB5+XZMDyoPB5xXnywyDMa4D7npiUGw203mHg85Ty+frI
F/LM5+s78gW/kT8vGBF77P7DNIcb+Y1onqjZr3u4kvxGNDZXJe9XE0smdHVU
n9CUrSK/CcNDqS/WXiGWTXiQNL+o06wgvwlzkW+91Pos1ZcKhP4FwvtSwJ+v
o4CfRyoU/IW43nNzemyWWC7EyAbn5AlPysMhrJeK+H4oEvIrEvxFQv9ioX8x
/37LxXyejmI4L17/+4A3m7+EzwsliLzouiL+OOUrl6Cufn6wqo3lVwJ1Zm6S
qu0x8peite8n1df+xChF/hvREa6HXckv6I5SwW/m68PMn69spu+RC/nNgr+M
11GGmvMp2u6PJPKX0X36R7vkL6M85pZYsvA6LIJf0B0Wvp9Uzq+HwHI5ndcC
+QVdsgr5CSxbhf5W+n4uI79NmN/G5yPb+PN02IT7Y+fvR5CdPz/Y+X52O99P
tvPzfGAX5rXzed9h/WYo/520D0n6F8sFLls=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQNioVt3b8xWcoDwPtjX9GzvK2WH8RkcVvOyezet
UoTyORycTRK6iiNhfAGHm9UFxnt+K0D5Ig7C93g+XZkO40s4bKp99fu/BYwv
48DAUn774Dl5KF/BwSR0xsMjv+WgfCWH0LVbpva4wfgqDlufsMRLTZeF8tUc
mnn8bke9loHyNRy+5DpxFTjC+FoOtvdmHF61XBrK13HYlC6mtooLxtdziElM
WPfARwrKN3CIe55QwjlZEso3dFB4uXnrjfsSUL6Rw4XPPw5ciIfxjR12L5Kb
UyMF45s4iFkpFPHUikP5pg7Heg6Vl+0Xg/LNHKY22C4WdILxzR2uauQkLtsu
CuVbODxuFNIoSIbxLR2us7Vfl/0kAuVbOVRfreRlSIDxrdH4Ng5Ca69mfqiD
8W0dmo6Hx/7ygfHtHJwOBstpy8P49g4HtJ3erimC8R0cVMoZJ5u9F4bwGxwc
Nn6Sml+VAeUzODosXHJCtP+aEFQejc/g5MAWyrj5w2GYvJPDkYADsxt2weSd
HXo3c2rvuw+Td3b44f2Uo9EHJu/iYB/+JcZPWhAq7+LwYwl73RNHmLwrmvmu
Dm+EI1O/dcLk3RySTijtMm6AuR+Nz+DuENfh9tL2CEze3WGq6t9IhvkweQ9U
foOHg1+xQPW0o7Dw8XTQPi7xdclDEQcAr8nGrw==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ltIk3EYx/G32WE28ZS+M126aS5TG3nePL2/TZ1zIVgh0urCIoWUms26
EaoXSi3ECy1K6AAmbTZN0HJhklhgWF50IBWEEuyAaCMlotRqFXv+hD3w5+HD
9+J/86gOWfdUSDiOS//z/m42fGn/YG91NLxaEIY7PqhDg5g5PF8xzbQMqchS
xD782ZFdyRwI58si4UYAcwhK3ia1qR8oyWGIq5Cfun+YWYEj9isenR+zEsHt
K6cFaxQ5GiOdrS1lLyLJW1EQsWE8Ucusxq6+hiZF0xZyHHKnKucOzirI8Rj8
7vrK72BOhF/3tu4EawRZg3MzsyU1i+HknZD4ntVeiGNOgs/r9snc+s3kZIy7
Ren8uzByClRPFxu125lT4W7wddafl5PTMKDYd3Q0ljkdVRnH/MVSnpyB6XnH
ybJroWQtsqpsbeX3Qsg6HJCGi2065kxEDtS6Gsc2kbMw5uq/bathzkbzXd+E
oelgcg5uZaaMOq4z5+KV0LpW/iaILMAeY55KfRxIBoqNT0be55BFwMPt9pSf
CKCuR9CnEH6B96eux8iXgL2W437UDbg6IVuyp8moGxBjvjxh6dxIPQ+9PdZL
mv1S6nmoO7P8qNq5nno+okzFOt65jno+HIOT/DMFmStYbbEAtV1ZQt9NjroR
Mp87dXMX11A3wnvPEuqFKLMk99iiPYK3F0KijF+Wdf3wmjMhpdn9TT+8RN2E
z7rlXwbNR+pFqy3+Z85M/9CI//wbDBHQhg==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQNioVt3b8xWcoDwPtjXJi4PmigJ4zM4HDleK7t5
jyKUz+EwXcf0zsQsGF/Agf1ADF+RKIwv4vB5Rv1r2R0KUL6EA/OXl+37omB8
GQfDBbJznJhhfAWHo495RDsc5aF8JQcVy0qP2WvkoHwVB4XlPgqMT2WhfDUH
2Sxl52ZRGF/DgUn+s6lXgwyUr+Wwi7fP7vJ2aShfx4FFe4Uhx30pKF/Pgf3m
+ZTbTDC+gYOtlaehUoIklG/ooOxbGtYQKwHlGzms9bj1rIgRxjd2aDPcLnc9
QBzKN3HYGlOVEJ4jBuWbOnzcHhSsbAfjmzkwzZj/26NBFMo3d5jZNy/rUBmM
b+GgyHL3wec/IlC+pUNM0qPHOi+EoXwrh+0FyyL1RGF8awdIfAlB+TYOJ6+p
fPnNIwjl2zpUah7/meovAOXbOay2UcrQOMwP5ds7/GcI/J9QAuM7oMo3ODj4
relzTd3KC5V3dLjG25Hx0w/Kb3B0mNDCvON+LBdU3slh4uPiaqfv7FB5J4e2
idlW1fJQPoOzg7yHr6XYKlaoPBqfwcWhdt7lPWIPmaHyLg7Fq63tNy1igMq7
OjApaP3iXv3HHiKPxmdwczDuffvd8cBPqLybAzfz2qpXkz9C5d3R5N2h5sKA
Byq/AY3P4AnnAwBG4bLC
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ltIk2Ecx/E3p2ZNzWzOZeZhzjRbq2Zqa+l+bm5ubrPMwk7QMHahkoep
XWSH6UVkpKJJhURgUIEyQy06Da2uUtJIo+4KsyQHkh2tZa5i/+fCPfDw8OH7
PH/eize+uGK31Y/juKx/+//JlnDvnYe9ZWJ4Nau61LSL9yKUmcNEplBReTOe
HITKxpHyG7nMYRi8F1O4MB1HFuB7guuZrI1ZhDHL4GtJGnM0gvXdmV+ux5Lj
ML3pfMvM+xiyGCW8Eqt1I7MENX8iR6xVa8nrIHIUnpIOR5OTUVef3OpKZE6B
f2NLadfZNWQpnuicfaOjUWQZjMoTBkEx82ZwL8uryj6uJm9BR678mKiIWQ7P
xftH3k2IyKlomBy01e9k3opad9KtoeFIchq+ntHu08qZ03HleaIh8JyQnIGk
NwWdtQHM2xCrNyuEXRFkBZSltsuW2wLydogOO8eadcxKhPMjnVPOVeQdKH4q
fpBqZ85EU/+yDQNvw8lZ+Gn8EFRvYlZh4FDi4xg+M7A+P0GgPbrSazsw9Ery
7XcwmcvG/g5HZ4Q0jHo2PFyBx1Kzgroamj3z6QG6UOpqhNjkyvGGEOoajETN
utrDllPXQNrvH5jevJR6Dnp7KtplB4Oo56B1srpOPce6FievjjuFEzzqWhQd
kPfYxB6Vt+tgyjh9d1LGug58nuO468ISep8L7//tR93HnJ7uf/bOs/uYM/h0
H3N5+KRwL6hlP6jnobpbqeq7xtF84+LvtRt9ummx7Sb4xaW4+d3zNN/sM9+M
1KaZuexHv6jnL7Y9n+5Pqf4Ceyf3Ng==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n8s1HEcx/HvpNjkR5wfocNFS0mOkKh7+XU459wZQiydmWSNRqtpq+9k
M01qxS6VhQotEk3lV34tVGNL44+SLP2ehmmLfpxqvT9/uO/23XePPT+ffT/7
fD5O6uyYdD2O42R/339f9ljFtXY0Z4nwX3OSpKmtZb4WzBzqg0q0zv1OZEP8
VMdGqTOZzTBS3+kczzEL8DHadHJVuSPZBlkmBdnmPsz22DGeFPjhoQPZET1X
vdc4WzKL8D4i2lWaLiQ746u84dbdZxvIm/BxbVfvaiHzZpxZdrg5n2JP3oIr
x8KvjXbakd0QVlwnsxYzu+OL8Lck55At2QOKhBPi+fH1ZDFc7A/uq1Exe8LD
cUnrX2dD9oJ7Rctsyi9r8g6kJsYvabKYvbHwY+DxxEsrsg+MXnw7oj3J7AtN
bXW9SMi8E6cL+yc0PZZkPzhOW5ZfT2TehbRXnZ11MwKyPwoG96b8kDMHIFn9
dtrtkwV5N9RDonYvnnkPqm8MWZ4bNydLdAyIpZfbZMNkHqjorjsW58Z6IEYl
F/StX6+jHqjTg9A1WPRm8RSbH4T0ylq9E1U0ngteaT4YBe/UZ981sB4CV8VG
Qehh1kMQwh//LS5iPRQBnvIik1TWQ+EUmFF8VGtGXYrc5qZiZT7rUnTYllW2
zbIeBr+RjqqBKTIfhia7hgejkabUw3F/7vx222ET6uE42qEM2LlI5iKwbbd7
bPcHY+oRUDSUhqa3kjmZTpdh3YzAas6KzY/EMqdaTs2j//GRWNC2JxYYsPXJ
kXvbX9JSw9YnX7leLkpnf6Ig7fp8CM/Z/ih0zkcBo1WN+V8ush6NR8kuvUIj
dj7RyBlf6DvgxM5PicT9feFJCXRfoEQlP5ZveofMK5GVYKBK05B7lLiXk7uQ
dJzdL9XK8VAho1wvz9iL7ievQrKhLX/Jj9yjQqH+k6eGGnZ/Y2DeOJY5d5KM
GEwmlBaVfBfgD0HbJso=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIU2Ecx/Hj0jSXeUmXprY5NUVLmre5pfnbnNeczmoVFgmRr1aYF3LN
F52wsiAD7YVgvSgJK63QQsNLZKldlJQk8kUXg5FQkfdLDrUL/p/A88Dh8OF7
+D/POSfgaMGefBHHcbq/1787WxJjS0ezSY4VTSSOPR78MOvGzKGtrdWofBhA
dkKkUfI5Yz+zG6KCb4Y0T8jInsgraJqcqWb2hvup/tPKeGY/jBiO1V9plJJl
+FZdUX7HkVmOiKlA1yMHt5CD8On1V/3wJX/yVoxWymYtz/3IoRgf6Gn1ymEO
g4OL/3A870vehprtt4balzeTI9BnN6gOyWHege5MzzxjnQ9ZgU7VOIqqvMmR
aPEZHZkZ2USOQhwCRZiSkKNRYrsrV6iZY1B+rvtjTZcXORZv7w1OB51gViJ6
qLI0uN2THIcKS4/513VmFWqzztqszsxqPDpZPJ1r3kjeiUOpT51tTR7keKz8
P+YEWDuX+HAl8y68y59bF9rmTk6EjjcvKSqYgcOOdbW+yWQecDnu8eNioRt1
DVQDHTdefCHzGiTtW4x1SNlAXYveade9uYXrqWvx5KV6LNRK5pJWP88nQSQL
s4kbWdfh2nvxQn2MmLoOVdbiMu28I/VkSNP0KkmDA/VkWM7Ynpka1lJPwbjK
tqyNIPMpkC6/6Y+bcKaeile9CaUl7U7UU3GhyqQuk7L5abjdMSzp82Pz05Bz
WRFuf96eejp9XxH1dIjX3Ld8v2pHPYPeZzFxpQvM7UZU5c95TdcCdYG5TDr/
HHXmUep6QdfTvmxl0XkmqWcJ5mfjQG7kgyL5b+rZgm5YbRgE8wS9y/B//z9Q
PBkF
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIU2EYB/BTmppKXibTbd4vscoky7RS2386p3O6HawRlgV5KVOkSMQQ
jBMkZR8M7eYFizKLGC6chZgWttI+BIamQoZfSkFjpNIYfki74Pt82Dnwcvjx
f973eXmfqOLzBWWbOY7T/Fv///RJTS8HeyujsaFl1bajN0/Yfcgc2rqbptZ7
o5i9cO5T/c+042R/DChjTbK1SOYgRBrTW+yd5BC4tdbXWzXkULRNWviP/RHM
kZipiUhqDydHY72kc71DCGeOxa8qzw/9K2HM2xHgGI2fSiArMSuUVpiPhDLv
hG5C+qXmqoI5HjbtkHVsTM6cgD/eDcX3I8h7MCPd8mzMKGNORLd1pOv65xDm
vZApKsvvVZH3Ib7P3SO5KZg5CaXz1S8aU8n74bHsN91cLmVOxreHkyZ/OTkF
JV+Hhp7ag5gPoGuuoTjzDPkg7sStFXIPJMyHYMleKqj1JadiY16BzGlY1c97
Xckjp2NXmFR29jT5sMgqrD72vDynJgMTqhb34NmADQuAj1tP3Y9bzJwaGuHS
WuI1ytXYYYgJyqqiPANPYnJnkmz+LM/AoPx258ASM5eJ3QHKlfZxyjNd6zkN
VMccRQYFna/BZJlzq3KAzs+C9vViBcYpz4LzhiX4pINyrai/FoELwzZzAeXZ
qO593sjX0f5s135cjmh/DhQh3xeaW+h+OuRrR0fm0inXwVdiq72w6MfyXFSb
U1XWR5TnutZzeoSZf08XpVB/veh98lzfU8iDd9fqKe0I3S/f1UK+aD4GUW4Q
zdfoasGIN0Vxb8N9KOfxnh/uEF4xg4ddUljmbKR6Hh6mTX3L75iHeSzevaju
UUnwF6dmC0Q=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd01tIk2Ecx/F3QyLT0LmTptMpTaRNyco5LfPnnHOHLkyQ2li6inWSLLUS
p9XKCzGMoEVBKhEOqxuppiOLooOHRJbeuIuMYp0skDbBRCLtgM//Ql94efnw
5Tnx8KYeOFHu4HMcl/fv/f+lR1LR/+RBdRqWFS50lKvvn40ic4B/+JPSm8q8
Fk3BGY/ARo7Fvi9Hay79kDOLUGlxtqRcJsdDm2kKRorJSbDKxxvyalOY5fh6
MGIosyuZOQ2LvPqQLSBj3gjB3LBqMoucjh7ZUkxzdRJzBo7rBcK+0UTmTZB8
s3LyNLIKZ6Krpg65NjBngR/ZomnLIG+GtCmkuXA6gTkbIv+70aXv8cxb0M2/
dV2RT94KsTRH6b8oZd6Gsrm+0Uc6cg56Fu+mpHdKmNU4p3J21ITFzLlol05c
na8la/C7OyJ1ekLEnAe1e/CIMY56Pgym9rcPLdS3w9monA4oyDvQ5Zp0xvQK
mQsw5uu/V3eSvBPaLPu1Oju5ECUFn5vHf8UxA2sqeN7wK2YXkK2/OWDyUy9C
rCo78c0fAetFWNe9UKkfYua0OHZqwcfbQ+O1K+fjiuF2hN22O9SLV82vw41g
O+/9LHUdntkUL5KjqJdgRmhxzLdRL8Fg2fMO12PqenzsUOdMuanr0VsaKm+I
pvOWruqlUMokCYf303jDyv24DLjteS2+EqBuxNOR1g8L56kbsfy/UDfB7J01
7c5l67lMsFS9NFj30vpmJA/U+1rHqJvRNNm4nrPT/e2CciT+pycowl99F9wD

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzV1I02EUx/EHW8sV07l0ruVy+xexbKw2azm3tZ/LqReKvSADJQJhEBQY
zqhoF8MKRjljoVchyLwoNAZTDLZRbRe6KLCLQrvpBQvDICZUc47Qip3nQg88
PHz4Hjja7p6zniLGmPHf+//zUXRMJ6KXBBS04hhof1V/QcHN8CQp6g/EteRi
CO5b28Rd3DIE189lKjY05HIEE21p0Ti3Eh0u+euQm7sKY5LU0vKnarIGLa3q
8PARbgFPzSXJD8P7yAfwrO9jq3xOTT6I9OJvh0/FrcM34fn8aFsVuQbbpeoF
m38vWY/v92NN1rSKbMBiILcgK+U+isfj8cBO7R6yEZMs7L8nU5JNmEmNvU92
V5JrIV4pnQ9dVJCP4UX1Q+WIhPs4Uvtv65hQQTYjmhtcVqKcfAJTV7w/O6/v
JtfBZf/qe5OXky3I3o1Unv9VRq7HO09WootxW2GZS4zOfpaRbfBOWB2TYW47
EqqhkViG+yRuHEqvedq5HbiaOG2ry5WQAWmvyfq2X1qwH1jTP/A9uiyh3oBo
pGfI0FVMfYuZE7XBH6sNSdr3O/Fyxn6tL877KeinRGLz4A7qW8waEfrivelc
5b0RZwaMh0V3RNRdcHeaIr3ChqPQXSjS1OR3TfwpmDUhY8mvOw1Z6txL1Js3
29+8eZ+10B3G/gJ19MAv
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdk2lIVFEYhm+T+2RZ6eSSjUuUpkw5Zjqa+Tou464z46hY9CNo08hyQcjK
qWwDCywpyZAWSNNSSrTFkIko2ixK8E+hiFIQihalOKktzHd+nHPhcnnuc77v
/c5d/HeUGHbKJEna/u/8f2WHwtTVc684ADaajHv7xD61xomxhOvKca9VHf7E
Tojqmt9rl8zYDSVqTfjtYT9id3iPqRorzjL2RFHlJ6NsA+OV+OXa7eBTpyT2
Q3VD24Gf71YRB6Awv2H3tkWMV6Nqt9phMXyJ16DujHPrxLGVxEGIrgxq+tjt
Q7wOcs2uwbFIxqEo/Jqh8z3hTaxCVkFV2PcBL+INGPSxG3KZ8iQOA4aObl2a
zFiNCuvajlevVxCHIwqBMvxQEG9EaNdN02wP4wg4Pg28GjrmQbwJJ2qefb5s
YRyJ3wevVWfuYRyFwYLzp2un3Yk1uJJ1zDriwjgao0XB0XOnlxPHIHi14+i0
jvFmJMWOHn5vXUYci3OdziG9Q4y3CD4O7boJQ+UiVg+U72nuzVaQNwNf1geE
7w9eSj4eHT53HnxMX0I+Hq6l6pj+467ktWiJf/b8hRexWYvilw97+x/JySeg
z3vyW72bC/kEvHweW1n+2Il8IiY7P8wd8XAmn4h77SX1qq3MJwk+CYFplwYK
W6iflAzlfN+bqEnWPxmNA/KZWxEsX4eZ0AuHm/exeh3fT0rh88wpOFVXHF2l
dCSfys9rThXmS8ORpv4niuGF5NOgTMnUKFrtyadDXxsWYnfSjnw6bP+bjHwG
ws+NT8dbZuJsPgMyv3VWedusjaVMns0CS1mCz0J+obq9NOAP+WzBZ/N5Ug6/
HjnCPDkoa4uJu39Dss1ryRHy9byHnu9n1vPPx6KHfOHdQ98uLqD9G3iGQag3
CPkGYX4jzzDy681GZERWPxhRsXyjkJ/Lvw8IbM4V6nOFehO/P5iE921C3UhZ
lXaavieLie8n5fHrkSfk5/F5ljx+f1I+JjTWea1qivafT/cl6S+bPnz+
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2Ecx/FZkjOCTN2cTct5yxvWtLTU2s/LNt3mZpasYUUYUmTibeKr
6jjIMDVRIqgoCi+LmIJZWduYRRoi1AsNJayEZqgkKd5SLLvg83+hBw6HD99z
/s/D4ZHkFWXnb+LxeLJ/9/8nXcKcZ7aOgkCsaUY2PGsbtGwn8yB6cfH21jYJ
Mx/tbuWZEi3ZAytlraXq6QBmbzS1/rJHPCKLEBYnG9FoyH7gP0HNxy+7mQMg
7kvtL/MlB2L21ujrKcMu5mB43e/t1b31Zw5F5dmm5tlEchgK3ke5lzb4MUdg
0m4qdljEzFFY0Kt4+u87maPRUiQNClWS9yGk/oNiucSXWYpP9msJy+Mi5hiY
nN2llTpyLEb+iG25Rh/m/Zirkp+Qx5APwGH15M/cFDLH4frl0z6WeQFzPIpc
VqoeJ5IPomPpxqQI3syH8KOwZyF20Ys5Ae3K6eyKbeREOO2/uch4T+YkXDAu
PXfRkw/jYXOfoH6IfGRDl8F43uzQCcmAaSyvbsyyY80cIBY5JxoaPVhPhiT5
XHX5KjOXvKGnYG7VajC5UU+BTD9/Uitm83ipCNcGecsLaX4qBmSNrj6fqaeh
JSG2z3yP7YdLw+1uc0VOFO1PjjMlp1b6J+h7OZbU3/iVGuqK9e9zChwbqq4d
8Kf/pcSWHJfOmTfUlegqbjVEC6inQxN/pcsZzcyloyfr1V3OSvMzUFPXEtK2
mXoGpIo7L1XvqKsgtYr3fC2n+SpMeRnyF6upq9fP49So63SPdIxS1yA82G3s
p5Lma9avx8tE1t4HgUYROx9cJo7WSiNdr9J50cJsGxb2+7HzxGnR7j8YGDFO
XYdLubKkp8cF+AsuCvng
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/GDoTMIdalr6nQ6LEzGqFnaprafm568bGXrYhdfiKBISkZK
hjN2gghCyzaKSkG6KJahZCiF80WZSihIFFlZkbGUVS+yRCvxUrH/Q+w8cDh8
+PL8D5yHJ6640lrix3Gc6e/z782WbF+vq7tcBa9mDPO2laXFCGYOBZ6h8y9d
ceRAvOlaqbWWModg7HZ//H6OOQxnxqcM3a2xZDmKqls9mhxmBS5a+TbnrJIc
i5Fp3ffTxcwqWAqu/EjtiSHHg2+bKJn7Gk3egEZ745RZy5yAW/qR2brLCnIi
7qdIo98GMKtxMjGsqnd3FFkDsyTJf/R9JHkTvrif/VLGMG/GnWnNa8+BCLIW
kwsPuU67nJyEpUFlfc/EOvIWNOiXS001zFsxuvHoPcWijJyMgJngcUcZcwoy
1wepP0iZt+HahZYjAyfCyToUBkYKV3VhZD1Otbzol30MJadiz/i5hufRzGkY
zH/ULPStJaejUHKzKSpLSt4O3Zjr+vBkCNmAKLnb43AyA/kViaNzEWQBONjU
eSNczXoGLPzw0Kd01jOwJnSg5tjnYOpGFBzSdh1XkQUj7qapyhKesG7y/Z5g
Qr225F1zEZufCdPexWR/Poh6Jn6rnXXtFaupZ+HpUHpNdV8g9Sx0d1Ve0hwm
czyU2RadrMOfOo+zjnK9TSmhvgMOd5XN+JMsiMxlo931SjaiYPuzfedxOai1
Lzwu7wigniPquaL9uTCn2B+4Nauo5/layKPzZN0M7/3zo26m/7li8HYLvukW
lo2aea8FkbmdNIeWIDK3S9RF5vJ9DZGF//4D/en3Uw==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzF1Ik1Ecx/FnDttos2m6p2Ur55pLhswslznN57fNzReiVhFSpBdS4Ca9
kItiXfRIFo0MNgov7KYEE1mrNJvibmxEF4JIFy0KTKgrDdRIS0eMCv8nmAcO
h8/5nvMvbL14/FwGx3GWv/vfyRZ/8lVsqF2PdS0J8eHiso9KZg6zp8c6k7FC
shzLge8p8QxzNryOgXm1nDkPmWupb65RHVkD301P27VmZi2m3l5wqlcLyDoM
qpUeaxOzHgmV8cWX/l1kA/yyWxPm9zvJRsgbnvUu8szFmBHPesMntGQTRo5y
rYYHO8gl6LQEViwmZjMmJdPWPcfyyXvBzwjjvp7t5DLITNFufkRD3odQnzS4
UMO8H55EkVkR2kYuh6j61dViYbZAvCIsW408+QDCOQsa40s1uQLvnk7/MJxn
Pojqldefu1uYK+EufaT3afLIVsz1XLZFhFxyFe7e6y+KSJmr8cY98VAc30o+
BK9vNSppYq5Bx9DzgNufQxbwZHfjp/J4Nhk41Rt5rC4hi4AyN3710pyKug3R
pWBp/tQW6jYksu60rR3Jom5HsEs6Ntu8mbodt0Pt1usFMuqOdIsOLFYmU3bz
Juq1GIh94Ce1mdRrcbjixuhXs5S6EwppxD9/X0LdiQydKakI/xbWuyvdoovm
/6Ret+F/HTrCVcJwH0fz69Pfi/V0z1ZDusUN5hr/+w/gosAM
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQNioVt3b8xWcoDwPtg/Pbqb7YwIjM/gsL151WvV
g4pQPocDK/vyS+/iYHwBB6etO5dL8sH4Ig5S1iU1KzcrQPkSDpxxhidVXWF8
GQcZ8c32nOfkoXwFhy1R2UvyxWB8JYd3KdPFZOrloHwVh7V7AstX3JaF8tUc
LnX7dWmqw/gaDvuvllobFMlA+VoO9tHpwccPS0P5Og6vpC1uLpaD8fUcUg9t
D5i/TQrKN3A4csNrlvNTSSjf0MH/um4C5w8JKN/IYc2ViMrbETC+sUPlxsAf
GlXiUL6JQ9vEbKtqeRjf1IG1RFa7focYlG/msDWmKiE8B8Y3dzD7FKXhfV8U
yrdwUGS5++DzHxEo39JBIn7PpT43GN/Kwce8fvtjPWEo39qhJGP5Pn8xISjf
Bo1v6xDDvmiWtKsglG/nsEzZ65bJIQEo397h9R31Fv0mGN/BQfCNiNgHMT4I
v8HBwW9Nn2vqVl6ovKPDCsfDR49JQvkNjg7feHc2/jHlgco7Ocy+xv1zmSk3
VN7J4afOpJrlOZxQeWdUfoOzw8Z1+VP0ojmg8i4O8h6+lmKrWKHyLg7Ld18X
OyUD5TO4OgT2GGqztLJA5V0duJnXVr2azAiVd3OonXd5j9hDZqi8mwMkPTNB
5d0dildb229axACVd3dgUtD6xb36jz1E3gNq3kd7AKChuRM=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdymtIk3EUx/FHpQvZck5d0znTR1dWa9ms5W3u5+Zm69UIQxpSsloEFdFC
ikBYEmEhzLYZRBGUCc6cLS8kWuuCUBqBYcwgg3VhDaUa0oux2qjw/N904HD4
8D1F1lP7bKkcx5X93X+XjXj/6MSD4zyWFdVet4a1D4XMHIKlh7pG7xeRV0Pm
c3Z/O8wsRORAj/ncKuZszG1N7Uv6C8kSdKY8lvJm5nzYXH7Fhy8byIUYmBmQ
eQ3MPGxq4Zm4s4BcguJoKPB2XkbeiOHpezGXibkUe4xZ0yN388lb8K4pNPXi
q5SsgL92rGqsmVkJzZAu0uXLI5fhU0dsTpjBvAMHj96+sNKRS1YhOvwm0ZbD
XA79d2/3ySMS8k4873Rm9vDrybtgDYSWkiNishqX4zP9uYkc8m68ikeuXOpl
roDaPXnMJGKuRDymv3NWkU2ugmXpvVqeyCJXw/qSHy93MNdAp2zx2FuYNZg0
P73hGBeRaxFolj8rSGfWYipY8vPX2kwy0LrZ43YNCZftABbnN13c3k7m6iA4
IVrsOM16HaSSz5GrLtZ1aJ0w11TE1lH/z5weTRbVoJ3PoK6HvvG3eoWR9Xps
0ygbn4QF1Oth8g72y2/SP2eAwK6qnm1n3YDivdeClr411I14nRdd8AjJDiPa
bs0+En9Mo96A9DTf+QV3CvUG/KiMJ3XKsPYPN9DCxQ==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIk1Ecx/FHl1nNyEqXrWmbmbUR87Kcl2n7bV43V1FowmohofRCyGpY
mhGzVKgYGEJFGIEkLm9oUSajkBgopoIJ2o0KlPBCWISzTdGK/c+LPQ8cHj58
Oef83xzZmfLjpYEcx2X8W///7BMVPnf2lEXDp5/aY+qe4fFwZg6ucyeEC/0y
8gYMPwoZHSxhDsWXbyUKyUbmMAR5VudzeqXkCKgKq03iQmYJxifrlY7F3WQp
JqbKUjrkzNEwjZ5e/6EoihyD2ZqG9I6uSHIsZhNlAyKvhLwfdZ/i5CcvMSuQ
Ujkm6B7aRT6ASP394opsZiXUa3Mvpu1icjzuuUZaCpw7yQkQ3k6u6nwdQU6E
szmq6aqYWYU3+Q7F2Kkd5INIi+1+32EXkZOw2FvX5/4YTlbjrXfmVn0LczLK
A5br2zTMKYi33Gh95QgjpyLmckCjemE7OQ3BUesKXO+YNXh23vrbXMmcjoSc
B33GkW3kDLSkqQZbHzIfwp/HwdemdcxaFF+wLA/NbCUDMt3ZmxWroT7bgCr5
gKf0KJnTwdqu0T5tZl2H+c/7auOus673t00Pw5Outr1NW6hnwr25r2YlKYR6
JvYY706YHZuoZ6GhVvDyq4Vsy8KdKWu1fimYejZanZOiIUkQ9Wyo7D+WdP0e
ra/nYCHVu6pXun228czlQijovDLX+It6LvXv1PP8z7PlwfceAul+g79tBhSZ
E7suRq/RfiMCpQqvsH2F9ht59+fz5svnzW/izWfizXeY13nmjtCcHPcXKZ8C
uQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1I01EYx/G/G9lsOG1b822ruVLmEjHNSsv225xrc6OyIUIXGZFgGESp
mStpdVPSXC8aSg5ji4penFhIZMVGZSVBF0WziyhXlJBEM8g5EanYcy7cgT+H
D9/n8Nz8s/cd2lXP4ziu7N/3/2ZHVjP8aKhRhZjC2vu9I80FYmYOWRaXVzKc
TRZg+k3dh2Ibcyr43rYdx+aVZCnUqws7x9zM6Xj4RWZ8aWaWY4nm/VXDxCqy
Eja1nH/CyKzCoLda67+ykrwGruuTQreEORe8BY+//6SCrEb0sLnBMCwna5CU
mVF3Oo85HykzI6ZwYxa5AM7XIdFEIJNciJ4DaZxHzrwOz6zSuhpvBrkIf8SR
/c9zmYuhCQ6IBb3p5PVo6va1JwXSyCUYu3y3ekrNvAEvnE9bj/pl5I34PHWz
pda9grwJ44lnxhW/peRS2NvWTgZzmMuQH3b5HpyXkDejJ+RM+DQtJm+BLdjh
fKtgvRyzlm+CU1bWt2LZtdk9xtHlZC2ahgY7dtqZgZa87q5L91JjdgC1u4t8
R1Qp1HUw3/LdznGTHTqcK6r/2LeX5jk9DuovPBF5RNT1CCafbYhuT6Zegb6g
MHqjREi9Aq9Gy1ubRwTUDbj4tem4PrKUugG/SucW9AWJ1CvjeiV4Ss2c8M68
NtaNNP89ZgfzDPVtEPIH7D+6Euh9nDkTYv8/j7oJ7f3vHstCfOrmuPfmuP1V
1Kdpf1XcfsvieYcFxZ0/I7pAlLp18bzDSns57i/dNOla
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdyVtI03EYxvE/stLQPM5lbjX9s1Ta0Dxkc5p75tzcLnIWiSBDaB3YWBCU
05zlhmZX2VDIi06UBwTNJGRqWmIosnlhRTqJIpoVBWJICKUVVvj+LuyFh5cP
32TLuWOnQziOy/m7f5+dqNw79sjOY1Mr6siaheCbKGYO1TxviptIJodB4L21
4apijkawduS6QsAsxOL45Ivn3UnkBJQPm5fmNcwS5Et+NzS9lpKT8HFZc8or
ZOYRVVVW6DLtJcuQYS/9NPdgDzkFtnifTSRkTkNEU3t7f52EvB8z46rRqSkx
WYFAWMNJk4Q5HR6Z6Xa+J5F8AI6nUueAkjkTw4PNqhNDu8lZMCbOvZwuZs7G
tzvp+pGdzDmQdrY0ph5JIB+EYz11wD+zi5wLa/27Mx0hzIcAy9BCW62IrERf
zNeElMF4ch66b1yIeQxmFWL7520rDUJyPi7fffVEFIwjF8BZJ/8c2Mf6YVh8
/Gi2m/VCmC2LHxRfmNW43+WL9wRiyUC1tWfcJCK7AXNox02xLoa6BuqKVXOp
mOzWIG927N70+2jqRfAHZKs/I1gvwtLb1CsZjaxr4RgrK1D+iKSuRZe/sya8
mswVb7W7GH0FvDVtMoq6Dtrjv3K36VnXoVLeapi9GE5dv9Xu/8yVYE3Rdqnn
7A7qJXC61p/Ze7dTN+Bqq11VLw2lbsDRa5lyQbOAuhEVlVkPz/Mb6s1uRHbL
8nfNxJr6D/cqyjg=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0FtIk2Ecx/G3rLZQS0vnoW1uJjk6DKcudfa63zt16nSSkheRFxEF0S68
UAxW1lqYCHlRCxYUChUrs4KZhtNOFptSEIhk2eEiMonIXBkehrkK/0/Q+8DD
w4fvc4BHfaCu+tBKjuP4P/PvyoaspnfAa0vFsoLGJ90a3XgUMwe30veZ61WT
pUjfzGcW1DLHQDie5MkIq8hxsOrdg1Me5kSoYudciwKzHFkt0wnO5ylkFVqu
urJ3q5hTkRYdpR33KMlp8HZcbry1gnkL3o7bOWulgqzBiwoFP+OTk7diNtp3
alHPvB33hoKzRvcmshZKYanHMptMzkBzazsvVzPrUDhtSXeeTiJnoltodS6E
E8lZuFiRVi1tY85Go1d5vuZ9AlmPg5/qe1rzmXdiJhTwv3sjI+egIdSZqjMw
5yL3iDGzLSGenIeqs7ptq5rjyAY0tY/el33YSM6H90dyh/0w8y7MX5OcmBA2
kHkouhbHanNiyQWwmgP+CT6GbMTMUv9ep4QZCHNV4f0N65ftAGK/xsmCsnXU
BdwQnvoDSdHUBVE3YQev3fNoknUTLo1FLnj0kdQLMdL38ufrebKjELbhvoej
PtaL8GDI8E3zMYp6keh8MbLapuaEx2upFyN4d+RXUzyZM2PYzx9t6JdSN2M6
L7Rk0q6hXoIz52yGYykS6iX0nxHUS0W9FPaToUHbTXa+THR/Gbx36i5o95E5
y//7HRbR++W4PvBK9ky+mno56rvyjd1XOOoViIy4bf/i+m5c7iJzVrpvkrpV
1Cv/9d8uE/th
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtMk1cYB/A34hRXO6UIKliB4qUKgoJ4g45/QS4WBHqnNRpCgnNqYmAq
8/5ayYY3RCCbl+zLokAA7zcumbxQqsbLEiA2i3PuA8tCJGoVMwQF3bLnfHhP
kzfNL//znOec09M3onCbqWicIAhf//v8980+wdYbbVe2aPC/fMlGm7/i92Bm
AbcONQzM7Ygg+8PdUGhf7GCeitjYzvaQ9+HkafAmb/AFVTPPQNnLQz9eXsY8
C+W6miWuK2HkcHR09Yn3vbPJGlxwx3iUgcxzUKR+d/qyQ02ehwjV/tl+J2aR
tXDvq4+qexhKXojRjetK696EkKNRq/6sotfGHIPbuapnbQ0zyYuxstTSN2Fk
BnkJ1PHfPw4rZI7DsdZXTzYcnU6OR8XOA66kZ8Hkpfj54OSr54zMCXgw0n/k
u/NB5GXoiCzTChrm5UjcXHKq4Po08gqYvYeP9agDySvRlSedFVtV5FU43V5X
ao1mToSqX+psNAWQk7A2/Y7nL91Usg71erfnzkwl+Uuc9SqGaxMU5GR4BqeY
ncWTyYCyJC6x10XjReCmrzI25NEXlOtxKbTpVk/WFMr1XL8UNCZpNmndLE+B
3Rl3sURDFlLlFlO59a2GM+pk5q/f0vrE1Qgbe/Rghe9zytPk6xfT5OOFdMQf
fzGklyZRno5Iww9eZz2rz+DyDG7+TLnFTNzz6Eq3t/pTvgb/KFsOfkig8xLX
YMu95tu9Lay/gcsN3PqyUFnm1/znejZ/Fk72fbMnZWgi5dlc/2x0Nz9++9s7
Vr+WyzkLOfjl7qqX2j7WPwfD0VV767bSfoVc+XmIudz68+BVlm8azqHfA3nc
eXOW8rjzMcJ3rXt0XxD1g5HrZ5T3k4zc+k3y/cLEnacJ48IXjigayZKJu79m
+fwwI6epIq3oBrvPZizSxVja/yZLZu5+WuSGBYNjrQ7XRLrfogU7FtRUV10l
SxYo/C7sfl7N/n9WLArQvj7TTTms8vGiFW0hNT+1vGL1nAWbfDxsGHg6vyzW
xeq5XLLJ+wl2ROi/OrxjjNXbURtpeLK0k9XbodyqGigvZvV2+fxCPj4Kxo8F
29n+87Frwd3holxWny+fT8rn3j8OFBSvf3+/nwyH/H0lOtCTXDV++h+US1wu
OJF17bXBuDwQnwDhhb5I
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQNioVt3b8xWcoDwPthfn/F3UxEnjM/gsEFy90rp
+YpQPofDuuS2/VesYXwBB5/tBrrhLxWgfBEHH4UAJ60+GF/CgafBsyvJAsaX
cVASPh0y64A8lK/goOD+Y+12MxhfySFAWTZYokoOyldxmLqRhe3tA1koX81h
0ol7hnM5YHwNByUmnR0sFTJQvpbDH+Z/m09vlIbydRz+RXela26QgvL1HNad
rwy0MofxDRwMnZapLl0gCeUbOlQ0CE4vvygB5Rs5TFZ4+iLAEcY3djh4eCnT
tUhxKN/EYXfPhOXVG8WgfFOHs84Rkk9/iEL5Zg67CnS+BzPB+OYOKuWMk83e
C0P5Fg4Ll5wQ7b8mBOVbOtgY+bTzJQhC+VYOr++ot+g3CUD51g7OIX/MWN34
oHwbh73Hrd5pPOaB8m0dmBS0fnGvhvHtHH7qTKpZnsMJ5duj8R0cjHvffnc8
AOU3ODhsXJc/RS+aAyrv6NA2MduqWp4dKu/osHz3dbFTMqxQeSeH95a//jnp
sUHlnRwmPi6udvoOVc/gjMpvcEZVz+DiENhjqM3SygKVd3HwMa/f/liPGSrv
6iDv4WsptgpqX4Mr1H9/7CHyblDzvkH4DW5Q//yEyrujqm9A4zN4OIRHGa0r
UvoPlfdANY/BE8p/BpVH8AENXM0D
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIk1EYBvAvxUwS01w6N1O3tLzbpqnldM/cxet0FWsYGmYtozK7iaBQ
X2pEWaFdqGaieUnSXGSkOEUz6UKi2BUqC0MJswQllVFpFzznD3fg4/Djec+F
77yCrNwteiuGYZT/vv8zHS7aBx339guxoElpX9ucupFLzeDVdEfWhy4B8TJ8
b682BO2kdsSzdwODYTbUHLiUxwQOVnkRc9GfvcM0AWp31G0b1lQNexJ7YXT3
x1yFiFqIMPMbxWyZB7E3un4WGplPq4nX4nex6WqFiNoXOZXOxSaTO7E/rhSc
vDBhQx0I5S65cqmWTxwMXc+YzL6BR7we/bzJ8cuO1CIMCKJlcVo3YjFsrP50
+pRwiUNRILkZo/WmDkNPb73V2zRX4g1Q6kfun7vmQhyObs8KbqUddQTCeXa1
U9WriCNRO3oqS76HQ7wRyREn2kaCnYk3QaQytCf2rySOQubhjF/Px5yIJUi3
rTHwldTR8EtZw1HmUMfgtX7WzredWoqRzjk2IILuBwhk2Wfy5h0XzAJS3XR6
Cp/WyxDk5DtleEFzGSTi5NMOmTSPxZcQYehBP2I2Ft+G1pWEFJF6Rr7YrBx5
HRpJpNmB5ApoDvj3zbjRXIGjTVHSlhq6Xgk+d2Ss/CLNLcyoFtezKui2i41H
hCtIHgd750f5h74Ss3FIuG1s9LlB83g0SYR7fXtpbmEmAa2TZSG8fnJfNgF3
+XfaXibRPBFq1ZPHo9H0fAszSRb3S8KPeVNakS3Nky3OT0apWD9UkUlzNfSV
t6wKq+n/VVu8XwqWWzcXjF+ieQpmzxpdM6bp+6Ri3zFz6xIdqWdTcb27IV8b
SNdrYK6zPT4qI4YGpefrfZqtSf+xGsT2bPUI8CT9+VCD+MRz71vSaL9uRsBT
7kzdZw7+AhM8Db4=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1X9MlHUcB/AnfoiGCCicyA8RErSgMyAQ+SHvgzh+Jhx3/LiDA0eyuaAx
Aakw5hNZUYGBObcwWZSJidCQlfxKH0LqKHEDJrB5LROpoWa3QQrOIBuf7x/f
57bb7bX3fb7P5/t9nvucT2FpRpGVIAjik/f/n+ylyPy2r7PYFyuyxKwb9vNp
t2cWUH8MbaZ2H/JqxEy95j2TzuwE64TS4IH5LWQX+IUvb5huYnbDEVV/QKSK
2RPNtq379l/yJm9ByHvN5ZVrmX3xztWGyuGizeStiDDPHPWZ8iL747J0dXL2
pid5OwbmWsq9tjI/h92TnfkXEjzIgSi52Zjm/4M7WYlbtQuTTo7ML8CsrVT8
+ukmchDM/e9HLP7pRg6G35prOcqZjeQQDAx+ZTWhZ34R+ur78XX/KMihGC8x
95j2MYehzfm+m3+XK3knXrnR3996z4UcDrvNNrorYxvIu3BKvF7l2MEcgZbT
JtePJ9aTI/Hgw46NxnlnchQ+Ci4yn9zrRI7GXfO2IztqmHfL8hg433NRWBTr
yOAtAt9ZGna4j7BchbmlXn2NHdWLKnzjcf7iWIoj5bFoi/Ldv32QLMZitPv6
/NSCPeVxGJpz1BoOrKU8Tpa/JLu+zEI8sg3BHWW+bP14OJQFR47XOFCulq2v
xlnV4NCPm1iegAcOPW8/DmV5gqw+UVafCENAY+K1N1h/SXy/YhKKTd2XxntY
noyTE/aLZ0JZnoyGI9bdvxmfpjwFi4HH3motWUN5CkbcLXeOO7E8le9HTJX1
/7JsfZmFPfx64h6E1P/1UCXR9YQ0WZ6GwC6bVWFH7ShPR9XhRwPF51atGOnQ
1AUF2LxrQ99Px8p8sFqxlA576/aqO588RfUaPocG5W2RMRe+EKheg+rm8X7F
79ZUr0Fr36TiZ09bqs9A6s7DF6eVlCNDdv0MmIaiX6/oXU31GejsKD2uzCUL
Wn6/0PK5qOXPX9Ly+xV0aJwuPxT7kM4DOli6Rv+tdmX3S8evJ+n4foRMfn1k
4pnkExOGs+y8M+G9NPJLuIUsZcqenyxZfRb+3vVoKVZJ/YlZ/HlJWbL7l80b
2fx+xGzZ/rNlz18O/7xBZjEHz0crdZf/IEs5ONiXHhW+wH6fej6HHqeHv6y0
r2C/Zz0/PyS9bD4ZoG9qb3ENJMOAN5/9abEojc0bAz1PrN4Ah5L1d2sPsPpc
WX0u34+Yy88TKZfvT8jDsqBZ3ltB8wV5SPq645zfZ2ze5PHzUMpDnO5xmK2a
1Rv5HEZ+f6IRRafOWB36nOa1ZETN7cL62+fZ/M6H+vvZVzFKRj6Cej223TpI
8158YnVTT/IIWcrH7IkyVXsM+38ogHbig7oxLzIKUGjy7Q0RyWIB8mvVs9FX
yFIBPG/kwKnRBf8BDREYPg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1Ecx/FHnWbe0qZLbepcEZVjNVfqXLrf5tQ5tZuKNOlNIEgLJ2qM
7LJH7PKmzUIJNBCMxJgXciLaRauFGEYXX3R7E+UgMAgXacZgWbH/ebEOHA4f
vodzzouTecJytD6U4zjV3/lvZUNUM/FgzCxFQF6N8Ypv6mQMM4fLCe0DzXcz
yZGotq+uZ9Uyx8Ofp/d3hDMnYqlNoe4bkpCTIZqfvfjQwCyGWuy/0PEhgyzB
nLnqdaieWQqT0913sz2dvB2xCvch23waeQfmFlc151KZdyKk+8dMWoOYvBuH
Xcr8V+NbyTI0FFbPSEKY5RhYtK1E2VLJezHtKk83vEghK6CyVnsifMnkbBzv
lPV8tDArMfwu7dPg7S3kfVjWNJZ9DmfeD6krsne2UkTOgcV+JkXYlUTORes9
t+SpkTkPWZ0lL3XPE8kqOJpOO+uqmPMh8zpGJzuFZDV6Hg1aa2SbyQfwZY9U
2bgrgVyAGKHb2rS0iVyIY70j/UmyeLIGB4cdxfUTsWTglO7adFx/XMA8sDD1
ZuX9r2jqWmwz3nhruhNFXYtnswXW1vuR1HUYG7V0y+vIvO6/XgSl/dua9vFG
6kXB53F6eMcX/OeTWNdDNi6IyHFsoF6M656Ws7o1Ml+MNpvvidkZQb0Eyyrf
b52czJcg8J9DqZei1pQ92ixd1wR6KY5cVWQJLgmoG4L38wZU5NomPfIw6mXB
5suQYahUiZzh1I3B5/FGtAypNa5bHPVyet9Pur8c0WEjbV+7vgfMVdA+jvsD
oTncUA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2Ecx/HjpuU0Yra5ltdtWSxborOmU9t+bs7L3DKDoQlCaUJYEtjl
hWQsa0VQKCsoo5I2SEgN1jQtWxeIgiJylOU7KYjQAjfsKl4q9n9eeA48HD58
ec45/4ejbDi0q0nAcVzhv/X/zi6ZY2jUd0CFiELGkw1+bjCWmcPgL48ne0BJ
jkXPhr5Ui5VZDF+t4dWVbwqyFA6zONx5hlmO+R5d95KOOQXhp1/qVw2kkxVQ
CxtnupOZVRiKkXgvu9LIGbjlyk2bep5K3og6d6P8sYZZja8T3tpidwo5E12d
Y3bpj2SyBuFrAdGJKuYsSLxPun3PksjZ2BkXdWFyH3MOhv2ugr331pG1aB63
xFxPYM5FW9FNgyNDTt6Kz4LhY+5Pa8nbsNCqtB/NZ9ZhRj+3aMqSkfMQ7H8z
m9GSSM7HWH/g3Kn3UrIeHS9q6udszAWo9Iet1XkSciGO7O99VCVbQy7Cu6af
IvX9BPJ2lAammhFkNmDTjvVSSwuzEUVa29nVe5iBLQnq8NWgOGInMLv4YHfH
SjJXjODI+PeJ3/HUi/FH4z7ee1BE3YSQP7jQnkh2mtB1WjgyWR9H3YzXSaHp
S2Ky04z0crtedjuGegnab7x9KPsopF6C6vM5m6Nd0dQtdH4rqFvQO/pB9jKF
7S/l7S9FvHCgbfpiFPUyRP5vAfUyHO4rNN71cNTLUVOnvdOqWjJGOs9cBQSK
zLn4vnnqFbxu5XXr8vdxlbzvr+TNb1s+r9PGe76d5gkb/wKNHOf5
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBWIQDQNioVt3b8xWcoDwPtgvu2QSEs4L4zM4WAX6m/5Y
pwjlcziYJ75LTQyD8QUc5rnELjzzQQHKF3HIVH/04fIkGF/CwZjfhjlNE8aX
cVj8X2Rvz3x5KF/BYfLRrPCrT+WgfCWHEMWuR8LuML6Kw12xN7nRM2ShfDWH
7PL1tSvvyUD5Gg6Lj4q8W2wB42s5+K6SnnNhizSUr+NwMf2IhyQ7jK/nMHfS
7AUtHVJQvoFDWTtTEscOSSjf0IFLuzmW84MElG/kEJ624scvZhjf2OFzm2uE
q5E4lG/i8N7y1z8nPTEo39ThX9F3Vc6jolC+mcPMvnlZh8pgfHMHobVXMz/U
iUD5Fg7sciwhRy4JQ/mWDs81P1UaBsD4Vg6Gu6TVH5UKQfnWaHwbh73H2+//
qIfxbR2upH7j1NgpCOXbOcSwL5ol7Qrj2zt8/rcrsoldAMp3QOU3ODisl16z
/ZI3P1Te0SHHacJevoV8UHlHByYFrV/cq3mg8k4O2Sd27Lu8kxsq7+QwoYV5
x/1YLqi8s4Oy17RrUSug/AZnh6r6XwezV7FB5V0clu++LnZKhhUq7+Jg3Pv2
u+OBn/YQeVeH4tXW9psWMUDlXR1q513eI/aQGarfDU0ejc/g7sDNvLbq1WRG
qLw7mvkeqPwGD6j6j1B5T2j8foPKw/jPoPJecD4AYjvZzw==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtIU3EYx/GjrqVlppuXmZpumEiOkXM619T9tjnd2kwURqgU2cWoSbMb
lUUuIypq5mYvhF4phKA2mJXDYqED7WW9SQMDoSjS0EyhVGJd8PkHnj8cDh++
53n+R3rEWXs8kuM47d/n35udZPuzF36HDOta1E3n6KqbxMwcJk+memqGpeRo
PAw+/XS3gTke77ofhcbDWeREqOcTps/0MEuQo0bLVCVzOhwf9guvzWWSs+AV
vRf0ypllqBspL6vu3knOhud1j7w0kjkHTRlptX2NGeRcOJMEkslgOnk33qjM
tysimOUwHTWahPY0sgLZC1tW8kd2kPfANH76incXcz5uDIbE9kOpZCWGp5ZV
olcScgEmznsuOc3MKnw9NtS+NJhCLsTCwbFA40QyuQiXOxPfWiKY1Shaqs+1
ziSRi1F8Sqd0pzBr4F/pmJUgkbwX8sUOX+C+mKyF+0lM3ssZEbkEJUrbrbjD
CeRSiL6MhgZqmcsg1Z+4cyEcT9YhVhy62DK7nQwsh5/XtW+m7gKaDZ3BuJ44
6nr82DZy/VdhLHU9VuXeq33NMdQN8PucDxQN0dQNaG1bG3P0C6kbkWmu0iT3
b6JuxLkBrW6ol6NejgP1St9Z2W/deueZM2Fr1OPWua4ImjehwD3/Uz+6Sr2C
1yt485W8/ZW8+82ouZefJ7gpoHkzbOq2wEdFFHXLxu9dFnzTrIUNis+0f99G
u3jmrLxupb3s2Oj/v1O38XrVf/8BPdvesA==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2EYB/CjLm8TNGdzXqdWViYzZ2lObc/m/TIvm/OoSKaoERZClllD
24e0gi6IUWSUtzBJSrSruep8mYhZfZCUyKBQjCxpUHnLtGLPG5z3wBg//ud5
znt5AkurtOW2DMOU/P39+yePWP9gsK8yCKyyKPXz3+WjrsQMyMNateq+QLQj
qF99qlOzxG4gua+QuVgC0B6gCq9uWa4nloDy2uevTzcT+0Jv2sX8uVYpOgCW
Dcy+YAFxELz7VVW8rcQfvQmKzrz3EJn80MHgnJ01Wiwi3gqaxSW57qAvOgQ6
Ym0crn7xQYfCoaHXigY7Yhk4VAyMvK3xRu8AqbnxzcSMFzocWpLlNRKWWA7y
tTKv520SdAScWpvU2jsR7wTLfHn9h3ZP9C5obKpUGKTEkTDwouAhWyBGR8GV
rvbuIH/i3VB1/riXqHkDOhoOlP2sDdtCrID+3kZ/yaQHOgY6pxtK4yuIY8Fd
6GmaMYnQcbB406F+WuWO3gNCuzsnZpvXo5WQYKz9HX6aGKD8epetoQ1tBNAk
DZmn49wwV4Ffz8p4URTJVRCo2n/26CrJ1eDcubg3yUxyNSjZH0WZPqR/PL+f
MR7YQvndw0GumCeAbUDIsrDHBfMEqBx+/GxsQIh5ImxMuzxe2O2MeSKE3hPY
R15wwDwJpCmaaPHtdZgnwa3BCfGIL5pJBut822JOmUmBuhtjJvFHO8xToLon
RtnfwWCeiudng3kqrndFac3TIOL83IKKW7LaSJlJ5/czpvP7MRl4HmtYn0H1
11C5Br5FL6+qZfOYZ1Lfz6Tqs6h6ykw2ZESdfDQlw/1DNnWeVM5lU+vP4Rty
+O8bKXM5kHMufLugQYD1WqpeS31fy78fTov7t8d6HTRNVRvUCzgPoINhc9yx
I08csV4HL70ts5fccH44HZ6XE9bn8vtBLrX+XP55cVTO6PnzBnpqnvT8/XCU
mTzq/POoec3j3y+XR80nyzew1Dyw+B4+HIv7ncH7z/+f/wHSKoAI
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQNioVt3b8xWcoDwPtiXdDt0F0nC+AwOje/84jVO
KkL5HA6hyc1H7+bB+AIO8t8MDV5KwfgiDudXpkoeX68A5Us4iH/7uWqCPYwv
4/CsY5Fq/315KF/BYc7MkyxTVGB8JYfuj79+z6iSg/JVHPbXZIT+ey8L5as5
/NjT9ErAFMbXcHhb9Hc6zzYZKF/LoUeO98DFvdJQvo7DdVu2suA/UlC+nkOF
0eEH5TEwvoGDu2tJJvMfCSjf0OH61dpTXTYwvpFD/2WB7jNe4lC+sUNV/a+D
2avEoHwTh6R9Dz792wLjmzp0/rqwSvKvKJRv5mDz9eC9njgY39xB5naEg8BE
ESjfwiGYweLcRkEY39Lh5bQix7X2wlC+lcOj2WamtycLQfnWDt+61onHfhGE
8m0cUucuY6peAOPbOpy8pvLlNw+Mb+fw+o56i36TAJRv7yAt8fjFxEkwvgMq
v8HBYb30mu2XvPmh8o4Oe49bvdN4zAOVd3RwDvljxurGB5V3cuAtMrK+3MQL
lXdymH2N++cyU26ovLPDWakPr6YIcEHl0fgMLg7vLX/9c9Jjg8q7OOhsZmEz
62OHyrs6BPYYarO0skDlXaHqv9lD5N2g6qCgAY3P4I4mj8Zn8ICa98weAESP
vDg=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0V1I01EYx/E/OtfmUHuxvaRublmIWyNnvmv/3zbnNq3QRozMCyklcYKV
k0oF10VCkqUuCwpiGlEoSWuFZWSKRIZFYBgVWBdFSBiaRdEoV7HndOGBw+HD
9znn5qj3N+yuieA4Lufv/neyJd1z577fpUFYi/yF+Ux5KJqZQ9O8c+7JdTVZ
hFeGWpXVzrwaMm565vJSMjkeZ5W6X45TzHJ4uyIP16mZE5Gl6w0cuKQiJ8OX
5BV2/FaSNXDfvJJXXcecgrdiiWHL7STyZoSCJ1KeLiSSU9E3MSvXFjCnwVzW
v3HvxQSyDmXDaepsM7MeS4qxqCb/BvJWvKlxK6sFzOmQzvIj7vMKsgGGULXi
oU9OzoCvVyR6PC0jb4MjXcS9djBnQrgY97K7VkrOwlRwrqP96npyNlpmjsdw
VfHkHBzsjXDHZDDnInCo8WvFsXXkPFgKP7Q+D64l56MzINaOvmMuwDTfI5DN
riEXIvyfrG/HaOWmcaWEmQfv/Fa5K4HNA4MFmtrUibiwPUC9qetBbF8sdSNC
XHmoys26Ec4Kw9ARDZkzwTV5d/TFPQl1E1TLz6ZyFqOpmzH5qPCoe0RE3Yz2
bldei2oV9SI0twXHXQNC6kUrugX+oYZz+n3svgU/dT2t1+rF1IuR0fn5h3GM
7Cle0a3QBQTCrDP0nscKlW1nrnQgiroN5afTtYKTAuo27MhuG36vj6RuR+Ng
Pn+rn6NuhyTyRvMn7xc+3EtojpanBAu5wWWT/iP1UvL3sD2l/+//ARDI0t0=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQNioVt3b8xWcoDwPthf4hIqMBGE8RkcTh69P7d7
tyKUz+EgdThm1Y04GF/A4Xvenatf2GB8EQdTxlCNWRsVoHwJh5lRxcIHomF8
GYfouFvG6x/KQ/kKDjd3sB57JA/jKzlo7v80rTxPDspXcQhOsemSPiEL5as5
3HkuslPjuwyUr+FwfP22i+laML6Wg9itVU3ejdJQvo6DyjuuH4Y7paB8PYf1
2nIWLh8koXwDh+fPjgp8UYLxDR2aHu8vavSXgPKNHCo3Bv7QqBKH8o0d+srq
m2zuiUH5Jg6Ncy/ESxbA+KYOJ6+0tJaeFIXyzRy0j0t8XfJQBMo3d5jl1/jr
MReMb+HwXPNTpWGAMJRvica3cujuXaq6lhnGt3aIdt/P9WuDEJRv43DJfhKL
+F1BKN/WoSRj+T5/MZi8nYNLQ8Vfw3aYvL3DMmWvWyaHBKB8B4fwKKN1RUr8
EH6Dg8N/hsD/CSVQPoOjg9+aPtfUrbxQeUcHZa9p16JWcEHlnRxOHLUtL9nF
AZV3cli++7rYKRlWqLyzAyR9MUHlnR24mddWvZrMCJV3cfAxr9/+WI8ZKu8C
dc9/e4i8q4Nx79vvjgd+QvgNrlD9H6Hybg7vLX/9c9J7BpV3g8sDAH+DuPU=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtMU1ccB/CjIA9pM15DHmK1cxNQUcpQHlO+RYuIBWlrKbaaEDOSRYwY
pjIw6pU594cTIRJMRM1CfIVoN0YYIj6uGuzm1GhqSEx8xMEwapSKCggbONPf
ibnnJk3zyfd8zzn39KQz1pWZSyYyxjb9//nwzZ8Ia1tnS6kWXnkyX8d3Vl4P
5WbY7ko91tA2gxyAX55IjYVG7mAERpr6PQPTyeGwHKnYItVyR2KHS+VImM89
FdOkuZrHLRrydFT/2tC/YWAaWQvn1uHK48XcM3Fh80Nj6K1Y8hdo9R2/VzE2
lRyH6JOWg2+/4U7AOXXNYnd7DHkO3A8uDQaouRPRZBi9UbE7mjwf++scod/f
jiIn4edJstlVxa2DM+R639OmSHIynn/9W/XA6SnkL3G4/eXe2EDuFBxVHfw9
/G4EeQFCavOZXse9EGPlQ58Hdn1KTkXZvsqosAPcaSibMLqnOYM7Hc5Ytzbh
STg5A9Uu29oRI/dX6F0fn/7fj2HkRfCzTmj1XA0lL0bSuZhZf2/hzsTwin8C
dhm5geFj/jt69WQJWOPfdCjGEEK5Hp3R9Uc6+oMp1+PP7plvRlU8z0LfPG3y
xniylIW9upL7jcU0ni3BODONF2/+hPIlUIVdqdj0lMyWYm5I3KtDd/j8S5GX
fa2rdxHvG2Cz65zlWt434JT+ate1KDXl2bDPrsu59V0Q5dko/ePsRXcHmS0T
8mWY0+rrt6DGn/IcbD/qPh/x2IdywWw5NDl5aRHNkyhfLvRzlZZyUdfz7bas
IZ6vUFoSzIzYU1eavk3Dc6Owfh5MPyXN9v3Bl/I85XiWj9rdPmcfrZ1MuWC2
Ep/lNnTbT/F8pXA+BbgZ7XlWH0w5CtDYHfTuRAo/rwJlXxbMTNCM3fwr1cP7
JqFvQv7pGkNJG/1esgkXXOkv43pU1DdDXa7LcFdTDjMG1R27/k2hXDIr9yub
lfMzC1qcZfWJjgDqW4TzFCxb4P2/m0j9VUpjlXAfhFwWcmaFceHO9p5EMqyo
2jlyubTZj/pW5f2RrcL6hcr5IFgqpPs/nuntC2Y2JO97MaSX33kNG4J8zlQ9
O/DKa8mG/rSRsazEQerbaF3+FFHeR33BUpHQL1LOz1YrjdVCX7AsjGd2oW9X
vo8k5LJduR/mEPbvUL6fJOTyx/w9N9XV9Q==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQNioVt3b8xWcoDwPtjPLVJZl8AF4zM4KG/Qfd+8
VRHK53CQ2za7eloojC/gUPH99laj7wpQvogDx9XoGfnzYXwJh/gU0f2XbWB8
GYfy93rqQsvloXwFB29D47daN+SgfCWHEMWuR8LuML6Kg11RgKPVfFkoX83h
0WMLRaVNMlC+hgO/wI5Jxe+koXwth2uTmTddCILxdRzu3Xme3j9DCsrXc4hJ
TFj3wAfGN3A4edUt96C5JJRv6CDveVRu8jwJKN/IofSX+vqTp8ShfGOHlKfF
WzqtYXwTh91PN8ncXyYG5Zs67NslxPFhCoxv5nBVIydx2XZRKN/cYZ3sZSWt
5yJQvoVDX0HpquhgGN/SISbp0WOdF8JQvpXD9oJlkXqiML61w8z9y8tDdYSg
fBuHk9dUvvzmEYTybR14hA+VF7zkh/LtHJacXFzGXcIH5ds7rHA8fPSYJC+U
7+DwU2dSzfIcTgi/wcHhrNSHV1MEuKDyjg4TWph33I+F8hscHarqfx3MXsUG
lXdyqJ13eY/YQ2aovJMDk4LWL+7Vf+wh8s4Oxr1vvzse+AnhNzg7vLf89c9J
7xlU3gVVfYMLVP4bVN4VVX2DqwM389qqV5M/2gMAuKe0gw==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0FtI02EYx/E/BR4usi0PWZvmpIOVzM1qHnLut+kOmmC4hAQFMxalVGNe
tCLboMWYWLEMIxcWUUrkqF1sOkwYNSyQNjo4AhONeZEXiWW1MRArfJ+LfOHl
5cOXhxceUdv5BsMGjuNkf++/l05Wo3fM05GPNS0pWrl7o6/SyRyG9a6BiRER
cwr2XE/a1dJE5sEcm/YWx/KYM2CTuKXhPnI2bItX7zyXkYUIFilcieAO5jzo
G2ejwU3kfPDNppikLZd5J7zayvuD/hzm3UhJ41f8zCcXQN5VN1PvEDLvg27K
tdLyScBciMdPu2/8KCKL8X3miK/v4nZmCTo8ZuPJ5W3MUgQkjlPGbnIxjHfP
1b8JZDMfwFxilHNbyAdhW/3ckJRKPoQzafFjZ4e2MsvQ1LWo7vmVxVyCpKXN
EedpcimqCqfCG69lMpchsF/1bdiUwVyOroEPL7K+pDMfRq6/02efJFdgoc+k
dCvIcqjl85fDiS3Mleg1LPU2D5EViD9KvjKvJAPNyQ/7BWr+mq3AR8Pv1AI/
M6cEr1AqCK1SV8IYWX55QkTzKlRbzStSO3UVBNnRr85bPNarUBYaezAxx2xd
Z64anZ5njqOXaH6dOTU04wvteEddjfHX9tm4hf7XQKrp99e+ZbZqoI84et7n
0D60/9uqxaTP+8RkpK6DnisNefhs31Yd6kosI1Ex9RqoxK23Ta00X4P59r3l
K3bqtbiQ6eJuDlKvhXD6OHjODPwBksvaug==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0W9IU1EYx/FDLlPTXGlTc7Y5loSNodNsZnp/29w0ddKKMBQjChFaIGa+
MaO9SaLSSgKVMjLwT5oLjUVggYoWFRplWgRRwxB6IY4mMzVdxZ7zonvhcPnw
5dzzXE7iyarDFRsYYzl/1783f2RHXUMDdhUC8gjLo6qWt2HcDB2xN6rdrkRy
CBrSZ6e+lnBLYaiP60rxK8nRSGQ+X4qTOxYfHJ5RWxm3HPoJZY5pTUFWIljf
97M8jVsFnza07UrHTrIap9rjPfL5BHISJr51um2HuHdj7HTyoqtVTk7GiLej
JkHNrcGTlx6f0BJP1mIy6p50eXYHOQW1zxV1j/TcqXhQ+1m4fT2OrEPyTP+2
kNZYchq0bYML5b9jyOnwNpiPmXXce9G11qNIuiMjZ6DSPmcajuDeh9UtlcKI
eTtZj+6hj7LXcu5M2K6l7pFciibvx/HLlh/ZY1HkLLQ7pusindwHcLWxc1d/
EHc2pJrU+En/VnIO3gvNkpgv3AJezagXV8O5Aavlxfj3bGnADsDPbP4T5yKp
G1D8sMlc4YqgbsC4N/JIaXU4dSPePZ1e/PRrM3Uj0hrnlwzDodRN0DyWBGc0
baJuwoCz6pa2LIR6LuourozYe4Op5+LC3alnMncQdbOoi8wsUORbM2W9G6lb
cHO25rxxic5jeVjWNNd3n6F5HHmi+fKhWJ94o/eEUReZHRT9n8isQLS/4P/z
WKFo/kK6Xwn1ItT0ZQmD9xn1IpSU6pxnVX4h0K1YyFxZN2rnAnZw+6gXi3ox
fZexP2JvAs8=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtI01EYx/G/WqZTcZVNXdrmEFGTVVvqZtp+3mfNNzMbKt0sCVxUq6zo
gitovWmGlxARRXphtULImG4YyxDsMhO8JAsztcFCKjSIciJa4XMI9sDh8OHL
ucRVntFW+XMcl/l3/dvZCEqtfU/1EqxpQRX29WL/Cx4zh5bm80qDNY4chJFv
hYPaUmY+wrPSutzLYnIEHPWXPDctzFGIngpyvC1hjoE6dsgsmBORxTjGtz0x
pzNLEB8WKv3QuY0cj0OPjlYcDmBOgDvpyIGxvFhyIgzjQzqeKYacDJdu5s2r
L1vJKeCZBjqFjcxSdJ8UJFh4zDuxyrtV2S4SknfBOapctR+PJssgnntmdU1H
keVwf9QabgQy70aZRNHhOhhJTsWV2qWXeouAnAa7s6xHV8acjoeTA/faJraQ
FVBUq2TmSGYl+LcNJ6bvR5AzUHe2xlJRwrwHKQt1Xb13N5Mz0Tx7x+/Tj03k
LHxuTUudbGTei+oLiz1+OmYVxqt+BSfaN5KBUVXDusgpshHw7JDITyexng3l
cF/H4Ayfejb6hE1t9nkyl4OapKbGhm7Wc6Arl3Wdk4RTz4Vo5Z1TscCjnovW
iRBvZ2oI9TzoX9scY3ayMQ/l2+vVw5dZz/fp+T69AP7i5KWQx6HUCzBie//T
tch6oc/5QnhTGq49OBVMXQ2RulgpsKynrsa8cmklRxpIvQimen3GVdEG6kXQ
pNf2uqUB1PfhevvYc8Es2ehjbj/k5u+/s/u9qrXuY05D/1+mrqH3PdSL6R4a
43//Ae7H8aQ=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2EYB/CT97zgfd5W0ym1qUyd5mVmezadzvvumgWJaQVSihZFoi3J
JMiJKUVSVCZlrRQnsso+7ItghYGF1Qc/FIpYFikNNTOt2PMG5z1wOPz2P++e
53nPG1VVp6lxYhjm4N/735NcHP3o2HAtHxxaki7cFRziuBIzYP2cGG0fjUJ7
gPhIZbNJS+wHt0RDdRsrkegg6G0Jqt+6ThwKHYWdN5LExFy4HbE26N/PQ0fC
84Dq5ko/Yj6ktIrMAu1OdAyUWQRV5ZYd6F3ArY4Zt9u5aAF03vR8qjhKHAvt
asWcdSICHQ9myfDM7EI4WgRheb/CYyTEifDjU9sdw3QYOgk+Tiz6Hw8hFkPU
i+X2dGEoOhlGe+/JTL4h6BToO+9t6Vdz0HvgQf3k1DFTMDoVqkqEA5vexGlQ
W+6uPnwtEJ0OXwP316xcCkBnwFq/e8ucjFgC8wn85BNCf3QmnBL2dF+x+KH3
wuLM7gsJrcRZMBTxyPqm0Be9D3waxJlvW33QUuBtTr5KX/JEAyR3fFuV2bY7
bKTMyKBrtrFJvuqOuQyGB+t6RAc8MJeDl/Pjs1+6t2Euh0ZzptTSx2CeDY7z
5YR5NvCUxRmch66Y58D3jPVNucgN8xyIH3FxSzVhPUYBE+NZp08+w3pGBSyN
TP1uDib95UJFXJfy9RkvzHMhuuDqu4oBMl8eTD2Ztn9YI3keNb+SPY9RCUVp
56yzImfM8+H+2HvOSy72a8xnz8sUgFNk7LqXeUPqyAtwnhWHmUIoqxAPNvC3
MKfMFOF+/8S8iFpfjPWWMS9m12NKqPolVH+l7P02llK5ij0vqKh+Vez+bCpq
vZptUFPfm8ptaup8aNj/Dxr8HS+jBvdjHutr2PvBaNnvg5b9vpHKbVpqvY7d
D+io86hjn0ebDi521UqaeOR86kF9OSnOpc0F1+up+fXs72PTU/UNbIOB6t9A
7b/h//n4A0XWdhY=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQNioVt3b8xWcoDwPtg3fn+3+TEHjM/g0DvJYfWJ
tYpQPodDg8bdXxHhML6AQxbTbfUNjDC+iMOZHwH/Ny5WgPIlHDJNZf37vWF8
GYd2/RkrNXfIQ/kKDqlty7KLXspB+UoOYXpqhlLmML6KQ/VPRY/IYlkoX81h
Xtf5WR57ZKB8DQfzksI7+UYwvpbDo59LmANnSkP5Og7v3RsfBF+TgvL1HHz2
c25bFgnjGzh8T7Y4O+G1JJRv6HBLjHXlOX8Y38ihokFwevlFCSjf2EG4wPtg
Xi2Mb+JQuTHwh0aVOJRv6mCltuHGml4xKN/MIcs8j68hFMY3d5h1SmjXgnWi
UL6FwzrZy0paz0WgfEuHwB5DbZZWGN/KoXbe5T1iD4WhfGuHn4nFfxu3wvg2
DtMf9jDe+ygE5ds67ItRPSjHDePbofHtHWyMfNr5EgShfAcHoRcHDq0OgvIb
HByWKXvdMjkkAJV3dCjdHWBj8YMPKu/o4LemzzV1Ky9U3smBt8jI+nITlN/g
5LDaRilD4zA/VN7ZwTnkjxmrG0y/M6p6BheH7BM79l3eyQ2Vd3GY0MK8434s
F1Te1eGnzqSa5TmcUHlXh/eWv/456bFB5d0cfMzrtz/WY4bKuzmERxmtK1L6
bw+Rd4eqg4IGND6DB5wPAFBssrA=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlH9MlHUcxx9+KCRiJHIoHh4QNgJGccghIN2bQ+T4fT847u5Bi2RsbVfa
wEWDiCdI00gHYT+t/qCWC+imIiR6sQe2FnoBEhtatJrBprlMstK4hVTj8/3j
+9x2u732+n6ez3Pv7/f7id2731LrLwjCvv++//+yj8o2cOG0Kw4rtKC/NG1M
qPNjLCD50YR9756KJQ6GYeJ6s8HOOAyNrZN3LvpiiDdAOxykmfqE8UZE3l3s
6dAzVmPgw4/d+jENcQzCQk5FGdcwjkPbNx0vXKzdQhyP80FPHnz7x2jiR9By
NvD91M2ME3B24trI5WY1cSJcY+eGp4c2EydjJvjlmnI14xSI10sKotuiiB/H
8VuNb2q+3UScionYnNwCG2MtRrzdO6oPbSROwxmhW2oPY7wNEZHpSeOtkcTp
eKrYA88oYx2s7y3PmdSMM3D1rWqx77KKeDuGvM5Bu5NxJmzfrTpyuCmCOAtT
fZN/xD/HOBs1sx7PyV83EO+A8eaV4XXtjHMg3pnVbV0KJ34Cvr/zuhuSmddj
8en6pVcGmAeK+38vMmcQS8DPJ3Tps13ryeeidX7v0fm+h8jnYv0NebTXQiwY
YHo20fvXpjDyBqwNH214/pcHyedhJvTwM4tloeTz4B+T6AvpXUt+J8r6juXX
DjC/E6F12uzpVmIhX1GfD839ce/2hTXkd6GxxTfi6llNfhdOXriiuqReRb6A
Z6kAK+fdn7wRzR9Ne1TXAsgbFfWFCl+IkIDPG292+ZEvgvmN1KTAg4HkixTP
L1b0L1bUl6C+N1t/plsgXwK7qHXXxS3rV3ypor4Up937j6dUBVN9GTrn6psM
94LIl2Hsq5yGA+eZL8dC/9RSc8QD5MvR8WrAuZ/2sPxMEJM6jRMvhqwwTLyX
THy9bMKhTldWk4b6CWY+H5j595PMSO4PXK07RutlMzTG0kxVD8vXwntYcDvT
d9+QwvbTwuclWxT5WlGS0fLFXArrb1Xsl5VfL1sV+VfwDAVLFYr6CsX5sPHn
DzZFfxt/PmQb/75CJf9/UcnnIVUi7eite7kyy7+S7yfYFfnZ+fWSnd9P2Y4v
v876LWGO3T8HBhc6HosaX0f1DiwL5uXqA3R/JQedR2LZgcLP3D1bP2D324l2
be0PJ6rp/sOJTx8u+n7bKJsHTkT3/jOzO4PmhezE3dfdkXv+ZPNDpHxp3kDE
7rY08eoNYklEfs78S5M+YlmEyxFkrnmHza8qbBmqH3zNS4wqxDf4deluh+Nf
dm/D1A==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQNioVt3b8xWcoDwPth7tf/akcUD4zM4XOJjWxm2
VhHK53BgyDk6vTQaxhdwWFydU6jJDuOLOCxe9meP1goFKF/CIaRy0v+MMBhf
xmERw6M97JwwvoJD/+5Shrk18lC+kkN475OCXwfkoHwVh+zuGR38rDC+msOH
gy1/WSNloXwNB2P/k2wG5TJQvpbDuySWuxteSkP5Og71uv/feHLA+HoO/7la
k+bJS0H5Bg4LLFu5HvdKQvmGDvfCHlYe4YbxjRyaRRXqZ3ZIQPnGDguV5sgU
bBKH8k0c1oewsHx8JwblmzpkmefxNYTC+GYO6vcCF5aywvjmDmaTj2R4ColC
+RYOv344LyrXEYHyLR3SpzKV8BrD+FYOkfGHPKIihKF8a4d9MaoH5biFoHwb
B27mtVWvJgtC+bYOu6WmzN35XgDKt3OQlnj8YuIkGN/ewXPlulWqc/ihfAcH
wTciYh/E+CD8BgeHb7w7G/+Y8kDlHR32Hrd6p/EYym9wdLi44+qXGz+4ofJO
DlHaEz3OVUD5DU4ORz/zB0cVwvQ7O5yV+vBqigAXVN7ZQWczC5tZHztU3sWh
qv7XwexVbFB5F4faeZf3iD1khsq7Qv3HCJVH4zO4ORSvtrbftIgBKu/m8N7y
1z8nvW/2EHl3VH6DO1QfDHjA+QAzk7cA
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtQVFUcB/Arqagryua6PJaKXXwsvlAgIneBL+Lu8nJ32Qe7e3Wcwtna
ydkyFCPKurNDPv7QBLUmU8fCUUsikdZJSbjIIDhTKFGUPYZpYKCpsC0cQ4a0
ms7vj3t35s7OZ773/M7vnDnnaitecPijOI4L/vv8908/tTvc2rxVh/8VybvV
f3s0Po7MwbAb7b1hLfMs7M4c6h/0kGNR+OBiae7dZGYV+hJ9HSPvkuMRylUZ
L6SRk/BG97UJ65XHmJMx468ja1ZHHmXWYdZwT/QWA3kRVJ0zLYpLjzAvge2t
8MjnKrIeje9k147lJDEvQ9CsXPDJdQ3zCuxasrn1loK8CjsPtJysqUpkXo2h
lI6ME20JzGtQPxbQv2Ygp+PvZ2qq/TfimTOQoNkaeDtIzsSD57bs7RmNY34c
lQnBb8ZeJ2dhRbjBPdWqZn4CWX/y+pLBhczZ6Eip1XM68pOYapiuHb2pYl6L
XSf6P1P/tIDZgIoe3eUMgWzETPe0lkjnw8w5eO9Uz8I3B8i52GhpnzN5npwH
U87wqzcmyZBagOz9fISGK/YPNypZno9N0e8f1ZiYuXXQxA/9XFcfy3KZuQKs
VOr/ONpHeQGqUg8fqr9A+XqMpOkynk+l+usxp2Fis7mL6puwI3Cmzaam/kzw
Hz8d9cpJys3Q5j+7r+o+1Tfj5dTue34b1bfg1x+W1qaFKLfgnFEX0HfOZ3kh
lL+p1BH1PJYX4mx+Z9e1hBiWF+HU9Yadih2UF+Fi5GBa4hfMXDGqWu3G7AnK
i6X1uBJEJS+bVJyby/IS9H369Z1vJxQsL5XOJ5RiZc4qV/sIzb9BNv8GWX0r
PHx6U6WOrUeQmbNJ1yvYMH7/si8UTftjl+4P7LJ6dsRUphv6Q6wf0Y6BmL2B
e1bqrwwFrqmsGWbWD8rQNT7fyb9I6y2Trl8sw5Xutbf1Q8ycQ7ofcIBfXlfY
W80syHLRIa3POaX7B5kFp6x/J6yNB0z+MPXvkhou6fuCS7o+UfY+55aNd6Po
g6YPFx+j/XNLz6Polp2/cpxOKf4u8yrtfzm2N3+8z15D90FmsRyKhz6q+eUQ
nX8PvvLfna2/xAyP9H4IHmwbGL/6tJbdH1GWc16p4YUxvXTPvKdovFd630Uv
8jx3Nlk1NN6HVGuKyhSk8T7Z/D58mVc/Pe5HGi8zx2N/y+zlbYOsP/Bosvzu
eGku+74JPFq2bR/nq5lFHk4uu7dZSd/HjUj63ovYOhX+AUYosso=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1XlQlGUcB/CXQ0AW4hBX7mNNIy4NAbn5crhyxLG7HLvLVSSK0UwlFMdU
vlozRIZiZWpa06AIcVVSBAj4KmAagwUIOtQMM+ngYGU7VnIMYTb8nj/ed2d2
dj7ze7/v8+zzvM/v9Sp6WV1szHHc/sff/3/ZR5717YWvSxVYlSHG5IvaljQb
Zg5d7tMNRh1eZAuk7L4YE65mtkW0nS7m5qIn2QGXuMiIBw3MjnjUfNjyaRWz
K2ITrrRG/+5B9sRuu7jZM2HMCmhTlEu1Ze7kJzEScXK+vc+NvBnIKDqhuu9K
9kZNlsLRJYfZB78unjVRnXQh+8G/0qm9uteZHIDBsd55MyvmrSiZcv+qs9GJ
/Axkh7ZXtQ84kgNhI2gajR2Zt+G3bz6d2dqygRwEnSL081vZzMH4zOp4l8MN
OTkEVfUOk0lGzNthUE0cORaynhwKn9zQ4YF05jB0uE0ofO46kMPxSdqBpduW
zBEo1ZqrXji+jhyJ/u9rZhb225OjUF7SNJAuZ46Gr5vcac/zzDHwit1T+9qK
LRmwWne54pU5m1XzQHzmcsga5RNUj4V/VEDmxVlrqsfioXXPgeVgK6rHPR4/
/L73bTIvMRcPQ+fYv2+uX0v1eFwdjqoo77WgeoLYvMTcDkl+B7bV/TEfK5A5
pdi8EqemZIvngmVU3wmPldGRUIMl1XdK8okovdo9MNFD1/OJ4vG4JMn8krDo
98EbTS+xejL8Ok3NQg6bUz1ZPB6XIsmnSMZ/VjI/iblU6H2PJl6vZPNLRXPs
4PAVJ9oPLg3W+wIjJg6y/UnD8F82Gv2rbP3TxfvFp4vvx2Wg/h2T7pl8Gg8Z
2Jj88ZS+mc0nQ7yegqTOqSR5leT/SuqCSrzenFqSV2PU2XDvI1s2vhp/hi2t
xAWYUV6Npgs35T+4rqG8BmWtETHnGzjKa2Ds6bMka12OWc1rkKMP7NineLRq
QWIuEzKT9up7HxpRPhMeialh8ha6Py+xkCl5PrPE64MsyfMkqQuSOpeNse7J
v28tsHy2+Ho+W7xfQrb4PHI56DLUb3EepfOKHJy9duZ1WTmZzxGfZ0FS57S0
HnT+ocWhwOJfTj1H/YHXojVSUeI9SHVBiy9d2r4bTyFzOpzbmDwddJmuh07c
X3gdbhQ/XOvdY0d5HZT9cy9ijMzpcfBOUd2dNjL04v7F68X9S9DjWlVC5K7N
rP/lwl62oW+2j4xcFLyrnIsaIvO5iLukcff1oP4p5MLc3TRzaJzl8+B/14W3
NKU68pBn4cyfCCPzeaipHqpcOM3yebBvn9xreIv143wkJr8/fV7H8vlw/VkL
26Msn4+f2vpr355i+XwEjddVbOpl+QL4HlFejxth+QJx/+cL6Hmn94NQgL27
/qnc8hR7XxSi8ViZXQ/IKETIA713ygyZL8TpHzclmb0nx3+IUAte
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAGIQDQNioVt3b8xWcoDwPthHOHs1OfPB+AwOHj5SMw5u
U4TyORwYf8s0HoqD8QUcXKyror3/K0D5Ig7Fq63tNy2C8SUcjvDViaqbw/gy
DtNqz/tf3yIP5Ss4SCqfO8ouD+MrOfici2O7GS4H5as4TF9+3d1mliyUr+Zg
tmjywi2nZaB8DYfdP7Z9FdOF8bUcNjZIvridJQ3l6ziEH3zhyLNcCsrXc1h2
aO+xrBOSUL6Bg6pMRvSiQBjf0KG/0nGZxkkJKN/I4cFPudAmAxjf2KH0l/r6
k6fEoXwTh9OaeRtk/ohB+aYOjS8V9z/yhPHNHGqj7W22hIhC+eYOSX6aK/7x
wPgWDlvt037U5IhA+ZYOU1X/RjLMF4byrRyWWhmfWD5XCMq3djh5TeXLbx5B
KN/GYbWNUobGYX4o3xYa/gJQvh2avL2D58p1q1TnwPgODv8ZAv8nlED5DWh8
BkeHizuufrnxgxsq7+hg3Pv2u+MBTqi8k8PGdflT9KI5oPJODm0Ts62q5dmh
8s4Oy3dfFzslwwqVd3aoqv91MHsVG1TexaF23uU9Yg+ZofIuDpD0yASVd3UI
jzJaV6T03x4i7wq1/yeEz+CGJo/GZ3BHk3eHhg8D1HwPB27mtVWvJjNC7fdA
k/dEc58nmvleDu8tf/1z0nsGNd8LzX3eUPM/QuW94eoB87/kgQ==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tMjXEcx/HHoSNddDmno5Qup6KThKI4RZ86Xc/R6VxkK2yY5nK6Kmqu
T61Jhin1B6NFaF2wtMqEncSKZO5iNjNsUstBbOg0rO/vj86zPXv22vt5nt9v
e76Pz6YcXYaA4zjNv/P/lR2S1LbOFoMUEzJFZSenJjU5M3NoH+/2z77mQ7bG
aPiYS38asyMclT2HI4XMYhztTO6Z1uhNdsV47YKyD1pmD8Re70oL/uZF9obQ
UDT2UsQsxejMR2us13uS/bDQoP74rHkOeS7uqD35F8Me5ABIj2x52z6PORCS
140lqmJ3chAE69a8+tQxmxyMYxFVsmIb5kWoiX58WK10Iy9G7snslF6jKzkE
ipGG6qzNzKEoeF3X6zQwi7wEDzpW2/i5MS/FQPWG9OZHEnIYHryvMyOQORxd
vqUBnNSFvAzOl55vM+0Xk5djS7WgwD6UWY4P22Vyc5mIHIEL8tDe+jPO5EjE
3xzcjsdO5BWI5YvMi8uYVyLjzEXBnlrmKNhnOg8dynMkAztlVScqr5J5IO3U
pbMuQaxH4/y9ul22BTOpR0OxeizMKp7MxcBpWCwxSViPgf2OkIinJfbUFZPN
K+A13t+3zGRDPRZBrdOEYcemU4/FxDwKqMdhX83TG5J3U6nHYfeB312GRiH1
eIsej4MVBvkeL3ofl4DeuysKC65bU0/A8dKp196uZ+sn4ldQ5d76zBnUE9Fy
OacqeC3dzyXhy/Lf4zHBtB6fhPrOl5L7HlbUlRbrKy26avJ+eJXF/ldZrL8K
6fMrEh8W2VJPRv9s0+cqR9ovn2zR1bj73UGfnmdHXY2bPfKRgPdkLsWip+CK
e3PHE5UDdQ00mYF9P9zoe0OD/KaIqKvn2Dxo0BQp3RrQTfcbNUhquNzof5o9
r4Wd6HZh7iAZWgy9mVe6sIQ9r8W9F36jf+xo/oxayNS+4rgsNo865LdcKdfs
JkM3eX55HW6t8+/ytKV5N+owLErL+FnO5l8PYeqUVlM3GXr0tbc17Mil/4XX
Q9X6VakNJxv1+LUx31zcJsJfcA0+eg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1G1QVFUYB/ALWWKIruu2wKLAojgrKikEi8LKf0GWt2XdVxYwm8qhscAR
NSpxxm5lwpdFYMocoxB10KAoIpFVxBsvmhFZvGgzZDriqJQ6CyRtymo1PefD
3Z3Z2fnN/3nOnnPvOUf58lZzoS/Hca/8+/3vl33kthOnW4oi8L9cyVLLV45f
/Zk5DPxwv23fl0qyH/h8XYNKzyyBp/7ofuPDcLIMDs9GZ98x5iDUL73cmm5k
XoCbFYcj910NI4djrKb8veMzmSPw6EFTdsKmUPJirJCPH/nojYXkJdjguOjy
nVhAVuFWh7Nuk405CjmNIbU/fRNCXo7Na62d4T7M0ehMGlEPFinIK1F97bfU
4OvB5FW4e3G8WLOSOQYH9IvNfo4gcixGFr12+PwS5uews8XkVpUFkuNQnR4Y
XXZZTo7HzirZcKYPsxp3Kn/8OnngGXICujMmP1V2MK9G88LBiKhbMvIatLgr
x4LAnIhQ54628r755CR8GOnJ5+qYNchuHc8yqZnXQq9+++RoNHMyVukOOrP6
pWRgtMPDL1OTeS9zWgwVTs1SOedRrsVAcs2MwCtkLgUllya7XlKy/hQUftLg
u+sQy1MREjR6u7pGQnkqSk8bkxLccyhfB3tBTPP2iLmUr8Ps+V1vloyRuTQE
FEv/qNjG+tPwmDM9fvF1luvE9bwOmZ81N0bWsjwdAdtjEgffDaA8HR9f8v+7
Ic6f8gzEOu7+pRVmUZ6Bou/aOwedLM9Ev8L1+weSpynPRNWeJ9qvbiRzWeid
nGsp2Dab8iyv/mxMBTjfmY5jebZ4PpweP7cP//mLm+p5vbiey/HKc3Dm/Jp7
qlGWG8TmDVihibaevcnGX4+wR/19CS42//Ve/UYc13b3ngumehi91mNEm6vq
WUU/vS/BCMPnlWmFJ9j4JvF6YfLqN8E3POqBfxNZMHmt3yweD2bxfHgzilOq
zsypZ/9v9pq/Rfy8YMG8OzK5S071vEVcL1iQap2Of1LH9p8VObpzvTc0tL9g
hfS20NVkZvvdiqWGRbK0LWTBCvfRmbtvaNn5sOEpm0+rq5sMG1omFHVlm+m8
8Ta8UKEb0/SQBRtSvrWELgtj5zkX97b03I+dohy5qCwpbdxgoZzPxfN+Cv7A
arKQC+kXw6+6drN+OwomRuIjPazf7tVvR3lZz1vuWtZvh3LGlWuT06w/D4Yd
kl37e8nIw1afh3sbE+k+4vNw8HvpqUPNZCEPF4b2vF96gd1X+eL7DPm4Xj9k
kyjk+ActHq6Z
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GlIVFEUB/CXY2lNuaRNpZU2WpmJptPitP4dHbdcZp/BFmyRCtNqkhbL
epUShS2WJBmo9aHMzBrCspWpbKMyRIyCaCES2ic0Kylb8NwP9w0Mw4//Pe/d
d87cN3bJakOOmyAIS/99//+yj8LceMWRq0SfXHM3y2VrXF7MArY3FtsrLo0l
e+LTtUV1yw3MPpjVkdhskzH7w27IH11WE0weAa8ae746lXkU+oe3Vye8CiIH
o2TXcv19FbMSbtajzT7rx5BDccpoSYx4OZo8Hvu37X+bFsMcho6d5/Z2W0eR
w3HWETreuyiQHIGcmxd11RcCyJFYdutCdOkQ5sk4Ulk4tatqJDkacxTj6nua
R5BjsPtX2xNHPLMKmxz6H2GFw8lT8PCiaVDoSOapkLd1re3dqiBPQ8WJY7XK
MczT0Vr/uDM0bxg5FiuXfdsYNYFZjaFn2le6tvqTZ0g8E5/zmr+puv3Is9Cy
2Pa18xnzbFS8Lu334utQ8hwUrDh5PVPBPBcTM0L8tXm+ZEDdcqXmziufPovA
h+cTiqN2kIU4/BH0f7ILvCmPg+9Hf4VL4UW5Bhn1+7Q5jUMo1yD3XtP1tkty
yuPhaFhdHjnfk/J4yGVnCt8f6kd5Aoqq2q4qXssoT8AXdU+vJnIA5VpJvRYR
590HTNvnQXkigpLT1Yq6/pQnwnW+9XfRsIGUJ+He7dkbCi6z+iQ8CnC9L/cZ
RHkyv16UWEjh14sp/H6EVMn1JRbm4UCxrOnlQlYvsZCGnxEHt5xcxe6fhtud
3sastYMpT0drU3vX0x/UTzFdsv8MuAWH98hP03oxA9fuzvgc9obVZyKo99GD
WBe7f6ZkfzqEpB5+klVLOXSSfuig2vvpe5yT7NRJ6vW8oUfhtp4buXU0P1HP
z8cpsWDgDQM/X9GAsjfrNmu+k50Gvh+CkX8+GCXzMPL9dhqRNaksuWUjqzfx
14dJMm+TpN7E90Mw888LM/Sl0ZPcS9yp3sz/X5xmfr+Chd8PLPz8RAusWTEN
diWdP6cFg/1ubljzjixY+fMLKzqilKr8iXS+RSsWeByvDNSSnZL1gg3dexqG
L+yiHDb+/SHaoInMLrdn++Evxm+dvw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQNioVt3b8xWcoDwPtifkelR8eaB8Rkc/h2L4tFb
qgjlczgUWC4QC/aF8QUcfgaoMsm8U4DyRRxiJ8arzeiH8SUcHjz95PVGA8aX
cQiwCG3vXCcP5Ss4BK5x2Sj9Uw7KV3Jgvju1cqUcjK/iwKM6efNSf1koX81B
iUlnB0uFDJSv4dDCErjwwj5pKF/L4fLd/d84eGF8HQfpo8H5LF5SUL6ewwLW
A0HHqyShfAMHRivtnec5YXxDB/4DwUuZJCSgfCOHlKfFWzqtxaF8Y4epDbaL
BZ3EoHwTh5NXWlpLT4pC+aYOZm+e3V3DDuObOWz80fdSwkEEyjd3kNtZvK39
tDCUb+HwXPNTpWEAjG/pENNsHHXjhRCUb+WwL0b1oBw3jG/twLX4R5zbUUEo
38ZBWuLxi4mTBKB8W4fwKKN1RUr8UL6dwzXejoyffrxQvr3D7GvcP5eZckP5
Dg7GvW+/Ox7ghPAbHBzOSn14NUWACyrv6HDiqG15yS4OqLyjQ2CPoTZLKwtU
3glq3397iLyTw3vLX/+c9L5B+AzOUP4zqLwzVB8DAwBmdJRM
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03lI02Ecx/FVHtk8ay7zSJ0HHjN1pum0/Mxj3nMrpbAsW1mWiihSCSo/
s0yKpkVRJEGZqZSZEU7FErECxRRMvMrojwqlcx6FZmhF3+cP/cH48eL9jD08
z3eO6pyd6at5PF7U38+/N3uEyc3tjzJF+C9daPLPGclLM2Ye0izOFnc0OJLX
4uF7p0pBHLM5tKNd+rXfHMgCxEoDob7IbAU9L+XRQFdmWzwo+cEvO2lPdoA2
wLTz7dXNZBGSvKVpkxN2ZGdoC6oBEbMrnh/3mG2+bkt2w3h50yehObMHilz3
t4/xbchiyLJdpMeSrclb8Hqx7/PH/k1kH7jYZuytVjH7Qt3aFNT1xoosgbzK
aKrOk9kPQqlDnnHRRvJWON4qEcj6hGR/OOcOjM1bMgeg99fk+bK7luRtaLQb
FHlMCMiBsDrw5JVGzhyEnoKIkMOuG8hS3K7ptqwYXk8OhrvCSRCZbUEOgZeF
29SNAXPydizxVEtp+WbkHdDqKr2t+0zJoQhP+h2gL2cGLL4IhDohmQMUDZrI
9GYT6jKkeF6K7j/Fpy5DZndrx2AbmReGgdah2dE51sMwbFKeMa9g3w9f0cNh
v9jXG6hbRz0C8+LLhXVZRtQjIH6sZxCgMaQeicoza1rfpdJ6LhJVw/z5Wn/2
+/Ll++Hky9fzolbsPwovZsx2peQaU4+GSZ4kePA07ZeLXnF+MajpuXOCn8/O
Jwa7UySNeSLWY5ev52JxP0SU4faM9ThckKSPV6XR/XBx6Bl2nl0wZvcXj3br
KzfbvrMeD3Oxr03/EusJmKsxLP4go/vnEvD//8rmQYF9pX4po5OsKzDhPl3g
q2TzkwixTtPYUkHmEpG5x1B16BrrSjSHHpkrzKL5gxKdnmFfG/LInBI+qaV1
T+vJnUqMGJwbsZtm86qCWuFev2hM8w0VclYtlN0LJnMqDLllHaxtscQfkPMa
ag==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIk1Ecx/FNRJwSauo2U+eFWlZDtDU1s/bbxce5wjKz60yKpuICRSSQ
DNadxTB0L+xCrajYO0nDZLYcEUYrfOGFUVqJvUkh8MlkrSmtovN/0Q48PHz4
PudwnnNyTrbsN0cJBILiP8/fNw1x7eCzfksu/olXJ64eXNMpJQswf2X64ZA3
hzkWsvQ2S7CenIj3Z1uVnpVs5hSkV8nD/ffJUrQ1iLyHOXIGZjYutezxZzFn
4/LVxmqfkpyLAlQtdp+RMa+Hc0YpTlrIZJZDFD9gt2jIeTDrjKpsZwbzZgiq
G5bdoXRmBRICwwbeQs5H1q+xtyX8OuYCHDgfHp/SkgvRc282NNucxrwVAxrb
hZ9hKbMSttVJf7+OvA35NwcW61YlzCp8D70a/TAtZi5CDJ/g724iFyPqhnPF
YE1lLsGlaN+b2N4U5u2Q1nsmujhyKWr8NvtEZjLzDvTO2YWfvq1lLoOvQ192
Sk59J7ZkitMaT1Dfhc+3i1QzDrIaX5OPmAM2Mv7/3gpMqHuiJR+TWNeguT34
VHiIugbHKrxxocc0XwvTReXRd/PUtYipFT7hX1LXob3JNbJXTF0H7vlCM8Zp
fT1GTBteyOKp6zFlDojy3NTLEfcgeJwbZbaWI3CtT1K3TJ2L2D8X8X8VcJh5
h8lFvQJfNi11FO6j8zLgUanytesOdUPE+VWikLvlNo5Rr4SC7+obuk7zjTh3
d9IjnmO2GjGobgh2nqb7243hVsWPmqhU/AbEldkc
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQNioVt3b8xWcoDwPtg3c1/ouyYA4zM4KEQu7vfc
rwjlczhceLxiuk8mjC/g0PFN5pM+L4wv4rD54pFbzqsUoHwJh2+fD57SiITx
ZRxi9qfI1rHB+AoO9ntKXofXy0P5Sg5HV0yaGH5BDspXcUg9znhSjgvGV3PY
cnUSg7O1LJSv4dDKwfFnbb4MlK/lsMWfIUllijSUr+Mw8XlBSuNDKShfzyE3
aOZ2BQkY38BBtf+K289CSSjf0MFOTHXNryMSUL6Rw4OfcqFNBjC+sQPvlzkv
veeIQ/kmDqwlstr1O8SgfFOHN33nNtlfEoXyzRxiOKQaZliKQPnmDkknlHYZ
NwhD+RYOb4QjU791CkH5lg42Rj7tfAmCUL6Vg66gxsdZFwWgfGuH13fUW/Sb
YHwbh20fJuhLneWD8m0d/jME/k8o4Yfy7dD49mjqHRxWOB4+ekySF8JvcHAQ
fCMi9kEMJu/ocHHH1S83fnBD5R0dZl/j/rnMFMpncEKTd3Iw7n373fEAJ1Te
2WHi4+Jqp+/sUHlnh586k2qW58DkXVD5DS4ObROzrarloeoZXB3Co4zWFSn9
t4fIuzq8t/z1z0nvG4TP4AblP4PKu0H1wYA7Kr8Bjc/ggabfw4GbeW3Vq8kf
7QF/XcI3
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2EYB/BTqV20pabznppdRKdlpunS/G8uXV636SbaBYksYZEfrLRV
dIjsapFlFt2NzLBSLKKLWSvRtNAukkZ9EJoFRZdphqmlFT3vh3MGh/Hj/5z3
fc578V9doMsbz3Hcyr/Pv3/2k+pvNtQbZ+K/rHGueXP3j5vCzEFpLTE8r/Yn
T8Lr01nOHzOYHSF59j7v1aAf2QUBPSG/rBeZ3WHcdcR0L5vZG4YHHiVFQ75k
P6hTfC4cm8c8Ewf6hkdOmGaQZ8E4981mS6MPeQ583EY6P3gxByIRe/u4Dd7k
ILysPZ91q8aLLEOMuSp37TTmUDTWtVW1V3qS5+O4c+yDWosHOQwefs0Giy3z
AnQkrrL/4e1ODkepfHRtfJEbeSFORDdUfHkkJUdANVsi63FijkST+vtZ/3uu
5EXottvT7dPvQo6C+lP3fckB5miok0rfXM9mlqO+3/OcKX86eTHatqhi1sxh
jkGVPLy1+owzORYqvvh32B4n8hL4K9bt2zTqSI5DW9esgREHlgNxWQMr0rzI
PBDiFNh38gWrV2CM047lbpxGuQLrlYcbJZUSypXomro3fyhtKuVKXFY0Nbd4
kLl45ASXqTuK7SmPR0BSRVfO5SmUq+A72v40ykrmVWhtji3aeHcS5Uvhq06N
ltbYUr4U36KHR5WhdpQnwLRj+KGxhswnoMxSuFU5OJHyRIQf/DKoME+mPBHW
Gy9+b3clc2rsLjPKt/pSPa9GdUO39Ik3zcctE5pfJqznkiC7YWMXeYi9n4TD
uybc7lnJvi9Z1F+yaPwUYb98iqi/VLR7Wj+VO7L1EZlLE9bzacL5uHTR/Omo
ry0oD13O1leDU132Q5ciaH+gQeNj+ddAiwPVa4T9mTWi8bXC74HIvFbYr1mL
8X5Bw/ZXaHxOJzwf0AnXj9dBWxoWbFNiQ+/rRP1nCPcDGcKcz8CQ7Mi26vW0
PmaRuUzh+MgUnbdM4fqaM0X7qxeeZ+hhbL19v/MOO+96OH12kVqldF/Memxq
0MRE/WT3x4DUhJbm3li6bzAg++S1SlcZmTdgZ+/qg71X6X6aDSisr9unMbH7
m4V3pyIj3h51xh8uj4A9
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU1EcB/BVZmpSmjqnm+ZjiUsJ36+0fX3N+dqmEj184IOBTKyliSUW
VwpDMyG1rFAsQsysbIpJSaaBZhqGEUqQFWmh9tJ8kJpQ0fn9MS9cLh++v++B
c89xzDyaqN7I4/Fi/r7/vvTw93d06XKc8F+z0vSvGo3AgszDe/mW4oFWR2Yj
SN7aixuTyGZYLI14UTHnwGyJ8SqP5Zh6sgBX3R9VKvzJIvADw76MNO1kdkBP
na+h2IrsBJ+0jCyPaHtmMQzEhn2tyXbMLgg5FTeuLBMxu+KWaJdaPSZk3o1R
o9NZShHZHSXpss7aI7bMe/BEF1thMmjD7AETtzOpxrMCZk/YCHOya3PJXrjh
VCfStlkze8O93cDQr5Lsg7U8x/iCALIvmhs+33dL5TP7ocX8u8Cl3YrZH8GL
ve8q0sgBSKqrERZ5kgORYmTLXQm0ZA5CpbbgdnISeS9SMj9OuE9ZMAdj6EFH
c56WHALdT9uGomzyPkSGTBa/XNnBLMUraZWB9bg5MyB7PK3BCDMH5Otay1RF
lIeiQFJTXdVmxvJQSA8spCiElIfBruX3aIo/9cNwUvJsWa1k87xwBA53Xe//
QP1wSBTOlpG51I9Y14/A81Hxwqop5ZEQCiamLlZRP3Ld+jKYWjwt1E5vZ7kM
8bL+vskQyqP01+Oi1u1fjq2b7hbNVFMux2v1krHrQ8qjsVR+zzp1gfJoHM9u
6lby6X/GIP1Y6urgFOXrzIvVn+di0RjkPdBUT/04/fPh4tCuzZ8/fILOLx6T
GknQ2jlmLh7DGQfn5t9QrsA1RcnKhAm7H5wC4sIN1X4/KFfqz3NK/XmeSn8e
Kuh+VU4LQOup0OMW9u1OHnOPCvKZse5t56mfgACN1OuCNbu/SECv81lXnhMz
l4CmrjH+oIi5JwEOE1aXbh6i+56IT5svL3XWUj8RQytT5aWNVvgDBeolbA==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tIU3EUB/CfzvlolfOR6VpuLpHp1kqtqcvp2dRN56P5yGgSQQ8oFjnD
MExygoZQRpYV2T8JkaIlmkSaPTbDksKVOFwhYbIIMsKNKFN8VOz8/ti9cLl8
+J5z7rk/uDGHK0uO+RJCCv/d/5/0itj3aLjfKAKPXJk5L1xh2SHUBOzBNoVP
Xww6EJSn1gwfDdRcmBy0qIJY1OEgbXYf1XUJ0ZHQEe8Y0Oqp+UD8aqatNgFa
CNN/TDefCalF0GR7eJ1XF42OhR1R3bWmn1vRceCyNq6wD1CLoXqelxxv4aMT
oHzE/t0RSi0FPncooE2zBS2DsdQzF7nveeidUNawNmFXUycCy97hyGiKQidB
lHC03MmmTgaYOV8RoolE7wJTc7u7qmozejcY3m04cWs2Ai0HRVzfh/st1Clw
SK70/zS+CZ0KzoZQsekIdRpIXkf+ujsbjlaA2loaLRFQ74H42IAvC9owdDo4
n66YJSmhaCWk2YbvvPrMRWfA9hCxu32COhPWh43UmL4FowF60kXHxS/RZoCs
smU5W7MRcxVs092YMnStw1wFgtXxt6kuNFFDf29lm6wiEHM1SAf8/OWXAzDP
8q43Z3nXk2zG/GzG/By4PcVZvLebg3kOGCStubazaKKB5JYfCypLEOYMEy1j
vhaMY4PPJ4dofy4jz4VxnmuujUvfnweL0qt1nSfp/DzGfjq40sganDlI+3Xe
9SQf5tOWVtUyf8zz4UKrUXFOQM+nAApS6h87ZSzMC8DzP/piXghjo8qa6if0
fAuhtn7JauzGeaSIMb/Iex7ZC8WXEiV+TX6YM0z00DnsiHjDZ3sMeuCwHtTO
XfPBer33PhY97Dck9Z4WrWV6+ou9DcXY7/bYzMgtjJyU4P5fsZ9hM/Vv7C8B
X2HCEqdnGftL8TsI+QuLkzU+
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw9yWtIU3EYx/GjCy9ZHa153Mp2s2KZSqaWZzrP7+xiEJggKETYnLEUJoh4
xZDsRUUvGlhivuqOSNPCdC/KCHQpKwgLE8FehV2WFDuvAlezC3v+PvDw8Hm+
xsbWGk8ix3H5//b/ZSPUBqYnvCbEpUgvDt7fz/HMHHycFNNPGckpyA/rkwyN
zOn4NP7W92ArsxpVCy81Z6cMZA12fgtN6OqYs+Fq0l5/pejJBgSrv57uKmE2
oS2h+vOHZh15H8zLwyOqa3vJB1Cxcm7NHc4mm7F6OxT6s4U5F+4qWy0v7iHn
4W7ExYcHdpML8PiQrtShaMmHoeUHLXdE5kII8mrLWJeGfAQdRfPWzjdZ5CI0
nKpbv+llLsawOD30Y1Ygl8Cet7SgupRJPgrXcuDMYo+afAzr7vbYxcAucike
HY/UdG9jFvHe8zPV/DSDbIGjvydWeIW5DA1t9b9eh5nLYZSbrnZupJOtGMk5
sVI8y1yBjO9qQRF2kCX4y03N5iBPBk6O+ZyewPa4+4FROTg3ryVzMpTJd7G+
zFTqMkJz1u6OZynUbei9EJ3xPkyibsPlAa/lvD6Zuh19txafCx9V1O1IU433
rt1IoO5AoiE3mub/LcW7A+3+MunJPY66ExExumEr+ELdSX82lZv+CytNqNI=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQNioVt3b8xWcoDwPtifZprmJ8IH4zM4TDT75Ou4
WhHK53A4tP7Ulg+hML6Ag3xXvZrJXwUoX8RBouTCtnfzYHwJh6ivS15rO8D4
Mg4cS949ZtglD+UrOPzzWdVZzgrjKzkcnHZwd6utHJSv4rB252F9syxZKF/N
Id5A/bvYFRkoX8PB+9qnxZKmML6Wg3xS4++pttJQvo7D00+bLQ5skoLy9Rzm
LTCNTDCE8Q0cfu+8wM9WKQnlGzrcC3tYeYQbxjdy6DN+zXgrUALKN3YQPqyo
Kz5fHMo3cVhjveSY1wsxKN/UYftpcdY/CTC+mcNE2cw3sx6LQvnmDiU7Dykc
9oLxLRyss4pmJGwRgfItHZwOBstpy8P4Vg7lorMZ+pcJQ/nWDkcCDsxu2CUE
5ds42Id/ifGTFoTybR1KNadMnrRJAMq3c6jUPP4z1R/Gt3cIjzJaV6TED+U7
OOQ4TdjLt5APwm9wcJh9jfvnMlNuqLyjg/y/s6ctPnBB5R0dJj4urnb6zg6V
d3LQ2czCZtYH5Tc4Och7+FqKrWKFyjs7BPYYarO0skDlnR2KV1vbb1rEAJV3
QeU3uDhwM6+tejWZESrvCnXvf3uIvCuafjcH49633x0P/LQHAC/rrAg=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1Ik1Ecx/GnjZm5nDPnfG1Ne7FElmbq1NXz2+brMi8Ea74lDRLDCwvC
wAhHTYpKiZIZeefMTFOxtRzYhRZlCQVeNC3CLgwDJZq0ahsaFfsfYj5wePjw
Pf9zcThJpuaKUwKO49R/178/++SVjomxpmQE5Oat2cJ5xTZmDiJ771DkoyRy
KHjubMtiFbMU2qX6tGNhzDJ037l85pVdSY6FRGPRhVQzJ0Li87Y/CGFWIh9h
ZT2VO8jJcIiibN3tCvIufHDaH68NbifvwUxthEXtSSTvxUP3ZKephjkVFbKn
+6ZHE8hp2NzfWXFlPZ6swrg33bjKM6cjQ2NT+o/GkTPgTplWiE7Hkg8gb2XR
PGqNIWei8cJCQ6+A+SBgejJ367ycnIW7SkfE0pdocjY0P6YWbpxgzoHtc7tJ
3yAjq/H2pHH1+/soci6q6p+VVBuZ83C9497uYSFzPn5eG4mp80SSNeCPe2rL
E5gPYeVjimX/JSn5MPpe21rE5yRkHq7wq42+8nAyIFCm+sVDWwM2AwPa5y9e
xrGuxazznWfeK6auxU6D1VU9EEZdhx6X2NefxboOYyPNXaqaUOp63LQInZ/q
aL9Zjzfx7uUuKZsvQGubf6ppMIR6Ae5PzMlnEkXUC4PPMxfCbZ9dvxi9hXoR
vuX6f+tUbL4IZTlt44sqIfViBN63gHrxhvNLgm0uCd7PlSKz4+sv7aSPD/RS
uq+1gDlDsM0GiIXDrcu3N9H8kQ3z//0Hc/TjFQ==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAmIQDQNioVt3b8xWcoDwPtg/K5W9tZUXxmdwMGQpeu+x
ShHK53Bw8n+e+sofxhdwyLj57s2zzwpQvojDqgYTgwlLYXwJB9U9F64re8D4
Mg4677m+u12Uh/IVHG7/KJi+VwHGV3KYztV2TbpODspXcbhroKnq8k4Wyldz
yGWunRRoC+NrOEQ2bLFJ2SED5Ws5/GbVlpopD+PrOHiyM8z/7iAN5es5zJ00
e0FLhxSUb+Dwcr/n7Fk/JaF8Q4dLJ24YrdaA8Y0cGCdc+veyUQLKN3Y4ILKa
PfGVOJRv4tA2MduqWh7GN3UwEp+fGNMmBuWbOeT3VkoKTxaF8s0dDGKbl+9d
IQLlWziolDNONnsvDOVbOlRVaj+/pgqTt3I4vW3ryqICmLy1g7asmGR6ohCU
b4PGt3XIKvmxjTEcxrdzKNWcMnnSJgEo396hdHeAjcUPPijfwUHwjYjYBzEo
v8HBIfvEjn2Xd3JD5R0dZl/j/rnMFMpvcHSoqv91MHsVG1TeyYGbeW3Vq8mM
UHknh+LV1vabFjFA5Z0djHvffnc88NMeIu/s8N7y1z8nvW8QPoMLKr/BBaqP
gQEAipWg3g==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtMFFcUB/DLyyIogsEFBQGhtfLIpqiUItX5s0BdXuu+lx01MU37waxI
xNoSlTIQ8YOgESWQGGJLv9BA1NhNI0hj1igGNG5ifED8IoZILLVljRYLPmib
Pdfk3kk2k1/+58ycvfdm1nxZa/06lDFW89/v/zu/dI5fhy560hFUQDlWmV7x
IJybITe8bsbYt4YciaaUiq5iO3csvppYuL77bRo5HpEX8mqrznInoidzzLvV
zJ2M5ASvstifSk5DsVL4UfMy7nRsbNb3r7OlkD9EzMc92tToavJanLBMPOvN
4l6Hth/U9sHuZHIWJtVvS+yJ3DnoXrv3hb81iaxHVO2T5saRVeRP4P0+Yrgh
mzsX453jSubwSvJ6TIz8EVeTwL0Bv1ffrv+rPpG8EeeMD6fqQrjzsMvtnOvy
JJA/xYyyt+xxBHc+zNbZpAvNOvJnGL13pOXA6ApyAXqHxnQ3k7k3wTg9diWm
NZ5cCMNVW0p2KvfnOGNqmp+M4t6MRY4Qb+DacvIW7Nq38/XNp3FkBbE5uUn+
BW4g05QRX1pD1gDF9XKHKYnnRSjwD/14YyKW8iKY92Td+nslmRkQ9yxeF9DF
UG7A8ItlNnXfEsqLcWfg/svxf6IpL4aa3W7015NZCWaXDja9yaN6rQQZ5Z0P
1J+jKC/FXM6pw717FlNeiturAtMdsTz/AhfP13bot0dSLpltxckjYQOPdlK9
JpkZxXk0IzwjA1fuDvL5ytA+uf+Q4dUHlJdhZHjzd99c5s8vF62VI9VYVaDr
i6C8gvaTrFWgMr/x0qQ+jPJKhKZlzUf3v1GCeaXUXyVaq8LRds+mQ6k0DzPB
0pabHd4STrkJBxvnr3r6FlG+TerfJtYzs2iYsb+/UPnlJ0b1Zmw4/uerIt9c
cD6fGdFh5w5Onw6hfguC349Q6reIuWYR/69PMrOi4ezd33SPybCK82tWcX19
kpkNAe+dtw0r6HzAJp0Hm3h+fFLO7OL+wC6tl12cxyfVM4dYD4e03w5xfX0O
cb2YU9x/OMVcc4r74XPCpa4/X5e+EKxnLswUzL8z6Gep30Xr/5zOE8+naP9c
9F5+VYuGZK1a6pdy5pb63dL73VK/W5yXqWIOVepXpfMnmW1//7x/AbW2sgo=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQNioVt3b8xWcoDwPtg/Pbqb7YwIjM/goLxB933z
VkUon8NBKbyZmS0axhdwqJj8YrXpbwUoX8TB3kxqSc5yGF/CYaX3PMEPwTC+
jEPa2t3/Gb7JQ/kKDgrh7zwqrWB8JYf737dNcJolB+WrOOwtuecjdE4Wyldz
+H1a6Uq0Coyv4RC3MVh75wIZKF/L4Xd7/f01IjC+jsP6jSpq/LXSUL6ew3rW
s54vWGF8A4dlsqx9l8OkoHxDB6fdf7rc6yShfCMHkbN3Tv57KQHlGztY7qy/
L6oH45s4bJV8dv/LfXEo39QhUsliwY0wGN/MYVEjz6YlgWJQvrlDj/iFSd8K
RaF8Cwft4xJflzwUgfItHWI4pBpmWML4Vg4bP0nNr8oQhvKtHVxtn9Sc/yUE
5ds4GO6SVn9UCuPbOvxYwl73xBHGt3NIKIz9feqFIJRv7+C292WWw0UY38Hh
W9c68dgvUH6DgwPX4h9xbkdh8o6o5jU4Ouw93n7/Rz3MfCeHgmufDyUqwuSd
HC7ZT2IRvwvT7+zQ9CSp98kamPnODpbndi849kAAKu/isFtqytyd76H8BhcH
Rcf0ztJ/MHlXB00/ZRHXXJh+VwehFwcOrQ6Cme+G6r8GNwcBHUPpc/9h8u4O
WSU/tjGGw9zn7nCy0sUmRQ0Wnh4OU1X/RjLMF3YAAFXsxac=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIk1Ecx/GHOS/TVsP08a5zZaaT1TR185K/TTc3NzdNTYmICqSgKDJE
s8gZ9EKwLPBNOCGCWltektCy0Y3MgnCgEVSElEKJIE0Lb4hW7H9e6IHD4cP3
nMN5cxKPnz1QK+A4Lv/f/L+ywVcNuPtPyeCTt+CSvNLeKGHm0GCan//8LJEc
hMZbPw92H2GWoPbrnaHkVSk5DM4Wd0R9D3MkhlKCf5fUMMciIKhdM+fHLMWa
Yqa/z5JAlgFJVdOS1njyTsyau50P38eRd8FPFtes5pl3w95j++7RxZJTMcaf
mxhsjSGnoaErab18LJqsgNwzLbJYmPfiuTV0wu2KIivxhfd3eqzM6WirCjaM
90WSM6DvFM055Mz7YPGUDTtORpAzocIOAeZ5chYGDjcdrT7NnI3LaU2dZ7zh
ZBUq7B0xTUpmNWoM7ZLJF2HkHGhfVcTLE5hzERgvrBwe307OQ0N4J9d+jzkf
d3My3jm6Qsn7oXwakzxZz1wAeRwfdeIYM6D2uG+PfJP4bAMupLxdrrWSOQ2M
zl5Xkn0bdQ0GvTf2RI9upa7Ffc3rNyNRYupa1LvL8lRLrBdCIE1dCXmwhXoh
FsRDLauZZK5oo21FGI32znRIgqnrkPZIGJB1PZC6blPXY+zJxz+flkKo6yGu
S8/9cIXewxVv3G8rxs2p8xe1i3QfZ0DGtdlFzUsRdQPK25Ry4VUhdeNG24xI
MJSqeZc/9RL4/o+Aesmm8yaYs5sfTyn8qJs2dTOqD6X31snWC3zdTO9Z9pkr
xS/1yppWsUCd+Qd1C93DcX8BHf/n1g==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GlIVFEYBuCLIZnjaI42qWOWW41lWpZLafmONk6ONc6mY7bYNlRo5dIY
GcRtgTLILMMf2qIW5oZLm0WZgy0W0Y+KhBZosUJQYsKyrNCKvvPj3oFheHjP
Ofec73x3AjfuNFqdOI7b9Pf775d95BlXb3bkBuG/HImrKqZkV0qZOVRVSnf/
vBxIdsHLXHV7UQ7zZBwb3cY3Spi98fFui/+3rhlkH7yTLHA2r2P2R+menUOb
3ZhnIOfsQX1B1nRyEKbXSVa+6gggh6BWceSN7sU08kxEhs6R5yQyK9H93BY/
r9CfPBtDu71i2xoU5HAEqMauaEf8yBEoLrtcU2Jjnofiw04bXa77kufj9q0A
84QhH3IUUqonfbk4h3kBHCPWfW9rp5IXotPuqjk3KCdHY194SfUOxxRyDPr3
y5T5m5hjEVNxd2uqjDkOZfm2ptUmb/IihIVM/PBd40VejNWabtef7TJyPPL7
hns2BDInoKijrVRf4klegvpg7cuFPZPJS1HUHJ94qY45EYGqLaW2MWZA4dM/
cOIkmQekebLBIwUsV6E5IWir8o4H5SoMvp51KPIAy5NwzVEe6ffYnfIktCla
Op+m0XguGRceni+W7GJ5Mmw39QlxP8jcMuQllXe517J8GXQtZWrrVSnlakgL
o+KfHSDzajSo7ty778vyFKH5FOF6nAb6vNmPvvmy82lE+18OW9ipipOXWL5c
VM9UoflUrJlYV6VQs1wL65l6p701LNdCNmDvaTayPE20fhr2hPWOWtPZ81dg
rqfyS9UTlq8Q7W+lqL4iczphvXidsF5cuqh+6Zi7JMLc/YnleuH9QC8ar0fu
g+u3n92Q/Lddj2BtZV92gyvNNwgNA6r7JKP10TSeN4jmG3Bv2MOUXeBG843o
6l38WdlPhlF0XqOwX+xG0f2ahOeHCZ5D3nKHnM03Cdezm4Tn5czCfoUZqY2t
TaGnWb+bhfWwm0X9myF8HkTmM2DJjmotDKL17Bmi+8tEsvl3jHMKm58peh8y
Mc4ZxtfvYvMzhe8jZxHuFxZRv1vwsC/k6y836ke7BWG6YG/1dtafWRg52jp1
7VcysvC+Oib6VQX9v/BZCHeUtXYe98IfycCJAg==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0GtIU2Ecx/GTGqjLXF7mpdk2s5uzmbdymu4352Xq1FUrQdEksgINTYqy
C5xgvlgpafqiGEkvTCPI8kVLEVIKTSgDiyJidEFQGFhLdF6QWbH/E+wcOBw+
fJ//8zwcxYmGw7U+HMfp/r7/vuyRHH02PFAXC4+cmhrF7Kn5UGYOW0zDd3f1
K8j+MKw1brhhZBZDv24zZLvk5DD0dT8RxVmZIzH9fPz4g3xmKd7eGTE0OmVk
OeTlP/XNGcyxWDad7bZe20aOg6yj6phtLIa8E/e+h4jNYubd4H3sjuBcKTke
U5JzX22WreQERGQO9kzMRZNVaLF0Z0kVzPtwX90SON0WRU6CaFSuSbwSSU5G
dfziQp2MOQV88JK5Oi2CnIoP9fahiZMSchrcTUs7AsbCyfuhfB252PMjjHwA
F8Ot3K3eUHI6ZvfMNycZmdWoLBgJXH0aQs7AkU+W1vcxrGfi/Jm+F2US1g9C
oT1tueAWk7PQu73oS+pL5mzcTK61W2uYNYL1gM3Znhg9udljHtibpTKNzARR
12Jq8OPC52URdS0eal+NjUexnoOUtrkl7WgA9RwM9Dd0qSr9qeswGe10dIkD
qetQoezQv7tE+3G5WEm4fbWvns3nwhU0dH0tbRP1PMF8nvd5XD7azb6D36pY
z4fMPfkm3UnmCiDTl6gljzZSF5jT41BrktKvxY+6Hr/Uq+4clUvj6YUQ+T6+
7Oj87TFfKOhFtA89fBH1GerF3uaLvddzBsG8wFyJYL5EcH6pt/lS7/tyZfS/
VqiXobwiub8pdp260XseRsF5xv/3+QMlHwhg
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0F1I01EYx/H5AlnGcjZ1+VdzK2vLmU5zOlv5m9O5uWkSqSi7CMGSSrwo
KxfpvxcQEYmcYAyHRRnqWqJlUiNBDBQiswLrotxFRaJFaWkr7BXPc7MDh8OH
L+fAc6SVtfurAgUCgfbf/n/SiiwZ8gwclWFVX7LXn1yQr4SSBUiP658qHZYy
h6BQNDhiKCeHQTk0HV69GM8sxvLM/Ee1nSzB96mJ5gY9OQYG1+hSzZvNzPHI
mplyWtRkGSred2lKOuKYt0L/VGerFJG3AdfTNQNnY5nlaLQ5vMeWY5h3QDxR
X9pQRFbiRYq9o7qTY96J4MQeVYg3mjkF5+o/nZJyZBU6Hj3pPuDZxJwKk6c2
6msAOQ1lh3p8P4MkzLswf9fpTemLYk7HgrBkTJFMVsPRO6pfckcyZ0C9WCE3
eyOYM5F4yTCZ81jMrIFx7uWIsIWcBWtINH9FQ96NygnZgzR+I7PWz3vQ0tqd
4A4i74X1QlrFq9lw5mz4bqxpeKcjA7n86V+qJtGqeeD4QH9zsY1ZoEOYUsVN
/qGuw8PxJq+vke7n+PUcVDlvBp65Svf1iHWtTFszqOuRXfbNWsRRz0WSSL7g
eBbGei7qFeM/qvYxC/JQ7nBfi1BSzwMneTt7uY26AXWKdnvbIHUDpLrDzXW/
qef79XyYem/3JXRuYN2IOk+xNtMnZN0Il1ZWLR+jbkI/d2v4uZmZN8ET3e68
/5neL8D86+0Xk8/T+wV+3QxtqqVJeJDmN0NRtEWcV0PzWxAa5LbN2albcOSE
715AGf1vIVrvrE0c8TLzhUj6wPHrgsX4C+q96Rs=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/GDI7yMyrw1L+VcajbXNC85zeVP3eZlsy1rmJoGllCUFkJW
mraUxF4IonthSUUXSjAFu1mUZRpIiIXIIHsRraZlFM3IslHrwv5PsHPgcPjw
fZ4H/g+ciIqDhZUeHMep/77/vuwJMt6+P7BfApfsGebic71GT2YOLUen9HOX
Ishe2D3to4gqYPaFsW1fu2BeTA7Axx5VaM1lZhF2rk1ory9gDkOa0FdbLWAW
Y1T/rrQ2OZwswbZ7Hc7uxtXkSNR5nhqWW1aRo+FnH1poiWOOgUjTp+03h5Gl
SC4R1b63hZJlaNa/KR06wiyH6lW9098SQo5HVeGZQbGIeQMOlTc+jtQFkxOw
q2rgQpdFRE5ElPezHfKZleQkWGMrR4Qy5mRUPHz9xXkriLwRjbK67mp7IDkF
xuklp1vrmRWIHRMtXLEGkFMRX9Z8baiHOQ1NY0VlDh3zJpS3auaUT/zJ6Xh6
TJW+J5pZCbXSdvy5w4+8GYvaGa+TOuYMNNkq2mzXV5CBw+vMnR03fF02AVfX
5L9MGiFzmTAckI4vBLOeieKzfRcDZaxnoTddsjdmdDn1LNyxt8eFTCyjno31
Svn2R7NLqWdj8q7l64tFIXUVwp0T4wq7D3UV7DcnfzUEelNXo+H81IMgq4C6
GkUlCf01kt8Zrq7B51SHM0v+zWWTBkJBX92HznnqOUhs+/Q9c/gH9Rze/lx3
m3Ld13N5vJ4HD7HUIez9ST3f3SaeOS1vvxau/82D5tNBl3Ji8K2czafj9QLe
+TxzW3jzM89S17vfh0nPm8/gfh4MvPUG9/OGeea2/vcf2IIilw==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQNioVt3b8xWcoDwPtjbPwvhvsYG4zM4mB55nRyy
WhHK53BgffKmQzkIxhdwOG1c6KbzTAHKF3Hor02f4N0H40s4yPFZ/bhgBOPL
OLgJzGmbc0IeyldwODDHlE1FFMZXcuDmYEjbGSIH5as4bHW3m79spyyUr+bA
rCRbbykG42s4yAe66943k4HytRxcC6e+uVcpDeXrOOQ8mOivdkgKytdzCLW5
laJySxLKN3DIXlolVaYD4xs63BD8JJlZIgHlGzkcPbj4xoEkcSjf2OEAn/ne
Q0IwvonDvl1CHB+miEH5pg6nf73oalsqCuWbOVxna78u+0kEyjd3MLnUW666
C8a3cKidd3mP2ENhKN/SYe/x9vs/6oWgfCsHbVkxyfREGN/aIaEw9vepF4JQ
vo1DDPuiWdKuML6tQ+SstQtFdQSgfDsHXVu9kP3PeKF8ewfj3rffHQ9wQvkO
DhMfF1c7fWeH8BscHHzM67c/1mOGyjs6cDOvrXo1mREq74gm7+QAST9MUHkn
VPUMzmjyzg5MClq/uFf/sYfIu0DVQUGDi8N7y1//nPSeQeVd4fIAh9qbqg==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzGtI01EYx/G/15S5Ep1/LWdukiG2lrY2L9P227zNTFIrKvJFrHKQoaJT
wQpnECEUkb4JrcAMBwOLIJs1wQuNvLwpopKKqImXgmgvzDmRWbHnBP4fOBw+
fM955Kb6qvPBHMdp/55/Nxv++JDzSW0KAvLoXkb0pkPCzCGtSvw7a0xOjoCj
umZAVc8cjaVhjXcknlmCmeWU618dMnICGodqPKknmaWwT93d4D3JZBle1R59
HVzInILHDyp1oz07ybsgzpw40j6dRN6NfYk9k43hzGmoyI5aNOdKyengP9qv
lnUkkhX48nnRfOvODrIS7Ukbqrq67eQMZMh8fq0tgZyJ+WBHS5c7nrwfrvH+
2TETswrn5puedmqZD8AxEx+2foYnq+Fv9KZGuuLIGsx1xKQ1nGXOwr3hvNPd
jyTkbFSb3HOKpVhyDty9GvWn7hhyLi5YVp8FnWDWQq43dzb7o8l5ONUz2Ben
YM5HVOxEa8P3beSDaHZW5GWvbiXrsDdfeWx0QUwGHk71t4gs1K3Am+F3y7Or
Iur6zbbq0fte5BtQs24QdANWxM871tVR1AvgU3Rdtl2MpF6Atva18Vp7OPVC
TLryWy0vIqgLzBXh9lzTJYN3C/Ui2Jwf+GlpGPViVN7I3BN6LZR6saCXINlY
nsPbydYSXLn/doT/FkLdKPhv3PyeK4UoZLDtR3cQ9VKobv706sd8ukA/hF85
a36DciVgK/MC9TLaQ2MVmDss6AJz5f/9B89i4cQ=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlHtMjWEcx9/q6MqIOoU4FQtJOm7d5HxPJZWizqVzOthcm+0YkUbRvEwY
lSXzj83MZlFjo6HU7EVZZaRynfxhsbXSZJl0kcvO77E9z7u9e/fZ5/k9v9/v
2e95g7buMexwliTJ/vf992WP2nyn/pY9GA4a0FX8Srqa78dYwvUi/duF94OI
3fHjbsi7jbsZT0Hbab+ur96MfaBF2EttXSCxPyrMGyJ25jAOQO546aS+MQ1x
IM4UBIZ6LWccjCu6xjHrztnEc9EWntGYUjmLOAQ9LZrcT0MBxPNRMrzj4ugi
xqHITUosOJkzkzgMc1IvvLZdm0EcjrLY8wuOejKOwGhV74uTh6cTa+EWsP1z
3Fl/4iUo7847FD/kR7wU/Sc8qopPMV6GoMtHffTP1MTLsX/kerA2hvEKtLw8
Xpzf4ksciW3vGxoqv/gQR8EoRT2/5c04Gs+3WL8NvptGHAO32SpTYwfjWNTk
5g3aDjJeCVezU83A46nEcejQnVP5ffAmXoXNezeNtvYw1mFqj/Ko2sAY6Oua
d3zxsSkOloFr+sdNT6ZPIq+n8/Mkr8fX6JHx+HBX8vE8y/EoPDLy0F7FfALP
cgJOlNtjDmncyCfCMX/O5BORFnnkXne4C/nVPMur4eVyo7C3wol8EvKqY3W3
r0jkk5BZol2oKlaRX4OiS50N6o8sfg2/XkqGxbbk5r7g3zqHT4ZzYOiIV/WY
g6UULC3tH9Irw+RT+PVSqlB/qlD/WsGvFepP41lOE/Kn0/n+oPzpgl8n7L9O
yL9e6H+90H8GH48MYb3glQyh/0x+PwgsZ/L9KYKXDHy9MKCy/o26NWACxRv4
ehTBS0ZoktOj1VXEMArxRgyHnTtcucuD4o0YqGn/VeRLLJn4+YYJTYOTjba9
EyneROdNrJj4/SQzmpviDuy/707xZuE+mPl5VwQvZfH3A1kIq1G5riij9XIW
X6+SxeeTLDSf5GHh65MtQv0WtNe++v72pxfFW/l+YYW9ufZBZx152QrN+LOn
UQN0PoqVzydl0/+R6kW2cN+z+X6VbOH+24T5swnzY/s//38AjeHBVA==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0l1I01EYx/E/m1a6LDfn1NT2d/TmC0tdm26l+23OOSFsmYEMrTBk0MrY
RRALa6OIujAVCaIJy4yoVkZYuqxklMVCEESKgVEXplgaLZBcq6Riz7nowOHw
4fs8dyev5Xh9q4DjuJK/99/Ljmz/oycPHArEFdHbPLWnhUnMHNRjC4cb/Hnk
NWi+XuGMNjCn4mm74+7lCE+WorPPxVd2MWfikCb3YH0xcw6uZUcHxDfkZB4r
Os/U7KeNZAVc9ndD0zzzJnxsXNsbMuaStyCYOJ5/X59D3oY2e/hAwrFscgFa
nw9bfUMbyEVoEo02etOYlViWaGW8PItcjGmf3XnRn0kuQQ8/O281MJfCuvTw
dcCUQVbh2eK+uj39MvIObH2/t+9EIrMagiu+nxZ3OlmD8iP60o4M5jIUdpon
jONScjmu1nliM8nMWrSEFCMqdxpZh6azKlt4XkLeiTFr0OseYd6Fue0KVVu+
mFyBlKOShQvOVHIlam8P3Nncu56sh3hRKovI1pGBW4YXL19lpcTtBiYDb5bC
URF1A2yF3ZaJk2S3Ad63oh831awbERmc/N2enkTdiK5zwsCH5mTqVXCEAqNT
j9l+FVQdX5YNQZrnTCgaTFilubSaugnnux26U3IyV434/xRQr8busjPDM0oh
dTMEfEFM5P+lj3czvmpjK0bl97i5mv/troFIeM/1uecbdQv1Of0fflzCeg==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03kwlHEcx/GNaZiwjti0udqWKYlCusQHu461y+6arSgzRjRNqejS8UdP
qsEo5Iihg1HSUDMdxDaVDkmXSWXKH3RPt23UP3RP3+8fPDPPPPOa9/P7zjy/
53mmpm7Qp5uJRCLN3/PflQ+JofnS2bUy/JcpdKeVeaZJzBbhaPog1E1TyZbw
eVtgW6xk26G3ykb69I0H2RHXhlLkXgfZzuh+ffpm3kK2CwZ+KfbsvupO9kDf
FvfAKje2DE+fWCU573MjyxFUX9hRKWZ7YXtCv0q5ypU8HYnCheC0VheyN3IM
S+qXx7N9IF+TY/BNnUL2RUTLh5K5BVLybJR93lHi3jOZPAfxLimtga5sf0R8
OVW+Ls2ZHICackvLzp5J5EAccSu/Uh3CnosrRgdLU5mEHIR7r+p+wps9D2aV
x0aiBSfyfIxk1ezSrGYvwMxO5+/HXziSF8KtbVNL7t2J5EXo2q4ITvNiByMl
K3nkzjt78mJ09cq/jVizQ2CT4fAxL8uOHArridezM9/bkoGhX8bEHAvqArA0
yf/MRhn3MDSE3ei4NdmGehiK95q3DiRPoB6OaapDvUkNZCEc9p8cJSaJmHoE
4poKlenNvD5i9DyRYvT9ggIZ4cWXxbW8XonjXXVbrTZzV8LMw3vYqtGaeuSY
+ZFoMRX7Se/z+qjRzyNEjZkfPWZ+9Jj9iYEm8lbH68W8PzGYZT/9a9VD3k8V
LknLjrQNclfhrZ8sYP0M3v9YuDb+6F0xjyzEIthfnStO4a6Gnc+cKQ9+c1ej
NN1UuuKkA3UNbmrbqwUjWdCg4MAJz9Pm/P7jcDGzPtHXiSzE4XzmpqGkbdzj
ke1ULSqq5x6PtcssdCsruGtR8WL/uP6vNB9apN6WGQMEvl8Lefa40qBBcrsW
OZ1Lk4fV/H3qENhzINvTSIZudBd0iFbt7zuXSG7XwaR7VFQexN+7Hg+buofk
68jQw/BsfH7eTrKgh+Lwc4e2fHK7Hi9rHxvspPw/JaDG1kz6QynBH1M2LNo=

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQNioVt3b8xWcoDwPtibqwR9t+OH8Rkc7CXP9Pqu
U4TyORwCpSdJv42A8QUcylKLv/n9VYDyRRx+SqxpcZgF40s4nH+y9kiHFYwv
4zDzyrqA09vloXwFB5kpdUIRbDC+koPThbxTRX5yUL6KgwuzB8O3ybJQvpoD
o+Ss8PMXZaB8DYd1S2MV3wrC+FoO6zeqqPHXSkP5Og7O215NMu2WgvL1HLj+
G2e9uScJ5Rs4THqboVFnDeMbOszwUQni6JWA8o0cjoiUVyp8EofyjR2y9X7f
v3RSDMo3ceiqixNf80UUyjd1CL3J2tlRDeObOcRf3xp3uUIEyjd3mNtwtYp/
nTCUb+HgvfmjV6A5jG/pkFXyYxtjuBCUb+XAzby26tVkQSjf2kFa4vGLiZME
oHwbh4AcrdNfJWF8WwfBNyJiH8T4oHw7B/l/Z09bfOCC8u0dThy1LS/ZxQHl
Ozgoe027FrUCKt+AxmdwdGibmG1VLc8OlXd0COwx1GZpZYHKO0HdxwiVd0KT
d3ZYvvu62CkZVqi8s8N7y1//nPTYoPIuDlX1vw5mr4LyG1wcIOmRCSrv6hAe
ZbSuSOm/PUTeFU3eDZXf4OZg3Pv2u+OBnxD1DO5Q+75B9btD3fsRKu8BlX8G
lfdAk/dEk0fwAef8z0k=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQNioVt3b8xWcoDwPthvNgjMvc8F4zM4xHyW/P54
gyKUz+Ewy79s0vYAGF/Agdk93+jgFwUoX8TB6uy0m0XTYXwJByube3dfmcL4
Mg6sXZ27X6yTh/IVHNLq0p4tvysH5Ss5zJP8L5qhCOOrOCzmnL4hvUYWyldz
OO60KlrhpQyUr+EgcqIyrM4PxtdyeFMubL5+hTSUr+Mg6ZufekgQxtdzONV4
9xi3rRSUb+CQcU1uw+alklC+ocO9sIeVR7hhfCOHp0zbyyY9EofyjR2CZ/5/
HCAD45s4ZJnn8TWEikH5pg6rBd9JqG0WhfLNHOKvb427XCEC5Zs7JJ1Q2mXc
IAzlWzj8WMJe98RRCMq3dNgtNWXuzvcCUL6Vw2obpQyNw/xQvrWDr9uxo09s
YfI2aPK2Duul12y/5A3j2zno2uqF7H/GC+XbO0RpT/Q4V8EN5Ts4fNh88W+t
KCeE3+DgcOKobXnJLg6ovKPDxMfF1U7f2aHyjg4b1+VP0YuGyTs5tE3MtqqW
h8k7OdTOu7xH7CEzVN7ZYfnu62KnZFih8mh8BheH8CijdUVK/+0h8i4O3Mxr
q15NZoTKuzoY97797njgJ1Te1eG95a9/TnrfIHwGN6g6KGhwg+r/aA8An7G1
eA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQNioVt3b8xWcoDwPtiLnG0+XCYK4zM4HDusWya6
UxHK53AwyzopUJEE4ws4aEnomNpIwPgiDvJtm79Kr1GA8iUcbr1l+JwfAePL
OFicVbBz/isP5Ss4eOuLhp+zgPGVHNgNvOz4SuWgfBWH3bm20osuykL5ag7W
Ogx7QzlhfA2Hq9xrWWUbZaB8LYcgkT2ax9dLQ/k6DqutNt55/EIKytdz+JJ/
3jeqEMY3cHjV1KwmvE4Syjd0uPq2geP1Ywko38jhnHsc91cZGN/YIVLJYsGN
MHEo38TBIWnb9UnlYlC+qcObvnOb7C+JQvlmDiU7Dykc9oLxzR12Feh8D2aC
8S0ctPvdzjmdFoHyLR2iPt02U/0rDOVbOSSdUNpl3ADjWzsYus3a6XVWCMq3
cZic+mFyzHIY39bhkv0kFvG7glC+nYNLQ8Vfw3YY397BPvxLjJ80jO/gYHlu
94JjDwQg/AYHh1LNKZMnbYLyGRwdtn2YoC91lg8q7+gwoYV5x/1YLqi8k8OH
zRf/1opyQuWdHN5b/vrnpMcGlXd2gKQvJqi8s0N4lNG6IqX/9hB5FwcmBa1f
3Kv/QPgNLg7czGurXk3+CJV3RZN3hZr/DSrvhqq+wQ0q/wwq744m744m74Em
7wF1Nwx4wvkAcc/ELg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQDQNioVt3b8xWcoDwPti/fa5ZNlsaxmdwKFFS8hc+
oAjlczgctRFasD8NxhdwOMhrK6HODeOLOGytSDy3YJcClC/hsFE6od8vEMaX
cTg0YfV5pY/yUL6Cw9knLyX4dGF8JQcmu9dh0k1yUL6Kw7nQBuFdP2WhfDWH
6jlKi0ISYHwNh0LmDT9UbslA+VoOX+32C69zg/F1HKRY0mcdXCsN5es5lDPE
29/7LAXlGzhs/2EQ8dEexjd0OGDQmVbQJQnlGzmUJL5g2pUmAeUbOzxl2l42
6ZE4lG/ioFZz/eJhdxjf1GFRI8+mJYFiUL6Zg5kU5+KPC0ShfHOHx41CGgXJ
ML6Fg/Zxia9LHopA+ZYO73KPfDX+JgzlWzlMf9jDeO+jEJRv7eBjXr/9sR5M
3sZhe8GySD1RGN/WgS2UcfOHwzD1dg6X7CexiN8VhPLtHWRX/7kWYw7jOzjY
GPm08yVA+Q0ODpWax3+m+gtA5R0dVtsoZWgc5ofKOzqscDx89JgkL1TeySH7
xI59l3dyQ+WdHJS9pl2LWsEFlXd2+KkzqWZ5DidU3tmhbWK2VbU8O1TexUFn
MwubWR+U3+DiIO/haym2ihUq7+pQVf/rYPYqNqi8K6p6BjeH2nmX94g9ZIbK
uzkwKWj94l79xx4i7+4QHmW0rkjpP4TfgMZn8HAw7n373fHAT6i8B9RcBgYA
eLO8gw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQNioVt3b8xWcoDwPtjXzGiynMAF4zM47Ny5LdR8
kyKUz+EgtfnMnem+ML6AQ3xNqMC/hwpQvojD/H13Dx6aAONLOGSV3w5mMoDx
ZRxuvJfLK7whD+UrONwqlTeZJQfjKzlsuRzyXyBODspXcWBrCHl9Y6oslK/m
sHpmhfjLuzJQvoaDlefF4w0KML6Ww69dFtH/q6WhfB0Hllk74iZfl4Ly9Rwk
3X9LqVjB+AYOt8RYV57zl4TyDR3qZMWXfnoqAeUbObw3sPLd9EUcyjd2EBU3
1T7bBOObOMxaedD561oxKN/UIb+3UlJ4siiUb+bQdna6ZIQOjG/uYBDbvHzv
ChEo38Jhc0Hx56gKYSjf0kFbVkwyPVEIyrdyKN64vjOgShDKt3ZYpux1y+SQ
AJRv49BtlHpndgKMb+vAW2RkfbmJF8q3c4jSnuhxroIbyrd3OHHUtrxkFweU
7+AQ2GOozdLKAuE3ODjUzru8R+whM1Te0YGbeW3Vq8kf7SHyjg7vLX/9c9J7
BuEzOKHyG5xQ1TM4Q+W/QeWdoebCgAucDwBeaJsU
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0VtIk3EYx/G36eywCN1sHjLnlpRNmbnV3HS2n/M0d1ATlmQFYe5qQWEJ
ziEOykhS0YSKQpldhAccVmjailaRwkIJgkArKLyLDpOKbLVO7PlfuBdeXj58
/8/F83+lDSdr7TyO44r+vf+/7BHbJn23HDJEFNQrOqtFznRmDqJdh64e8UvJ
G9Dt7z2e28gcj7CmNHyWz5yIHom5hT+RQU7GzKVhX5OFOQ1PegeH835KyBkI
uIU7Yg4yy9DxMvS1bSGdnAl5UqDKu4l5J4audCU/PLWdnIWR1brn2TNpZDkW
J7+MuwTMOXgqdJwTmLeRFVh5Y5667Ewl74FNt9SYuZRCzkPD9IT28atkshJn
VLNFzfNJZBXCTVJrs4Z5L9QjtUdNLjF5H64FhPc83q1kNWyL/M4LLuZ8DEzr
Dvd7E8katA2+uC9+JyJrYclvv7usYC5A5P8IyYWwD9zkuTwJZB0uKu2vrx+L
JxdBu+DzzL5l3o+aE/Jn31KY9Uj4kCgOireQAefuuR/2aupuYCrYm5s6z3ox
mn01Os0q2V2MB3MFn7KWN1M3oD67z7jQIqBugKr74/di/0bqJTjf5yhwSdZT
L0HOndg4dQ+ZK43qpbR/DPUynB4r1N++wVEvo/vgUS9fe95djrp6pbdJ9kcf
6RV0v6xX4EBXXnZsRyzNG9faHWWuEhKjVSse5VOvRGt76JFjNI66Kaqb1u7D
maP2M+OzNvTboGDzlqh5CwQx463v+9dRt0btbwUvQx4SjP2i/aro/Ir+L8EU
5gs=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdy11Ik3EUx/GHdWOWpsOtveXLCAk3rM00ddXz23RztNLIwnrIm2IROJK1
WFmudjUqbJZQYGBpUhaJuomMKJkQeuGaYZEXEYGVkkQ1sJUushd2/hftwOHw
4cspONK8zy7iOE7/d/9dNtIDI48DTWokFePHeucKJdnMHBItXT5dqICchjKh
59XpeuYs2E8p5C2JfHIOdt8IP/MPMMuwEOTfz9QxqxCdOGGWLOWR8zGo7A+9
sDGrcdBmSVxy5ZI3Yv/s5c7XzzeQCyGOjcZ9m5k3obdycrH1uopchFJB5v74
QUnWYibt/NE6FXMxDNNhV/UxBXkLwgFbW/qknKxD092zCreWWY/Gdm3n22YZ
uQRzopC749168lYc8nwxt8Wl5FI8uD0/pGlkLsNPZ/eFPccl5G0IDvpyZW9y
yOXQtFumTBHmCgSW/AsyMFdCZ7n5aFdUTDbA3nVPdK47m7wdfMO3w7VK5h3I
cIg/XXRmkXdir6MoEpcz83CYro5m9mSSgdp+v9k+kpG0F7hvfDo+ISdzRowv
rqsXnGupG5G3Eo2Ux9KpmyBorlmnzqyhbsKytqO1z7GaehViw9O/PBKytwqe
Wy+fSGdXUa+G66GBD97hqKeYM6PkyucfxrFlPtlTzFlSugVfKxIrpuLv1GtS
eg0aBP3ASfVv6tb/7bXS/zz/BwYY0RE=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBWIQDQNioVt3b8xWcoDwPtjb/tSNF2OD8RkcLmVMW1Oz
VhHK53CoXfhQJzEYxhdwSLSacjXvnQKUL+KQ03uuZ+cMGF/CYZ9wrNcTJxhf
xsEx8889xjvyUL6CQ0jvRi51FRhfyaF0zjreSR1yUL6Kw75f1esY7slC+WoO
/fX9T32MYHwNh/ZQJQnpcBkoX8vh0roF4dtXSUP5Og7HnTebVXHC+HoOSx/V
f+Gql4LyDRw2/BTqU3orCeUbOmQvrZIq04HxjRzOfmyrUymSgPKNHRRPfmy3
0ITxTRw6p7qzyl8Qh/JNHYokc6+/rYfxzRy2H+Byn/9aDMo3d9gaU5UQngPj
Wzjsl58tMZcTxrd0aDs7XTJCRxTKt3KI4ZBqmGEpAuVbO7ycVuS41l4Yyrdx
KLj2+VCiohCUb+sg9OLAodVBglC+nUO3Ueqd2QkCUL69A2+O0OuOQhjfwaF0
d4CNxQ8+CL/BweHijqtfbvzghso7OvzUmVSzPIcTKu/o8GHzxb+1olA+g5OD
ce/b744HYPJODhvX5U/Ri+aAyjuj8hucHXQ2s7CZ9bFD5V0cJj4urnb6DuU3
uKDpd0W1r8HVoW1itlW1PEy/m8N7y1//nPTYoPJuDrXzLu8Re8gMlXeHuu+n
PUTe3YGbeW3Vq8kfIXwGD6j+Z1B5D6g+GPBE5Td4oqpn8ILLAwBl5swB
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1G1IlFkUB/AnKyrNMps139JxaBfftjHdzHyp/4w6qaPjvOo4ZBuGEBW7
pLOZ9eWhBO3NNPoSSgS9oxSxa2lD9WCZllmWZH0oklVqiqwJjXST2F0698O9
Aw/Dj8M5zzn33ufGVPxurfSTJGnbf8///+wX4ujwXNmuwXf51s9k+GV/9GeW
cPmk1629EkOej7gXUSvO2piDsFB94at+Qk1Woc8wNr7rKHMowg9Ea5+lM0ei
tvpVZNSjaLIaLmdSXXkCswZ1k0VbvjVGkVfgUKPnUUf3cvJPMBV2v3umZo6F
du7gkPpgJDke9X7FNZ7eCHIi/rq0v2GZnnkl+pI87sMD4eQkPEh94+94GUZe
Bbdv1Y1gHXMyBiemlMFfQ8kpCJxsfWtsXUb+BakXreUFe0PIq1HbpHqaP4s5
FTmtI8FdB34gr4GSoB9vr1KR02D881OBZc1S8lrsG6s4Mta+hJyOtQ89p+6O
BJEz8FqrSfktjsUzkW2fSZ1rWETOwgXd7Z67YYHkddje13lzqCuAvB6PO59O
Pp9iBgbCfe+OB/l/tww01c3ufFVOlnS8ZR381PH/BLQtpLgew4ENW6dN9D5Z
jzP3Tu8KcLN+svl+5GwhPwem9sbcyg4Wz8HliPZrT4yLKZ7L15NzcaM3/UPs
KMs34OeslfZbr1m+ge9H2sC/T96AwKrkjKF9LJ4nxPOEeL7Qf75Qv0DIFywZ
hXwjP69UiCXvVSG+EDZfIT+PVISrviZt+ACLF+EPjzkzbYqtr0mobxLOQ7GQ
XyzMZ+b7gVmoZ+bnVcxoy9Rsjb3N9sfC14OF70+2CPkWtAwHTJ9bzc6fFX09
WTXu6/Mp3wpXQnPew90Ul62I/jbQn+aj86cIccnGn2/Y+PMt2/jzrdjQPFq9
V/9lHuXb+fqwI+XI+BedsoDyBSt29Ewstrl2sv118PPBIeynYMUhfB8lKHUl
X6rS0HqihF9fuQQRoaPe5mP0/SslMO+I7/8cxu6DUv57QSlq43qnK4spLgtW
ShHsVbrbrOz+cCIzubB+0WYynNi8s/zrfS9ZduLErfM1jsRgynfijllpka+T
pTL+/kIZNjUY3mbdIctliOqqvlrfT1bKsLHi79FEL7vvXNhTm/Bm+Ee6D+FC
zJyXIxMzKvwLqGyx1g==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/GTLVua6WxNS8tLVmZzZZa3Mn9O52VuukuJrqSQRpCFrRWT
rDyF3dBWVnSxAl/YzcISkbxQLkszQ0KkGwW+mIRgpqaUWa0L/p8XeuBw+PA9
nOfwnP8JyM3XGZ04jsv4d/6/skOyqa6pJi8QExqKaywZcwmaw8xB+H52kbk6
gCyEPO7GXmsmsweMCVt+DP/0J4sBgblNVMnsjQ9xFQ9iNjL7IrN5/jHLDz+y
P153q7IrVcyBWHU+MdPn0CJyEGaUnLsof7WQvBS923sHrvoyB6OL+5Pw+6Av
OQSfLXMj79/2IUuhXmetrRtbQJZh57jd6NAzr4L0RoVXSOl8chgKeNElS5c3
eTXsH3WmI87M4Rg5rshSrPYir4Fr96jJcVhCXouIr4bgtJ555Ajsa2jxf6pk
jkSx4EWH8JKYHIXaPeYRQ8FccjSkQ9bqh2eYY5DbHtgYzjOvQ1hSeYOy05O8
HttMOT87+kTkWCTyBb/DTjBvgI+3va/snAc5boqB/o/LilceJfOAOqmttTeW
9Xjsb9KsjxqbQz0eee31j7sbXKnL4efofBk15EJdjrPF0+t7cshcAsrs5kL5
95nUE3CgaPxJXpUz9UQMRo875DIyn4iJeXSiroAqsuihXTadugLa0rAVgmMC
6km41fRW0uE7g3oSpLUC5wgrrcclwy9FHS2pYj0Zx8vyYgr9WE+Zsn4Kaqrz
L8g2C6mnIvz0wPd42yzqqWhvjbXsa2Rdia7616Pvxmg/eCVEn8WSIQntF5eG
1hF3vcE0m3ra5Ps5FRYrL74x3Gb7p8Kj5zFfgu10P6ee8nw1nPxDxl3vsp4+
+Xvw6fjm1nDk11rWM6b0DKTfsyqMdW7UNQiNlW1s/kSGZvL78xqk3qmuWnLN
fcI2Ddx2efafNLH50CIgfsep/Q4ytAgVBQ+Xd7F50sJ4/aZTYQXNo00Lzz5b
y10dm08dzDX3T2kOkKHD8vTFYsVuMq/DleZblk1SmnebDs80tqt8I5t/PbK3
tqQYsuj/gB5BlmnnIwbJvB5bhAv4y9Fi/AXR+EGo
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0WtIU2Ecx/FTzrJ0eUmP1qzpkohlI63NS+Z+3qauOTenhGWKYTTaC7WE
rta69yItsSSwCIKszCQRcRrVtAsqWIg0AwmjiKiMVlreFl3Y/3mxc+Bw+PB9
/s95OCdyZ3nervkcxxn/3f+f7OILOh60WWRwy6luv9JdpQhi5vAc07qSlkiy
D14OnoxNKmAOAB4q8oonIsjBeNcimytrZA6Dvaj9gE7JHI4jkRqtvFVKjoCm
dPqR9ttKsgzVo2PjuwuZo5C815CSeH0FeTVGEsYH3o6Ek9fA/2S/y8ozy3E/
2ZZoK5KQo3H1S01xzfnlZAX4N+ruqoZl5PU4uiL05o8PYeQYFMt/TlqkzLHw
OXpBMlASSt6AIs7EG+p48kY8ljaGXVvErMSdisEhc20IWYX4PerYmlDmOKjq
n5qzg5jjMbdkt7ongzkBTuPwhcsq5kQEnK0sG7sRTN6EdR8l1sUi5iR0VjQV
KkKWkjej/2B6Utlq5mS8a1QpR+uDyGpUOCZ6SyOZgYDoGMmLP4FuWwH11ski
vYTMpaDfETU558d6CvyW9u6v+ORPPdXT1lTcTZKZ1zxhPQ1p+S6Vt2YJ9TQ8
m/A3bav0o54Oh/iceUYvpp4O8d7YTcMnyFwGAseDeSfP5jOgb6nN2NXBukaw
v0Ywn4n5EfJZ37v0PmsmhmyvJl9P+1LPwi9x13GXkvUsWPpsj4a7WM/GKm2D
Y9vtxdSzcfGUl21sB5nTwtk+9Ls6ZBF1raBvEcxvwYaar1MpdlrP6dD3bPP+
qm4f6jpIs3IS+GZv6jkwno9ZKzotop4j6HqcqbMkHpYupK7HoWOzPZbmBdRz
Ed0uWqCqZT1XMG/wXA+D4DwGNDp8Z5qU9D3sBrS1ll9SbKfOGT0NI+re7zuc
OsXeJ7Dd6HleLg+3HozwA+F0HghsFdieB13csc73Ci+aN8HX696hz/XzaN5E
/9ulds+b6HvPuG1n67+7zeXTPhz3F1OcOaQ=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0VtIE1Acx/HljAQfjHSb2VzbTDNdo2VmqelPnXm/jki7oIZCFy1TAx1Y
i1x78FKEYpmpJFtWNDK1pQ4yZplJmXgjiSgEhwXlEm9hdKHzf2gHDocP3/Nw
Dn/JsTPpeQ4cDifyz/570uIf6OptPyXFP82FP/+sz9KvI3Pg1GCuVt+XMDvh
6cURm/YgeT1GS9rWGFfFzG542RISdu022R35Zl4aUshCnJWsJFV+2cwsRltA
1mSPgCzF1YzwI+G5IuYtaKnlnp+1eDL7wPBx1tKYR/ZFpqYzNPeJkNkPw4Nj
+td9m5hluDnhvGIIJMuhqouuN5Z7MO/Ar8CCcp1lI7MCcR5jIy+U5J0YHRBy
p9aRAzC3dUC09oQ78y7Ibzz6dnRVwBwIV4tku6CZvBuXFSbRZCo5CEPbTj8U
rvKZ98BmSld5hZH3ouTHXakimByMcd/8HIOJxxyCZ14VvhwpORQhJ4uuZ3e6
Me9DTeG5e4dV5DCUN42a+Z9cmcNhKjRkynlkYLBMGZrrw6wB2r97NKuPU49A
YtAF07ScegQi5dm1RdnUI/+/r4lEQoctPi2IehQqq/XeD7jUo3BLM652MVJX
4k1Ohm3+HXUl6rx/ZnKaqUfb9Wioy/ytE970v/3Y4Cwwz5ip25kTg47C4vlD
pdRj7P4Xi68F/QsBi9TtzImDqLv4sW6IehxkczVG0xXq8Whfrpl1B3uPJh5p
VQp/Ry29LwE6dX/pciP1BKy2Okqsb6knwug5KvWzUk/Eh4waXdUS9STc6Z3k
vxKyeWuS0FMoW1I50PyTIZ7m1bVmUk/GpQrL+/o+6imIko0Pc7XUU7Bg0nYv
TlFPhSV2vkliZkYqGsRdLjNWHn4DedwORw==
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/GjkjovtMzNSzO3ZaHORnm/7+d0zsvUVZo3hCwkw0JrRaWZ
J3xVdMHLy5AKcqUmGpS3TNGkUSsCwSDoRSwLtMxAFIdpxf7Pi50Dh8OH73M7
B47ieP3hGleO43T/7v9PdklLno0N1inh0LJmfmbM3erPzGFz0SB/O6wge6I0
9sfc4zJmMQaCj2lNbsz++LzSLuozy8mBKL7cvlV7lFmGu1aJotqFWY4Ieeuw
qCyUrERNvNhkv7ObHIZQyeJUzngIeR9sz8WtSz7M4Rg8O7/YVy4jR2K6+ZHK
bN1FjsKc59UTRTJmNWb7vlt9TgWTDyDq4b2AyJtB5IPwUrVWiZYDydFoTL2f
XhLGHIPEmZamrtEAcixGZOVnLHuZ43Dd/qEn6I+EHI/4jle1uX7MCbjdcKGn
8og/ORFDDd3laslOchIq9RNe9gE/cjIiwjy+rulZT4EqRBp0spr1VKze6A+o
WtlBThM4Hd178j7FTonJGvSmKmvDp7eTgf1p6uKJb74O80CdZfjl7Ig39QxU
qNpy3l8i8xlY9R25thHnQ12L8dfJS+E2Mq+FqzzS7t3LeqbzeD4T74KXFzrF
XtSzsB7VfsV8WkQ9C202U5N2zYO6ztm8DoP99Z3qSk/q2bDMpF08P0rms2Ee
+yh9I9tGXY9fSfZNrdqduh7NXbMvpF/cqOc4mxeYy4Xj/3ClnivoeTAktAzZ
1Gx+Hr3/hsbR8+Ht9qRxocOFer7zepzBeTxvQGlFdP855RbNL4CpN0Xz9AFH
8wuc9+MKBesXCtYvEvQiwfmMiLn1cy1jct1hGAXnMdL3W3V40kjr/ab5h2gf
jvsLppQRmQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2EYB/BZgZYzb8tcauryMs1LztLM29/LnNc5LR2FhIqC2aqpyWAS
LQmsJAPtOoNqlVJbgoYjNVG0q1IgpPbBMNIsM7PSxLKiovf5sB04HH78z/Oc
9z3v41l4KLt4BYfDEf+9/z3pcspp72rdL8B/fY717nEvibEmc6CouPBO3erJ
bIW1Aym/h3LJdvh17cZ52bIHMw8am5OJLU1kZwTuVrw0ysmu4Eb72NpyyR6o
96+ra93nzixAYOSZVd/vbWT2QjD/tlo578bsg6rLAt2ufLIQfMmVqiytK7M/
vINuKu+/d2EOgJrbf33x4QbmIOzcy6s9l0zegotOs08KmvnMIRie1VjNTDgz
i2DpWvQ2+gw5FKPDRwZORZG3YqaorfqrYT3zNuQ2NYrkXHIYUGgcrVc5MYdD
b//J2efuOubtCPs49cpgSY5A7+b4WUM5j3kHvFQWDWFzjsyRGDS23ypXkqPw
QNbbqOl0YI5G9+Oa8aWj5BiUHl4yWsjJsXhRvLha2GHPDFzqaVblBLBcY2ZO
HJQj830FnpTHwU3/cyQvnOrjkdQ9XYohZk08rFfeUX9ooDzB9HuaBORZ6rQu
YsoTMTPmezy42o7liZAp/Ae/8Zk5Ysj3iFrKBbYsF0MfJSgR9jNzkhBoL/yi
HaL6JDwd8VpY5lJ/CWwUDjMnyiiXmK0/2aw+2aw+BVPBgtCDfrT+FPhJN/HE
ByhPRYU+MrZNR/WpiJUv5EldKE8z7adJQ6Xf2Yb6NtpfOriOfSrlNO0vHbWi
4rHGfMozEPG86+qj19Q/A9WThacnDdRfavq/NVKz88s0O79MhHS6+L6ppFxm
Oi+QISRJ25H6jN6XoUUyl63isnnrlUErPfZjYg3NZxbsasqKxnU8/AHryhIP

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2Ecx/HHS1nNvHs0W84tCzMx76ZW+zmXbdPpLkoxuiFYLxQqb0VS
LSIFUTD1ZQStwEgUJowkZ40gtUBCJBZUSESBQnhJlo7Iiv3Pi/McGIcP33P2
/M/Do6y7ZKkPZoxZ//3+38VLqHWNOxtUCGhZrTAOvxhTiGbYyGqZ3DmpJG9D
g7MnOuii6Cj4R117p8JEx0HJfL6skRRyIhrd8WZUi5Zj2jjdWvhNQU5BX8yn
UEeGaBV0M46tX08lk1PRLazK3Pf3kPdjIUc5Jfjl5DTcLkjvNOhFp+OJfF99
vXc3OQPugUNdd/JEZ6Jk9mWz9kISOQun3+m3T3zcRc6GtnAp35YpOgczKx03
U5sSyblocyb31X5OIOehI/tZstckOh/j3b2D7U6BXICCVVtaxXw8uRAKnbFI
eCr6MM55XWfnrsWRi1A3rXqea48lF2NiqnN+/VYMuQS+rpGEM2vR5CNoPTDQ
3zcaRT6K8NhXVy8vRJKPYZOZN8+3iFbj8ZtHbbKWCDLQqOmdiHhItoPrpXj9
M9JquxJOnTPTYHbs/dqHdRl1DWaSlhcHonZQL0PHvYbidkUY9TIMjnuFt/It
1LUInL9g6lrk9vz4VerZUAf6cchChq8v9q8EbOfMyrFU5P+jyfxOvZx7/wR1
H3XOTIeTtpyRJtUmdZ10HqZHcEq6Xzb0m7peuh4zcPMZuP+v4HoF1yul89or
6fkgWt8Ic3f2wdC7obQ/Rm7/qnDjwZxb+BJCvYp7v5r7vmru+0zS52Hi9ssk
nc/DdWaWdnC2m6X75zFz61vQPFSiHnUwWt/CzWvh1ufMrNJ5YOXOA2ePlTs/
NdIOzvYampOxv/2xaRc=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0H8s1HEcx/HPojnhOjkcdxUWc4gOdyKXlx/3Q3dKRobarLotzBpro83W
nX/QH7V2bG2mZIrVTTUzjmKtwtZQadaPlYa0tRb9Euao5v35g+/22XePPb/f
z2efd+DJs1mmLYyxxH/r/5s/PjldffdLgrCu+STLn2+d0wJuhtzaUubeGkgW
oLk0JNhJzy2COOrUYuZ0AFmMt66/Je0N3BIUT7y+80zLLUPZj7EnrlO7yQEI
Lm5SFXlxB6G6tOCM59Fd5D3wk2bWxtbtJIeg03ntTcWqjByKF2wt1VHFHYZH
sv5r471ScgScw9sVgkl/ciRG/Oe/1Iu498HYA438qh9ZAZ3mXJHTioQcjc/d
NoUimzsGwsqwYx+svuRYfBfmPJZHcSsR2GwRJ4/4kFWoW35+28/hTY6D6uvs
e5sL936IaspOT7aIyfFoCHbksete5AR06OayKty5D2CqUaV8Z91BTsTCxQ7f
E788yWr0+dc32edE5IM4Lx9aMh3hTsLP1d68ahduIDV7RbVVK1y3GVjwsFtW
lO7Uk1Ey3NM/bnejnozGCbelW0oyS9n4vTll434sFYdtlzSmLg/qm8zSkB9+
RT9ayfdP23ge02w6X4O96sjsgVn+vxZ3pbbul4bt1LXIzY/uKA8iMx0ytINP
Z9R0X7MO8aN9zYMf+f31eGVacA210/zMeogiFNLRNT7PdEw/cJjD42je5nQU
6Aa2Ld/j8z+Emwkxw21NvG8yM0CjnqkaW+bdgEXDJ4HFyLsRD4dqJhcv8G6E
1TRvPd7GewZutA57X57gPQMpkYX15YVe+AsQSvFI
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJw10G1IU1Ecx/Gb28K6q/bkndWqqSFO12VL3dSy+3ObM7Q3hgUFgxVE0QYW
EVFY7UURQWC6HmiW9iA4kSilB8FF0CsJKsTUaISEJpTGNlbibErF/ufA4fDh
++b/P3mHm/ceyeI4zvLv/n/ZEfY9H+r35SOjuORP+p52aJg5iGHuVPRZHjkb
oWF51FvHrMLkx64/DbNGsg5n14SezLUx50Lx5Vh/RzmzAdqFsdfW8BayEXeV
9ycexjeT86Ev8/AvKpi3wiXbzc0HN5ELkfR237MpmYvwqqmh0OI0kIvxyK86
tLJtI9mMzpi5V/d7A1mEKd0ipZqZLfi8/G722/v1ZCt+fkj4qy3M2xHtOnry
al8uuRTinYGYJ60nl8F7YH/qto+5HIHs0gvJaYFsQ6xycdkhMtsRbxxtvWnL
IVdAw+sjMxEtuRLTx01VS1eYq/CgezindVxD3oGpyFKgxM68E7zs8bkfQTW5
GtvURYnQiIq8C6dNN4LtA8wSlNo3Z058X0cGnE1pm8K9NuMAoJ7TCXGBzNUg
y1i8yPcpqddgZHDs16cFnroDBfW3xg+GV1N34Pol2eCkh8w5kTK3t/T4V1F3
omdoQnhrUFB3YY/94sspUUbdhfOdoxHhK5mrReM1a4n8spx6Le27grqb5ktL
me6mnsiYq6P/n6HOPC/9Bc58waE=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1Ik1Ecx/EHhzRTbOp8mts0N3OsGivdsuZWz2/TvYVNVNJC094kaYVF
CSEFu4kRapKWhdmbvSywjYwGmiW93Fh3NUu6XEKULVQIa13YC/ufizxwOHz4
/s/N4aj2tVY3J3EcZ/y7/51s8TvCY8NeNRKaE6bNwgtFGjOHow8qg91BFVmM
d56d9zKrmCVI7jtg8cbzyVKE3LfXrb/OLMPXavFPTQWzEs5Lep32wypyPs74
D1a9MjCr4fXHDMG9eeTV8Nw/Z28O55I1qHssmRyYUZK1UOXHjJ1FzGsRnch2
zbYryDrkWRcfbVuQk/WoaZR2XHQxb0Bh96QjfiyHXITffaP7P0Zl5GIUbG+r
9e1mNqDpuS9neRazEbV3rxTXpa0kb4SvTfhequHJJSiRp9yav5FN3oTA2BT/
Wsm8GVdHLPW9ISnZhKapcGPkJHMpGsRy32UTsxk17892vs3NIlvQ0XWnMChi
3oITLYHxSj6TvBWOp18O4U0GWYCluMKfvocZWOMpkNqPkH2AQjb9+XyPhLoV
DcsG+xV21q3Y1R+8ma1j3YYhi7pF+3IFdduS+2VLehkyYlJ+jk+nXg7vxMh4
ZDSVejniup5TgcMp1O0YDrVe0NeLqdvp/ZKpO5D4v0nUHTg+ZBYeDnLUnTh9
LfKEj4qoO/+f51yYNf1atOkXhER3wdD17Yf1WTxhzo1UUbB9pneeupvmPwl/
AJh0xsk=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03lIVEEcB/CXR2uZtaa75lGu22WemamplV81z1bbdXe1jMiCKFAq0rI0
8SWV/dHhVgSRCGVph3YYmmnRSlpSCIm0BR2SgkQRHkUemB3sb4g3D5blw3fm
N/N+b8Zn+56MHTaCIOT8/f37Z4/S2Nh6L1cNq4ZiLOLqnsUyZgEW360VjXd8
yA5weTIlm2NklqO+3FlRNagiu6Lt8tNAWSXzPLz8mNKsiWb2Qkbdq5GPJm+y
Cg87ZcMNXxeQ1Yg3TIbbJzIvQnJTe1/S6fnkJUhQ3Wmv7vQi+8JblxTYG87s
h+o8+bbpJk9yAI72fdbuHfYgB+FujiaiKYF5Od7rDyg/XHQnh+BaQ0f1iZ55
5BVody08pBpxI4dC4Rbm31XGvBJ10VefpX5WksNQMHFDHRLFHI6WvQGjehsF
OQJe7zZCbnIlr0J5UfvBsUrmSBQqLglnalzIUfCfr3TfuW0uORqPn5f3jpUy
r0ZIi+fSvv3MazAQrA7dvcyZvBbfp1o2lcnk5Bg0DVUEe3TNJgPdza9/vB1z
tFoEKo7aNvdumUl5LO7d3nM+aLMD5bEIPfVtNNY8g/I4mPrzi+NGZZTH4bgp
N6rYmyzEI/9WdEzDFYHyeNio/CYcb03GWPN1UouchQQ42tYXfTk3THkCBiMn
puKCBihPpP2MU57IzU+C9Xzb0PpJqG19o3zhZU/7S5ZaTIZ3clqk8ibLU7j3
S8F4wNnDtXns/VMxdL/7V4mCLKZiYeoFS/Z11r/10vHiemk/BQ2KSifacm9O
p1zDrZ+GLo+hL+flVE9M475POi5ZHMdrwtj3S+fyDdQvVn8DV18rNbTQRJQ+
6A+ypfFaZGWvuL1P/dvaT7NW2k9BJ82h4743l5t1KKnqeaT8RPWFDOhOhvjb
HbOj9TmLnM0Z0v0Jemk96NHZsaawoIWdV720/2a9tJ+CAT+dHh6ZDJtF8w2w
OJ3YNZ7uRPMN0vthNnDn3yg1jNx9MUr3YzZy9yOT238mnfdpND9Ter7Nmdz5
z6I69CBLmotZ3Pz/4/8Ac9qJCw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdyVtI03EYxvE/a5WW5iE3Xa2cIyLcXNtss7S1ZwenVBBrmbRySjS6GGGH
haPA/hdWGDVRKaICtVG2YqIMC5JyFNMIsgtJrwxisK6EYavJOqxi7++iXnh4
+fCtON5+0C3gOE79Z38/O3HT+MSYR46sEsbyMZ+3L5eZw68pZ57qQQU5B9om
8ce9h5kL0R7TdyZSMnIJutQhzftbzGVIKV7q+CpmKeo8k0WjT8vJMryr69Yu
LW4my9HT0Rc8YGbeAk9yOZi8v4m8Fa7OuVDwk5S8DfvmlgISHXMl0vzMYG3z
RrIS05aw/kIuswozC2HHQvcGshq9vs+tQxJmDbpObJ9OX5GQtYjLA1/d98rI
1fCn2hpPfSgl70BkXc2LV8XMOgQH4qOKFjFZj5OeuCWSz1wDwe2B7428iLwT
Cftsz0098y60zo+7Zn0l5Fr4T59/fNTBXIcO0V2u5+F68m70uxP9x4aLyQZ8
uzZS2pIsIu+Blff91FxlNmJNYNllizIDR+6EhkTKwqx5IMPZM23eAuomVBlU
hybj+dRNeGR6HZ2SkDkzol8KHM4zedTN/3ULqm8spkyRXOoWvIkaOrzPc6hb
0Rs7d9GcWk3dCmVYuErvJ3P1GJ6YF7+VrqReD/t1jUJ4WUjd9q95G/bXXHoW
U62g3oBmp3bkrDxjzPYGCGSV6bVPfhh/A0Mkvpc=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03tIU2EYx/Hjdcu1MjFTs7xFidrw0rzMdL+pm3PqnDcCa1CGEFiJJhj2
R8eSWiCiJGpqBOEtL4GGqVmZhWWWQUhi/5QgmmmYokgulYo9L7EdGIcP3/O+
53kPzDsnPz3XmuM49d/fvzu7XLJ6B7vzfGDSsjzmW1N34S5mDn3fg3zXer3J
QtyziVHUnmJ2xHynPkS64UV2Rk+zV92RRmZXfPYQTJ9RMHvgZWY4Hz/gSfbC
+xO3qgxCZh9kXJ/eWMw7SD4EvbIrwOrxAfJhQJdTl7bkQfZDXWP51MxZZn8E
zYpb+In95EAIWirSb265kyWoLLPp/6pnDsLzVKcvg+1u5GBYORtWt7dcySFQ
NexYaQ1gDsWFphzBjYv7yMcwWF7ZeqXbhSxFkfGBT7CMOQyCYd/GwB97yeGY
tatZ76tljkCZ7dsxYa0zORL12lLjjAOzDMGq+gHNuBM5Cs2y0NHWu8zHMfN0
iw8IZ47GnaHW4qxA5hicLtD/HpvfQ5ZDfN5p0VDgSAaevZEt+c3sNJkHjkZL
MofmxNQV0HZWKHN7ybwCH/s/rU39ElGPhef2+LuIZQfqscgOqFJ/uMx6HH1v
1uMwOhJdXPRESD3eYn08xt2XF6odyZwSDZOijRYp7ccrYe3lbxR10Lycyty8
CuLCkKiJa2z+BLQpXo28dmPzJyAuczPMTrWLutr8vLwak2LDuQ0tW5+IkdXd
GdkFbP9ErIsHSjel7P0a+GpqJrPb2PwadD/Mr5acZOdLQuAjW/uwCgH1JIvz
J5ubT8bPSON2rMSeego81SmRLu121FNQctU4nNfOutaia2H6P1tTTzU3b2FO
h0sdUfKe+5zJ0NH33JSbntfRPOsmv9BBZNNVsnB7xWQuzbwjjfali2d9jtb/
738AtoMd5w==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2Ecx/HTLNyYTZduXpq2Dakxc23a1G3Zfrtp6ioUwmHvSqOwUFLS
Cmq9kKCWZQXRgkrxknkJA7MaxooiKwgCsRdBlEOhostKJxqtC/s/LzoPHB4+
fJ/zf86Lo9rVUFUn4DjO/Pf5t7Ml3zEaGKlXI6Zv1tN7dl7+IWTmENA+i34a
UZGFODCnuCl1MydBlnPHLJhTklMgvGVs2HqVOQ0ZpyaFKh2zAuGKtyY8XkNW
olYvHp6OZJHVCC70/0zXM2fDcKP7Wlt9JnktagTlXScCCrIGs7mSopEsZi2W
vC+vm6tXk9fD9+K95F0wg6yDT6bPbtQx61Emcdyt6kgnG3AsM7Xn+0waOQ+D
k57DbzzM+ZgRjB06P51K3ohRf6+tPZHZCH//Q8f8kJxcAFH0oshSwFyIfbXz
rRvWychFqPQZcpa3pZBNqPfEV+6+lEw2o7N7QnZ2ahXZgua9fQ+2y5k3YbIu
ItLck5KL4fS2/jKcZN6MXKkm7H+VRLYiIflRS+OHRDIw/tT8RRNKiNkLbBts
d9WNrqRuw377uXFJp4S6DQKldkk8QOc5O65MiRd7jWLqdkw8KW5pvi+k7kBH
qOmofSGeugN9gdfy54oV1J1wFx4fC+niqDshjhs68vHCMuou5J/5vGALLlpj
3YWmAYv1dhdHvYT3fgli/7OAeun/572lvPlbUF2TN3xQ/Zvm88yV4atpKWrX
RajzzJWTZ6nzzFXwegXdH6bu5nU3fRfH/QEma+Z+
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQDQNioVt3b8xWcoDwPtifZT/6cJcQjM/g8HDmGaHD
uxWhfA6HDdEr63ZEw/gCDoJh99LbfitA+SIOGsoGvSfnwPgSDgUbN8/v9ofx
ZRw8+J75zXgjD+UrONxoT5reqw7jKznMKS8qzcyWg/JVHARV54ddvCQL5as5
WB/cY1pkBuNrOPA0T5u2tlIGytdyWPfAd/2ENmkoX8dh3nudlSJfpaB8PYcN
CT7m21xhfAOHBTMt1dpjJKF8Q4eCmXn+Jw5IQPlGDg9+yoU2GcD4xg79lwW6
z3iJQ/kmDsv+rpBXmyMG5Zs6nP71oqttqSiUb+YQPGeKdJUhjG/u8Gcxi+Lz
CyJQvoXDxk9S86syhKF8S4fezZza++4LQflWDlklP7YxhsP41g4z9y8vD9WB
8W0cdktNmbvzvQCUb+vw+o56i34TjG+Hxrd30LXVC9n/jBfKd3AQfCMi9kGM
D8JvcHDIPrFj3+Wd3FB5R4efOpNqludwQuUdHarqfx3MXsUGlXdykPfwtRRb
xQqVd3II7DHUZmllgco7OxSvtrbftIgBKu/s8N7y1z8nPZh+F4flu6+LnZKB
6XdxqJ13eY/YQ2aovKsDN/PaqleTGaHyrg6Q9MoElXeDyn+0h8i7QcVhwB2V
34DgAwCut7TU
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz3tIU2EYx/HjNWmVpm5e0ymapiY6y5yW+20629TNGYkpVhb6l4KmhGVG
S4ggNZEw1JlUotScRUYJ3bDMIAkNJWhRSv0xtMhLBuY0rfB5g50XDocPX57z
vCfoeNmBYnuO45R/n39vdkQ5Dx7fKwnGuuZkUTO6NyEuzBxiHStmVcYgsguO
lpsLXucyuyGyyytBtyQme6L9dP6XLgOzN+KeKmvKFcz+eOv6rKl4JJAsxmi6
5zV/d+Zg1M1bl1uqA8gh+BSzIzR1Zht5Ozp+S8wLmczh6EwcXqhp9idHwDLf
OjVm8SNHIey66f3DZOZoTJeKEsosvuQY6DbaNUwWMcfi9skPMkOjD1mCnefN
RwQ/vclxCOxsqA3TMO/Ct6K+2h8mL/JuBLyc+DWmYY5HW9bSZOGaiLwH7aOh
audLzAl4F156rLtfSJZiLnu8sTmeOREThy5frF/0JCdBW+l25uoQ814UuPjq
W6TM+1AlNHCN3R7kZDjn2N2fG3Qny1B44vDy8NRWMrCw+iivdoPbuvVAXlvv
DWEUmZOjTlL80VDIuhy5+ZI7FcGu1BW462fqH8sg6xWo7EmS9d1k8ynY5PGi
qnya9RSkHFyJd0rbQj0Vt+SDQ698NlNPRX5kk2rklIC6EtXnrM9LjM7UlQhU
aaQioxP1NGTXx0Y6XnCknoazHeNPRJ8dqO+n+67J1jvPnAoCh97qr1fsaF7F
62rYiyOsgp4VmlfzerrtPn06/T9H+zMQ1/B9UT6wRPM8c5m0f556Js2xo7G1
nmdOi1mpdVURbaF5re33uCze/ixe19nOQ8e7D68P6Hj7s//7D8cvDgo=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H9MzHEcx/FPdbnQKZWTrvRjVJRSydVd6dX16+r6cVczVLawi1Vb6bTo
WF8tYdpI8Ydf6WwiZCWiH5vCGDOb/PhHfuxsCGmzhVR+rPfnj7vbvrs99vy+
39/P95+v7+bSbL0tY0zz7/r/z3/Stdd7O4r9MKOxuA2NC3KPS7gZNOeU7tqL
vmQH6GRHZV/Xczsj9EnhMx/G7YaBljsrxKd8yO6IMojeGpTcnuga3nZhZ5c3
2QcTRlbgL+L2Q49NntPYisXkJUi0U7PxRi+yP/rvK0YDzZ7kQLjq9bqcCO7l
EB08XNR2QEYOhn6wW9t8w4McAvHwoY5ro4vIKzEqvtvYnMwdhoFHppiCOndy
ODqZSTjkzB2BesV0YULlQvIq5LMcqbZBSo5EwGtdS4U992qY97oElm1ZQJaj
3WvIb/kHN3IUjM93SVgBdzSOLZ3awJpdyQq8L1qmmNrPrcRd7e2TQo8LOQbm
vikhSM4di4LtG38//DifvAb60+dtjWe54+Abv/VgxbQzGfC6NPkiX05dAMpe
fB/c5Mv3xVvOC/HIF5tOyJL4PhU+vwqoDa2hfYIKJaoj/fNa5lFPwFXZ5e6n
GifqCZCUhyuHaiTUE1HRq42J+kn3C4lwdB2sLPtE97MkzP/iJh2T8p6Eccmt
vZORjtSTcaTW7uabjXOoJ6PBbDCqfoipp+DBvdjKHT0O1FPwK/jo7taS2dTV
+BY9Ma0KmUVdDW91RrS0zZ56quU+IdVyH0tDR3tpU0ge35+Gxx5jI03OdB6m
seoaVFVPDBS30fNYOuoaihVGb74/Heny6m5ziB31DOw5M9QnfUcWMrAuN7y9
3O9P3EzPxFy7K1UjjTbUM63msyzfR8iCrj4sSLRPRF1raVhZ0FrO39ZanV+H
1t6X0oee1KGD4ZIyrtPEaF6Hme+LLc3rrM6fbWlYWcim5zD2F6nOGwc=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzmtI01EYx/H/DGVdFrbcMtPU6cJyzNrUptP223Re5i1WUa7shSUElZdV
SEG1mS8CNYNMSIqcCBleaIUvvBCj3lhmsBQLk964ZHTBa2bStGLPCbYDh8OH
7zkPJ7q0wlgWwHFc+t/972RLfKR3wH5WAq9mNWPtmceuhTBzqF14eb/VHk3m
w6aauB50iDkYT/T1ObdXo8ghyO3oKXG2MoeiVjsYr9YyhyMsYTF0bjCSHIW5
b66Lde6dZAlKqht5qfHMsfjx5pX9cnMEeRdcw18XnSvh5DjwmhaeR5xh3gPz
A0Wb7NMOsgw3R86Lq2KZ5ThsXXOO6cLIezEhDnz8tmg7eR8q75UXDTlCyQpM
TRqrrEHMStT3z0ycrNtGToQKMQGYF5OTMHpusm/oNHMypqzCuMpTIvJ+JL5r
qJb2h5BVMM1/TJZ6tpJTcFfqKeYeMqfC1j4kahwXktU4cUNp+uBmTsNy3me+
NZ85HdMJEmX57i3kA6hxlTa4upg1ELodLzqNzEBxS7dNJAv22gJcGjiYplre
TF3ra4sWhV239GW9Auo6LAn6rL+TNlHXQWBWqEdrWM9A5OrIsGp2A/UMzD5z
eq6K1lPP9LXFz5zer+t953FZiDE0j5s62Pwsv/fZsPdUNMmP86ln49HAe/Hr
8EDqOdi4rvvKlzs86jm40KnWPG3jqOf62pKLoyZFj1mypvF2A2ZSVlZ18mmv
LQYoG77/1Dp+Uc+jvkQ9z/c+l+/X8+k/c9QL/OYX0L/YKvzf/wAcxALx
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQNioVt3b8xWcoDwPtjbiM+YISUA4zM4ZCh9dny6
ThHK53BYxsluxhgA4ws4SGyx0uP5oADliziw7/zUYjcFxpdw6NP4euKXDYwv
4yC4J2nJvdPyUL6Cw++Soym/hGB8JQfeimWthVFyUL6Kg9+aPtfUrbJQvprD
QY/qGcsYYHwNhxXOSaK97jJQvpbDtuMfvtlPl4bydRzk/509bfFBCsrXcwie
6jp9XS2Mb+Cw7NDeY1knJKF8Q4cVq3Z1cCnC+EYOD37tYFhbLwHlGzssVJoj
U7BJHMo3cQg25GC4GQzjmzr8LVL0LbWA8c0c9svPlpjLKQblmzusLDh7MaNP
FMq3cLDIsjfqFYfxLR20+93OOZ0WgfKtHJqOh8f+8oHxrR2mP+xhvPdRCMq3
cYh238/1awOMb+vQ3btUdS2zMJRvh8a3d/ixhL3uiSNMvYOD296XWQ4XBSH8
BgcHXUGNj7MuCkDlHR14i4ysLzfxQuUdHb7x7mz8Y8oDlXdy+KkzqWZ5DidU
3smhbWK2VbU8O1Te2eGs1IdXUwS4oPLODhvX5U/Ri+aAyrs46GxmYTPrg6pv
cHHgZl5b9WoyI1Te1YFJQesX9+o/9hB5ND6Dm8N7y1//nPS+2QMA9T6ryQ==

          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2Ecx/GTopZLm7mWrlVeUlTCSpvX9Py8TJ3pDGPEBlYIi26maRBZ
0FF8MV8UlUnQ0NQXSsyKLoY6IqWVERp2m8oISqOYaK4MdSJ2Yf8ncAcOhw/f
5/88z5sTWlperPfgOI7/+/77skeq6TLfPxEGlxx8zIy/d2MgM4dTrbeeCt2h
5NUorh6696WEWYwO7fyzcE9mCa4+uvGVM4WQg3AuesCpL2KW421/hd13Zis5
BN5Jpp8l8cxhsJ9Jqft8bAt5G2xF/NjN5s3kSAzWVtWrhuXkKJRaH7b3JzLH
oER/eyK9YhN5O5quGVvqDDJyLAYTvvlqPgaTd8L5rtwn+yzzLqRLIzoXLUHk
ONjCj7cNRDLHozK4bGT64kbybvTItWUvI5gVGG08rOsclpITUNM0fCi4gjkR
463vNWIZcxI0Y171hvMbyMno4o8sXDgpIafgoCHHnmYJJKfCsq/PKPSuJ+/B
uDFBYWtgTsNUoFY/V8+cjmh1uERZFkDmkfza3PLik5gMzC73amt9yALw2HFl
h2zIn3oGAqYkUoeULGRA3XlZqe/yo54Jo1XkbFeIqGfiyUDK96iJtdSz8Hx2
3X7dabKQBauf4ahTzeazV1rIxpxfT82Sgs0rMSRzTF4X+1JXus3nuM3nwCMk
ZlFkYvO5eNP94dfoArtfLuIvTc9n9K2hnoeZ5MXlzFhv6nnoMI9IX8m9qKsg
8rxTPdmwiroKVaZU/kEbRz2f9nPyrp5P+825zO3FAV3c3cqw39TdzBXQfZeo
F8D1P3rQ/oVu5xeuPI9T0zp6BDWt/0G96H//A0GX/v8=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQNioVt3b8xWcoDwPtj/fnb8Fj8/jM/gYNsgVxm4
WRHK53DIOltxfJ0vjC/gsFtqytyd7xWgfBGH2UuvB8a3wvgSDlfb85p/qMP4
Mg71V29p1M2Uh/IVHNY7xPZV3ZeD8pUcft3me+X9SxbKV3HoYnspmi8P46s5
HGp16L2eJwPlazjMLveYf2mPNJSv5fDoLHdyw3cpKF/HYZksa9/lMBhfz+H3
zgv8bJWSUL6Bg9H/FMn9CySgfEMH1nxu49yj4lC+kcOZ7SFcKpIwvrHDztOR
28IjxaB8E4eSXyuVDK1gfFOHeDNbtrtnRaF8M4d1speVtJ6LQPnmDu1VRyp+
zIHxLRyajofH/vKB8S0doj7dNlP9KwzlWzls/CQ1vyoDxrd2mNtwtYp/HYxv
47BwyQnR/mtCUL6tw/SHPYz3PsL4dg6X7CexiN8VhPLtHRQd0ztL/wlA+Q4O
vDlCrzsKofwGB4dKzeM/U/1h8o4OS04uLuMu4YPKOzqclfrwaooAF1TeyeHD
5ot/a0U5ofJODlX1vw5mr2KDyjs7bFyXP0UvmgMq7+wASW9MUHkXh+W7r4ud
kmGFyrugybs6cDOvrXo1+aM9RN4VKs7AAADZ063z
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2EYB/Dp8lI6N29z3vJaSa2hlvfbs+mWms65aZepHwyEQEEzzVpZ
RwkKIjGTIEhQjLyVaLrygjGtqWUTRNEKIysJWmGrQaS4WeHzfjjnwOHw43/+
h/e8zzlBp8qVJbYsFkv57/x/JQc/XzvaXxoM2zKlCNcUr0MdiVmwwJ2Nt+kL
QjtCbdtHYbGKmAfswcctM+ZAtAcUPukZb7lLLABz+zHNBSD2A1njzY2nywHo
QDCueK1q2cTB0DfppXMO2Y0OBVfBWyu7yB+9F769aT8hbvJDh0HOxS675GVf
9H44WP7gskFELITwFWNRvtYHLYK8uq25BQlxOLTa6ZRTGm90BAQJii2G9wJ0
JFheBNwYfOeFPgQ6l5ixCTfiw9DKtfXZlPLRUdAxusR/5eeJjoYl+2tL/r88
0DHQUFHdXaAijoX14rOWOq07Og4iRnz3fap2Q8cDTxjhO7vlik4A/57NxcIY
4kTIlk3qV5N46CQ4ro7srQzmopOhU/xcP+nNQaeAs/tETcVXkgPdFID8YYO0
REvuF9P7lBjuv2w/51TlgrkEFjnXT6/LSS6Bsan4tbDPzpingvrArfTZ806Y
p8K6sOlSR9lOzNPANDBnqfVEU2mMXEo3JYVpfVJN1Ygj5jLo7y1vFhWgKRk0
XmUPfSjahfkRCLAaZmJNaIphVjp9vVQ6GHxMxmYeyTMgJPPOorqT9DNAb+aq
1GfI+2Uy9ieTkR8FTmVkwnw9yRlmZTH2L4vRz2asP5uRy+mm5OD63YNv4pP5
5ED1qCIx9g+ayoGMrt7uPffI/BV0gwLM1pGT9Q74PVEKKJM0jrm0YV+nYMw3
F35zhus2o9CQS99/KhdKp4eezQ/j/HWM+1lK+nxByfgelCAc2GEf3eCAfSVo
rmyMl3bbY1+F/5sd9lXgxH6kMd62wb4K/4etlO0+yX9um5WHz8ED8uBH3IZV
IvqS8hfsolBz
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd011IU3EYx/GT0xouZZbOly2n0yTNNFdbU9Pz23yb0wWZZVgXFkSBkZlF
oURHCgksyncjiBIsca1MSSnDsDBMp1jKqosuStJMqAWSOMMy9vyJeeBw+PB9
zv88Nyf8cEneEQ+O41KX739Pdsn2Pu59VKyCSw4+Rv3lSr6YmcN+bfPsvofh
ZDFsinlpQx6zFKKsEnX/XBjZH/Vy7Z6+G8xBmJ6YVHqBWQFb8/Pckw4lOQw5
8QEFozpmFdJvf/568WAoORIvogc7dD0byFFYHFZNHIhk3oTSCVuBd5WCHINL
nrvvjPXJybE4VJ/fbYxgjkNlUWZP04kQ8lYcs4d2dLUGkxMwPTUgnVMxq/HA
b2hqpiWIvA01k2UVhvlA8nZcG5dW20zMGrxvKCq8PyYjaxFZ+ubDQgDzDlj8
vgdFdQWQdVj0Pcr3ZzAnLu//ekjc5E9OwpZpueDtyZyMmcZTeiu/nrwT1Vdb
N1pFzCmQxibIR//4kVNXmMdbvtYz8CMzcCa6vq62U+qyAPgcXzd7uZTM6dHt
uB4fMuJLXQ+PsBinxLKWusHdggG/fJ5U/tawnobCzTXG0XMS6mlo078ceBXs
Qz3dfV5Ih3JpZFjn8KaegZt2ycJdDXs/AxGmRnthG+uZGBxIOXv6qZh6Jqpq
ipMqlGuoZ+FHonPJELeaehbKLzj7i9vJnBHnb40/k30SUTdCIrKWf6tbRT3b
3UK2+zxnwr3ed7IhhRd1E1z/kwf1nBXn56z4fq77vkIulEZzoqydzuPM7vOC
GWWWZL6zhaO+i/b7ybv6f/8FXBr1Rw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQNioVt3b8xWcoDwPthzfbpoxS8E4zM4ODGyWTYe
UITyORwuOPOeUUuD8QUc+G3N1j3+owDlizgcZLCx/rQIxpdw4Hjn8S/cGcaX
cbCW+VvXfFMeyldwWNylOfVFCoyv5HAtXWLyonlyUL6Kw8yDrlM3vJWF8tUc
zKqeqvFxwfgaDhVRE+veu8hA+VoOu/Z8eKxbLw3l6zjoVkiurdolBeXrOax+
7ZjuZwLjGziI3bXfVTJNEso3dPg/bWfyo4cSUL6Rg2WY2/xObhjf2OGQ9wqt
izHiUL6JA/flL4X/6sSgfFOHzJSvFfrqolC+mUOER7/Ao/0iUL65QwyHVMMM
SxjfwsHV9knN+V9CUL6lQ1bJj22M4TC+lYNLQ8Vfw3ZBKN/a4eQ1lS+/eWB8
G4dlyl63TA4JQPm2DktOLi7jLuGD8u0c/Nb0uaZu5YXy7R2OfuYPjirkgfId
HDauy5+iF80B4Tc4OJw4altesgvKZ3B00NnMwmbWxw6VR+MzOKHpd3JYvvu6
2CkZVqi8Myq/wRlVPYMLmryLQ2CPoTZLKwtU3tXhveWvf056bFB5V4faeZf3
iD1khsq7ORSvtrbftIgBKu/mEB5ltK5I6b89RN7dgZt5bdWryR8h/AZ3qHnP
oPIeUHOgoAGNz+CJJu8J1w8AEynBZQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H9MzHEcx/GTEfp96pTCFfnRnaYrPyq5V1ddd5Vzl9ptTRTLtPKjjJHK
V9qyIZIfbSEb6ybJMC4cdzWcGCu5mFpWbURpl9MkMz/W+/NH992+++6x5+ez
fb/fz+f79d+8MznLgcfjKf+d/6/sEKTeeXAzJwDjskordRbDqDMzD5Ytb8Kd
9f7kaUjcapRGJDO7Y59I5d/yVUj2xL3kS5mFZczeSBu5MiACsx/0IteuWy3z
yEIItUOK/RHMAYg0Grsjq+eSF8C23dGsH55DXojpyzpjbqQyL4aDMGjM6Zof
OQju9UN+EjGzGHuP7alRVPmSg1Ha26/eNTybvAwph/60vZExh+BwffPM1I0+
ZAnuvrWF8c3e5FC02kZNrZuYw5DdERjsVDGLvBxD6U36zKcC8gqc4aIue8iY
V6JYXFC9w+pFXoUVlY+3KfnM4djSaTDoBj3JEfDeZHhdLmeOxOez+dHXpTPJ
q3Gu59ik7mE+OQq7OmzNmf7Ma5CRl/7reb8HWQqp9vsGlS8zJpoDXHL5A0fy
3KlHo3Z+wvuwZjIXbddlUOcGvRjxYV0GbZqkIT/AjXoMVPXlcVl3XKjHIOdZ
46P2e07UY1Hd4fSzdjmZi8XL2dYvp91nUI9D6PGvP6JN06nHoa3R8v3dKJsv
nziek8N6u+13kReN58VD9+Ct4LnfFOrxKDg41pRTN5W6AkUX2w2CnsnUFXZd
iYq+3QdkPxyp25mXgJ/iU4W6XHZ/CThZOrnxQzq7/0S750vEQ3PE0OI+Z+pJ
eGJzW5+WR+aS4JIviWwvoffFWwuPQU+BVeBKfa3dfBWWRgWnGD+y96ui74H1
dVBebagLPE/rwa3DUUlWV3UGWz81Yrl9v0PKaP2hxvj/gPYPp0bIfd9FvXvI
JjU+Lfm2P0TN9p8GFzhLgVsDGRqUmLXpY0m0XzkN+Nct2dZiskkD0Qn5K9kL
tp+T4VBV80vBeeEvVNYsqw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQNioVt3b8xWcoDwPtgvOdr/dY0IjM/g4HD22GPt
zYpQPocD42+ZxkNxML6Aw+bY5cWJLDC+iMObFS7SRYsVoHwJh6+Pog+H+sL4
Mg61f2c3aTyRh/IVHJ7pbZumIwfjKzmolWyYIlktB+WrOOwWkV5md0cWyldz
2Mzy/2b5PxkoX8MhbmOw9s4FML6Wg+29GYdXLZeG8nUcWGbtiJt8XQrK13NI
ObzNsIcXxjdwKPlguFfIURLKN3Qw+p8iuX+BBJRv5LAya66EzlZxKN/Ywe9c
wJHlGTC+iYND0rbrk8rFoHxTB7NPURre90WhfDOHpVOLBXc6wPjmDtZZRTMS
tohA+RYOUZ9um6n+FYbyLR2WWhmfWD5XCMq3cijeuL4zoEoQyrd2WKbsdcvk
kACUb+Pw+d+uyCZ2GN/WwTnkjxmrGx+Ub+fAW2RkfbmJF8q3d/Bb0+eauhXG
d3AQfCMi9kEMqr7BwSFKe6LHuQpuqLyjw0+dSTXLczih8o4O7y1//XPSY4PK
OzkwKWj94l79xx4i7wSV/wbhMzg7cDOvrXo1+SNU3hkq/8weAFAInqg=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2Ecx/HjLa/VMl3OS16KkBqzvDZN/Tmbbt43Z6ZmSWC+MHCoYF7C
CRJE5CXDMtHyjVp5wbwkGTkK04rKMCsilJSIBEvxliFasf/zYmdwGB++5/88
z9mZ59k8dbYpx3Gaf9f/b/YRpvQP9eR6waCF8ICZhrQQO2YOp6dSymv6PMlW
iMbIhFbDLAAXULS8wjE7wDYmo/hNswfZCVY/FZupkcyuUEnvR4tm3ckeaHJw
HT3nzewF66Kym6LKveT9+P62/NvSBzfyARQ73Z6wEzN7Y6N+MbRS60o+iEpz
Vcv4ExeyGKN9Yy+K3ZglkITJp9pznMmHccM+dLhrVkQ+ghXLudacHmZfTLmY
T9usOpH9kFktbpjKY/aHNPo9HnTvIQfgRGujb6odcyAqmsbPiLRCchAqfngO
zyiZj6K4xmFSacIshbsiXiq850gORtvQR+FLV+YQ6A/J5jvyHcjHkFAgKK0f
YQ7FSUW1YGaYOQxJPne8Cp2Yw9GrLVhKv7CbDLwa6L+bryXrgLrshbpTbfbU
I2D4f5B1ESjo6b6cVLKLugyt+2I++z8VUJfhim/2l8YsMheJtFudLY5i1iOx
xam2sgp3Uj+OgYUaH+fXO6jzzMkRqdkItIhiXY6Ejip5dv926lF4Nzi5/Om3
LfUotEc8G3kuYj0aNZVmg9OZNtR55hRYF18raztvTV2Bnq6865IMK+pKY+uU
EPeabwussqQeY2xdDP1eptRj6X1aUI/lzcdhbCS0qPARWz8OtbMFpbI11uPp
/bP5eNiadZbM1ZlQT0BcUPnDWYkZ9QRcqs0NLnVn84m88yXyepLxfkji3c/r
ep45lfHzQoXUdN+ufK+tcMO8yvi8ehUuNk88Fn6l83JqY0NtfL9ODb+r82sR
+nXDeno1fkn/bMokqwZzycYdybz9eV2fzJvX0H6LNK/hzfO6XkPn5ri/KUZQ
Jg==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0nlIk3Ecx/EHg645tzzWPOaxnFjZMGtqqfnxmM7p3MjKa5JlA1GhKWYQ
Cask/ENEnXR4/FEWXmFmSFtepBQeWNRqdCKo1cyoRWKatg76/f5wDzw8vHjz
PL/n+X0fv+MnD2ocGIaJ+3v+u9KDd7i3706hEP9lja5oa6mb4FEzmFUFnHUe
8iPeiIJGt50DBdRccOOC3pezqV1x+coF7ehdX2I+mp6Zzvw6Qu0FfqikfNzk
Q+yLEeXH7DIJtRAVC4o8W7U3sT/eBW8XxX8REAdAI1i62p1JHYhpDmeuu9SL
eAdE4pvafosncRB4lizGV0gtRsHPGY0tzYM4GFV+ESPL/e7Eu2HrEIRlu1OH
4MkJWUpeO594D5busdK9RrcS70WDcnkq9zePWIL1Vo65Np86FFPzrafSm9yI
w3BfG/QjzYE6HD23L3rz37oS70OzITJb30W9HzJ51eueTOoIZB4dlmVluBBH
4vGxjG/fX1FHYboxVPJG70x8AINq0QNvFnU0nmsWNwUatxADY2b/hRVHYh3g
yZ+x1NZxSY8Bu8h5vrKYWBeDpPauDlETh/RYpN6qlmp62aTH4sZYSxmr1In0
OBTF1gw4XSPWxaFw1DBoMrJIj8c2+SVzVttm0uNRU7HOMJVDzEjhY5ucCLfS
LsVTw4uFl0v0/gRMelg/1XNpT7DriWufp0u0W18GM7syfzmVvr8M7JKQCNN5
YiYJu6LEh4Y+0G5nRm7X5djy2ZVn5dHvT7bbn2Qsso3nViWOpKesXU+XYre/
Cji6DJ/WzhHrFFAkPHo4G0Xnk4rOSGF+4AjtqejzqG82fqVdCfWG6w2eUjpf
JQSdq2Z1GJ2/CrnFOSvjFmKooNdY9epW8r/oVIgV59aX5LrgD2wyD2Y=
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtMU1ccB/AL8lLEAdoLClJhDHXtmjEtD59fyqPlKS29tLhUwxLFCKaw
LZuKhuuyTWc6Rwmbi4RNMlOFLTolPBQ1V93EjEhWjTBngpIu2UxILEHLI+oe
2e/8ce9Nbm4++Z5zzzn3nt9Jfsdp2RHMcdzOf+//nuzihZ6B87Up+F/+zQ59
DV8TxczhaGB6ZeS5ZHIEvBPGmxaBORqrs1xdaTMryEvg/PFbTUQnczyE/Ngh
t405ER80f8+pZ9XkFbhwRNtUtp45BXmXvuYTxSRyKqb2hA/2TS4np6HfHXD4
splXocc55ZhoSyS/jlHhQbA1ilkLL98w1vtZAlmHukfuLWnXl5HfxES15+RP
euZ0DCdvzDEKS8lvoXDAGTcVxLwGu+/lh7bHMK+F+rvPP1pZGk/WI9QZuWbP
z3HkDLQnfXm1bRNzJq5eio3wt/LkLKQ2eO/Pqpiz4Yr7tSXQoCKvg2Yw/tmp
8SXk9TAVuX6/UMW8AQe/uXuZH19M3ojhavvk1H3mTRjq7el8t555M46Pu4LG
JmPJwJXBww9nmsgisPv9md4gG8tzEK1NTxj+O4byHAwsa22/+CSacgPeiFk1
ecJLFg1YuPj6h/WPX6E8F+cSfui7U0wWc1FnaL6yqGMR5XkIRF089Fy/kPI8
vFr01cjWMwsoz0fzx/P6HzrIYj5mtS0HTtfNp7wA3v57T3+biaS8QNHfiP1N
c9dqu8IoN8Lte6/RMB1OuQna7pCwjGNk0QR/t/fFQRV7fyHUL28PZfnZ+IXy
+XBFaBuJnPXo2fhF8vZcMbZq3KbhvSwvVsy/BE+y514adGx+JTg9MMr/khhK
eSn933mUK8yVKfqXwexK14R8EkL5FsX6FebK5f2hsFiOT9216xrV9H2kcsX4
ZpRkNvX5dGSY5eOLZnl7yQy1qTSb72Lrs8jXC4s8Fy3y90mK9lyFfH6oUKxX
YakC5886W3VvR1B/q3y/QGHRKt9fkhW51ucZoQVs/wry/Q0BCfG+v9wtrB4U
lgTsaPcEN56keuIqETh6Ns7xlIxKaJbzS2uqWT1Wwnf5hajJJEuV6Dh1S/XF
CKtPG8KEoG7/DTJs6Kv3VOlUVO+iDatTw/+YNpIlG06UHZrzLWDnhx3792n+
HHmNDDu2j/Zsu7uXLNrl549kx4Zn18Zc29j5VIXO+tveXcfIqMJxT8eZlCQe
/wC0Aqev
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlGlMVFcUx68jMqZTRJE+QbCMRBrZJgItShH5A8oiDMzKMMM2Y2K0pY1R
ccGk7YuNxKTU1Bo/tB/UuEQjaKKNKy7PxIX4wUJILR8ao4FAouIuFkOkNXOu
yT0vmUx++Z17zj3n3fvmr1rnWm0SQvz0/+/9v3w075nuUy3JCNOzwiO/Vu4f
MkkWqGuP3NzZNZ94Ovoel910eSXPRNrER9+fGLUSx+LCUPuOrR2S45DQFTPu
y5SciOHjma8W3koituKfs8MpqXGSk9G3aqBXa/uUeAEsNU9q7WPziD9Dynj9
wCVIXojWIntS+6ZE4jTsGzk89GIwgTgDu76Or5kTkmzD7EPGb6euzyVehPPd
pj83miVnoeXItrmbM+KJsxH96qR7NDuOOAf/nrP4EnvmEH+Or+6m2Cy7JX+B
gb3BQFevRpyLtl9i/6qYInkxlr6+dq+j6RPiJVjU+OPRy8diifPw5Nvrr3PG
ZhN/idQF5qE3ZZLzMZL6oi3LIXkp0udp8WtCMcQFaDAf/D1hxSziZYj6JubR
zvUziQvx8t1F/3azZGDW41jtmTYjzDpjUYQSz0TutFLpixC1ITu/f3sU+WLc
jdq5dryaWC9GZoHNc3VY+hJMCudksDWafAnzy1XWl+PGy2h3YP3H5Fegpef8
lf4LFvKMRSkC6bvL72yVvhQ9Nwq2tF6cTr4MSeX2PO34NPJlyPgjIjJ3l5l8
OaoW/3Bu0DaVfDme5r19V2yLJF+B8P0wka+AZeqJbQ/3TCG/Er5A9skNyZOF
Yb8SGzvzC08fFOQrYbKmvbV0TpCvpPxjYRZVzFex9XZW367WE9X4bl//Je2B
3H818zVsfzVqPeFQ88OBnJ9H3xQZ4xTvUOMNB+vfqTKcbJ5Ott5J/Q9TfRet
fx5muNT56C51/wbzwq3mg1vNp7vVeMOt9ic8qodHzad71HwGixdeVt9Lc6FH
Z2x42fpaVr+WzZ95g7Hwsfo+tp6x4WPnq469/zr1feqMDRYv/Or9gh/Ojqz0
iB0RtN6vnk/Dj6Pdf2u3EyleBFSPADvvAdY/Y1HP5lfP+mfeqGf3o4H136DO
R29g54950ah6MNYbWf1Gdv6a1PuBJnafGRtN6rxFM5tfszpfnbHRrL4fEVT7
twbZfQ6q/QSD7HvF4g8wbzB/n7EIqfO0htT5IPThfP8HhBdYoQ==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQNioVt3b8xWcoDwPthzzcpR5hKF8RkcrI6HZv9Z
qQjlczgoxsptPOoL4ws4KPPPesP+TQHKF3G4O8ngp9dcGF/CYbpyc+JzYxhf
xuGIvv3sX0fkoXwFh4mPPT8zqML4Sg7sBl52fKVyUL6KgxNzgAXDFVkoX81h
Ioeu9isDGF/DYW+It5qBswyUr+XA0tmftapDGsrXceg5/ZDvwQEpKF/PYeXR
u4m2ETC+gUNZO1MSxw5JKN/QQXDLbsmJWjC+kUNPKJfHpfUSUL6xg/zi3iZ1
XxjfxKFyY+APjSpxKN/UYe+bYD//xWJQvpnDv6LvqpxHRaF8cwdFlrsPPv8R
gfItHKI+3TZT/SsM5Vs6RMYf8oiKgPGtHLYXLIvUE4XxrR0g8SUE5ds4XEn9
xqmxUxDKt3WwD/8S4ycN49s5BORonf4qKQDl2zvwFhlZX27ihfIdHM5KfXg1
RYALwm9wAMZHcbXTd3aovKODvIevpdgqVqi8o4POZhY2sz6YvJNDVf2vg9mr
2KDyTg7hUUbripT+20PknR2Me99+dzzwE8JvcHYoXm1tv2kRA1S/C5q8i8N7
y1//nPS+QfW7QvnPoPKuUH0w4IYmj8ZncIfzATQYtB8=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtQlFUYB/CXS6iBAoobAgpsRYjr4kLI3f3vggiLwO6yFy7rZM1sVjTl
xJIZU7w1GlMW4BB8wHKSSBGFJh0uK4pvFmkJH4ppPzgUU6QNOdkyKa6Ml2z2
OR/eszM7O7/5P885e973nJP43KtmZ6AgCK6H3/9/2UdhHRz9qk4Jv7zaoOPv
95WHMwv49qq2o6A3kbwUE/kfqB0G5gj8PtYdVj+XQI7ClWW3ons7mKPh3NFq
eF7FHIfrPRNLnzkTT07Ax5+aFzeNryMr8UNsXrglifkJjFR2B50/sJachACp
4ddd03HkZEScvBGXpmJOQUzwrq6v+2PJKpTltpwe9MWQ1Zj/pXSocy/zJpRX
NWrmPWvIGkxs+aPIPBlNToM95Oa0LYM5HVnjTY2HzzxGfhoNmUnOQSdzBkav
noqbOaogb4bYoL2Zk8SciVvD+90LV1aTs/BFR32kG8zZMKZ+pnRFR5FzoPK2
DAy3riLnYq7zNV2/ljkPR3ourW71rCTnQ1PU5TZMMm/BSy7fUICdWYtC8Y17
muZIMrAxMnm+68cIv0Xg+vRT+1LfJQs6HEhzTh/ayXIdwlZd2LN7LpxyPTbm
qy3nry2nXI+6SyNjU+5QygvQti9oZGbHo5QX4L2DdTmN8UsoL8TB2fpG/W2y
WAjV6eCQzS0s3yq3yFkowj/Zi/f16hDKi7A9s2l4Vh1E+Tb493cg5dtg+lCz
IXh/MOXFeOvw1FnFb1QvFnN5idxiCTe+gZvfgNCg/jf/ag+gvJTr5yxs53LO
QhmXl3HjlyMwIWUx9MRdrT8vR/2JXO2pboHyCvn/FSu4529EfHFZtqLvEb9h
5OqN8vEko3w+wUTrX/AbJnm9aJI/f8nErc8sf/8w43FDp6eml+0XM9I/+vu2
TlpG/ZyFSsTfn7yc5aV6cBYrce5izo3k2TDqr8TCcvc7dzPIggU933/+eqhr
BfVbUHJ8oO/JT2h/ixY0jBrzsnyUS1y9YJXXw4ovY08O/1TK+q1cvxUPBNOD
nS52fmzYu/7iHWcFnS/Y8LK+7dyKI1Qv2rh+m/y8CXZ5PewY8ralxkyyfjt6
dd+Mf7eG6iU7DnlC7xzNYOezSn5eUSWvF6vk80lcLlTL14tq+XrEalxLVaa/
sp7uG6karheOjVUo2H1Ug92efy88m0hGDWbP3hM3ZJLFGrQ7ve2OY2SJqxdq
H77f5hlfE+uvpf1L96NYi3Xu+qHmy2SplrtPHXT+yXBg0VfQvUdF96/owMr+
n1/0vk2WHBhYO6VM+TMK/wEQLNYb
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n9IE2Ecx/HTldlOzOac2pw/RoVZLNP8MW3bx6nb/JGBIauwDGEgSCRm
yQTRov6ppHCWiFjGpIhVYGKGrZJKbJlCVEJQhihGhTmJpjPTin2fP7yD43jx
vud5vgcXV3682OLPcZz23/3/yS5ZSe+j7kolfHLrWg52OErWMXNoHj3RtWCP
IwficvPDV2Um5hC0hJulZ+djyVL0vwtW1bcxR+BA6AfzqJY5CvM95xJtzhhy
LFzI/f38ZzRZif2e4p06NfNm/Hrt6rZeVZC3QqRUNKhlzPF4+v5kZmJ1FDkB
nSuX2s7fkJN3IGZ5ZDjdvYmswmnrTG2cnDkRnWsHiofqIsm7MC5f81nsiSAn
IVJeWdF6jDkZqrb7s4eXwsm70RF95Um7ljkFfQNi4/XvMnIqylI1AZ9Gwshp
SLW9qMiTMKejzrr9y9gWKVkNCR/unHaGkjMw/KD3dnUVcyZaJy76jc9JyHtg
s7htpbeYNRDbF44YBjeStTgzVd40dYdZB4Vjaaw0jRm4kGT52H40xOdGwLpt
yGvZR+ayEBT6rLbq6wbqWehy2U/xNcHU9Xg8lPEjfjKIuh7tY7z3ZgpPPRvJ
TTPzWQPrqWfD3fPmT30YmcvBy0FNbU1/IPUczKoXl/WqAOq58P2f/tRzwYvu
1n2z+VE3wHwo6V61ckXn6wbUX3vrlE2IqBsF3UjzeH3mTIJuWn0el4fCtIa+
SRXt15i3+n0uH/6xCYu8Y4nW5wv2L6B556gX0Pd5qBcKeqFg/V5BF5grov2m
qRfR3Bz3F1BcAlg=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU2EYx/E1olV20Wbzui0v2TRb6Sorrf2mm5vT5pYZWW6mtC5YmZnY
IuKQ0lAs0bBQIiLKCikyqdAkL0hlQdEqhchFS2yRf6hNszSo6H3+sAOHw4fv
e86B931C8gq2WPk8Hk/75/77pEuUee9hU34o/mlYWVtYqnstJPPgtkxVtbWE
MM+GTr7tTu92sjd+XFMrT/9YwuwLL/1O24tLZH/sWeE6uUlLDobF1O/83iFl
XoLBClVx5nxyKLIy3OabOglzODwnDO2eu2LmCOw883KYPxrMLENB6SmuS0iO
gqawdshpC2KORgkvR+n8Fsgsx8jr+A5XHXkVmgWOxz9nk2OgHxY1lVkDmGPx
RHVnrqvLn1kBc1V0nbOAvBqWqDFPvpS8BrYm04TsuB/zWuTLJz84ekTMcWj4
dUMacZG8DtXi/UP1nxYzr8db2YHchgfkDeibZe8Tj/oyx2O7rsrb1U5OgH9O
m+NsMnkjJC1F9+3Phcyb0Hy46NuOY2QlNBsHTrz8uYgZ+HL+iOqWknUOyOgt
r3SIab0KMa1By1zFbD2nwpAwyzpeTu8noq79eklmNPVEPMpe2inxop4Eh7Jm
pl+/D+tJSIhNsy/YxcxTQ80d+xVjp65GQ5j+3eoub9Y16OkN90zOo65BkP8n
d3UN9WSs8JGN1L9i5pJR1BivvHuFuhZf3y8rW3mKuhbZgiv1QRr6vw7ixqne
7Dj6vg6DK0MVhyKppyDSEOarOUg9BW+s43NkLdT12FVonnzmpq7HeMVtP7OH
eup/+5eKiauCkwMq2p80LBeLAvbmUk/DhY+VM5wj1Dejx6ZO2B1B57MZnyNH
bTFGOh/D9PPlDMh7Gtqq4KinT58HLh0Cycyt3Q7qRiR2ZkiWS9n8wIi9tfyj
8xXMnBFrz3XvS1nE5rHDiISxTmelhebTNH1eYcLlhfzAKQ2bb86Eaq2f/Hif
CL8B7ncZcA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0n8s1HEcx/FvycghdO7Oj8JVuouSk3Pkx+uc4zh3jiZRt3TRaqUffmS0
tmNs/WBJ0Q9bMTLrh8ZYKvcPScIfFlIjayQra9dITKyaz+cPvtt33z32/H62
7+fz/rrpzsSlrmUYRvbv/v+kFye++WXDST6WZQxpaxR4f7CkZnCxU1JT3uxG
bA5xUtVA9j5qG9T2jz6Y++ZKzIbK0N2Udo+ah8qsYe0JJbUzJL2uwbJFF2JX
GHOvLKiPUvMhTzHdGde+mXgrJLw7WqkjtTsE72/XmhRvIhaAfcgh++C8M/EO
1Ml09sUR1J5QpOsMfc1OxLvgostbKAui3g1f0SOG1eRI7I0e8VeL+BEHYhF+
2f1OeeVO7YOe4PHwuF4e8R5kfqx+YzvEJfbF/toKUYIltRjPurmmf5I5xH5w
Uaj8OQ/tiSUwxr67Viam9od4amLksRl1ANQZNhfKO9jEexFb5O2xrpA6ENXj
hTrZMeog2LG4rROtG4mD0ZUTFpjiTh2C5XnbEQPJ57QLbydtl60H5pRfzPOi
aZdi9ko9VztDuxRnB6fbjrjRHor+1Nn1gue0h0Ko3sKWpxEzMnwf3l7glW9D
ugxZwps3ShuJmTBML71IzDejPQwJSaL6dP4G0uWo6ao+z8q0Jl2OU6ElBusq
YiYctlNsjpFDezhclnq7JUYL0iNWWh+BvpaBmaE5FukKlBSYtIxqaVesWh+5
8n19JAatLh2fV1uRHoU6aXvHawdifRQMnQE/BGOWpCtXfq9eCSfe2OT1Urr/
aOQIO+dTY+j+o5F490mVvSftKlwVpQ5XJNOuWrVejQkvvs9pIT1/NTIanl7W
5NLzj8FY66Lew4/MSx+DW5+L1nz6SeenQeLhNkXSAfJ/QIOybYuJzH1ivQYa
r0p+Jo+Nv1IVCls=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxV0XlI02Ecx/HfDMmcpU5b5rTptkzFzdS5zTz2cZu7omBiBKVWdmBZFBUF
EjZk4D9FkUInCFOSHRoFGbHssMAj/EPBSQeJJNIBumGl2bCDfZ/ABx4eXrx5
vv980+tOVh6O4Diu8O/997Ij3PXQd79BgrAC2tHBFqchipnD84VD41PudHIU
+htUctiY44A+RWXtfBo5ER1ZvgXVDeYkPE2osU7rmFMw9uLU5+g5MTkN/o8N
Gm8WswRSx+03jXs3kWWov9m2Or8zlZwB18Gdbft5zJkQ20zySVUKORvVRwZr
PtWKyDmQzUYv5j1OJivgKDsgj3VtJG9F78S8UjCQRM7DO+kx50AGcz6imq6I
hvdtIBcgxqW2PWkXkpUQm3cUCd3ryYXo8k0Ih1OYVRB0jx8NNCWS1Zg98ep7
wY8Esgay87xW1RxzEa5PXeJ9CArI29A30DK5eJG5GOF9MZegebru8rQ3nlwK
eXxm8NZoHLkMX99vceQ2M2txV2p9q+xnBlI9IX+1mv7bgSG/7NuvGDavHBZX
j3vznVjq5egc6jjHP7uOug73RN5HY9tZ10FfFVJFGlnXozdwNTd5hGzXQ16q
qHo2s5a6YeU8uwGeEkl95kuax1WsnGevgHh55LUmEE3diJ851y50HV9D3Uj7
iKRuwu49+T2nJb+14W7CGU+x9oGTo25GRFr2Et8Tom4Gf1V345fWYNicZaXt
FswVLS3rFDPUrf/9BxeW0sU=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIk1EYB/AXzW7ec05zarbsopk2zZxp7r95TU13UWrpygKj6EoqmkK8
RSJZkpgpdKEZYYaXSMlKidYo+6Qxa+qHpLKI7GKWZYtMKzzPh+2Fl5cf//Oc
w3vOc5buOqTOt+M4TvPv/f+lR5h9u/vWPjFmNS4zGgZ+ODqROUyIsnOqm5Yy
z8czT53kSwbZDZ1DRofGsQBmARYEtut/1JO94aH+1RIeR/aFqFz6YMvjJcwB
WDsSeb3VnSzG2eKaG5kKf+ZAZIcKnpTo/ZhXIPhGOVf125d5FaaL9/RIleRg
xLRph9acFzGHoG+4QzN8yoc5FP4FCeLnXxczr8X23Q3H5/JkCZITC/faT3kz
hyO2a6DcVEmOgDnndfTotBfzOmz4+Ia/WUeOhDGtKdiUS16PMd3DOzt7hMxR
qG9saBL7k6UwtTydCDzgyRyNwbkVg37fBMwboDojWT2nnByDy7y51LXNgzkW
2h3GlG1byRsxWndE3iojxyGt42uqKoosg6RLtHKkaBEzMHv+zDwwWdnmpfvu
znI58i832pXpmXkbcwosem8wNqspV6CgOUbWftWN5fF4FyaOOBhEeTws1+Yd
eyun9RNs5k/A6fD8FxfzqD4RM5xqJq/QleWJmJju0p6YR3mStfkkm/pkOHkY
iw+PUn2y9XxcCm6KWu70p1GeAu2F1gbPEKrfBPdPAuG40IXlm2zqU7FfUX3f
pYHyVMRnTa13SGLm0jDpfO/4VKQTy23MpSOi6vNPuWEBy9PR6zP+odZtIcs3
o/qk/d2XOmZ+M0x3zd+HLI4sz7CZPwOd49VhPr20fqbN/mVa/y+nRFG3MlZq
YePxz0G152raaT+V1udpUCI2PL3CJY/OX2V9/lBZj+dtbFAhuq9b3/OK9leN
oIxlgsQDVK+GW4hE1DdD/aC27g+DGn7NUwO5UbS+Bv2ymjlew1SvgSTpwr3U
XupnDW5987lSuof1v0GD88v/aLkrdB+yoAzTiwu92f1CFsrMR525PGY+CxWl
j0oslwT4C1RATsI=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1I02EUx/E/Np1MDMs57e/aGyZNzZzTlTPbz81Ni6wMJXIFIxpli4R5
U0toF02wwhl4YckIQzeZsVpuvbCLCEJECLQLuyhbBAVRpBkJLpkVOw/BDjwc
PnxvnoujPN19zJ7BcZzu7/u32Ug6orGwQ4WUlg0+Z0nIJmLmMKyOWEujSnI2
jJfnykbamPNwxGb7OJ7FLIZBx49dCCjIRXjbkdQcMjNLMa+/dLImLicrsENw
e6O8mFkF1fN3T9Yuysgl8Hu0si/T28ml6OzrbfbnMu/EHYm6yzMqJZdh0DvX
Kv5VTK7Aj/lZfmIXcyWS1utn1Q95chWEizfCU9+3kTX4rdWGCruYq9E7HXov
WikiayGUnvnU4GWuwdeIL14VLCTXwnU18cIRlJB1kLe01kmCBeQ9UAoWP/xc
F5P3ov68c9gWYa6DUCZof/k6n6xHeIW/6zrHXI/RsZkC78JW8j58yz9hX+1n
bsC4XjsT8DHvR0/4Qf9R1xayATF+yPdsKY8MPF4e3M2/2pyyGzC1r+syLWSu
EYfvD5jt0VzqjRhZyFnz1+ZQN2Lw2qan8VMi6kZUTAmydANC6ib03XLor8jJ
bhMCsTeSWWkm9SaEQ91DldZs6k1ou6kpF3gE1M3omaw3PLrHUU8zZ0HqfjOo
W3C8szrkVG0YUr0ZGYqyRM7kesruNHMtWKpLJI2Vq9TTzB0gf6aeZu4g/YPG
/d9/AA2nztQ=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQNioVt3b8xWcoDwPti3xn5teiUG4zM4lB1QCjHb
oQjlcziEuP5NVkiF8QUcVOOEnlSzwPgiDjodH1O8VihA+RIOetKb+RqCYXwZ
h5R7r7ZNfCoP5Ss42PjmOX3UgvGVHAKUZYMlquSgfBWHmQddp254Kwvlqzk4
y0wNa3SF8TUcGKd83iebIQPlaznMLveYf2mPNJSv47Ce9aznC1YYX8/h4OZF
R5i1pKB8A4drDbO+be2QhPINHUTO3jn576UElG/kYCemuubXERjf2KGxeIv+
GS8Y38RB+LCirvh8cSjf1GGW/8/7Cf/FoHwzB4ekbdcnlcP45g5ddXHia76I
QvkWDituH5469xqMb+nQdna6ZIQOjG/l4PHq+j6+bhEo3xqNb+Mwy6/x12Mu
GN/WITuCPTB5ujCUb+egqcL+5Ls7jG/v8EY4MvVbpxCU7+BgY+TTzpcgCOE3
ODhISzx+MXGSAFTe0UHRMb2z9B+U3+DoUKo5ZfKkTTB5J4eAHK3TXyVh8k4O
S04uLuMu4YPKOzvsPW71TuMxD1Te2UHZa9q1qBVcUHkXh43r8qfoRXNA5V0c
qup/HcxexQaVd3UI7DHUZmllgcq7OnAzr616NZkRKu+Gym9wc2BS0PrFvfqP
PUTeHZXf4A5V/xEq74Em7+Hw3vLXPye9b1B5T6g9DAwALMPDuQ==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1X9MlHUcB/BHzoA8EUrAH4jHL1u580rx+GVyb4gT5Jdwx8H95B5rzdq1
gVKzSPK5ampLKIH1B25mbJGDeRvdnKDOPepgVuICx4W1MrOZo7U7h0kHiNXu
8/3j+T7b7fba+/k+d9/n+/l+vukvN5lejRIE4fB/n/+/2ZVsOXN+0JOBiEIG
y/Mqb7uaWYDjxIEKoTedHAtV0NOTVcicAJU30bBnKo2ciL8zp6/pOplXIy+l
dcXKAuZ1WC9t0twe1JDT4G07FBj7fj05AzdT/7Q2zaeSs5DucxZ2FTA/gz8u
DH/+imUd+Vl8OxB/7eJoCnkjNjX1vTemY9bii6A7/t6xtWQdNCOHJn+4u4b8
Akpyg3q7jnkzjLGqhQeDq8lb8Hpgg059bBU5Gx7d/K2Jb5LJW5G1d/xmOIlZ
j/kVewyXjEnkHPxi7Th8dDaRnIt3J9+JE0TmPIR3tzzynllJzoc21OE7+wlz
AZwfZNun7j1N3sb5Rfx2PEf/UxfzdiRoN6dcf/wUuRDOmN6eFCOzgTPQl1n+
49bLCRFLQIN9i29fRjzlRRiZiTfb9y6nvAjHA+pwn15NeTEexg17F/Qs5yy8
hMzyzwL2U8so5yyUYGxtaLo7geUlyG7/a7ZIfpJyIz79UDV0y8VyI66ObN//
5rlYyndA618andMRQ/kOtB6cu+Tpj6a8FJqyqvzk/icoL4Vadbp1umsJ5WWI
Sts4px5YMETyMgTz5xaLdQ8jFnYqLe2k/xemvJwbz1mooN+7T3kFPe8u5ZVK
S5XK+4UqLq/i8mou5yzsonnSJe3i8hrl88BZqlHeL9dw869Vzhe13PuqVd4v
c7lgUuYwoWVgm+HrXoHWy4TK3INn7+hUEcsmbn3NCPnHH7UlUb3AjEFfU7fO
QfUhcZY5C3VKow6axbHv8kKs3uqU9SfX4VTRlZHRNXE03qKsd3CWLMr9InMW
6pVGPcaHJh9M/UOW6hHWdh746g2an1zP7Z8GpdHA7YcGbv6cBSv3/qy0PvR+
JSsi50MUjbcq10ewUb94TOtn4+rHxtWPjcaxy640OEt2brydq38HV78Orv4c
yvqUHdz+dyoNJ9pO3LiQfJvqTXIq+43s5PqTi1s/F1c/LniuDl28MczW34VA
3JHXwtWsfhoxs3jO9n4M9V80Iv/6+ZOjv7J+3Kjs13IjJgydS1f9zPq3G82B
mcu706n/w41oyxJ/6ApZcqPCf7+8NpfOE9kNf3PLjP1tdr6I6Kn2zt1ZRudR
mghfadC0fznlEPFx+5cbTqvIoghz4KOjE6lkScRzWTG/z5aST4oo1ond+0T2
eyI6mt/qd5gT8S81RUKn
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQNioVt3b8xWcoDwPthfLPI8eEEQxmdwyNih6X9s
oyKUz+GgeVr00vsgGF/A4fwFXq83zxWgfBGH4tXW9psWwfgSDtdesN1p9oPx
ZRxirnMYv2aC8RUcdNR+S7v7yUP5Sg6HvE6ulNwvB+WrOIjcfiQ4UwLGV3PI
3v+Dx7lBFsrXcGjm8bsd9VoGytdyuMjw3/lvDYyv4zDjhFuA1ANpKF/PQb1B
KTPMBcY3cLifWV1jUSEF5Rs67N/o3cN1ShLKN3IwtFms8MsXxjd2kF/c26Tu
KwHlmzj8PSLfveWWOJRv6vC5zTXC1QjGN3PY/XSTzP1lYlC+ucOiRp5NSwJh
fAsHeQ9fS7FVolC+pcPy3dfFTsnA+FYOTcfDY3/5iED51g6/fjgvKteB8W0c
NFXYn3x3F4bybR2WWhmfWD5XCMq3cxB6ceDQ6iBBKN/ewdft2NEntgJQvoPD
f4bA/wkl/BB+g4PDNd6OjJ9+vFB5R4fZ17h/LjPlhso7Omxclz9FL5oDKu+E
ym9wcpj4uLja6Ts7VN7ZoXbe5T1iD5mh8s4OPub12x/rQfkMLmjyLg5MClq/
uFf/sYfIuzq8t/z1z0nvG4Tf4OrAzby26tXkj1B5N6j8M6g8Gp/BHc4HACWV
voo=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQNioVt3b8xWcoDwPtgvrv8pPIsHxmdwuDYh0TFi
iyKUz+Hw8Vz8DeNgGF/AQVFsgcSTHwpQvoiDIOv/CY2zYHwJh6eLLyULe8H4
Mg4p915tm/hUHspXcBDbaDZnkiiMr+Sg3DL7ZlW0HJSv4sC/fvGKh2dkoXw1
B5YZ7UbuLDC+hkP/XK6drukyUL6Ww4eOjEcHj0pD+ToOJyxKuwUuSEH5eg7z
FphGJhjC+AYOPy/ns7uUS0L5hg6KEol/z96VgPKNHN4bWPlu+iIO5Rs7HOs5
VF62XwzKN3GYV7riloESjG/qoPBYdOriSFEo38zBw6vn1qZIESjf3GFzQfHn
qAphKN/CoXczp/a++0JQvqWD5bndC449EIDyrRxKNadMnrQJxrd20BXU+Djr
Ioxv4+Ac8seM1Y0Pyrd1kP939rTFBy4o385B2WvatagVML69Q1X9r4PZq9ig
fAeH95a//jnpQfkNaHwGR4fAHkNtllYWqLyjg495/fbHesxQeScHSPphgso7
OYRHGa0rUvpvD5F3dmBS0PrFvfoPhN/g7GDc+/a744GfUHkXqH3foPIuqOoZ
XFHVN7g6cDOvrXo1+SNU3g3qDgYGAFREsxg=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1Ecx/EHFzYvw2XTtGnOeVu6lmbqlref8zZnzbkyXCqBJgi+MKGQ
ejVrUZCrIHuRQooQKbLAJHBaOjBBMXuTSIQgpRgVoREqG2IX9j/BzoHDw4fv
/+GcFye+sc3SHCAIQtnf/e/LVmTNy4mRViV82iycdq9JpVHMAi6JcxXXJuLJ
YqQ4ApMarMxSzMuC5b1bCrIM3g5RU1UfcxQuJrQuV+iZY2AxPdLKJ+LICkyp
ar9+imZWYtaZJvGYjpAT4endGUoYiiUnQ1Yf3VHniSGr8OWVq6+phjkVxeaB
BGuPnKzGkw31kGzrMFmDroj0xMsa5nT0P9Yl366PJmfgbcFamWUhinwCq8uW
9s5A5kxYldr+D+cPkU9icjxcvNkdSc7C3KL91tW5CHI2Gk1HB/dCmXNQa7gv
/TwlI2thMHZ9fGFl1iG94eaz14PMp9Bj6vSuBjPn4q7jaZJTdJCcB8doUNrk
Sjg5H2/M7l7bOHMBpOoM+bvfB8iFiB3eXarPYQYWm7eDVC6yDfi+nGI/fkNK
vQjDecoW1XQYdc6CHsfyNeem1iXU9ViS3GnxmMhCMVpnxybfu0KoFyNub2Fe
uxlMvQQzv8LOXmgPpV6CbYmrczeLLJTigV00ttJA87ZSZDp+7BS5g6iXYXYm
v+PKuJg6Z6EcI8/bujV1rJdDPbovMPvefuoG+N5/AHUDAhSp3pDh3UJfr6Dz
PD7bKhAicl7/9vAndaP/vM2IDZ13T6/Zpl7J/V9JfZ36aboHLRtn4QzXOQsm
rnMWqrhexZ1v9jfM3DzX3ZyFav95VP/vfwCdhgGh
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtIU2EYBvBl6sxLatrSaXnromapLZez1MepU+dlR7cVmVEEgpWWZWFp
xEmiGxQ6o+gimohWVmZ3tUwsyy4WaFl0IaJSLK1RZDnELvh+f+wMDuPH8757
z/nO981nzcaMbAuRSLTs3/X/m30k+qstjet9MS5j9JXXI3dDJMwiKPKvFdTc
8SHboCfXa+fqTcxOaEg58EnszOyKzqrFUYZqb7Ibhqrl7keVzJ54KV3qo+rz
InvjfdT2dTI9sy/e7K1tmlE5gzwTla9lEueB6eTZsOU0j1e5MPtDpnlgHVLo
SQ6EqTl8xZ9iD3IQKp/aTy7vlpLnIyZvVsRaPXMIqo4pZu/NcieH4qbiGzaX
uZEXYFfBleDHamYZ8mrWiPdsmEZeiG8K05hyvoQchk9WR4avH51KlkM+2Pf2
nJh5EUruL1tpSnElh6OCf17keMGFrEDjd2llUQ5zBFYk3LY1XZxCXozsilqL
4ipn8hJMrx/tzVrEHImtAYfLDZecyFG4ZiwNlnZNJkfDedBVYpQwA8MOTbtG
w+zHzQN+6iO9madtKY8xNx+DE712I7VhdpQrUfahoFj5S0y5EnUtLyQPPa0o
j0XQZUtr+SGWx2IkyLCjLncS5XGQHRz6FdNG5uOwvvNGa08T+/14wfx4Qa6C
11jXo3Ajy1Xo7Igs3NJsQ3mCeT2fgF6HfTkjaQ6UJ8LCO9BkV8+eP1GQJ+HW
/Yiv/h9YnoTMuWWJT7ax+Wp0SY2fDzux+Wp0/HDUZm6ielGy+XrxySjdPfHG
u5VsfVME9yewKNV8vfhUwfqnCdYnTXB/GvPn4TWI1Y3KrVTs/XNIOnPh7KyT
juMGh1TVvY6PkbR/eA5bW7gl4b+pvo2DvUt7Yf4A1YvS8WOseXmJmOqRjlo/
9auF7aw/HcuPnz81NYjclg4uN/DRT3e2PzOQJa4+7hFP+xcZ5vuZF+RtGYL9
rxX0a1HQ2LCfK2L9Wnx5M2d3cAmbr0VfsK9sQwDr12FLTl2rRkLnCzp0Rxss
p71l/To8yx6e5N/E5usw/n/JzqMe1voJl413WL8e/QHft4dydH55Peb1e/C2
lq74CzsUXYU=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU3EYx/HTNM3UZt7SplNXim1iOVObWvtt3ubdKSVZgRj2Qo1CI8wS
j2lE1Ex70UBI0MrEiWHeqWQmaVZYaRcCQUohjKwhoU28VOw5L3YOjMOH7/O/
jLGAgjPZhQKGYZL+ff6/ucfzcO/jrmIJLDIpDY36onEnzgwmGjebNAMB5C3I
CgyoScnh7AJn123P2A1/sjsCO8ble1s5e6FLlH8zQ8vZB/rP6vKri35kf2T3
1yl6gjhL8FZq195TICbvRu/1r/N9zb7kIBzTvTEJFn3IwUj/Y5bnlHCW4qVB
+HpoVEQOQazxfv4pIedQfBevKc8W7STvw6tJxcbgSW9yGDbVT67PV3uR5ci1
+z19JIJzOEq9T39aqNpB3o8mJ32f+3tPcgT0rc1tEjHnSNTUjkzrjR7kKHT6
Tkmk39zJB6AezhHL/DgrcIf9UCHsdCNHQ9ftIBuacSXH4Ifb0cKla5xjcXmu
QDfXsZ18EMftWxpFCZwP4cKeMXNhpgtZiYeijv7JVCEZuDd+97zjuW0Ws0Dx
i4GhqUFH6ipeV0HgL11xNDhRVyNP1qCZKKd5Vo2nY9E/g2e5Hoc21cjzUW9n
6nG8/eOx5DxYvRpB82w86mttBmZObKWeAFP3u7VKDwfqCQjptrWLrLOnnoiK
qpXh4nY76on4pVhZV4eSmSReT0LDbNlF9TK3XoNdKbc/5rXReawG5pBblx6U
0HlMsvV92GTe+SnW+7E8M6nQ3giT2V6xpZ7Ku1+atdk0pEVV9c+G2lBPh+X/
KaCejjJDjPJRC0M9A5VNU088v9A8m8Fbn2k9z2YiN0/eWSrZUFp6Fv2eqxYj
C+G6hWWV0Wwxy7ORN89oeeu19H2WaL2W7sEwfwFt3iIC
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd031IU1EYBvCbWRa6PlytVZbToiTH0JmZmvpszrVq1pzza0JgIpRK2iwq
rVyFkVSCKZGQBhWVmsayqKHB7eOviD6I6p+ITMOsRlZgJmIf7D3EOYMxfjz3
3T3nuedGbKuwlwRIkrTz7/ffL/uocm71esoi4ddIWlXMfseFmcwS2qyHkhQ3
I8gz4Nuqfh5iZ54DS3TYiSCfhjwPY0WON+UNzGoMPtr3vms1cxieFIasTD4a
TtZg/quR+Pb3S8mROOuqvHomlXk5trc0B+kvLSGvwC77nrrBIOYoDPV5zxfn
hJFXQe55/LmidTFZC9Pbmknly0VkHco8+yqLfywkx+B7q858R8EciybNh482
g5qsR3tpq1p7awE5DtW7l1V0GphXw/lUsaOlX0WOx9fE8UmjjnkNXkaVF12+
PZ+cANO5d6Heeua12O29r3mwkTkRcrTRd801j5yEiYuBEUPPmJPhGWsYVoN5
HbYeNw+nPFSSU/BFWVAyWh9KToX57nApns8lp6HKc73eVs0MhCjv760cnu23
G9jTa1u3dmwW5QYoXPrkF0cUlBswqvAenogPodzI223EL+3pA1fKZ1KejsaB
qhrjzyDK06mf6ZSbeLtNqK4dv1fWwfIMaHsCp69pYPMZCLdkJqo6plFuRtbJ
2OjAukDKBUvrETy1q/pT0xTKBUsWWBNqbw/oplJuofWMpvnzDcL8BvjflwCa
34iDbS/6VP1sXrC0SdjfJni6K5p1hTMot/L7dVv5/UqZiDvl+2mQqU93Jt+n
tFlY/2ahvy041liWVBPO+tuCK72vVY/CWH82fn+woaozOe3GBYmutyHPqe92
Rf729yHbaD2/qJ8svi8IdmfR/3+jeSGX7AjQrBoP7pygebuwHzv/vGXBUjbf
F7KF55HN9yFnC+fPwedwCPOCZYfQXw6/XuTw63MLlgVLucL9c4XznMs/DzlX
OF95/HlEntBfHv98ZeF6KZ+/H/KF9ecL/QmWCvg+UCC8L4LlAn4/kpM/X3AK
58cpnB8nzbFPIW/89x+nFrmj
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIk1Ecx/EHFWx7rNSZzvsc3TRbOTVnqfttrnmbRkGGkhrlXmV4KbOy
SIlQQyMv1UqLYFGQKSVZlAZamURE4kDtRXbRirlKpZpMyi7sf170HDgcPnw5
/M+bE7a7eJvRheO4pL/738mW7/buntt75XBqRp3gZzIFeDJzeFyz8/zwgzDy
Iqxq7ZfUFDJ7wqQY6rvlxuyD0lqNzdomI0vxwTy8R5LOHASzqP+j9U0oWYbJ
wtfFuihmOS6Kb4wEVoeQl2NcxCvX3gkmr0RNXXv2w19B5NWQls+WtJxgjoC6
WuxvehlIjsRUoOqVOYRZgTZbQ35DfQB5PRrfjif7v/cnR8FhKXbXVTArcXf0
W4z3oJQcDb5Ppl5XyRwDxYWu6byffuRY5MhVV8aymTdg7Oyu3JtDvuQ4eJ3J
4jRKZhUWyuZWiAaWkePRGWyRR3zyIW9EwWh3vuUQ8yZIC3qHT+uZE/B135Mf
0XYJORHWc2WaDjVzEj5Lcoz2Om+yGvZTnX55373IQE9Ay6X7055OVwGLi7xt
taVkToPy8Jbmpi7WNTgcPugwbmFd+7+rtMjUPx2YTGQ9GR6SRxUl1qXUk3H1
mfkgf2AJdR1cZBHzfLsHdR1CF148V82IqW9G6wjvuBbLUxeY0yO64cucpk9E
XQ9HZNPR60VkLgWNE/srtXPu1FNw7LKl1/edK/VUbK2PWuN20o16Kgxxx+9N
KFhPg/N/uFBPw45cZWeZ/Lfa2dNpvsPpKoG5DEHPAO/acWSqeZa6AdPx8wta
hZ26QXA/U9AzBfOzBD2L3s1xfwA9DgDF
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtIU2EYB/DjttS8T+cyZ80bw0yHl/KSbnucl3nXnWOUSiDWNFBQMz94
w3WjojJL6UOppYKKK8vEkjRchgVGyAj1SxhRhlSaIngrXcWe98M5Bw6HH//n
fc/7nvOc41NYRut4FEVp/53/r+QQHx0aGSjxBYuWVYaR7o8dTsQUSJRTNydG
fdC2kNXuaBaeJHaBJ54F6ko+sQjypOHFP3q80R5w0UE5dp8m9gJt18aM35gU
7Q1VI9mxURv70b5wb/bCnF8gsT8MM538sWv70DJQ0KfGi+a90AHw9vEzU3Eg
cSCUJyVUXy6SoIMgYa52x23aEy2HtJi6FFEhcQi0dnken3yzFx0Ki1MrpYoQ
4jCYkwg+2a15oMPhVie/aUlJfAhkdbOm15o96MPQvd0rlbWK0RFQ3SSaTrEi
jgSDcMlDNuiOjgKmtUVSE0ocDW3DsfnN/SL0EWgsr+rLZ4hj4IC/zdd1jRs6
FjbS5m3PpbuiFaBr6+bVPhCileC6YBw30MQqWN15kXvexgUNkPmwMVE35Gix
HmDG8crpzUw0Fce2Po5dT6lhYtWZyatwwFwNfql3ZvJ67TCPh4H+shZ5vi3m
8bA8aNqud9+NeQIEDQqsIxptMOeYSoRf0Vs7ark15omQHtnw/Iucj3kS1Ld/
GBV/RuuT4FheWP8ZX7PKkmvY9XoN1DRsvSrpw/moZM79k6FnZFY86bUL8xTO
/VPY+6FS2fX6VHY9lQba66EHBZcEmKex10ulc9bHMZXB3o8+A3jegVv2hj+4
v0wIv7G4HmfcxDyTs/8ssOc/qvnebIXzZ7HXQ2WzDdlg+R/wsJ5jI8eUFioN
MaqnnRSO13LGa0GanBEt7sPnY9TCZtDtup5S8v5ptoEG6c77d1HL2D96mt1/
RhqCFfKcsW+k/xgoVTe9dOpwwvEMmCmtueCsM45nIFgYsHLXhP1uZKCg4sTv
yQXyPeTAT7dc3dpVV/gLJMQ/uw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1EYB/C3MNREU9M5nXnN8F7e7+4/r7s5t8pCUyvJGBkkzmr1pRWF
XRSahclMMC3LTMVEwznUnJdIkjKSFKQPXqgwL2g5P5gVnhO4F15efvzPc96H
cx73vHMH87czDMP/+/770oeV0d7VWuCBTS1y29d8C47soGagr+hm9A3uxGY4
lnM8XiGktoZ8fH5udtmN2A7Xx2a4rY+p2dCp81ZXJNTOsP4Y8H1pzpXYDaF9
42UxYmoPzJ96wHK+4kK8FxmBdkPKmj3E+2CYbj9U9cmZ2Buemm2V5e85xL4w
0RV+jrCi9sfcyfqa/jAn4kCwJrna4gpH4gPQRS2gSM0mDkKpdmEi944DcTAG
S/suXuhhEYcgOX+qrbSSOhQ9rlXsanPqMGje2mprmu2JwxF+r18usKWOQN30
jbzE03bEkZg+4xO9XrKbOApthYrlLCV1NFw6FR0lw9Qx+FZRxGviUsfCIJox
uyq2JY6DtX8QZ2TDhjgev243O+SsUHORpFKuB5VQAwE23kuaD9abVgGKxhju
y1pihofl39rMa6Y05+F8lzQ20mBF8gQczQpuLvLYRfIEtHBevBoVETOJ6Fi8
u9/pHVmvSty6nkky2j8Jgobm514PaZ4M6Vnf4Z+ONE/GBiPbOFFM8xTYzNmx
Fll0/xQExAUe7pm1JHkqnvH0A4OOxKpUhJT9WOX1mpOcjyw/NX9EaUFyPsYs
b8rXJLRegLSUwYHpOPp/ATI1TY/s/en5CI36F6Ix1kPuraf9ibb2qxLhks/Q
Wn46rRcb1YuNzj/N6H7SkG1aq+Ek0/uToMvpfnXnAs0lqPcUToT20fp0cNhT
X9XlNE+HorXllvQyrZdiZ50hN2WAGFKMcstNHCaJVdKt89QrxZRuXeUXQedN
hifRIW+eVhNDhu5sr9cuFsQqGcrazP26vxD3yv7P+x9vpiNw
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02lIVGEUBuDrQm655DI6LrlVuGVmWubSvDruyzjOjFhmkIElKLlUmKYw
hokllZYYKv0oShPTmlxIxZwM0xRFC6aIJMiKEKoR24ySis73496BYXh4z+E7
5853PQ8VKfIMOY7L/Pv998s+osz+YU2BF/5LL7kXdLdJY8XMQerTp63q8ySb
wnfa4elnBbMNqo42rYUYMtujerLWpb3Tg+yENu/DEU4JzK6oLJDMvplwJ3vA
7OrSg9MGzF4YvLFYUC/fSN6EfBU3l3LCjbwF182bG1XPXMk+2Dcntr655EL2
g1XEC4+WzcwBWF5IGWgudyYHQrQgGTreLCYHIWm4yHHFgHk7Iod0Z+bPOZGD
UVzXulxS4kjegdbOh9Kv3SJyCGake8XvfjiQQ9Ex/Fw05cq8EzXGT6ZMr9iT
d0HJhc1qNjCHwXeTydvvCXbk3fB3E4mP5NqSw1GsWxnL9WSOQLnvxGpeug05
EgP6hm3OM1bkKGRlB/eUelmT96BNZ7HaHmpBlggMvtXA1qhA1eh7S8qjBXk0
vJObddm3zCmPwYyzfqnJhqyOwY7zH79Ha80ol2I14FJlRyFZLUVDjdH91wdY
f6wgj4Wmp6gpcL8p5XGYHI8qOz5EVgvMxfPPU8cj278xcfYk2y8B3ywHq3+F
rqc8Ae5rM9NhenZ+oqA/UTBfEmobC8JPuZtQnsTfl0vmz6tORkCv8bqdF6ie
SxHMn8Lfl0sVPL9UwX5pgueTBn3v/O8qB9YvE5wvE+yfLtg/HTrLuvxVGft/
5SiMaRixukb3B3IYevj9tOhi9XLIbl+Iy+uneq0ct6IfjT8Ws/4MjEyEf/JZ
pHpk8OvVglybwZ+HU2B8xVqZXcL6Ffx51Ar+/dYqUB+c96rtILv/SrR7J78M
GSNDCdsP2rEuxQbqV+KY5s5ZeQVZq4Qk60uOzIXMqZBjcr3VJY4MFSyMuiuW
LrN+FVpGO8oyA+j906owPdDfWVrM3tdMlDm0cRfb7fAHCDVY0Q==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0ntIU2EYBvCTF9SuK206p6WzzNLUps40bY8z19xybnPDtCIphEjJyKKr
cFhX0ELL1O6gkKmlaJiWUUvRiqigi3+IELGSbpKVaXazwvcjdg4cDj+e7/lu
nMANBaZcJ47jVv99/33ZI7a0djTnyTChIWWCd1WVr4iZg+K2/M7grUCyO6qe
FX1K3MgswvWQeRbJrwCyF3TF8QpTNbMPnmeu2yxXM/vhcJ5CZH02lxyAov3D
+1Z5M8tgG637IYmcQ54Hi7XSpeyqPzkYdRv15TmTmEOg6/1cI4nxIy9CrdPW
+0UXpOQw3Ivs2F7y0JccDmv9a9EJE3MkHh8bOao6JyEvQbpfTnu0P7McHqp7
7/R5PuQoDB7yqD94xJscjYxT43aDH3MMDKYRaZNVTFaA36Ecjg9mjsVr14qR
tsrZ5KUIsM8+WZPFHAeNtqSvJcuLHI/v35Krd4YxL8M5/vmeGY2e5ARkre/U
ZK9mToT95i8+NHYWeTn8G372ro2dSVZirVv1aWkKMzAQIYvaspDMA4UNy5Qt
1SLKkzDVs3Pn1rczKE/COGccz9lO5lQw5C968FVC43kV0tQ93a8SWT8ZxfLc
/jM5LE/GxSBtX3Qny1fgy+8bWVY3lq8Q5CnYvfDuWG46y1Nwbag0wvfhdMrV
jvvh1VicGG6+PTCN8pVIrWusn3+W5SvRkCDbFNLF9q8RzK+B1Mf+puw4Wz9V
0E913C+nxfv+BQcirKyvRbL5p8JVzfanQ2a2vHGbjPV1aJJebnuiY+uvwo4O
Q8LSbzSeF5hLE9xvGmZ+8BIPiVmudzwPr4f+8rGU3FZ2/nRcSurq7pGQ+XRk
h5ZpHu2aQrkBczVpceJ61wnDgDJ74V7VqBuNN2As7Pi+2nyPCdsMKD3g3P5i
3WTqGxGkrejNvkSGEVFHB0eTbDSeN6K5saA8fI079QXmTIL1TTCWLAl1OehC
fROKzj+9KX7pTH0T3ee4cqKf4Whk0P/LUV+Q2zLwMe77b1X4CPXN5AHqmx1z
XmCbGVOcr+x5d+IT9S10DnogMG9xnN/2P/8DjBlYNw==
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQNioVt3b8xWcoDwPtjv5RV11RKA8Rkc2gQblxZt
UITyORw+BR6ectkfxhdw+L99tsrV9wpQvoiD54p1sRcXwPgSDswzams3ucD4
Mg5nj+W5iv6Qh/IVHOzTLk0VcoPxlRwuaLGt2pIkB+WrOFxuuh1dM1sWyldz
2JRRtPf/WRkoX8MhZ7XHdjUpGF/LQfK528XAQmkoX8fhhEVpt8AFKShfz8F6
F8Na23+SUL6Bg/5/w82vmWF8Qwf5xb1N6r4SUL6Rg85mFjazPnEo39hh75tg
P//FYlC+icPX7a07v90ShfJNHYLnTJGuMoTxzRw8vHpubYoUgfLNHXSfSzdw
scD4Fg4B+guUSiRgfEuHc4kRHz/fFIbyrRwmp36YHLNcCMq3drAP/xLjJy0I
5ds4dBul3pmdIADl26Lx7RwiZ61dKKoD49s7eK5ct0p1Dj+U7+Cga6sXsv8Z
L4Tf4OBwccfVLzd+cEPlHR3k/509bfGBCyrv6LD3uNU7jcc8UHknhwktzDvu
x8LknRyitCd6nKuA6Xd2+KkzqWZ5DidU3tnBuPftd8cDUD6Di8PGdflT9KI5
oPIuDm0Ts62q5dmh8q6o/AZXNP1uDieO2paX7ILpd3N4b/nrn5MeG1Te3aF4
tbX9pkUMUHl3h/Aoo3VFSv/tIfIeUPXPIPwGD6g+GPBE5Tcg+ACPTcUE
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0VtI02EYx/F/Dck2qTXnPC7nNmK1YdlWbnO136ZzM3KIsLQxq9lJ6DSU
WGXJJImohCSIuuhE1MhR0MVYYNFaJZEkwWBQF6ZILg3xWGqIVOx5b3zh4eHD
F56bt6jxVO3hlRzHaf/N/82exBXueX5MjpQmzbFo4pcgg5nDw46LI0+CReR0
xLMaSiaczELIBhd6u0dlZDFkjYMDI1eYc3C16plboWYugFE7PlZ9v5AsQ/iB
byDCZ5bD+vnkx2bnerISfZeT8WRQSt6AMg33yrWaWYUlf1OvvqaAvAnXEnWT
3zvzyRp0JX2H2ofyyMXYvEenmJ7NJW+Bb1/bG+Vu5hJ8mrrUpmzOIW/FO7H/
rGw6m6xFJMq33/spIesQ6ctOWzzAvA0Thj9L1mLm7RhuF6l8B7PIpXC2CFtv
vheT9Qibj8yfP85sgCc9L3DLwGxEv7d+auZLJrkMe/fHHO56ZhNuvw76XRoR
eQceGbUfgneYd0ItleQe9TKb4UvMxLxFzIDoRzQWql2XcgAw1816nPlkzgJp
aDHhKWXdgo1Ohdh2gnUrHit2fdXFhNStyMiM+X2ja6mX43RPjUk/v4Z6OUIm
eZPqLesVy3oF3OouR/8ZAXUbrnfwXnxr4FO3oWu4pdU6t4p6JQod1QZJdxr1
Sly4G38pGeJRt0PAe3pu7MYK6nZoO8fnLNEFc6o76L9+pxxYZq6K7nDcX9aT
yCM=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAmIQDQNioVt3b8xWcoDwPtif3v7Xd5UEjM/gUO796dPN
vYpQPoeD5h05laXBML6Aw2mpTm3nXwpQvoiD0T52+YtLYHwJh4ataYtabWB8
GYeZV9YFnN4uD+UrOOyv5XwuxA/jKzn8e+z3JjhcDspXcbjtb39z1jxZKF/N
QUN7Q8SLxzJQvobDmQdbbtvzwfhaDqLri8+XFUtD+ToOJyxKuwUuSEH5eg5P
ph5pfqEP4xs4OO3+0+VeJwnlGzpYloc8ZvslAeUbOTSLKtTP7IDxjR2uX609
1WUD45s4HOrpF1ysJA7lmzrsfrpJ5v4yMSjfzGH6soUrlORgfHOH4DlTpKsM
RaF8C4f2qiMVP+aIQPmWDulTmUp4jWF8K4fga509l2SFoXxrh0ezzUxvTxaC
8m0cfng/5Wj0gfFtHYo3ru8MqBKE8u0ceIQPlRe85Ify7R3+MwT+TyiB8R0c
fupMqlmewwnhNzg4nDhqW16yiwMq7+jgY16//bEeM1Te0SE8ymhdkdJ/e4i8
E5o8Gp/B2UHew9dSbBUrVN7ZoXbe5T1iD2HyLg5tE7OtquXZofIuaPKuDkwK
Wr+4V/+B2NeAxmdwczDuffvd8cBPqLwbmrw7qnsb3FHVM3igyXs4BPYYarO0
skDt90TlN3iiuc8LzX9eDpD8xASV90Yz39uBm3lt1avJH6H2+zi8t/z1z0nv
GVTeB6qPgQEAUtXlbw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2EYB/CTLS9J4X1qas60zIk1rdQs99/UbU6nw1KSNLy0D13ASx9y
RnWoDzJMigxR0AoUFzU/mCTpNlMriwpJrRlFmLjwgqUQmiFGRe/zwb1wePnx
53nOc3iOqKQsR+fEcZzs7/PvpuOX+8jceSYM/7UoLRwzmzReZA7NkzHtKR0i
Zldcl69KErLIHuj+MLip/Xsosw96u/WlrrVkfwwXmsf5HeQgnJsQLuXd2M4c
ishGQWzTfAhzGBory+81JJPDoV1Ylk7zwcw7UeYr8LdZg5gjYThmLWgZ3sYc
BaXBqBZKyNEo7j6iF9cEMsfArULj8XUggHkvft8Pjj8eQJZA2xmanvfYnzkW
zZ5S55FfQuY4mJLahtQzfsz78GaqdQ1R5P1waryzquJ9mQ+g9JPFYpz3YY6H
am68b2stOQEXb49Z/Ca9mRNR8jKsN44nH8RsQ6WsQ0pOwu5wF/tPJfkQ6rrc
xH0TXsyH4Zy7oWvxKTkZU5Y1XhxPlkJhnT2NEU9mwGumf/BBDjMPaM9GvV4K
8GC5DInD5rtDX5h5GcyBt1p6FiiXrzcvxxV7SZ3dRP1TsLl15YTiOfV3MJeK
voKIgRB3Nh+fCuuLmomVyzRvGkalNwXCz1SfhpU2l0t2GeUKlNt+DBaLqF6B
d7plt8ge6q+E+8aO6rl6qlc65Cqk8lVrkhrKVSiqKFx9NUN5Oup1i/UFRuqf
jqYnxvO50fR+9fp5eAdzGQ7fl4F573zdsoHyzPX74jMd9q+BS4jg6LNRZl6D
ar142hZB/08WLrzXb+GKmPksqNTXPj7Mpzwbb01Ww1Ub5dnoF8u/mSop1+LU
yaWqPbt88Qea6wd/
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQNioVt3b8xWcoDwPtiv41r7PYkPxmdw6BN8KLd3
uSKUz+GQdbbi+DpfGF/AQTDsXnrbbwUoX8Rh8bI/e7RWwPgSDiuLLgnxuMH4
Mg5HL3Rtaz0sD+UrOJz3EpkrIwTjKzk83Pz+wLkwOShfxeFVxAH18xNkoXw1
h/dP2A22HpSB8jUcclZ7bFeTgvG1HFh5Za/bNEhD+ToOX8O9GMJfS0H5eg7/
uVqT5snD+AYOBww60wq6JKF8Q4eKBsHp5RcloHwjhyqbhXahKjC+sUPf9wSP
3KviUL6Jwyz/n/cT/otB+aYO3Je/FP6rg/HNHJx1rp5nbhWF8s0dPgRe7p9q
BuNbOPQVlK6KDhaB8i0doj7dNlP9KwzlWzm8nFbkuNYexrd2KMlYvs9fTAjK
t3Eo1ZwyedImASjf1uH1HfUW/SYY384hPMpoXZESP5Rv7+C3ps81dSsvlO/g
cHHH1S83fnBD+A0ODhNamHfcj+WCyjs6yP87e9riA5Tf4OjwYfPFv7WinFB5
J4e2idlW1fLsUHknh+W7r4udkmGFyjs7+JjXb3+sxwyVd3YI7DHUZmllgcq7
oPIbXBwg6ZEJKu/qwM28turVZEaovCvUP//tIfJuaPJuqPYxuKOqb3B3KF5t
bb9pEQNU3sPBuPftd8cDP6HyHg7vLX/9c9L7BjXfE2r+R6i8J1QfAwMAbjDN
Og==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd02tIU2EcBvCjlpemaV7m/V5RNqVmbrple5xO3bxtUxOkQAO/ZBRlIbqC
A90jA0vKZkJJpDaS0qK81EYk+dVgWl/KSIwiUSnUidmF/V/inAOHw4/nff7v
Cy8n8eBRc50nx3GGv++/L3uklU+HH9cnwa15TVSNz8i+EGYORyYrc3v6E8m+
MG5JPGMoZw6Cylwbm7yYQA5F8sfU1fl7zBFYu5N6YdrEHAOdsv5cxZd4cgJG
UnqtGh1zEhruLjkfPYgjb0ZVW+no5clY8lasH5qOLChm3oYmjyl/79cx5BRc
VC4GlexglkH/Vvr+5Nlochoy5DZO8iSKvBNf7foOqyuSvAvt0tmx2m5mOV6O
xFV4fY8gp2P5maQqZiycvBuOjcoXr4KZM6DoNR8wWKRkBfzW2vzUCmYl8m5P
BQ9eCiNnIvOQRt4SzpwFi7MpgKsJJavQyTubA/tCyGrc/HTF48NCMHkPbtm7
GytlzNnY79NljdZtIu/FcFRb5+BcEFmDBpta09/FDDRtf+OqKyPzQFW1vO94
UiDlOUjNTquwzwRQnoPx586f75YllGsx+iOwvPqYP+VazA+M/zod5kd5LsZG
sxtPDPlSnovWzw0W7ZIP5Xlwya6d6j5M6/k8dExIXPcz2Hwdkg03Jqp7NlCu
E+X5wv34fNH8ApxvrVdZ4sl8gSgvFPULRble1NdDNrDOW3GV5QZIvB42f7vu
QbkBc1kra9q0RY07L4JnQsqKxLbqNl8E9//mSf1iofli4TyuhO7jN/VF5krp
Pjnql4r6ZaL5InNG4XoYhefnWb7gtsOI9JbZpRyHi/Y3Cc8Dk3A9bxLOczDP
UN8sNP77D2KVLwM=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03sslXEYB/C3Q44cRui4Oy7pIilOFJLvwXG/nSNbTjQzrKZccjai5UzS
lmqJ2Yqa2UpRlktbYesk0oQtNbVqXf9wWS1zmRCqeX5/eN/t3bvPvnve5/c+
e17H1GxluoDjuJh/9/8nu8QJDztbMp2wqsmAQWHv1w5TZg43o874GrU7kvXx
xtxC6nyI2QQ71bK8mhUHsjmyh0db5u4xW6KrInVuJobZFsLIgawbPRKyA0RD
rSZKd2YnpJ1Ybo3KsCdvxkXxlKir1o68BT/EiS2CJVvyNvxWj1d7OzO7wmo0
5JUi14bshnr54kB+qTXZHYPWkxNVJsy7UWy3Is3KsiJ7oE/2wOBbtyXZE0dc
Z2cyJcxSLPVIytvfW5D34GjRp4x6AbMX6owF1n/kYrI3Xi6MXSi7tYm8F8fS
Zgt2bWXeB/XjbodnEcw+UE198HZZMiP7oi0nb1pVwOyHyvTJyqQGU/J+iHTu
F05UbiT7IyU3ebF/jPkAgjUFSx7nmQNgOqbtblIyA+We6R9rUkxWrQFObe+b
T48lczKE321udKk1plwGo5Oefq9LjCgPRM2IaP62l4jyQMy7XT3dcHwD5UGo
+J5XFDgnpDwIkrBoH3HjesqDeXkwfvksLAe661Euh+Kixw7dc7qUy9HQ+Vbc
b8vqQ9DSnF3lflif8hBIL/2ck2lZ/9C159GEwq1NV8/7MvXjwlBYvPA0s5H6
acJ47w/n9Q+nea+jPAJ5TX4BrfUc5TxzkXSe+YDVPBKr/5uA8qi1/TRRvPlE
o6wi07dIwuYTzZtvDK6U6jz6nGxAeQzv+2PhHFE9orrD8ti18+Li8KLXP1/d
QUbc2vlo4uh/oXptHHqnjeNVuYZUr8AKp1hJUdN+QIHp5Y7EEiHbJwV8hjrr
nn8haxW8/VLC0Kw7P2ec1SuRJKy/biOn/dQoce1JQ36CG+27Vsnb/3gknZWq
3o2REQ+hve7BnmEz/AU03DpT
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1H1M1HUcB/BftVLDQ46nkBPwTiiPCAI6RejizeEdAnpwT9ydS3e6sVyS
kWINc+0XYep0DS+iKbrOyKciG5QEOewmgjQHzaebOrZaMifS3BUuwxFU4/P5
4/e97XZ77f19+Hw/v999tRvftFc/LknSpv++///yJ9515mzHZh1mFS5M69am
+iPZEnzqXe+da9eS5yL5Wl/6uIkdheenHmWm3l1MjsX69M55Gz9gJ8A30h+5
PIm9CDd2Hwg4P0whL0ZcKGw49VsyWYf7uz49JOvYqYheF+HOakgiPwtbXUvg
Wtci8lKMtVyot97SkNNxT5N3sy2ZnYEj/tZA455EciayTcfTjgUWkl9E7cEt
FYPBBHI2/rmQsu+7W8+QcyAveNi43sDOxSeysU1tiie/BMfhZs2O7DiyAe9e
r1dJvljyMgxv8PwxcTOGvBwOKW+4Q815HpJ7tnXtvsT5CnT8mfjZjk3sfJiN
ozt/fhRNLsBTrse+DfexX4YjtHf/lSQeb8Sx/NzBE0c4fwWW3rHXcVlNLkRU
RrZmeIYNaIte27t9OmrWMrDtq4LCzs/JUhE0CbfvHvBzXiTkJhS6H7xq1dB6
sgl3snS5W/S8fjHWWAb6R408vxilp05/mXZ4AeUr8Y2m/fsr5WR5JbrCTVmJ
Q5GUm/HFT21vR9SRZTNmJNuMr47nWzAx/YO3YQ6vb4H30NdH4zK4vhJs1zd/
7O/kvASqmujxPW9xvkpZj7wK4yPPNWY1cF6KFcNnAwO/8vxS4fxlSstlqNdf
nKyu4LxcWa9cDvXvsfHheD7famH/1UL9a4T+CJas6L2Yf3/p7fmUW5EyPXQp
L/w05RUYSgzfa44iyxVYUtYSWnuS80o0NT7R/cs6MioxmeHfeaJmHo2vxObB
7nNXeyJmHaxUrifZlPvDhr9UPe9PGbgeG1pDEZPHDTxfyCU7Thb19Q8sVNF8
O9xrc05v1fF57crnG7QLz9+BGlNTb+RR6iccUG3NKbjaQOvJDmW/gw5hf6ey
H3Dicvf1Bzf+pnplp/J8QaeyX5JLqN8lnN+FF4yZzh/vUB50wdr+kbn6DFmq
UuaoQrFzatmTFn7fBQerhPfHLfTfLdTvFuYL4yWP8n2CB/Njzr9TO8b992Bf
TvVIq4/774HeuiTW/Ab/v72oDU2c36Cl+wZe5f0ie5X3UdALfeqc0YclMfgX
EUSqbw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtQVGUYB/CT0WQtSwoIayskIHLRKEAWvLV/WFguC8ue3bO7ZqAMtamB
hSMbyTi6MTVJGgbkOCXNpDB4jbwMo0bIahQxzXRhZ/hQlheYgGAMDXZ2QzMb
n+fD4czsnPnN/33ePe9z3vdElb9hdswRBGHDg9//d77CrJ1dZyqi8VCTWn/7
+caAILaAtN7xl6WTUeS5qL3o/bQ7lz0PAYmnhdbhxeRQ7CwdlTw1bBXSpZ6b
dZHsRcg/3nEituUZ8mJcjvlx3Qf+SHI0XhnZm7E7gL0ER1OeGDkuRpCXIn7Z
6XWjQ4vI8fjLVx7VH8FORJwreostW01eDv/YvZns60+Tk7D/7Y1fizvZzyM/
SHfB3LiQnIxju4pez1OzU1B/1zN4Rqcip0I51TJmaAknr0BF0sy1gf4wcho6
S2rL7JVsDRojtkx8MrSAnI5J0bP/gIadgY4IT3TiSCh5Jdbf+VUTey+EvAoj
CXd2JJvYq3Hwxr5Hfr8dTF6D5C/VcTed7LXo7nvvmm83+wVcKom9HKlga+Fr
e3zXcCYb8twFfNxztMa6nPNMPNnq26D/Zj7lmfC+3xFeOkUWsuBM+Ki56ew8
yrOwI6HP7ygmCzrMnwgNmwwLolwH46mGHEenkvJs6KS7msf0nGdDWRk8vmcb
1+fgC/Wp8wOGpyjPkc8n6FGZ9WF30GGu1+O+IN4vq6bxQq78eVy52JviuHqo
jOfPQ1Tmpnrnv5znQWufKjGqeX35aI8p+GXFFc5nWSjAyh+6Pvv2OucF8n4I
BqhVQ6ONTZwbZq2vcNb8hdh+crX27BHOi2CqTPx+eiHnRfJ+CEZ5P11GeT+F
Yji7TGsyfNyf4ln9Nz3YL6tuxQ8FPjRMODSo8LenKWi8Cc+uTZJ6/qDxbhMG
lXs2+41cL8rHQ0TFdxcueS5yvYi2/tY3FdX0/24RgSFXaqrG+PnN8n7BjPGr
ce88V8frNaN/cMnUTCC9D7cZCcaY0Jyt/H4s0HePvYafybBA8ejntX828361
YEDbFBD+G9db5PtZkOT7HZL8fLgkTIS86PDWk90SDOduF4jpfB6tOFe1/e/1
b5Fhxa2tvdOpXrLLik0H5lQrU+l8u62o67OX/lPI592GhirniZcsZNig2vjV
QIOe7LKhdfjdct2rXG+Dprl3c34wfz/sWNanmm67wfV27Av/qcm7bQH+A4s7
fvQ=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzE9I03EYx/GvS6nQydrcWulyipmpjE3n3HRrn7nmWoHVmsXAOkTr0jC0
LNLEVQRRy8jCQwwpCTrMFiscmh5EqKS6lOKtSKKyJGaX2tbsH3u+h34PfHl4
8eb7lBw+7vaJGGN1f9+/zUfROjoRPVaKjJatkl37K5wyboZocGxBNF5CXoOD
w5aOhIdbguLLfeX6FTW5AGbXW1NkiFuJp8nY60ELdxFUfvOnmTfFZDXa3cGj
WVruUmjREr9+ahO5DIttslQopiKX43fqXNnLeBG5AsYeaf47DXclVs9t6TrS
WUiuRqhjzqP/sJGsgeNJe8/AZm4tLoxMy1oPbSDrMHnC+9MQU5Jr8JANB65I
uGvRsPQ+8GBwPVmPnJOqqr4xBbkO4y+8sQNebgNuPZc+vh2Rk+uxL3SzsFvH
bUQ00f9ZiQKyCb1Ds5OKBRm5ARFn3H06j7sRd+7OyK/NS8lmqMLp+bb6dWQL
pItT02E39zaI/dKlSx0SshVntj5L+nZzA10Te8zGRH7GAcDuSRtymsnMhpaR
fodvVEzdBnFnTePseTJrgkhdmcoN51EXmNmx/OjVSq98LXU7ktUDZ+/5yWw7
9gZ1VdkXs6kLzBzIXXW/+8uNLOoOup+2Znrz/w4IzJyIm1K/mjTfqQvMdtD9
b9QFZi7UXv36wzaVpO4S/N9J/mj9AzFD0ek=
          "]], FontFamily -> "Arial"]}, {
       
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1Ecx/EHZ2kXZSsvm1puK0umjDbbdHPTn/Oym0gEZax3gvTCwpBs
qFSzqN4UOJIVIyIrKYUWYho6wohpgSitcL1J0oQC6bINWiaWFfsf4tmBw+HD
93/O8+aRNbUebE7iOE7/d/872co6NOIfapEjrnBlw7xssU/EzMHrSXOuDsvI
qZjoDkYuNjILkc29nrsVlZIz0JHmffTZzSzGzIVyT7eCOQ/WAd9gwc18shQe
Ub9Ru7aTLMcrxcbBx03Mu3H9/luzwbuDvAfJNy6rzcnMhbCHonclmjyyAtMn
AucDvlxyMYLHAhZJCrMSkXn7qKcjh7wPDUe6VJGQhKyCRDp5eGkDsxruO4Ke
rxVicgnCseazC33Z5P3of7f4Zm4li6zB1JXnztMTzFpoo45C+/tMcimKXoi/
31vMIJehs6PoU6iAWYfp0ZGBtpPbyXqo6rxjtplt5HKoxnP3fmhnNkBYrMqd
XReRjdDN+m9PLQjJFWj3HzCUraSTK3Hc1PM0vY8ZiKWNda9ptsbtAnbZPCHH
g83UqzDka+1VHk2lXoWZnPByr5B1E3/eZUJ4OPjrTOYm6tV4OWl0nhpn96tx
yd2i78pPoV6D+P+XRL0G9aXnniwpBdRr+XbVotGh9rXJ1yvjvY5vV4I5M77p
Vn+blDHqCeYs5I/ULfRdtqx8u6z8ec6GLYKHncvXInTfhpKrX35UPftJ3c63
y86f5+oT3v/vP+3u5yk=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0l1I01EYx/F/Ssucxcxtmc3mhmTEmGmutVn+f5tzTVOCaCwrYxXSesEN
uxAk25LhhTSI8mpBgdVimoWGLrWQksgKL1QYXRQRETQzmgWrrdEbe87FduBw
+PB9eK6O4rhzf2sWx3Gaf/f/y47UOjo5fEaJlKI8PzQxtk/MzMHp7ajSTinI
OVh2+MqDdmYRfPFTnqCQWYz+Hv9UW6CEXIhLq07+uq9nlqG+9cvHmZdycgkO
+IZzy0qZlRDF3CG3axO5FIajA/OOhWLyZvQKIhKnnHkLLnx4oe9wy8hbEVxq
7qz5tpGsgn1ePnbjMLMajW9vCUx3i8jbYHW/tp0wMFdgem7ihyCPuRKBgxGH
lt9A3o4C194nbV2F5Cr8DAltspn1ZA1UozetyUkpeQeUIzn+Z03MWrxKfOrt
uS0h70T3c1tLolFM1sGotve12wvIeoRcgWa1hLkaFWb/eMPsOvIuCKwrHkSn
mXfDFf7+9JiCuQbmx5HTmMsn8ygeTIaPaJmRbg/w+U2Zt7xbRN2A/CWxNCpd
S92A2Jrxi0lNHnUjroWF8YBGSN2Iy97sh+9acqnXYrYoutgnIntq0+c5U0Y3
Ia66cv7O2dXU6yC3NOmkAyup16Hr+sIj6fts6mbYDlXea1f+4VPdjNR/zqK+
J33ek2HOgnOD1fxIP0fdgq+6xG+jOpbax9VDmD3UuXh1mfZnmGugPRz3F0XS
0dc=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwA2IQDQNioVt3b8xWcoDwPthPurtMcAEXjM/gsCG+69fW
LYpQPoeD3AFHiW+BML6AQ/tPiancPxSgfBGH5fPWc6vMhvElHEJkRWecdobx
ZRwCLVe7Sz6Wh/IVHDyOLj31NAPGV3JwTWHVDTosB+WrOAjOVLvw2hrGV3P4
kJHUsShZFsrXcJBwW+u9booMlK/l8Lf8QV3xVWkoX8dBzvHfFq9vUlC+noP2
uRecfn4wvoHDkRtes5yfSkL5hg7v2I9Mnu8G4xs5sDL936PaIgHlGztMfFxc
7fRdHMo3cfh7RL57yy0Y39Th4OGlTNciYXwzh9OaeRtk/ohB+eYOrqmPN/fM
gPEtHEp2HlI47CUK5Vs6LH7SmuScJgLlWznEdbi9tD0iDOVbO0TGH/KIioDx
bRw0VdiffHeH8W0dfixhr3viKATl2znYGPm08yUIQvn2DsWrre03LRKA8h0c
/Nb0uaZu5YXwGxwcZl/j/rnMlBsq7wj1LztU3tEhsMdQm6WVBSrv5MDNvLbq
1WRGqLwT1HwGqLyzQ+28y3vEHjJD5Z0d3lv++uek980eIu8C1f8Rwm9wQZN3
dWBS0PrFvfoPVN7Vwbj37XfHAz+h8m6o9jW4odrH4I6mH43P4IFqXwMan8ET
ag4UNKDxGbzQ9HvB5QGI89PG
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtIU2EYwPEz7zg0b805b1M0dMpqmtpM3bPp5rzMbZVKpinJQJwQRhEa
1Ik07GIYQoEQNPugqY1MvIQ5B1qkdiEr+xQaprYuOAsd6rALe97g7IXD4cf/
ObzvOR9O1ImTh3QuFEUp/17/7mRxigdH+/XR4JBVUvnQxs2IIKbAUMuJ8zdF
ob0g+HOB5XA1sR9IlysTS7yJg2DoWqD2fjcfzYU15ebSdxVxGEwayzqf2CLR
fLj0quo1W0IcDV4ePF7r1Qh0DJhkdzwGxsPRe0B9a3D5RRBxHPTXL33rOxqG
FsCs8W7pcE8oOhEuplxZTxEQC6Ek+VF8YzUPvQ9uB2SOGxdD0CIQZdzjb6mI
k0AXK2JlzXDRyfD+2CexZScYvR+sG7rzCwbiFNALt+dnpzjoVJh619R8Zmo3
Og2i3D4u/LIHoQ9AY0PCylwssRiOtygsmZOB6HSIOctqT10lPggr8T8bRBri
DPAoZg1YJwLQmXC6psuk5hBnQVV9xfb0F3+0BBRjllp4QwxQ7tnZESpH0wDh
vfa58jTSpaCpE8ysh/hhdzIlgzpZ25ivwRe7DErLkoynondhz4Yha9te3kvS
s5nzVA5zns6B7CP2VHcF6XKmaTl0SyeePgvxwa6Aor4bct0gmlbAnE9LzWYR
6bmgfz5ievuYjT0X2ppcR+YrvLErmaaVcPmmPv1cpCf2POga/cCZDnPHngfa
66IEt2Y37PkQqVSJOT2k5wPb9UHj13YW9gIoTLswvCh0xV4ALnzBFrvXLnH0
QlgVb+3IhMsO04X4HFkq7BvYVcx5qgj3W8PuZErt1NVO+2vw+/92GDTM89Ma
SG79YZOaNx3drAHH/8IFz6l1el7LnKe1zP3N2v/v9wexZR2v
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIk1Ecx/G1lVvzktNp5jRzLJlZ0bSLM20/79NNdyNMKV80DEExUqNS
ssco0y6YlQiW4IVurgslkW5Yyy5apCGBVG8KRhFFNS0qK7vh/7zYBg/jw5fz
nIfzP9Fbt5tL+DweL//f8/+f/UI33nBcK5NjVm5NoUFTZJUw87BLNzX1fDCa
LMKv2OKGgRLmQEzXfr10S8wshc0lbmq4uIQchoDOygp1LnME1MH81Yp3UeQl
UPU1V5TOZ5bj9w+bLtG6mKxAv6VbcPtIJDkGj2NN0jcvIshKCCNjRptmZORl
mBDVWQ0RzMthKZYeadWGk1eieFtXvQ+3iLwKF3rtjeJoZhVGJxvqFJVh5HhU
v+gZkTxbSE7A0NFmSY+ceTXOPFma43M4lLwGPu4FEy2lzGuh2DH+fDqEeR3c
pqfNrWtDyIkwHVXFzT0oJatxYO7DR6I25iSk3bEsjotiXo+zSQkj5zuCyMmo
una1yVgjIafg4YTiy08/5g1YIVFOto8HkjWosq3XXO9mBtRjjs4Hr8gc4Ag/
1THwifVU2JLlpcq7C6inojzt+GBAVwD1NAwOJ31UuvyopyHh2Idvqc751NMx
cj9lV7VdRD0dRXEt2rHdvtQz8NV/oP7XGrbey7xMr/dnevUsHD8g6H+5RUw9
y3M/Xjb06/bddK0UUM/G7H3nU9d6mtPCV3C55t3JOdRzvHoOCorir1TK/2hm
e66nuVw6Xx6t13ntr0OUNk8d2juPuh7uvvGZvSF0Xpze6/vzPM+Ly8NOhzE5
8Ts7/3xPc/le8zdgT+zwdImBzdeAz7/thfuFbL5Gzw6j17yNkIW53racoO40
wr886H3jDrbehM3C7nZZJu0Hk+d940wIeuscspmpO03QFHzZnC9j32dGBrd7
RnWIrTejpOMcv7aTzJlpHmy9Gd91r0X1enb/LbhndJ7m7GRYULZJaLK2BeMv
ym00TQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1GtIU2Ecx/HjNW0ay3SambfUvGXe56a2n5ddvOwmjkIyu7BerCTpsiCK
ZkyCaBYGEkmRdqWZUTS82xISemVp7FUgqUUYor0QmWhW7P+82DlwOHz4nud5
/nDgJBw/U2f05ThO9e/+/2SXyOAYfn0qER4tyx7e+d0aFMrMIaTUEcz1JpCD
MB3RmLOkYRYiYXQMI+54cjgC5Ua7bZA5CkrzSdO+Y8wx0InvG7QrceR4NBzK
tjZmMCfi7XT9pvBILDkJWIDL0LObnIIVmXBgMIA5FdFdBvOTphhyOqz++u5P
Y7vImWiemJS2+TFnYSF2Q9ZiiiZno3Ct+d3oq53kHPhIMwYng5lzUTLkavt8
I4qch+++/eaO2UhyPi6IU4wOI3MB7mndM0c3ReRC3JUMdy6OM4sx2/3FIIxm
LsJca1hqy4kIsgRFJlmuLZJZivwp28XkoXByMaKaRqbaFcwlmDelSTeu7yCX
InO5va//FvMBpCVtmV9VMsswdjj5fawgjAyE/XSO2+u2e2wBfn3da91/TUi9
DGrFxIf5UrKlDBX164UBim3Uy/H44yOz4DzZUg7f+PQ1gT2EegU0ve1yoyOU
egW6XAL30wIB9UrctvoNzDRupV4Jd2bH5Weng6nLkWdbXC1zki1yXldgT3Wn
q+E5W6/gdSXiVGqJ6EUAdSWuPJgeEX3zo66CwO/lpYU7PtRVOGcvlr3p4ahX
4WBDbt/ZxE2Zp1fRPG6PuWrUiq/2z2XRfpZq6G/mZPi3+dP6Gu/9LDXe+3G1
vP1reeereV3tfR6n4c2v4Z2v5XUtliRrf8qzAqnrvDt08PwPfOl9nfc8Tp45
vfd80NP3X6d5ed2pp/N/yP4CaO4ZDw==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQNioVt3b8xWcoDwPtjHe94/ZswH4zM4XMuUnBi4
TRHK53CwMfJp50uA8QUcXkQuDqhgh/FFHDQE97QHLFWA8iUcrnlk7HjqCuPL
ONjNW79q73t5KF/BQendAxU5RxhfyUFz/6dp5XlyUL6KA0P1l/MyR2WhfDUH
lhntRu4sML6Gw70HEm3+SjJQvpZD61mrDXPbpaF8HQcW7RWGHPeloHw9B9ej
edWTVGF8A4e45wklnJMloXxDB8vykMdsvySgfCOHTQyLGroFYHxjB1FxU+2z
TeJQvonDsZ5D5WX7xaB8U4fVgu8k1DaLQvlmDiaXestVd4lA+eYOVZXaz6+p
wvgWDk+yNK3+tgtD+ZYOhruk1R+VCkH5Vg5ue19mOVwUhPKtHUo1p0yetEkA
yrdB49s68AgfKi94yQ/l2zlc4+3I+OnHC+XbO0xoYd5xP5YLyndA5Tc4OOhs
ZmEz62OHyjs6VNX/Opi9ig0q74gm7+QQ2GOozdLKApV3cqidd3mP2ENmqLyz
Azfz2qpXkxmh8s4OkPTGBJV3cQiPMlpXpPTfHiLvAlX/EcJncIWqY2AAAHQy
m38=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd0mtIU2Ecx/GDRJRkOXNOnbcty9uaqanzsu03L5vOeSkxkbRWIL5I0jAL
7YUnKVIKypWkrZpFtCzIuaxAQ8NKjXBQkVCo1AxLpEgwIsOo6Pm/8Bw4HD58
Oec8PM9ftr9mZ6UHx3G6v/e/J11+JfcHeg/I8V/ftB3npm2qYDIHx+0Zp2NE
xrwGs432x0+qyd6Q9A171ojIvqjqKbcs94Ux+8Ng9j08aCIHwXBRqYh8G8oc
Bkn3keYPiWQ5ujd0hFxuCmEOR2hbxa4Hz4KZt2B8TLMpMIMcCfeMSiZ3BjFH
wzHal8N/kTIrsMS7ulJLyUoM6x85Xa5A5m1QarKnb1WR43Cy9ao6SEaOx8es
lqav+wKYE6C3rl2wx/gzb8eVkPZBq0bCnIhu26wjpsKPOQnH52RD7lxyMvYm
qVdPjYuZVbgb/Foe/cmXOQXH3jR4cWZyKto3L5dxto3Mabh2Y0x8dsKHOR27
DUOeSw6yGnH90gh3PVmD9HjTqfVmEbMW2tLF8gIpGZiNlSccjGLmgaLq6Bff
A7xZ1+F0fOWk1czM69AQNfqzspB6BuYnI07ENlPPgNR/5nObhXom6u6kaZ3X
qWdCpqtqrf9NPQte1T7zLYeoC8xlr1wPn71yPZx+5f94veD7BsH3DUhxDXSN
vKeeg/qoC+ctTuoCc7mCnit434itosiFSy+pG1HX29Na1Ej7m4fnE+GLv9bR
/uahc8h+tERB52PCK61llWSKuklwfvl4WHuzTClm58/nI+/egnFHMs1DAfa0
6OfUT6kXCOalEMWcytUrYvPEFyLHeOads4zmqwj9tYofxR5i/AFLrfuS
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlg1MlHUcxx9RUjtBNDhBSY4zGwJiYb4A4n0PhXg5Tl7ugHuBe+7cLRc0
FF8TmY+mRXMmmLXUaGjmCyibmQUS9JjDl0yXw9CtmjhMN7SkqQiMsNr9/m3/
/7Pdbp99f7//9//y+/2fJ9JTnuf1kyRp77+///7Zo7Webj1ZqoeP+gzfZ67a
FTGRsYQHAyvr0toiicdh1IPFY6pkxkF4ojnf3uzPOBjW7d73ypt0xKHAF1NM
d0yMwzFcvt5/018RxDp09EwIqTYy1uPu8jEds+umE7+EoV8Ce7OGXiR+GXNm
xmhdBsZRyM/XWA7eDCeOxj19e1d9NuNYqKd+vF9eN404Dq6ga/ekh1OJX4HT
LTd1mxi/iqpjHy1wJIcRx+OdEN3mvdWhxHOx7uT03dbfphC/hn3LBm/Jz7TE
87Cl7idX2ErG83Hp+rbtay+FEC/A2RnboiQ944WIuRD65NDtYOIEJL1Z8Yn8
FeNEpPfeaA/cwTgJrhunSzo3MF6E9SH7pV2HXyBOhmnB5m964hgvxkDW7+O2
mCYTG7D1jmfnneOTiAFD4WOneRqxAuyI9/66Xw4i3YicsujLT8KIFSMyjjU1
zPx0IukpaFykXxF1jlhJEfQlWN2YZPjyIMtfgrdnXRj0LmPjL0VZSk1b4IFA
0pfCfPyDVO/pANJTBT0VHY8m5ttXTSA9DaUXm9s7WzSkpwn662i7kPhnVA+x
IrCUjq/7auZMvcLGT8ekB8HaPi2xlIHZyXGW7+7SfJQMXGv++fHNAfKTMhEx
cuXywr7nSc8U9CwMxu7edKRsPOlZONlUvifOMY50E/pOXfu7KoTpJszd+cdT
o0osZQt6tqCbUduzujLl6VjSzZiR+XGX/SjNR1rGsyKwlAN7TG361Q00X+Tw
81cEXc1BzbbRzbeKWX4urkzt690TRIxcYb65vJ+aK+Tn8TryeD8lDxc7ktev
OUP7pQrxUj6/vxBYyUdXQPWKQTOdn5rP14tkQUBFfFLnVtJhwVHjuY7zYey8
LXw9qhYcuvT5Os0aVh9WnmEV6sXK15dqRaE9vqlCz/qjgI9HAZZYhuf7p7F6
LODHVwuwtjVn0cIB5l8I274TB0JiqZ9QiEjjG++vHWH9VohZ5hnBqW9Rf6uF
SLjaWn++m/VfER+PIj5eKYJm9ImNvR+y/CJ46w77Vdaz+8OG697+8VEtxLAh
oGzy/epVzN/G3x+qTeh/Ox6NnLFtHcv87fx6FIFVu5DvEPbfIZyfg78PVAf8
dNFDmkbW/070B7RsGZ5HDCdfL4pTqF+n0N/FQv0XC/1TLPgXC/1bwtc3Snhd
KcHDhKGRlLjnKL8EGzcPnS1tIJZciEjPTtA2+FO+wIqLj1ddONJ6Q/tDOOmS
jHdrSxMrI+j+0Ml8/0Lm7xdZFsaXqT5G+bheRtVnnd9qb48mP0HvFnTJza9P
56b3F+lw8/GyG77vFT/yd9N5Dht8/m7eT3Xz6+t2C+v38Kzz8H7wUL8+840v
e+h9JpG/oNd76PwGfax6aH39Pu72kC97lv/P/wCSEYLM
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd1HtIU1EcwPGbmfmcOt+P3HxUMoel1Zzm3G9T59zDbY4iJ0goVqiUodZS
o1VWWjGYjmgxjAjMaZpiIijIKicWKPmP/xQpGVFa5KumFlqx3/lju3C4fPie
cy7n/nFiS88VlrtRFCX6N/6/yRN6bHCkvzIOHFri3zlVbFr1JKYgpm8cyiyx
aE/oKK4rnZMRB4DW/m4w1c5EB4MxiqMeNRGHQ38F95JdQhwNb/1HDeVTDDQT
qp5azY9pxHEw91N7f1YWg04AFijM3R170Pugye8Es3E1Gp0I3AY6bS6ZmAXP
e683hwmj0GzY/hg/3GqMRCdD3wZdH/c9An0Q2gXTtwskxClQbTqrmLCGo1Ph
TcmzldE04kNQY+y97GUNQx8GmpZ1/EMb8RGIaa6wrIUQc2DI6p33cDEUnQbL
Q4Xq+CxiLnBWNInS2RB0OliqJ6fP6IkzwKRvr3h5gfgozF+lJ1aXEWfCrfox
7bo5GM0DNcWd6g8kzoKSZtFX3lgQmg/SgWWJKo0Y4FtQUfmvFrrDOoDXMwlr
v30DsQtALhq3feIFYBdA0YOeRyFsNCWEbUq1fbLWH7vQpWfD4vv9TQeukfXZ
EBU+/8XQSnqOS8+BWMHplrot0nMh39LbtddM9s+FuhFlJnedhl0EtlV/tea8
L3YRTNh4F2uHPbHnwU1DZUYDYzf2PKi/svmisssDuxjYA+4eHD3pYjDM1zQI
7Wgq39m6fOf5lMSlS2AycmnBGOCNXQrxknszmk60Tgqdgle28Qg/7DJn62Sg
STKIp7Q+2OXO++nksMFubXxS5YW9ABhieXpo1y7sBfAjfXNLmEzOp3D+HzqF
y/mUoLqbkuR+w91hUILjPnDD+Urw2dlTv9C2w2GriykVuDFZmz7df/iO9Sr8
/mf+XzzRGGo=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd03ss1WEcx/FfKCoiOqio0wlF5hpJLp84jsrtXGpCKxldKBSF1PxY15VK
umxorays65JRUetULF23/ogZf1iOlmpFai6hy3y/f5x+29lvr72f73PO9jxn
XlKGOsVAEATl38+/Nz/Wa2obqtNkGFdvsIPR/ZcO09kCirYb9qRr55FN0Lel
2P1qItsCl4LDnEtHpOQZ2PoxNX3DabYtRNNWiwIF2w7RNoYnOr/PJUvR0pXm
d8OZLcPX5HPWdgVzyA6QVkVKJ3Tbk51Ql3cJkLEXwqXrydPCPXZkF/jE2+7+
qJtNdsWn2X5tlXPYbrg76LG2L3gW2QNl4V67bWNnkj3xKkinUL+2JXuh0uDC
WUd/tje2tji6TS2xIS+G7I5JWVOUNdkHxo/nV7h+kZB9Ia/otLx/hL0E5+8F
JJTemkH2Q6XuQFLoJvZSrD+s6AlstCL7o1GpLRfrLcnLkJo9WDchlh2AIl1S
se7GdHIg7K+PtKxbwg5C6OoR34mKaeRgVN/KOO2WYEIGSrqy8kMGjMct/mdh
OYZcT+2t2jaZ+nI0NwXmZNfzfAi+LR0eC3GbRD0EB0vS/PPn8nyo/noxFL01
b0f3SWg/QY6mfnNN/A5T6nLU9Z50n/Waf28Yfguq34nZ5tTDEFd286LE1YK6
AqZWT3Iye7gr9NcL4egfq48rMqb1YjjynJ8NpcTw/Ap9iyug3Oby8udM7iv1
v09ciaNeKR3lidxX4XPHgv3uRdxX/dcj8LzF4ccvUzoPMQJyMXfU8xCfTyQU
D3tS8ZZ7JAYjuk0KI/l8o3DZ37u56jxZjML7cl+f9lLu0XizcW1ffxvdFzEa
8d/bfR1H+f7EoCYzqz8+l3sMnufJA5KduCuREP5oyvBt2g9K/S4qkdQsq/cW
yVolLKfaPPjwgOdV+h0q5EjKhRNXeF6FoY1Zo4W1PK9C/rs8MyGR77sam88Y
ZJt5k6HG8cxd1xI0ZFEN1THPRUYHyFo1Du1pzB2s4HmNvqFBVUOr9Qs7+r+J
Gki7JGcq48haDcZ2DjhObpLgD12zP94=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdzFtI02EYx/H/jKBmW7Pc0h08LQ+0Ofrrf87DdL9N3ZwklBWlRCcYhV4o
sQoTtSSMIJEwiiJ2s5ohhoXUcHaRlUYKIxUqugjMSIhGTmjZSFex573xhYeH
D1+eN/NkS70rgeM44d/83+wpDj4Ze9ychbiWLK+bxq+0ipk5TKTxQslQJnkT
wsFjHwr3M8tQJEgH3JEMcjI8/MiR0T7mFLySdspzTcxqnP5uzA/dSCdnQD+4
YG4bTiNnoU3BXbavacg74dKs3H7UwJyDWaFxefGWmpyHZY9PZ0xg3gVxz0uf
sl9F1mPe2RkJxZRkA+638NocB/Nu3PUqD09NppJ58GZvRrSOuQCubF5UMZ1C
LsSif4jnDzALKJ7oavcEdpCN6LneXNqezlyEvfUR1XC3gmzC1ejbwdRVObkY
5p/jn64dZS6BMNt7PjuQTC6Frs8etE0zl6HDM/dMMb+dbIa/1ddgkDOXY4+p
y79gYK4AH1Dlfj67jWxBk3vlqegQM6DTKFJPnSBfBGR6XhWMJVG3Ij8pL3xn
RkbdCp+29qPwgszZUGefnPhSzroNMW5f7Lh7K/VK3HvjPZfollKvhORMQdlc
t4R6FSKS0Ut/jFuoV0Fbe/Nd4wMx9Wosjcysdsg3U6/GwNh7xZR6I3U7Ejc8
vPCtX0R9nTkHfpRE12yGiCXeHdTDcXM1KOwN/bI+/029Zl130v1X6k76l+P+
ArviyUQ=
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAmIQDQNioVt3b8xWcoDwPtj3+p8KVpWB8Rkc8lvKTcz3
K0L5HA7XcmNO9abC+AIOpxgjZkxih/FFHJ6ybEl6vlkBypdw2CPxyVk/HsaX
cSg1flqxnwnGV3BQXXrE0TNWHspXcvANn/7JeosclK/i4GJ+fl8+B4yv5jBd
T2f5Uw9ZKF/DYV6KqOOhbhkoX8uhN9le4u8jaShfx2H+eR6+yZekoHw9h8bK
t+WK0jC+gUPJB8O9Qo6SUL6hww3BT5KZJRJQvpGDpfsVh03rxaF8Y4dIJYsF
N8JgfBOHie7ielXXxaB8U4dZp4R2LVgnCuWbOZhc6i1X3SUC5Zs7BDNYnNso
CONbOPxMLP7buFUYyrd0mP6wh/HeRyEo38qh4NrnQ4mKML61g7TE4xcTJwlA
+TYOOU4T9vIt5IPybR1mX+P+ucyUG8q3c8g+sWPf5Z0wvr1DlPZEj3MVML6D
g7LXtGtRK7gg/AY0PoOjw0+dSTXLczih8o4OG9flT9GL5oDKO6HyG5wc2iZm
W1XLs0PlnR1q513eI/aQGSrv7MDNvLbq1WRGqLyLAyT9MUHlXRzeW/7656T3
zR4A6COhoA==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd021IU1Ecx/GbZmrTWmnzofk0SpyY+dDM6XQ/p9P5NFchUWaIZAoTsjRF
Cxs9UC8ybPamDDKN0plC6cwaiilTKyhK0BciSkZRpGVQOgmt2P8E3gOXy4fv
uefcc+EGFZ7YX+TAcZz67/XvzoYo12x5pJfAru/K+SdvJn8KmTlw/X434jqD
yC644FLX3XOIWQhp7FVT8FIg2RO3aj3LVm8ye2MlJbGrT8UshpvHYFXZ5wBy
IAbF/dJuMEuwK993zNjkT96B/LaCvKOOzMGo9r4z5hbmRw7Bpcnd0rxKMTkU
yrziAyND28lhyHKOdno15UsOh9Xs/LWjgDkCXcba8PpGH3IkXDUK2ZyKOQoz
Nv/c8xHe5GgMZraGvj3iRd4DFPZMGKtEZBmK9R+TB9yZYxDj69qy0LSNvBfC
yyePTTd7kmNhVh5fOlvKLMcn6Y/qSJ0HOQ7vG2Nkkw1byfF4pzSu95raQlZA
/trSNDwjJCcgO3XY+iGBORGlqvq+TXc3kZVIb+s07by9mQy0KyQlIUNkA3Da
olPELrH5Sbj3oqVSUEE2JKFvJG4+ZNaNugqtSUPWYR936iqMu18psWnJXDK0
D6+pi8ysJ0M/2ts/9lRAPQUOgaHLgnZaz5CCxnGB7b6MdTVGrQlVFc9cqKtR
f9Gxdzp/I/VUXJ8tP6NadKaeippzy8/1pg3U0xCgyZaLTE7U0/DAMiF6KSZz
GggcO2q+NKyjrsE3+fKKKvyX0t7TUd4er3zczFFPx8HDUZ2nJKvUM2D/fxyo
Z9B5flPPXDvfkMnrWYium1tMGrBRz+Ltn73WBp45Le/9tGvX43J46+fwntfR
+Rfsho63n46+E40Bnrl9//0H2IYUBQ==
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxd038s1HEcx/HvlJDOj0J+XR36IZS68iPSvfw4OeXcueRHaleb2GTi/Fiz
tsusUhzaakX9U5JkKiI/RpcSZZT86Jf4w9ZsTdNSiKZa788fd9/tu+8ee373
/Xw++3y+TkfTohINOI6L+Hv/e7LLJrqh9UGKM/5rSnSeX+T12YKZw5YqTvXx
oRPZGMF1Q9lpMcwW8Hx1bFDAMVtB2G60tr9CQLZF6quugbAAZkccln8andGu
JQswX+52ZtaY2Rm+BratXYFryOuQO+cUFqfikzdA8Pqtz/tBR7Irojv6rkj8
md1QENuWcL3PgeyBe4a9kglD5i2o5BtqBg7Yk7cieXjN/fpbduRtmKrv/33K
mlkI8+laxaTQlrwdHvVLl3lrVpN34N0lZXzNaxuyF5p74hpj4pi9MW+WJHoi
tib7QKqyyL3caUX2hdY9aLImg3kncqzLueLKVWQ/FNWbuLePrST7w51vY5d0
hHkXrj6+nRPtwRwAZfqh+ZcTluTdSDC6UeYgZhZhs6Xrt7J+CzIgO+7W88OO
rAYap0o87XvNqAeClyH0H8jjUQ9EW5ffV9fxFdSDMMw7lzwnZT0IKd1N7QPN
ptSDdd9XB+t+jwtBxYub2aaZNJ46BNIajTixgXUxujsDcjJbjKmLaX9MqIei
dFyVGzRjRD0UJflLmsYOLae+B53fzRXx6Wz8PfjJaz694MXmH4aqwKedz+3Y
/MN018NJdOejluitL1zv++F669sLA4HbL9O7rOuZ24fg/QvehqFs/fuwyMkX
lZnm1COQ1Srb5TvLegRi4oW1Gc6sS3WtlkJyp7Z6/TXWI3FBmDhSrmT7GwkH
2/GJ0ots/2VQ3fUX1d0gQ4ZKl/APOzrY+zJ8GdmY75lH1sogiplOkDqw8yTH
JqmLlTiVDDkGE3+auDaT1XI8k2nL1S10PrVyKIYLCt/w2fmOgseUpvZRMRlR
0JzIqj6ooP9BHYXcoZM8TknW6plTYDRWc7Zwxgp/AOm7L2A=
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQNioVt3b8xWcoDwPthvNgjMvc8F4zM4bFx97cax
1YpQPofDQ7tjttLuML6Aw59N12IKPypA+SIOc0PfObhPhPElHM4/WXukwwrG
l3Fg7erc/WKdPJSv4DDt7aRs9nNyUL6SQ8DStyWT/shC+SoOt29WMfj6wfhq
Dj629aVrVshA+RoOuW6CwltOSkP5Wg556TfiWHJhfB0HrvynTfUnpKB8PQfX
o3nVk1RhfAOHxr5pt9PXSEL5hg73pFnuc32TgPKNHDYxLGroFoDxjR3ObA/h
UpEUh/JNHLgvfyn8VycG5Zs6rLh9eOrca6JQvpnDh8DL/VPNYHxzh18/nBeV
64hA+RYOGz9Jza/KEIbyLR0ezTYzvT1ZCMq3cmh6ktT7ZI0glG/tEMO+aJa0
K4xv47DaRilD4zA/lG/rwKSg9Yt7NQ+Ub+cwoYV5x/1YLijf3uGnzqSa5Tmc
UL6Dw4mjtuUluzgg/AYHh9p5l/eIPWSGyjs6VNX/Opi9ig0q74iqnsHJYeLj
4mqn7+xQeSc0eWeHjevyp+hFw8x3RjPfxcHHvH77Yz0ov8HFAZIemaDyrqj8
BleH4tXW9psWMUDl3RzeW/7656T3zR4i7+bAzby26tXkj/YAOve8Qw==
          "]], 
         FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdlHtMU1ccx++AgaMwQASRIiA4YcBwFBF5dHwpiMiztEChLUZdWExgMgSH
4hauZKJRcQPRmCAJgtT5QMOMD2SPi6TQhUDmnGRZ+gcJxjGIG6gTSoA9wu/8
ce9NmptPvudzes7vnPvbsLdCU2rHcdzh/37/v9njXXCnr6csCCs0kxTq1v5i
KIAxh6zG5RvW/g3Eq6Cy5g9U7GHsjrn91ievHBmvQfD6380hVwOJfdDRN9Uc
pGPsh5NtqbcUPwUQB+JF4PnFXF/GQbjqdsH/Yp0/8UZ82Caf8Xu+nngTQlz2
zXaXMA7FbE7PpoFRP+Iw+HnkbTxXyjgCzg0DJt+zcuJIOJnOaI4v+RK/j0OK
gfEaI+MocL/sryybXEeswLhl2uPjtYyj0T/ckbi7wYd4C6qjB5UHR9YSx6DQ
1KrQuTDeinO8stND5U0ci+GFyZMNXV7E26C92CKvjWIch86nx/amfLSGOB62
PVVLR+94EicgK7bu3kQk40R0xUdbrrStJlaitM1kd6Tdg/gDyH0mJpua3YmT
JAycUpRaW3cT88Ddma82+468TXkyvhuK/zN0woXyZJhfumn1lcScCmWW+98/
7pVRrkJ04/O5ZOEtylPQc7OiJdKwivIUSZ4KW0TzZ1fKiflUtI7JbKYYmo/b
juCM82P6r50p3y7J0xBx28Fx6xknytMw4jsz1eJO47kdeHT/yatf59n6dkAf
3pQ+eoj56aitW+gvu+ZIeTqaJqqOqOZoPm4n/opbWFZFsnwnLGZlTfUD2g+X
IVlfhmT+TDHzmeJ6clkYcz2xz5bjSnkWXA8oEh7XE3PZkjxbkueIz4PPkew/
V8x8rvg8ODVmbj9a+tyL6g+1+Hx4tdgX1JL65IkZecg7HRXucMyB/DwEpGfH
eV97k3xJzmnoPtuTr4HMvrt26uwb5GtQdT0h6ZsOjnwN7ALDFmTXF5NWfK14
PLTi+XgtVvqbHflaiZ9P/uwKQ8J8Pp3/sxUW8qk+NvILxIwCGv+a/ALaJz2C
hLlC8fwolPy/hIVCyfp10OkVNw8E/UO+TlwvXieuj6AT14crktS/SPI9FeG1
a+/RxRi6X0IR3lNG5v/wjN2/Ylz+sfNTWTX1CxTDxfNhzSd/uJFfjIN96sRt
85QLxXi5/KC43on1Hz1uyW/c+zmTxkMv7j+8Hq7lq6dPVNJ4QQ91edjw3+uY
b6D9EsOAuNG+9sFx1s8MMAVn/LblIfMNOPzukK00l/lGcf+DEdlpg+anSuYb
xesVjJi2hnyxuZ75JXDunN+VZqZ+ixJMfLvEh8dSP+ZLcOmyxevLMWKhBKca
u97ptmf9exf8e6vuHh/2xL9AyPj1
          "]], FontFamily -> "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQNioVt3b8xWcoDwPtibqwR9t+OH8RkcPH2P6pvs
VYTyORzmM9s5To+B8QUc+G3N1j3+owDlizh4nxTSXTkHxpdwOBCzucLHFMaX
cVC2sJx6fpU8lK/gcGpZSuaV23JQvpKDJM9tVTN5GF/FQeePNccGO1koX81h
cvPOI2/my0D5Gg6nVvOf2XdMGsrXcsg9dt6qlRnG13GI4d4XMVtYCsrXc3ji
0lH/LlESyjdwOHHUtrxklwSUb+igN3PT+9g/4lC+kcPWWcsc+/hhfGOHvW+C
/fwXi0H5Jg4ucx4I7ewUhfJNHUp2HlI47AXjmzm0Vx2p+DFHBMo3d5DbWbyt
/bQwlG/h8DOx+G/jVhjf0qF3M6f2vvtCUL6VAyR+YHxrB67FP+LcjgpC+TYO
J6+pfPnNA+PbOvAIHyoveMkP5ds5LDm5uIy7hA/Kt0fjOzhkn9ix7/JObgi/
wcHhG+/Oxj+mPFB5Rwdlr2nXolZwQeUdHT5svvi3VpQTKu/k4GNev/2xHjNU
3smheLW1/aZFDFB5Z1R+AxqfwcVh+e7rYqdkWKHyLg7hUUbripT+20PkXR3e
W/7656T3DcJvQOMzuKHJw/jPoPLuUHsYGAAj3LzF
          "]], FontFamily -> 
         "Arial"]}, {
        RGBColor[1, 0.5, 0], 
        PointSize[0.002777777777777778], 
        AbsoluteThickness[1.6], 
        Opacity[0.2], 
        StyleBox[
         LineBox[CompressedData["
1:eJxdz2tIk1EYB/DjJiWOYNVc5mXN1ykmbpWWutzasznvmzrJLPNLlmQXGLi+
lEQvdPlQKFQriChMnAWy4YUwWrSNSozIIEFMklGrWUY0CyauyAqfE7znwMvL
j/95/jwno9Xe0CYihFT9/f796ZE33vcOHeNgRRHDg2nH+LUkagIy1eTsl9EM
dAK4Zp9ApIVaCuoTRsfNZSVaBgGiK/neS50MV+5Gzz/VUqdB+nHd3PjsJrQS
Lt1pfL15CzUHYGp/6z2oQKtg4mfrzOfudHQ2vPKN+Y4E09A5ED472BVtos6F
90t9YtuNVHQeNB3N6lelUmsgyJlDD+tS0FuhfUoxOOLaiN4G04eddo87GZ0P
7sqZcEccdQHs44p7pvdsQG8H78fhtGC/HL0DXsQ+XbzgSkIXQiDzXA7hqItA
PZfKJ8bL0MVw+vbkI/m79WgtTBzYu/DjDfVOsBSdGQ1pqEvg+Umz7lA2tQ4e
t2QFFJJ1aD203eoXdfasRe8Ca/nYsw96KdoAar1mty+8Bg3wMiUy75QmrpgH
yKy+PtV8D02McDnk6DQtrsbcCHkj8asKu9HEBEMeu1OzPwFzE75HjHkpNDXn
ezq4ZcNKXgqOgRLDcC/B3AwSsfvU/NU4nDfje+l8mdB8GdNfzsyXM/0VTF4h
3IdUQkHX10Wjfwn3q4Rv2thvkyaKeZXQfBWIlLkxycAvzKuF5quFfaSG6a9h
5i3YH8bcgnvTYxWatwrvk1pmv1p87wLmdUzOmNQL+4Axz9hfz/TbmHnGvE14
38+YNPz3H43nOYY=
          "]], FontFamily -> 
         "Arial"]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, {
        RGBColor[0, 0, 1], 
        PointSize[0.009166666666666668], 
        Thickness[Large], 
        StyleBox[
         LineBox[CompressedData["
1:eJxVlnlUk2cWxoPKiEoEFGUVQlQEXEBFtAThYUkAF5A1LCZ8CQkBZRQVF3QO
RIQWxaIFpaKjRmWswlFErKIsDeChahW0Fh3cYFgcXAatKxbUaU/f+0dzTk7O
7zzf897vvve9N6+DcnW4ehiPx7v6+/ePX/pMjPq+pnKlEH/SS5+FVUenrTIh
5uEb/82+MVUOjI2wedu9s5ZSYlP0iQ91xA4KGJtjx9krzVIdsSUsI55/ZSUm
tsXTMMnthl/sGQvgHFd0LN2eWAiHrobH41PtGE/BirtvlTMvTWLsiMp08f1C
I2InOK0/PVYaY8vYBY1LL+ZvOGnDeAb8tLnjvQetGc+CRVxlzYUwYjfERHi5
/a3MivFs2JkK03sNiOegdP8SyaxYS8ZzMdZ2Wn/DeQvG7jC8xuWYWRDPw6n1
vSWnNk9k7IFzeTVO8Q8nMJ6PvxsfTL0dSLwATf+puDijwpzxF3ByLbgjsCf2
xKjP2vC23eMZi7DeIUV/x4TYCwNYl2mQP47xQkiLfWs/GhF7Y9gUoeuhAjPG
PhBtGLaGN5EY8Jwnz/rhsOmfrAVyNvohyp0xzxeBzw/bFB42YbovCoQ/vHV8
PpbpfnBtDfvF2pOx1g9mtRInUx2f6f7gBYf7HrRirPXHsqHz1tU7jZkeALvn
oof7JjLWBiDt+OuRk46NYboYzZLy/LDFjLVi6H9rUvj2jma6BMcP3No/tY6x
VgJFe1+Wl5b0QCy+ZeN8MJf0QOTNuG8pVpAehIchuTPtBKQHoXRMZVafJenB
WHn5W9GRaaQHo/3Iq+uHONIXYc/lqrz4QtIXIePGjQWDt0hfjDrh2xMrDen9
F2OwaVx6jyvltwRtDs1PouNIX4KizFaDplLSl8Jjd+CUG92kL0XHuhYXuzm0
fyHY9rSXF7KJ9i8ErZKoRuku0kPx7vqhnYtekB6KXUfz0414VJ9laJXVhw16
McYy+Gjk8s5RVK9lyNsS6jP1I/Prl8H2p0sb7waQPwwvFJmpwankD0OO7NrS
uJPkD4N35qiYfdWM9WFoSpQHuu4gfzgelnok7GgnfzjGhLcMnbam8xSOqpsD
fONZjPXhMJ1gKzGfS+cvArbhHw2V6xkjApt91q13/Af5I1Dyc0D3+yDyRyCL
/0XUZNJ5kbhl/HrGkZnkj4S4eWfM9PHkj0TKiMv2ad7kj4RcdiJ+eAD5ozAk
zJ06SUj+KPiobPgtPuSPQk9ubF+rO/mj0DxYmDrVivzReDbCpLjSgvzReCn7
3Gy4gfzRuGS2YKv1MfJHQ+bSZuJkyfqRJ8XXdhbWj2wZQ4rZDiJVoh/1qxR7
9RMKUzwY66XYkptzabSU/DFwv9hsaUj9jRgM3B1syebTPIhBYXP3pAf15I/B
dO8TZY4XyR8LzeqK7ruT2fOIhY1our4sheLHQn9hh1P/K3r/WBgbhW4f0lP+
cagZcfaZuoTyj8MFzQdvdx7547CKf6BkaxH541CX9yjkg4z88ei/efWf16me
iMeYlvrQhr20f/Fwv13y9MIe8sej1Lhgsngqvf9yLOpMNnymovyXQ9Zj1Z5b
S/GXw8ZgijDfheWnX44Hva3eAdE0H2Xwzbd5eSCE8peh4HxfWfce2j8ZhkJH
/uqWSX4Ztpi/q0orJb8cRQVZ7u068svBtznyWDaW/HJ4tmzpXLiR/HKcO3ry
zWgJ+RMgmmfWf6+c/AnIeGc+/9EZ8ifgpuv4avFH8ieg3tY55fx35Ocw/JxX
pnQhYwGHouDWmSZraT0O4gabgO27GXMcvl59J7isjNbn8M52IPvJarZfOg7a
b+30Rn10Xjj0VszIU9Sw/u7kkL3gXnlmBvW/Alf5ja8c37D6CBQoNw0SRTxk
8wYKJLjZiz9PZzqnwNs1mv4NbTRfFPj+TPXsdbGMdQpYeu5/uquLzUu9Ai41
wbW6YrZepwKPW0xrve7TfFTCf8XEqno35hcokZ9ztnion+Ir0SGsn+/5lOmc
Ei8OdfRsF9A8VqIxdUN2wjD2vE6JNI1xFu8BxVfi852wiKtBo1h8JWLrhcN3
nWXMS4TH8lGtBqPZ/4UgEa2x9x+nnWaMRKjf+H5MX8uYS8T8Yx/+2zaZ5nki
ymXvPTJXUvxEvP7Zqvi4iM574l/3rzMR57Iiq50LqX9UeN9d03PKgNVLoELy
yY4mp23UTypcyl/UzU2g+quwYuNdj2nGVH8VMpx//KAOZaxT4WTXOOuUHXTe
VCjpkpud6GLcqcLKix7TdAK6f6jhK99bUG/BWKAG3++y3mArxVejtdrZv7KD
6q9GYUqCi88b6k81BNPr7lesofqrse/CnE+Dn+j/Rg3/yCEPQwnlr4Y0bs7p
tULq/yQ87t1UMJej/JOwag3vm+qtNA+S8OuX1y4njaD8k/C/T5nljTLKPwmV
myyyr/RS/knIjp+XXj+F5aNPwrp22Yj3IsadSaitVPlVJFH+GijdHEWfz1D+
GqTded2ocGD3N2gwUDoys8eXMafB/sjKKkEPe16rQYZZ8W/yfzPWaTAsfU7X
wFfseb0GAV8+D7wpZ9ypgY859+BZAd0Pk1HnvicKDRQ/GfzUcc/y1lD/J//1
fblkSOqerMAtip+Mf3nOvfLdQbae7vf1XBrsc49S/GT4zeL2rOXYfbUzGZUD
BU8sQffbFGxpy+DzOHP8HzhgPCw=
          "]], FontFamily -> 
         "Arial"]}}, {}, {}, {{}, {}}, {{}, {}}}}, AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
    AxesLabel -> {
      FormBox[
       StyleBox["\"t\"", Bold, StripOnInput -> False], TraditionalForm], 
      FormBox[
       StyleBox[
       "\"\\!\\(\\*SubscriptBox[\\(N\\), \\(t\\)]\\)\"", Bold, StripOnInput -> 
        False], TraditionalForm]}, AxesOrigin -> {0, 0.04605170185988092}, 
    AxesStyle -> Thickness[Large], BaseStyle -> {FontFamily -> "Arial"}, 
    DisplayFunction -> Identity, Frame -> {{False, False}, {False, False}}, 
    FrameLabel -> {{None, None}, {None, None}}, FrameTicks -> {{
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
    GridLines -> {None, None}, GridLinesStyle -> Directive[
      GrayLevel[0.5, 0.4]], ImagePadding -> All, LabelStyle -> 
    Directive[Background -> None], 
    Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Exp[#]& )[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Exp[#]& )[
           Part[#, 2]]}& )}}, PlotRange -> NCache[{{0, 200}, {0, 
        Log[10000]}}, {{0, 200}, {0, 9.210340371976184}}], PlotRangeClipping -> 
    True, PlotRangePadding -> {{0, 0}, {0, 0}}, Ticks -> 
    FrontEndValueCache[{Automatic, 
       Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{0.693147180559945, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {1.0986122886681091`, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {1.38629436111989, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {1.6094379124340996`, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {1.791759469228054, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {1.945910149055313, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {2.079441541679835, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {2.1972245773362187`, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {2.302585092994046, 
         FormBox["10", TraditionalForm], {0.01, 0.}, {
          Thickness[0.001]}}, {2.995732273553991, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {3.4011973816621546`, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {3.688879454113936, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {3.9120230054281455`, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {4.0943445622220995`, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {4.2484952420493585`, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {4.38202663467388, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {4.499809670330264, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {4.605170185988092, 
         FormBox["100", TraditionalForm], {0.01, 0.}, {
          Thickness[0.001]}}, {5.298317366548037, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {6.3969296552161445`, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {6.551080335043405, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {6.684611727667925, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {6.802394763324309, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {6.907755278982137, 
         FormBox["1000", TraditionalForm], {0.01, 0.}, {
          Thickness[0.001]}}, {7.600902459542082, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {8.006367567650246, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {8.294049640102028, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {8.517193191416236, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {8.699514748210191, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {8.85366542803745, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {8.987196820661971, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {9.104979856318355, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
          Thickness[0.001]}}, {9.210340371976184, 
         FormBox["10000", TraditionalForm], {0.01, 0.}, {
          Thickness[0.001]}}}}]],FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{"\"All replicates\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], FontFamily -> "Arial", 
                    RGBColor[1, 0.5, 0], 
                    Opacity[0.2]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], FontFamily -> "Arial", 
                    RGBColor[1, 0.5, 0], 
                    Opacity[0.2]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             Directive[Background -> None], FontFamily -> "Arial"}, 
            Background -> Automatic, StripOnInput -> False]& ), Editable -> 
          True, InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Opacity", "[", "0.2`", "]"}]}], "]"}]}], "}"}], 
               ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}], ",", 
               
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   
                   RowBox[{
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True", ",", 
                    "True", ",", "True", ",", "True", ",", "True"}], "}"}]}], 
               ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"Directive", "[", 
                   RowBox[{"Background", "\[Rule]", "None"}], "]"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )],
          TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Mean of the replicates\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.16500000000000004`], 
                    AbsoluteThickness[1.6], FontFamily -> "Arial", 
                    RGBColor[0, 0, 1], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.16500000000000004`], 
                    AbsoluteThickness[1.6], FontFamily -> "Arial", 
                    RGBColor[0, 0, 1], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, 
                GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), Editable -> True, 
          InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.009166666666666668`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], "}"}], 
               ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}], ",", 
               
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", "True", "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )],
          TraditionalForm]}}, AutoDelete -> False, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.702030141207961*^9, 3.702030175836627*^9, 3.7020302378821487`*^9, 
   3.702030404975274*^9, 3.7020306630798283`*^9, 3.702030767795496*^9, {
   3.702030806322263*^9, 3.702030849085206*^9}, {3.702030920292411*^9, 
   3.7020309411688843`*^9}, 3.702031248885127*^9, 3.702031315432971*^9},
 ExpressionUUID -> "88ad5769-d667-4912-8c1f-8034fe179194"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {{}, {}, {
       RGBColor[0, 0, 1], 
       PointSize[0.009166666666666668], 
       Thickness[Large], 
       StyleBox[
        LineBox[CompressedData["
1:eJxt1A1olVUcBvDDkBAJGSJlInG1ZZZ9mZmZrT067+ac2+7Hdne9++jdh2US
WmZlZfaGRIVIRYWCiHeZVhAlFUtE5JQmKZZmMzNbvrZCosJKwr7pPWf/f3Af
ujDGb8/77Nx7zv+eid3LM4vLjDEH4h/3+/9fP1XRH1DKkeRy8ljyOPIEcoI8
iVxBnkyeQr6KfDX5WvL15GnkG8jTyTeSZ5BvIs8k30yeRb6FPJt8K7mSfBu5
ioxSh2Qzh3KymYu/Xvv5aEN3anhuQnUgc1SNR8a+UXv64ZWSV+Oh7yZPG/n6
asnn4Y81S3evfP4pyedJ/1nJk9J/QfIkfkjvvPSJ7/skr4FrjxuxXfIa5Ge9
8+EDe96UvBbT/ettyWsx6vjWeypHvSv5fPjHt+ySfD5e3V8/8+k5VvI6PHnR
iY/PZ/dKXoe9v05pf+b9DyRfgLnBt0cmnTwg+QL5fIckr0f8cNw4LHk9tm/a
l9ix4ojkC+Efn3BU8oUYrLjg8RerP5W8AY9WzejcVTcgeQPeO9iX7D93TPJG
+OV//0zyRqTWb1g2Zu3nkjehpv/c3wOrTkjeBP/4mi8kT8GtXug9OWykcGyV
e0dfyvMpTNyxYslzP4ptCpeMyI2+5q1B6adR7jf8K+mn4R9ffUr6aZRNdTso
tmlc6Tckkn4Gh89nh7ZtEiODjw65lzjM4P74dHOjT0s/g/vcv68Smyx+iael
PC9GFvdWuhMWh1ksH7PWHuzTfhYbl7k/aL8ZF7vjHdJ+s+yv9puxZ8v46wYr
vpZ+M8786QZUbFpkP8VoQe/sU03rN4jDFsSbtfnsK9pvgZve9E7t5xAPW3yE
2s/JfA5JPwc/nuPFNod4GC4smyo2rTLfYrTKvGm/Vc5D+60o+Deo/Tz8cW7W
fh5+O7ZpPw+3e8l+7efhP85+7S8qNcjhIjl/7ZNNAf7jHtd+AfHwr7v7jPbJ
tgD/ds9qvw3Dv7+RfpvMrzhsw2P+ghBbsmmXedQ+OWzHPwPuH2qfbDrkvtB+
BzL+gLXfgSv8F0z7HXK/ab8Tn7jxWar9TrnvtE+2nfL91v7tuNxdF+u0Tw7J
lmyCUifICOR+FgfkkFwk2wAvu+PdKo4CuR91/a5SJ7rQ2O1uFF2fHHThMrdd
u3V9cpFsyRHZdJc6QQY5IIfkItmSI7LpofV78Ju7Dvfp+j1yH+r65LAHLyXd
Ba/rky05IpveUid68aC/8HR9ckAOyUWyJUdks7jUCTLIATkkF8mWHJHNHbQ+
GeSAHJKLZEuOyOZOWp8MckAOyUWyJUdks4TWJ4MckENykWzJEdnc9Z//BWsC
aVQ=
         "]], FontFamily -> "Arial"]}}, {}, {}, {{}, {}}, {{}, {}}}, 
    AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
    Axes -> {True, True}, AxesLabel -> {
      FormBox[
       StyleBox["\"t\"", Bold, StripOnInput -> False], TraditionalForm], 
      FormBox[
       StyleBox[
       "\"\\!\\(\\*SubscriptBox[\\(P\\), \\(ext\\)]\\)(t)\"", Bold, 
        StripOnInput -> False], TraditionalForm]}, AxesOrigin -> {0, 0}, 
    AxesStyle -> Thickness[Large], BaseStyle -> {FontFamily -> "Arial"}, 
    DisplayFunction -> Identity, Frame -> {{False, False}, {False, False}}, 
    FrameLabel -> {{None, None}, {None, None}}, 
    FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
    GridLines -> {None, None}, GridLinesStyle -> Directive[
      GrayLevel[0.5, 0.4]], ImagePadding -> All, LabelStyle -> 
    Directive[Background -> None], 
    Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& )}}, PlotRange -> {{0, 200}, {0, 1}}, 
    PlotRangeClipping -> True, PlotRangePadding -> {{0, 0}, {0, 0}}, 
    Ticks -> {Automatic, Automatic}],FormBox[
    FormBox[
     TemplateBox[{"\"Over all replicates\""}, "PointLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.16500000000000004`], 
                    AbsoluteThickness[1.6], FontFamily -> "Arial", 
                    RGBColor[0, 0, 1], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.16500000000000004`], 
                    AbsoluteThickness[1.6], FontFamily -> "Arial", 
                    RGBColor[0, 0, 1], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          Directive[Background -> None], FontFamily -> "Arial"}, Background -> 
         Automatic, StripOnInput -> False], TraditionalForm]& ), Editable -> 
      True, InterpretationFunction :> (RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"Directive", "[", 
               RowBox[{
                 RowBox[{"PointSize", "[", "0.009166666666666668`", "]"}], 
                 ",", 
                 RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                 RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[0, 0, 1]"], Appearance -> 
                   None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                   DefaultBaseStyle -> {}, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[0, 0, 1], Editable -> False, Selectable -> False], 
                 ",", 
                 RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], "}"}], 
           ",", 
           RowBox[{"{", #, "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"{", 
                 RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", "True", "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"Directive", "[", 
               RowBox[{"Background", "\[Rule]", "None"}], "]"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.702030141207961*^9, 3.702030175836627*^9, 3.7020302378821487`*^9, 
   3.702030404975274*^9, 3.7020306630798283`*^9, 3.702030767795496*^9, {
   3.702030806322263*^9, 3.702030849085206*^9}, {3.702030920292411*^9, 
   3.7020309411688843`*^9}, 3.702031248885127*^9, 3.702031316059268*^9},
 ExpressionUUID -> "e7f17cbb-f94b-42e3-b344-d2df2cd1f5e0"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1822, 985},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 154, 3, 99, "Title"],
Cell[CellGroupData[{
Cell[759, 29, 149, 3, 88, "Section"],
Cell[911, 34, 314, 6, 25, "Item"],
Cell[1228, 42, 3435, 80, 141, "Input"],
Cell[4666, 124, 280, 8, 25, "Item"],
Cell[4949, 134, 844, 16, 87, "Text"],
Cell[5796, 152, 1236, 31, 135, "Input"],
Cell[7035, 185, 436, 9, 25, "Item"],
Cell[7474, 196, 1757, 28, 239, "Text"],
Cell[9234, 226, 14482, 331, 671, "Input"],
Cell[23719, 559, 435, 6, 25, "Item"],
Cell[24157, 567, 1864, 29, 258, "Text"],
Cell[26024, 598, 5767, 132, 521, "Input"],
Cell[31794, 732, 500, 9, 25, "Item"],
Cell[32297, 743, 237, 5, 30, "Text"],
Cell[32537, 750, 3732, 98, 301, "Input"],
Cell[36272, 850, 435, 6, 25, "Item"],
Cell[36710, 858, 440, 10, 68, "Text"],
Cell[37153, 870, 8685, 169, 561, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45875, 1044, 181, 2, 88, "Section"],
Cell[CellGroupData[{
Cell[46081, 1050, 265, 8, 37, "Subsection"],
Cell[46349, 1060, 237, 3, 25, "Item"],
Cell[CellGroupData[{
Cell[46611, 1067, 2379, 62, 188, "Input"],
Cell[48993, 1131, 7590, 215, 171, "Output"]
}, Open  ]],
Cell[56598, 1349, 215, 3, 25, "Item"],
Cell[56816, 1354, 1140, 25, 40, "Input"],
Cell[57959, 1381, 260, 4, 25, "Item"],
Cell[58222, 1387, 5914, 202, 321, "Input"],
Cell[64139, 1591, 202, 3, 25, "Item"],
Cell[CellGroupData[{
Cell[64366, 1598, 5794, 136, 801, "Input"],
Cell[70163, 1736, 205191, 3758, 253, "Output"],
Cell[275357, 5496, 260580, 4689, 262, "Output"],
Cell[535940, 10187, 7089, 144, 267, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[543078, 10337, 258, 5, 37, "Subsection"],
Cell[543339, 10344, 201, 4, 25, "Item"],
Cell[543543, 10350, 2545, 62, 161, "Input"],
Cell[546091, 10414, 314, 6, 25, "Item"],
Cell[546408, 10422, 1331, 30, 40, "Input"],
Cell[547742, 10454, 215, 3, 25, "Item"],
Cell[547960, 10459, 1116, 25, 40, "Input"],
Cell[549079, 10486, 260, 4, 25, "Item"],
Cell[549342, 10492, 5914, 202, 321, "Input"],
Cell[555259, 10696, 175, 3, 25, "Item"],
Cell[CellGroupData[{
Cell[555459, 10703, 5794, 136, 801, "Input"],
Cell[561256, 10841, 4218752, 77941, 251, "Output"],
Cell[4780011, 88784, 3575010, 67447, 263, "Output"],
Cell[8355024, 156233, 9388, 190, 266, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

